(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     20434,        569]
NotebookOptionsPosition[     16481,        465]
NotebookOutlinePosition[     18721,        515]
CellTagsIndexPosition[     18678,        512]
WindowTitle->Wildfires Simulation Package - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["WILDFIRES DOC GUIDE", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Functions",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Functions", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"ConvertPositionFromCartesianToSigma\"\>":>
       Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/ConvertPositionFromCartesianToSigma"], \
"\<\"ConvertPositionFromSigmaToCartesian\"\>":>Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/ConvertPositionFromSigmaToCartesian"], \
"\<\"ConvertVelocityFromCartesianToSigma\"\>":>Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/ConvertVelocityFromCartesianToSigma"], \
"\<\"ConvertVelocityFromSigmaToCartesian\"\>":>Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/ConvertVelocityFromSigmaToCartesian"], \
"\<\"DivergenceFreeInterpolation2D\"\>":>Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/DivergenceFreeInterpolation2D"], \
"\<\"DivergenceFreeInterpolation3D\"\>":>Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/DivergenceFreeInterpolation3D"], \
"\<\"Extract2DIsoSurfacePoints\"\>":>Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/Extract2DIsoSurfacePoints"], \
"\<\"RadialBasicFunction\"\>":>Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/RadialBasicFunction"], \
"\<\"RBFInterpolation\"\>":>Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/RBFInterpolation"], "\<\"TrackLevelSet\"\>":>
       Documentation`HelpLookup["paclet:WildfiresDoc/ref/TrackLevelSet"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"GuideFunction"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Tutorials",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Tutorials", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"FireFrontTrackingInComplexTerrain\"\>":>
       Documentation`HelpLookup[
       "paclet:WildfiresDoc/tutorial/FireFrontTrackingInComplexTerrain"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"GuideTutorial"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->
         False], {"\<\"WildfiresDoc/guide/Wildfires Simulation\"\>":>
       None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["WildfiresDoc/guide/Wildfires Simulation"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/WildfiresDoc/guide/\
Wildfires Simulation.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "WildfiresDoc/guide/Wildfires Simulation", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["Wildfires Simulation Package", "GuideTitle",
 CellID->942062912],

Cell["\<\
This package provides tools for performing level-set simulations on complex \
terrain given a prescribed wind-field. Functions are also provided for \
generating two and three dimensional wind-fields using divergence-free \
interpolation. A custom interpolation scheme using radial basis functions is \
also provided for generating terrain surfaces from discrete data. The package \
also contains a function that performs time integration and evolution of an \
implicit level-set function by solving a nonlinear transport problem. A \
number of utility functions are also available to assist in prerforming \
various plotting or extracting data. \
\>", "GuideAbstract",
 CellID->2001916300]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "Learning Resources"
}], "GuideLearningResourcesSection",
 WholeCellGroupOpener->True],

Cell[BoxData[GridBox[{
   {Cell[BoxData[GridBox[{
       {Cell[BoxData[GridBox[{
           {
            GraphicsBox[RasterBox[CompressedData["
1:eJztlOly2lYYhj3T2+ifTu+ol5AbyF0krZ04TZvEMavNIhBCbGI1FgIJxI4k
zA7GruPaQGP/yQ30BQmCj3G2Tmf6o9+80mg05zzfes4Pjx7/9Oi7ra2tH/F8
j2f+/eF/+9csmxWXyq1L2ChBV3al+8CbmxuH083F4kvFuGgsYig6FxcNG+Lm
inChNb1+85YANhqKxWrfebb75Om2nw1kRWkhMZsTBUPz2DKGshlhLt6QAO2b
LARz763J5aKePX/x9JcdmmFFKZ+bS8oZcIP/CRcms5VgMgyrKKqb8qaPeakg
S4WClC+IhvIPuVjnm8w2gklRXkVVDw6dwVAE2/NycSF5wf8iFxaLnWDCC+Wh
n+++fPLzts/PyqWSXCwV5ioWDP4DLiTdhWSxHhBMs8Vutth+ffn7qzd7aT5T
LFcWKsslXUsXH/nFfOGOC6vtkGAGAuHrySQciVaqtbKuSrWky+Dfd3EnBbvd
QTCdLg9G3eX2RmMJbK/W6hVdn3BRuuMCvSCYfjbI+IPIfHtnN5E8qjeUWr1R
1bXkI02DX60uXVSWLsqHDhfBpGnG6aL2zTa3h8YatXmiNpuKpuG7rqi1hgLC
vtnKC7mPKdRq6y4cTmodOJ1OY/EkPtK80O72oFane9LuNFvtVJp3UV4xL2MB
RtfHsEJOclGeMBcjsnC5PUScHi+DLW6KDoU5AHv9AZ5Or18sV495nBKRDYYv
Li74TBYFR2ui8aSiag1V1bNAoXBeyL4HQxwXx5H/7RVmSRiMTgfDUX84kkuV
ozR/fX19dXX158IuLy+1ZhMu8nIpXyhqJy0UStGaiIpgctE4zwu0j8UpQ5ij
8RnNBIJhTi6We/3+bDabLmwymYCPgFvtdjKV9tJMu9NtdTooFMMECGYydXR7
e5sT86Dp6g2GCEbVmu+X9tfCZgs7P/+DYYMA9gaDbn+AKrGB8P3cURBd1VpD
x6JZlJd5v8la7U40nhiejoeo0ugUVUIjCCZQCFVn6tEiTtzG4/HZRiYsI+RQ
bSOv03GEi9/PXVU1VLWhavqySrWePDqOJVKiVCBocJRMHePCz+akVa2w9z5z
Op2t13OVfrFUAefdu0u80SD9e532EBP1hGx2B64sjPpqZV3RMIqYyUAoAiDy
RUHwRgqfZdI+P34CaLLYVj2CEA8OEWoLeCgS1VHaSfuzcWKKkPvZ2TnGG9uJ
xev89mJ0N4pgopL4gx7FE6lVj75WG3NHqMj99Z4JJ+6fM5E1mJD9wOn1+dd7
9M1M1BM3A96oZ2N+23yLcAl92GQImFCn08UN+YXayPwv298MF5pM
              "], {{0, 
              0}, {28, 35}}, {0, 255},
              ColorFunction->RGBColor],
             Background->GrayLevel[0.952941],
             ImageSize->{28, 35},
             PlotRange->{{0, 28}, {0, 35}}], GridBox[{
              {""},
              {Cell["Tutorials", "GuideTutorialsSection",
                WholeCellGroupOpener->True]},
              {Cell[BoxData[
                TemplateBox[{
                 Cell["FireFrontTrackingInComplexTerrain"],
                  "paclet:WildfiresDoc/tutorial/\
FireFrontTrackingInComplexTerrain"},
                 "RefLink",
                 BaseStyle->{"GuideTutorial"}]], "GuideTutorial"]}
             },
             GridBoxDividers->{"Rows" -> {{False}}}]}
          },
          GridBoxAlignment->{"Rows" -> {{Top}}},
          GridBoxSpacings->{"Columns" -> {{0.3}}}]], "GuideWebResource"]},
       {""}
      },
      GridBoxSpacings->{"Rows" -> {{2}}}]], "GuideWebResource"]}
  },
  GridBoxAlignment->{
   "Columns" -> {{Left, Center}}, 
    "Rows" -> {{Top}}}]], "GuideLearningResourcesGrid"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "Reference"
}], "GuideReferenceSection",
 WholeCellGroupOpener->True],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell[
     TextData["RadialBasicFunction"]],
    "paclet:WildfiresDoc/ref/RadialBasicFunction"},
   "RefLink",
   BaseStyle->"InlineFunctionSans"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " provides a listing of various radial basic functions available with the \
package and checks validity of custom user-specified radial basic functions."
}], "GuideText",
 CellID->551978490],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell[
     TextData["RBFInterpolation"]],"paclet:WildfiresDoc/ref/RBFInterpolation"},
   "RefLink",
   BaseStyle->"InlineFunctionSans"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " performs scattered data interpolation in any dimension."
}], "GuideText",
 CellID->203374175],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell[
     TextData["DivergenceFreeInterpolation2D"]],
    "paclet:WildfiresDoc/ref/DivergenceFreeInterpolation2D"},
   "RefLink",
   BaseStyle->"InlineFunctionSans"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " performs divergence-free interpolation in two dimensions using scattered \
2D velocity data."
}], "GuideText",
 CellID->1463276848],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell[
     TextData["DivergenceFreeInterpolation3D"]],
    "paclet:WildfiresDoc/ref/DivergenceFreeInterpolation3D"},
   "RefLink",
   BaseStyle->"InlineFunctionSans"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " performs divergence-free interpolation in three dimensions using scattered \
3D velocity data."
}], "GuideText",
 CellID->1562236687],

Cell["\t", "GuideDelimiter",
 CellID->311258892],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell[
     TextData["ConvertPositionFromCartesianToSigma"]],
    "paclet:WildfiresDoc/ref/ConvertPositionFromCartesianToSigma"},
   "RefLink",
   BaseStyle->"InlineFunctionSans"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " Converts a set of 3D cartesian points to it's corresponding points in the \
sigma coordinate system."
}], "GuideText",
 CellID->842004173],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell[
     TextData["ConvertPositionFromSigmaToCartesian"]],
    "paclet:WildfiresDoc/ref/ConvertPositionFromSigmaToCartesian"},
   "RefLink",
   BaseStyle->"InlineFunctionSans"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " Converts a set of 3D sigma points to it's corresponding points in the \
cartesian coordinate system."
}], "GuideText",
 CellID->1837454911],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell[
     TextData["ConvertVelocityFromCartesianToSigma"]],
    "paclet:WildfiresDoc/ref/ConvertVelocityFromCartesianToSigma"},
   "RefLink",
   BaseStyle->"InlineFunctionSans"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 "  Converts a set of 3D velocity components in the cartesian coordinate \
system to it's corresponding velocity components in the sigma coordinate \
system."
}], "GuideText",
 CellID->1655953684],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell[
     TextData["ConvertVelocityFromSigmaToCartesian"]],
    "paclet:WildfiresDoc/ref/ConvertVelocityFromSigmaToCartesian"},
   "RefLink",
   BaseStyle->"InlineFunctionSans"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " Converts a set of 3D velocity components in the sigma coordinate system to \
it's corresponding velocity components in the cartesian coordinate system."
}], "GuideText",
 CellID->665608066],

Cell["\t", "GuideDelimiter",
 CellID->1848742168],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell[
     TextData["TrackLevelSet"]],"paclet:WildfiresDoc/ref/TrackLevelSet"},
   "RefLink",
   BaseStyle->"InlineFunctionSans"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " performs numerical integration of nonlinear transport equation describing \
the evolution of the fire-front in the Eulerian framework. "
}], "GuideText",
 CellID->1144059961],

Cell["\t", "GuideDelimiter",
 CellID->1620768787],

Cell["Utility functions:", "GuideText",
 CellID->1578424561],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell[
     TextData["Extract2DIsoSurfacePoints"]],
    "paclet:WildfiresDoc/ref/Extract2DIsoSurfacePoints"},
   "RefLink",
   BaseStyle->"InlineFunctionSans"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " extracts the zero-level sets of a 3D implicit function at specified \
horizontal plane. Useful for extracting the fire-front from the implicit \
function."
}], "GuideText",
 CellID->1505956484],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell[
     TextData["Wildfires`Utility`TestCase"]],
    "paclet:WildfiresDoc/ref/Wildfires`Utility`TestCase"},
   "RefLink",
   BaseStyle->"InlineFunctionSans"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " provides access to the three different test cases locally available for \
testing the wildfires package. "
}], "GuideText",
 CellID->242814920],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell[
     TextData["Wildfires`Utility`PlotZeroLevelSetsInSigmaPlane"]],
    "paclet:WildfiresDoc/ref/Wildfires`Utility`PlotZeroLevelSetsInSigmaPlane"},
   "RefLink",
   BaseStyle->"InlineFunctionSans"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " plots the various contours from the TrackLevelSet simulation in the sigma \
plane at \[Sigma]=0. The contours are color-coded based on the time at which \
the contours were extracted."
}], "GuideText",
 CellID->504216638],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell[
     TextData["Wildfires`Utility`PlotZeroLevelSetsInCartesianDomain"]],
    "paclet:WildfiresDoc/ref/Wildfires`Utility`\
PlotZeroLevelSetsInCartesianDomain"},
   "RefLink",
   BaseStyle->"InlineFunctionSans"]], "InlineFunctionSans"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " plots the various contours from the TrackLevelSet simulation in the \
cartesian domain and projects the contours along the curved elevation map. "
}], "GuideText",
 CellID->398563804],

Cell[TextData[{
 Cell[BoxData[
 "Wildfires`Utility`DiscretizeElevationMap"], "InlineGuideFunction"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " samples a function describing the elevation map at uniformly spaced points \
with user specified resolution."
}], "GuideText",
 CellID->455452149],

Cell[TextData[{
 Cell[BoxData[
 "Wildfires`Utility`VelocityDataFromTerrainAndBCs"], "InlineGuideFunction"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " extracts the three-dimensonal velocity data from the various specified \
boundary conditions and terrain in three-dimensions. "
}], "GuideText",
 CellID->1701343439],

Cell[TextData[{
 Cell[BoxData[
 "Wildfires`Utility`VelocityDataInXYPlane"], "InlineGuideFunction"],
 " ",
 StyleBox["\[LongDash]", "GuideEmDash"],
 " extracts the two dimensional velocity data from the various specified \
boundary conditions and terrain on a specified horizontal plane. "
}], "GuideText",
 CellID->1384347955]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"Wildfires Simulation Package - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "GuideColor", "LinkTrails" -> 
  GridBox[{{
      RowBox[{
        StyleBox[
         ButtonBox[
         "Mathematica", ButtonData -> "paclet:guide/Mathematica", 
          BaseStyle -> {"Link", "DockedLinkTrail"}], FontSlant -> 
         "Italic"]}]}}, ColumnAlignments -> Left], "ExampleCounter" -> 1, 
  "ExamplePageLinks" -> None, "RootCaptions" -> "", 
  "Metadata" -> {
   "built" -> "{2014, 11, 8, 17, 51, 56.901014}", 
    "history" -> {"0.0", "", "", ""}, "context" -> "WildfiresDoc`", 
    "keywords" -> {}, "specialkeywords" -> {}, 
    "tutorialcollectionlinks" -> {}, "index" -> True, "label" -> 
    "Wildfires Doc Guide", "language" -> "en", "paclet" -> "WildfiresDoc", 
    "status" -> "None", "summary" -> 
    "This package provides tools for performing level-set simulations on \
complex terrain given a prescribed wind-field. Functions are also provided \
for generating two and three dimensional wind-fields using divergence-free \
interpolation. A custom interpolation scheme using radial basis functions is \
also provided for generating terrain surfaces from discrete data. The package \
also contains a function that performs time integration and evolution of an \
implicit level-set function by solving a nonlinear transport problem. A \
number of utility functions are also available to assist in prerforming \
various plotting or extracting data. ", "synonyms" -> {}, "title" -> 
    "Wildfires Simulation Package", "titlemodifier" -> "", "windowtitle" -> 
    "Wildfires Simulation Package", "type" -> "Guide", "uri" -> 
    "WildfiresDoc/guide/Wildfires Simulation"}, "SearchTextTranslated" -> 
  ""},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 29, \
2014)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[622, 21, 4719, 106, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[5366, 131, 70, 1, 70, "GuideTitle",
 CellID->942062912],
Cell[5439, 134, 700, 11, 70, "GuideAbstract",
 CellID->2001916300]
}, Open  ]],
Cell[CellGroupData[{
Cell[6176, 150, 274, 11, 70, "GuideLearningResourcesSection"],
Cell[6453, 163, 2554, 54, 70, "GuideLearningResourcesGrid"]
}, Closed]],
Cell[CellGroupData[{
Cell[9044, 222, 257, 11, 70, "GuideReferenceSection"],
Cell[9304, 235, 31, 0, 70, "SectionHeaderSpacer"],
Cell[9338, 237, 456, 12, 70, "GuideText",
 CellID->551978490],
Cell[9797, 251, 350, 10, 70, "GuideText",
 CellID->203374175],
Cell[10150, 263, 419, 12, 70, "GuideText",
 CellID->1463276848],
Cell[10572, 277, 421, 12, 70, "GuideText",
 CellID->1562236687],
Cell[10996, 291, 48, 1, 70, "GuideDelimiter",
 CellID->311258892],
Cell[11047, 294, 438, 12, 70, "GuideText",
 CellID->842004173],
Cell[11488, 308, 439, 12, 70, "GuideText",
 CellID->1837454911],
Cell[11930, 322, 493, 13, 70, "GuideText",
 CellID->1655953684],
Cell[12426, 337, 489, 12, 70, "GuideText",
 CellID->665608066],
Cell[12918, 351, 49, 1, 70, "GuideDelimiter",
 CellID->1848742168],
Cell[12970, 354, 425, 11, 70, "GuideText",
 CellID->1144059961],
Cell[13398, 367, 49, 1, 70, "GuideDelimiter",
 CellID->1620768787],
Cell[13450, 370, 60, 1, 70, "GuideText",
 CellID->1578424561],
Cell[13513, 373, 473, 13, 70, "GuideText",
 CellID->1505956484],
Cell[13989, 388, 425, 12, 70, "GuideText",
 CellID->242814920],
Cell[14417, 402, 545, 13, 70, "GuideText",
 CellID->504216638],
Cell[14965, 417, 519, 13, 70, "GuideText",
 CellID->398563804],
Cell[15487, 432, 297, 8, 70, "GuideText",
 CellID->455452149],
Cell[15787, 442, 323, 8, 70, "GuideText",
 CellID->1701343439],
Cell[16113, 452, 326, 8, 70, "GuideText",
 CellID->1384347955]
}, Open  ]],
Cell[16454, 463, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)
