(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     13393,        411]
NotebookOptionsPosition[     10030,        321]
NotebookOutlinePosition[     12456,        379]
CellTagsIndexPosition[     12413,        376]
WindowTitle->ConvertVelocityFromSigmaToCartesian - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["WILDFIRES DOC SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "See Also",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"See Also", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"ConvertVelocityFromCartesianToSigma\"\>":>
       Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/ConvertVelocityFromCartesianToSigma"], \
"\<\"ConvertPositionFromSigmaToCartesian\"\>":>Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/ConvertPositionFromSigmaToCartesian"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"SeeAlso"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Wildfires Simulation Package\"\>":>
       Documentation`HelpLookup[
       "paclet:WildfiresDoc/guide/Fire-front Tracking"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"MoreAbout"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->
         False], {"\<\"WildfiresDoc/ref/ConvertVelocityFromSigmaToCartesian\"\
\>":>None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["WildfiresDoc/ref/ConvertVelocityFromSigmaToCartesian"]}, 
            Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/WildfiresDoc/ref/\
ConvertVelocityFromSigmaToCartesian.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "WildfiresDoc/ref/ConvertVelocityFromSigmaToCartesian", 
             ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell["ConvertVelocityFromSigmaToCartesian", "ObjectName",
 CellID->1224892054],

Cell[CellGroupData[{

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"ConvertVelocityFromSigmaToCartesian", "[", 
       RowBox[{
       "sigmaCoords", ",", " ", "sigmaVelocity", ",", " ", "zmax", ",", " ", 
        "elevmap"}], "]"}]], "InlineFormula"],
     " \[LineSeparator]takes the Sigma coordinates ",
     Cell[BoxData["coords"], "InlineFormula"],
     " in the form {{x1,y1,\[Sigma]1},{x2,y2,\[Sigma]2}...}, the \
corresponding 3D velocity components, ",
     Cell[BoxData["sigmaVelocity"], "InlineFormula"],
     ", at the coordinates in the form ",
     Cell[BoxData[
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SuperscriptBox["u1", "*"], ",", 
          SuperscriptBox["v1", "*"], ",", 
          SuperscriptBox["w1", "*"]}], "}"}], ","}]}]], "InlineFormula"],
     Cell[BoxData[
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["u2", "*"], ",", 
        SuperscriptBox["v2", "*"], ",", 
        SuperscriptBox["w2", "*"]}], "}"}]], "InlineFormula"],
     "...}, the maximum elevation ",
     Cell[BoxData["zmax"], "InlineFormula"],
     ", and a numerical function ",
     Cell[BoxData["elevmap"], "InlineFormula"],
     " defining the terrain in the Cartesian system. The output is the \
transformed velocity in the Sigma system."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}}},
 CellID->982511436],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[Cell[TextData[{
   Cell[BoxData[
    InterpretationBox[
     StyleBox[
      GraphicsBox[{},
       BaselinePosition->Baseline,
       ImageSize->{6, 0}],
      CacheGraphics->False],
     Spacer[6]]]],
   "Details"
  }], "NotesFrameText"],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 WholeCellGroupOpener->True,
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->1828589273],

Cell["", "SectionHeaderSpacer"],

Cell["\<\
The transformation of the velocity from Cartesian to Sigma coordinate system \
is defined as:\
\>", "Notes",
 CellID->1067943069],

Cell[BoxData[
 FormBox[
  RowBox[{"\t\t", 
   RowBox[{
    RowBox[{"u", "=", 
     FractionBox[
      SuperscriptBox["u", "*"], 
      RowBox[{" ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"h", "(", 
          RowBox[{"x", ",", "y"}], ")"}], "-", 
         SubscriptBox["z", "max"]}], ")"}]}]]}], ",", " ", 
    RowBox[{"v", "=", 
     FractionBox[
      SuperscriptBox["v", "*"], 
      RowBox[{" ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"h", "(", 
          RowBox[{"x", ",", "y"}], ")"}], "-", 
         SubscriptBox["z", "max"]}], ")"}]}]]}], ",", " ", 
    RowBox[{"w", "=", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", 
        SubscriptBox["z", "max"]]}], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["w", "*"], "+", 
        RowBox[{"(", 
         RowBox[{"u", " ", 
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", 
            SubscriptBox["z", "max"]}], ")"}], 
          FractionBox[
           RowBox[{"\[PartialD]", "h"}], 
           RowBox[{"\[PartialD]", "x"}]]}], ")"}], "-", 
        RowBox[{"(", 
         RowBox[{"v", " ", 
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", 
            SubscriptBox["z", "max"]}], ")"}], 
          FractionBox[
           RowBox[{"\[PartialD]", "h"}], 
           RowBox[{"\[PartialD]", "y"}]]}], ")"}]}], ")"}]}]}], ","}]}], 
  TraditionalForm]],
 CellID->1381825968],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"h", " ", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], TraditionalForm]], "InlineMath"],
 " is the elevation map. The transformation is derived by transforming the \
continuity equation into the sigma-system."
}], "ExampleText",
 CellID->1986646463],

Cell["", "SectionFooterSpacer"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "See Also"
}], "SeeAlsoSection",
 WholeCellGroupOpener->True,
 CellID->1255426704],

Cell[TextData[{
 StyleBox[ButtonBox["ConvertVelocityFromCartesianToSigma",
  BaseStyle->"Link",
  ButtonData->"paclet:WildfiresDoc/ref/ConvertVelocityFromCartesianToSigma"],
  FontFamily->"Verdana"],
 " . ",
 StyleBox[ButtonBox["ConvertPositionFromSigmaToCartesian",
  BaseStyle->"Link",
  ButtonData->"paclet:WildfiresDoc/ref/ConvertPositionFromSigmaToCartesian"],
  FontFamily->"Verdana"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "Related Guides"
}], "MoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->38303248],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Wildfires Simulation Package"]],
   "paclet:WildfiresDoc/guide/Fire-front Tracking"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->461439094]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"ConvertVelocityFromSigmaToCartesian - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "SymbolColor", "LinkTrails" -> 
  GridBox[{{
      RowBox[{
        ButtonBox[
        "Mathematica", ButtonData -> "paclet:WildfiresDoc/guide/WildfiresDoc",
          BaseStyle -> {"Link", "DockedLinkTrail"}]}]}}, ColumnAlignments -> 
    Left], "HasOptions" -> False, "ExampleCounter" -> 1, 
  "ExamplePageLinks" -> {}, "RootCaptions" -> "", 
  "Metadata" -> {
   "built" -> "{2014, 11, 8, 17, 52, 6.053459}", 
    "history" -> {"0.0", "", "", ""}, "context" -> "WildfiresDoc`", 
    "keywords" -> {}, "specialkeywords" -> {}, 
    "tutorialcollectionlinks" -> {}, "index" -> True, "label" -> 
    "Wildfires Doc Symbol", "language" -> "en", "paclet" -> "WildfiresDoc", 
    "status" -> "None", "summary" -> 
    "ConvertVelocityFromSigmaToCartesian[sigmaCoords, sigmaVelocity, zmax, \\ \
elevmap] takes the Sigma coordinates coords in the form \
{{x1,y1,\[Sigma]1},{x2,y2,\[Sigma]2}...}, the corresponding 3D velocity \
components, sigmaVelocity, at the coordinates in the form {{u1^*, v1^*, \
w1^*},{u2^*, v2^*, w2^*}...}, the maximum elevation zmax, and a numerical \
function elevmap defining the terrain in the Cartesian system. The output is \
the transformed velocity in the Sigma system.", "synonyms" -> {}, "title" -> 
    "ConvertVelocityFromSigmaToCartesian", "titlemodifier" -> "", 
    "windowtitle" -> "ConvertVelocityFromSigmaToCartesian", "type" -> 
    "Symbol", "uri" -> 
    "WildfiresDoc/ref/ConvertVelocityFromSigmaToCartesian"}, 
  "SearchTextTranslated" -> ""},
CellContext->"Global`",
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 29, \
2014)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> 
  "10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 29, 2014)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[629, 21, 3747, 92, 70, "AnchorBarGrid",
 CellID->1],
Cell[4379, 115, 78, 1, 70, "ObjectName",
 CellID->1224892054],
Cell[CellGroupData[{
Cell[4482, 120, 1489, 39, 70, "Usage",
 CellID->982511436],
Cell[CellGroupData[{
Cell[5996, 163, 739, 24, 70, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->1828589273],
Cell[6738, 189, 31, 0, 70, "SectionHeaderSpacer"],
Cell[6772, 191, 139, 4, 70, "Notes",
 CellID->1067943069],
Cell[6914, 197, 1407, 47, 70, InheritFromParent,
 CellID->1381825968],
Cell[8324, 246, 326, 10, 70, "ExampleText",
 CellID->1986646463],
Cell[8653, 258, 31, 0, 70, "SectionFooterSpacer"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8733, 264, 270, 12, 70, "SeeAlsoSection",
 CellID->1255426704],
Cell[9006, 278, 425, 11, 70, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[9468, 294, 276, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[9747, 308, 31, 0, 70, "SectionHeaderSpacer"],
Cell[9781, 310, 207, 6, 70, "MoreAbout",
 CellID->461439094]
}, Open  ]],
Cell[10003, 319, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)
