(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    501023,       9134]
NotebookOptionsPosition[    492236,       8869]
NotebookOutlinePosition[    495898,       8957]
CellTagsIndexPosition[    495774,       8951]
WindowTitle->DivergenceFreeInterpolation2D - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["WILDFIRES DOC SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "See Also",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"See Also", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"RadialBasicFunction\"\>":>
       Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/RadialBasicFunction"], \
"\<\"RBFInterpolation\"\>":>Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/RBFInterpolation"], \
"\<\"DivergenceFreeInterpolation3D\"\>":>Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/DivergenceFreeInterpolation3D"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"SeeAlso"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Wildfires Simulation Package\"\>":>
       Documentation`HelpLookup[
       "paclet:WildfiresDoc/guide/Fire-front Tracking"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"MoreAbout"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->
         False], {"\<\"WildfiresDoc/ref/DivergenceFreeInterpolation2D\"\>":>
       None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["WildfiresDoc/ref/DivergenceFreeInterpolation2D"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/WildfiresDoc/ref/\
DivergenceFreeInterpolation2D.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "WildfiresDoc/ref/DivergenceFreeInterpolation2D", ".html"]], 
           None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell["DivergenceFreeInterpolation2D", "ObjectName",
 CellID->1224892054],

Cell[CellGroupData[{

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"DivergenceFreeInterpolation2D", "[", 
       RowBox[{"data", ",", "opts"}], "]"}]], "InlineFormula"],
     " \[LineSeparator]performs divergence-free interpolation for 2D \
scattered data and returns a black-box function. The data must be of the form \
{{{x1,y1},{u1,v1}}, {x2,y2},{u2,v2}, {x3,y3},{u3,v3},...}. The resulting \
interpolant exactly satisfies the divergence-free condition, ",
     StyleBox["\[PartialD]f/\[PartialD]x + \[PartialD]f/\[PartialD]y=0. \n",
      Deletable->True],
     Cell[BoxData[
      RowBox[{"DivergenceFreeInterpolation2D", "[", 
       RowBox[{"data", ",", "rbf", ",", "opts"}], "]"}]], "InlineFormula"],
     " \[LineSeparator]performs divergence-free interpolation for 2D \
scattered data using the specified radial basic function ",
     Cell[BoxData["rbf"], "InlineFormula"],
     ". The radial basic function can be a string specifying a name from the \
existing database or a function of the form ",
     Cell[BoxData[
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"e", ",", "r"}], "}"}], ",", " ", "..."}], "]"}]], 
      "InlineFormula"],
     "."
    }]]},
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"DivergenceFreeInterpolation2D", "[", 
       RowBox[{"data", ",", "rbf", ",", "scales", ",", "opts"}], "]"}]], 
      "InlineFormula"],
     " \[LineSeparator]performs divergence-free interpolation of 2D scattered \
data using the specified radial basic function and it's corresponding scales. \
The scaling parameter can be a scalar or a vector. If it is a vector, then it \
should have the same length as ",
     Cell[BoxData["data"], "InlineFormula"],
     "."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {None, {None}}, 
   "RowsIndexed" -> {}}},
 CellID->982511436],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[Cell[TextData[{
   Cell[BoxData[
    InterpretationBox[
     StyleBox[
      GraphicsBox[{},
       BaselinePosition->Baseline,
       ImageSize->{6, 0}],
      CacheGraphics->False],
     Spacer[6]]]],
   "Details"
  }], "NotesFrameText"],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 WholeCellGroupOpener->True,
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->843403541],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[{
 "The divergence-free interpolation relies on the property that a scalar \
function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalPhi]", "(", 
    RowBox[{"x", ",", "y"}], ")"}], TraditionalForm]], "InlineMath"],
 " can be converted to a vector function satisfying the divergence-free \
relation  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"\[PartialD]", 
       SubscriptBox["\[CapitalPhi]", "u"]}], 
      RowBox[{"\[PartialD]", "x"}]], "+", 
     FractionBox[
      RowBox[{"\[PartialD]", 
       SubscriptBox["\[CapitalPhi]", "v"]}], 
      RowBox[{"\[PartialD]", "y"}]]}], "=", "0"}], TraditionalForm]], 
  "InlineMath"],
 ", where the functions   ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[CapitalPhi]", "u"], "(", 
    RowBox[{"x", ",", "y"}], ")"}], TraditionalForm]], "InlineMath"],
 " and  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[CapitalPhi]", "v"], " ", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], TraditionalForm]], "InlineMath"],
 " are defined as:"
}], "ExampleText",
 CellID->1904423740],

Cell[TextData[{
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[CapitalPhi]", "u"], "(", 
      RowBox[{"x", ",", "y"}], ")"}], " ", "=", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["\[PartialD]", "2"], "\[CapitalPhi]"}], 
        RowBox[{"\[PartialD]", 
         SuperscriptBox["y", "2"]}]], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "\[CapitalPhi]"}], 
         RowBox[{
          RowBox[{"\[PartialD]", "x"}], 
          RowBox[{"\[PartialD]", "y"}]}]]}]}], ")"}]}], ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[CapitalPhi]", "v"], "(", 
      RowBox[{"x", ",", "y"}], ")"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "\[CapitalPhi]"}], 
          RowBox[{
           RowBox[{"\[PartialD]", "x"}], 
           RowBox[{"\[PartialD]", "y"}]}]]}], ",", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "\[CapitalPhi]"}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["x", "2"]}]]}], ")"}], " ", "."}]}]}], 
   TraditionalForm]], "InlineMath"]
}], "Input",
 CellID->669698642],

Cell["The interpolant is then defined as:", "ExampleText",
 CellID->142916237],

Cell[TextData[{
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"u", "(", 
      RowBox[{"x", ",", "y"}], ")"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "1"}], "N"], 
       RowBox[{
        SubscriptBox["\[Alpha]", "i"], 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], 
          SubscriptBox["\[Phi]", "i"]}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["y", "2"]}]]}]}], "-", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "1"}], "N"], 
       RowBox[{
        SubscriptBox["\[Beta]", "i"], 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], 
          SubscriptBox["\[Phi]", "i"]}], 
         RowBox[{
          RowBox[{"\[PartialD]", "x"}], 
          RowBox[{"\[PartialD]", "y"}]}]]}]}]}]}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"v", "(", 
      RowBox[{"x", ",", "y"}], ")"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "1"}], "N"], 
        RowBox[{
         SubscriptBox["\[Alpha]", "i"], 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], 
           SubscriptBox["\[Phi]", "i"]}], 
          RowBox[{
           RowBox[{"\[PartialD]", "x"}], 
           RowBox[{"\[PartialD]", "y"}]}]]}]}]}], "+", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "1"}], "N"], 
       RowBox[{
        SubscriptBox["\[Beta]", "i"], 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], 
          SubscriptBox["\[Phi]", "i"]}], 
         RowBox[{"\[PartialD]", 
          SuperscriptBox["x", "2"]}]]}]}]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Phi]", "i"], "(", 
      RowBox[{"x", ",", "y"}], ")"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"\[CapitalPhi]", "(", 
       RowBox[{"e", ",", 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "-", 
             SubscriptBox["cx", "i"]}], ")"}], "2"], " ", "+", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y", "-", 
             SubscriptBox["cy", "i"]}], ")"}], "2"]}]]}], ")"}], "."}]}]}], 
   TraditionalForm]], "InlineMath"]
}], "Input",
 CellID->1008861783],

Cell[TextData[{
 "The function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalPhi]", " ", 
    RowBox[{"(", 
     RowBox[{"e", ",", "r"}], ")"}]}], TraditionalForm]], "InlineMath"],
 "  is a ",
 StyleBox["radial basic function",
  FontSlant->"Italic"],
 ", and \[Phi] represents the various sfhits of the basic function. The pair ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["cx", "i"], ",", 
     SubscriptBox["cy", "i"]}], ")"}], TraditionalForm]], "InlineMath"],
 " are the centers/coordinates at which the data ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"u", "(", 
       RowBox[{
        SubscriptBox["x", "i"], ",", 
        SubscriptBox["y", "i"]}], ")"}], ",", " ", 
      RowBox[{"v", "(", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"i", ","}]], 
        SubscriptBox["y", "i"]}], ")"}]}], ")"}]}], TraditionalForm]], 
  "InlineMath"],
 " are given. are the coefficients \[Alpha],\[Beta] are computed be solving a \
system of linear equations. "
}], "ExampleText",
 CellID->1650356348],

Cell[TextData[{
 Cell[BoxData["DivergenceFreeInterpolation2D"], "InlineFormula"],
 " takes the following options:"
}], "ExampleText",
 CellID->694278449],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->1204276615],

Cell[BoxData[GridBox[{
   {Cell["      ", "TableRowIcon"], "\"\<Solver\>\"", 
    ButtonBox["Automatic",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/Automatic"], Cell[TextData[{
     Cell[BoxData[
      TemplateBox[{Cell[
         TextData["Specifies"]],"paclet:ref/Specifies"},
       "RefLink",
       BaseStyle->"InlineFormula"]], "InlineFormula"],
     " the type of solver to use. ",
     Cell[BoxData[
      TemplateBox[{Cell[
         TextData["Options"]],"paclet:ref/Options"},
       "RefLink",
       BaseStyle->"InlineFormula"]], "InlineFormula"],
     " include \"LinearSolve\", \"LeastSquares\". ",
     Cell[BoxData[
      TemplateBox[{Cell[
         TextData["If"]],"paclet:ref/If"},
       "RefLink",
       BaseStyle->"InlineFormula"]], "InlineFormula"],
     " Automatic, then the solver is chosen based on data and heurestics."
    }], "TableText"]},
   {Cell["      ", "TableRowIcon"], "\"\<Regularization\>\"", "0.", Cell[
    TextData[{
     Cell[BoxData[
      TemplateBox[{Cell[
         TextData["Specifies"]],"paclet:ref/Specifies"},
       "RefLink",
       BaseStyle->"InlineFormula"]], "InlineFormula"],
     " ",
     "a",
     " ",
     "positive",
     " ",
     "value",
     " ",
     "for",
     " ",
     "performing",
     " ",
     "smoothing",
     " ",
     "on",
     " ",
     "the",
     " ",
     "rbf",
     " ",
     "interpolant."
    }], "TableText"]}
  }]], "3ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {None, {None}}, 
   "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{True, True, True}}}},
 CellID->1068258589]
}, Open  ]],

Cell["", "SectionFooterSpacer"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(4)", "ExampleCount"]
}], "PrimaryExamplesSection",
 WholeCellGroupOpener->True,
 CellTags->"PrimaryExamplesSection",
 CellID->1691243387],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(4)", "ExampleCount"]
}], "ExampleSection", "ExampleSection",
 WholeCellGroupOpener->True,
 CellID->634053617],

Cell["\<\
Consider the Hill's spherical vortex. The velocity is sampled at 20 random \
points:\
\>", "ExampleText",
 CellID->1827560945],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", "2"}], ";", 
  RowBox[{"a", "=", "4"}], ";", 
  RowBox[{"A", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"3", "/", "2"}], ")"}]}], "*", 
    RowBox[{"U", "/", 
     RowBox[{"a", "^", "2"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"r", "=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"x", "^", "2"}], "+", 
     RowBox[{"y", "^", "2"}]}], " ", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"uu", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], "=", " ", 
    RowBox[{
     RowBox[{"-", "A"}], "*", 
     RowBox[{"(", 
      RowBox[{"x", "^", "2"}], ")"}], "*", "y"}]}], " ", ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"vv", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"-", "A"}], "*", "x", "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", "^", "2"}], " ", "-", " ", 
       RowBox[{"r", "^", "2"}], " ", "-", " ", 
       RowBox[{"x", "^", "2"}]}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SeedRandom", "[", "456", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"data", " ", "=", " ", 
    RowBox[{
     RowBox[{"RandomReal", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", "2"}], "}"}]}], "]"}], " ", "/.", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x_", "?", "NumericQ"}], ",", " ", 
        RowBox[{"y_", "?", "NumericQ"}]}], "}"}], "\[RuleDelayed]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"uu", "[", 
           RowBox[{"x", ",", "y"}], "]"}], ",", 
          RowBox[{"vv", "[", 
           RowBox[{"x", ",", "y"}], "]"}]}], "}"}]}], "}"}]}]}]}], " ", ";"}],
   " "}], "\[IndentingNewLine]", 
 RowBox[{"StreamPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"uu", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"vv", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", " ", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"data", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}]}]}], 
  "]"}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->828633328],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvelTVdn65/mL7n7R/0ZHdFT0i35R/YuK6KiuelPVHd1VXTkP9+Y8XDNJ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    "], {{0, 240}, {239, 
    0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{239, 240},
  PlotRange->{{0, 239}, {0, 240}}]], "Output",
 ImageSize->{243, 240},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[1]=",
 CellID->739495163]
}, Open  ]],

Cell["\<\
Perform a divergence-free interpolation using the second-order thin plate \
spline:\
\>", "ExampleText",
 CellID->347150731],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{"DivergenceFreeInterpolation2D", "[", 
   RowBox[{"data", ",", "\"\<TPS2\>\""}], "]"}]}]], "Input",
 CellLabel->"In[2]:=",
 CellID->2051871557],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"DivergenceFreeInterpolatingFunction", "[", "<>", "]"}],
  WildfiresDoc`Private`dfun$189316]], "Output",
 ImageSize->{290, 14},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->551384484]
}, Open  ]],

Cell["\<\
The interpolating function can now be used to query data at various points. \
For each point, the interpolating function will return a vector of values:\
\>", "ExampleText",
 CellID->727085783],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "1"}], "}"}], "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->1262823622],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.3097471065751094`", ",", "2.6166005668987955`"}], 
  "}"}]], "Output",
 ImageSize->{130, 13},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->646293822]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "3"}], "}"}]}], "}"}], "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->287979828],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.3097471065751094`", ",", "2.6166005668987955`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.2338086103597803`", ",", "1.9376046175910133`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.109905084054844`", ",", 
     RowBox[{"-", "7.451284490740068`"}]}], "}"}]}], "}"}]], "Output",
 ImageSize->{417, 13},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->405595608]
}, Open  ]],

Cell["\<\
Plot the resulting interpolating function. The interpolating function \
captures the major vortices quite well:\
\>", "ExampleText",
 CellID->732288078],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StreamPlot", "[", 
  RowBox[{
   RowBox[{"sol", "[", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->656973428],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvWd3VVe293lHd7/or9EfpZ+3Xb6ucqhbzqmMicJFTgJMsAEbTJAQCCEh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    "], {{0, 240}, {239, 
    0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{239, 240},
  PlotRange->{{0, 239}, {0, 240}}]], "Output",
 ImageSize->{243, 240},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[5]=",
 CellID->1207339352]
}, Open  ]],

Cell["\<\
We can validate that the resulting interpolating function is indeed \
divergence-free:\
\>", "ExampleText",
 CellID->1583802398],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dx", " ", "=", " ", 
   RowBox[{
    RowBox[{"Derivative", "[", 
     RowBox[{"1", ",", "0"}], "]"}], "[", "sol", "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dy", " ", "=", " ", 
   RowBox[{
    RowBox[{"Derivative", "[", 
     RowBox[{"0", ",", "1"}], "]"}], "[", "sol", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"First", "[", 
     RowBox[{"dx", "[", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], "]"}], "]"}], " ", "+", " ", 
    RowBox[{"Last", "[", 
     RowBox[{"dy", "[", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}]}], "Input",
 CellLabel->"In[6]:=",
 CellID->2033757402],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnc+PHMUVx1GSQ+6s4Zy/of+C5E9I/gKQstdISRTLllgjfOJiY4MSwhow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    "], {{0, 195}, {240, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{240, 195},
  PlotRange->{{0, 240}, {0, 195}}]], "Output",
 ImageSize->{244, 195},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[6]=",
 CellID->179508561]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->64987870],

Cell["\<\
Use only boundary conditions to get an estimate of the flow-field:\
\>", "ExampleText",
 CellID->262649421],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"inlet", "[", "y_", "]"}], ":=", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"y", "^", "2"}]}], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"internalBC", " ", "=", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"0.3", "*", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", "t", "]"}], ",", 
           RowBox[{"Sin", "[", "t", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", " ", 
        RowBox[{"2", "Pi"}], ",", " ", "0.2"}], "}"}]}], "]"}]}], " ", ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"leftBC", " ", "=", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1."}], ",", "y"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"inlet", "[", "y", "]"}], ",", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "1"}], ",", "1", ",", 
        RowBox[{"2.", "/", "20"}]}], "}"}]}], "]"}]}], " ", ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"topwall", " ", "=", " ", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "1"}], ",", "5", ",", 
        RowBox[{"6.", "/", "40"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"2", ";;", 
      RowBox[{"-", "2"}]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bottomwall", " ", "=", " ", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "1"}], ",", "5", ",", 
        RowBox[{"6.", "/", "40"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"2", ";;", 
      RowBox[{"-", "2"}]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"data", " ", "=", " ", 
    RowBox[{"N", "@", 
     RowBox[{"Join", "[", 
      RowBox[{
      "internalBC", ",", "leftBC", ",", "topwall", ",", "bottomwall"}], 
      "]"}]}]}], " ", ";"}], " "}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->450761097],

Cell["\<\
The red points are the location where the velocity is specified:\
\>", "ExampleText",
 CellID->1969984253],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sol", " ", "=", " ", 
   RowBox[{"DivergenceFreeInterpolation2D", "[", 
    RowBox[{"data", ",", "\"\<TPS2\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"StreamPlot", "[", 
    RowBox[{
     RowBox[{"sol", "[", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", " ", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ",", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"data", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], " ", "]"}], ",", " ", 
   RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], "Input",
 CellLabel->"In[2]:=",
 CellID->178388260],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztffdXW0meb7/ZmXPeOW933+zkme2dfT2z/8h7v25Hd5judrfbHax2xAlj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    "], {{0, 151}, {400, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{400, 151},
  PlotRange->{{0, 400}, {0, 151}}]], "Output",
 ImageSize->{404, 151},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[2]=",
 CellID->1933344339]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->541634329],

Cell["\<\
Get an estimate of the flow in a driven cavity using only the boundary \
conditions. Zero velocities at the bottom, left and right wall. Horizontal \
velocity of unit 1, and vertical velocity 0:\
\>", "ExampleText",
 CellID->922914713],

Cell[BoxData[{
 RowBox[{
  RowBox[{"leftwall", " ", "=", " ", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "y"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "0", ",", "1", ",", 
        RowBox[{"1.", "/", "20"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"2", ";;", 
      RowBox[{"-", "2"}]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rightwall", " ", "=", " ", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "y"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "0", ",", "1", ",", 
        RowBox[{"1.", "/", "20"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"2", ";;", 
      RowBox[{"-", "2"}]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"topwall", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1", ",", 
       RowBox[{"1.", "/", "20"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bottomwall", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1", ",", 
       RowBox[{"1.", "/", "20"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", "=", " ", 
   RowBox[{"Join", "[", 
    RowBox[{
    "leftwall", ",", " ", "rightwall", ",", " ", "topwall", ",", " ", 
     "bottomwall"}], "]"}]}], ";"}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->656945294],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"solTPS2", " ", "=", " ", 
    RowBox[{"DivergenceFreeInterpolation2D", "[", 
     RowBox[{"data", ",", "\"\<TPS2\>\""}], "]"}]}], " ", ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"StreamPlot", "[", 
  RowBox[{
   RowBox[{"soltps", "[", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", " ", 
   RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}]}], "Input",
 CellLabel->"In[2]:=",
 CellID->1940943096],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvfdfVcf6x/u95Yf7b9yf7/0n7v31xhSTnJMeE4/EiokFC2KPLbHQBbZ0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    "], {{0, 299}, {300, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{300, 299},
  PlotRange->{{0, 300}, {0, 299}}]], "Output",
 ImageSize->{304, 299},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[2]=",
 CellID->143242816]
}, Open  ]],

Cell["\<\
For some basic functions, the flow can become sensitive to the scaling \
parameter. Here is an example of flows obtained using the multi-quadric basic \
function for different scaling parameters:\
\>", "ExampleText",
 CellID->384086542],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"solMQ", " ", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"DivergenceFreeInterpolation2D", "[", 
       RowBox[{"data", ",", "\"\<MQ\>\"", ",", "#"}], "]"}], "&"}], ",", 
     RowBox[{"Range", "[", "6", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Rasterize", "[", 
  RowBox[{"Column", "@", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"GraphicsRow", "[", 
       RowBox[{"#", ",", 
        RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], "&"}], ",", 
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"StreamPlot", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"{", 
              RowBox[{"x", ",", "y"}], "}"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"y", ",", "0", ",", "1"}], "}"}]}], "]"}], "&"}], ",", 
         "solMQ"}], "]"}], ",", "3"}], "]"}]}], "]"}]}], "]"}]}], "Input",
 CellLabel->"In[3]:=",
 CellID->158754014],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzsvYtbVEe2939+z+8vef+eOXMyk0nmnUxycj1DNEbMaGxvwVtIvOANRTsC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   "], {{0, 0}, {500, 
   352}}, {0, 255},
   ColorFunction->RGBColor],
  ImageSize->{500, 352},
  PlotRange->{{0, 500}, {0, 352}}]], "Output",
 ImageSize->{504, 352},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->188743823]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->572711569],

Cell["\<\
Generate a synthetic terrain, extract the terrain contour at a specific \
z-level, and generate a candidate 2D velocity field at that level. First we \
define the terrain, and the inlet velocity field:\
\>", "ExampleText",
 CellID->488716687],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"uvel", "[", "z_", "]"}], ":=", " ", 
   RowBox[{"Erf", "[", "z", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hills", " ", "=", " ", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}], ",", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "0.02"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x", "-", "3"}], ")"}], "^", "2"}], "+", 
          RowBox[{"y", "^", "2"}]}], ")"}]}], "]"}], " ", "+", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "0.05"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x", "-", "9"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"y", "+", "9"}], ")"}], "^", "2"}]}], ")"}]}], "]"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"ymin", ",", "ymax"}], "}"}]}], "}"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "15"}], ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "20"}], ",", "20"}], "}"}]}], "}"}]}], ";"}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->958741851],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rasterize", "[", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"hills", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "xmin", ",", "xmax"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "ymin", ",", "ymax"}], "}"}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}], "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->895232116],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzsvWd4FMe2733u826DwuQsieDtfb7fc/ecc7yDd3TOOQcMBgwm5xwFSAiU
hZCEJAQCkaPIOZuMMRhMMNFkTFbWzLy1VlV1V/f0jALRuNez0NPqqREjaeqn
/wpV9fs23d5p8//9x3/8R+z/+Y//+IL8g+uAbrrppptuuummm2666aabbrrp
pptuuukWCFRXVz/sl6Cbbro9NJsxY0aPHj1GcqupqfH7/XPmzMnMzIyPjz91
6tTDfoG66abbQ7Bbt26NHj36yJEj0p0DBw5MnTqVXFy9enXs2LEP76Xppptu
D9MIHAgBtm7dSj8tLS2VrocMGUIkxMN7abrpptvDtMrKyvT09E2bNpFrEkrs
2rWL3h86dGhFRcVDfWm66abbQ7AbN25cv36dXNy+fbtPnz7kYu3atevXr6eP
Dhgw4OG9NN100+2h2ZEjRyZNmkQurly5kpCQQC7OnDmTlpZWW1t76NChrKys
h/0CddNNt4djM2bMSExMTElJOXz4ML2zZMmSkSNHDh8+/OLFiw/3temmm26P
vek9Errp9ls2vUdCN910Cza9R0I33X5T1h5NdXP79u3xgh0/fjyg90jopttv
wyQmBMOBTHOfYNJ9vUdCN90eV2vPTXUn/LP0HgnddHtcTSSAigyqO8Gm90jo
pttjZsEiIRBEhvrIBr1HQjfdHgOrc763F0y686BenW666fagrT4CQDVe81o3
3XR7DKyeQQG1/+AW0Mmgm26PqTUoImBAmOshHkyG+nwF3XTT7VG2OlOLoski
AZkgObkT/BQdDrrp9mu0BmUSNIGgk0E33R4ba2QmIQQTdDjoptuv3RoDhDke
hYeFQ3BI0tACh2666fbATJyh9U0tzvF4vV41FupChGZ5QieDbrrVaQ9yi5JG
phb53K+DDFqIIF9c80xnHQ666aayixcvpqWlBXDh4QPboqQxqUXVZG8QHPiz
4D/lRczgl3RPv0XddPt1m0SGB7BFSSNTi2FjBICD9GldcID/eo5OBt10q9sk
MtzXLUrugUgI4QoyBLsWGXQ46KZbnSaR4X5sUdKI1GL9mVBfOCjzDF40HQ66
6RbGVq5cefLkSUqGe7tFSaNFgpw6qN9krw8cvNxonkFsmQ5+2Xf5jeum22Ng
W7Zs6devHyXDPdmipPFNSoJIqL8GqJMMTCGIVUtl71OjX7xuuj3edvjw4YyM
DHp9N1uU3FXX4jz0hkcHoeAgiYTgaEJ1R1cOuukWysTNURtqjRAJChpQn8+d
34FJrcSFhs9Teygg6GTQTbcHZo1JLYYCwgKl402Y4EpchHGZCaqH6iKDDgfd
dLsn1jiRoJizmkBYGCM73oGnKFmh8BBA0IDDvDrIoMNBN90abY1MLYoTtk4g
LBIc78CzlLiQnAEhiBXh4aCTQTfd7pU1pv6oFTIoNIAmDRYH+SKEQxAuZGIs
0IhEGDG0go5QZNDhoJtu9bRGigTNvIHwhz4cEEo1HJ6Cj8qBwyINdaEdiQTJ
Cfh2QmQ1yVN0OOimWxgTgVDfNdHzOBCCJ77ginmtCYQlGs6AII3RkhbakUhQ
VpM4g8M8GQhSOUNvb9BNt2ALNRE0p4ZCJMDU40AQJ3vwNKcaYEmQNpAGLI2V
XJ6zeB38pdSuxIVMISYnGCLg2+HRTXBtVJcNuukmWWMyCVLqYKHABDbN+exe
pu3wLNVNAQh0gGoM5YPatcijGYmIckJeOqGqevCIIxgOOhl0+01Z4zMJgkhg
sy8YCMtjAyu0HZ4S4j6bsyvw6UqH+8u1UKPAhUYkIikKeemElpaQ+KDLBt1+
s3ZXqcWFQqKglM++pZwGEhBWxgVWoa/WcHiK8lO4sypO4fRRcrFSiZQgaITB
hVcwigj4xlUJCokPOhx0+02aSiSEf6srUosiE1RRwzL+1xxoEASENXGBtdoO
z1rLmRA8YB31ZuD0zpo4Ro+VsRIrFK4lM6RMhaQo4LteIqQm6g0HnQy6PWbW
0KiB1e+kcsOCGHUygTNBUgjyX3xKAwYEnNfrg3xDM3nOKu8z38h9Ezq93gBj
4CnrGCiYolgVy1ixMmRUImYt4OewNKZOOOiyQbfH2BqTWpzL2wjFisOi0FhY
yYAAT6FAWCcAQZrpm5izOcuv+f3mgc3ctwi+tXlgG/pW/BQHsGdxVsigWMMV
yMpYhSvDECRDrA4H3X6D1sjU4lyPpBNY0UGOHWKZK7AQJ2GBSX0RCPIffTbf
2bTdopj7cEea/sS/lbxFYDv6jhaBnfgRPoWH4CkKXAjAEUHB0hSxVFRIcIAf
y7LYRsDhHrY3PMgNunXTLdCQ9Y+B4DXRylYlnrKLlYsOS0NigQYO8BSZCfKf
eDZttzVXOM59uL+jBfOd3HcJvrtFYE9LdLzeDTfhWRwX7IsLlGBygioKOe5g
cICfzPLY+sDBe4+6IqX99AIPdoNu3R5Ne7gHN4R596o3TmFM0EgmyEWHZUIt
cnmcEgvN5HzCBhogKJjAJAHhwLdcA+wQCLAbp/nulnz6twzsFXwf+nctA/vR
v2MOT9kHA/C5kqhAsUG1xFakBIs4FAlM+MmsiA0DBxllC+5NTCGS4QFs0K3b
I2uP5sENcmpxtjswm2+tRrEQnGBcwkp+TB6IvlIsPSiwENiIUl9kAmChhRwa
bKdAEAiAcx8G01m//0nZv+d+4MnAwScDP+BH7uy/2N+SIgK+IMoJRgmKiC1K
PqyLY/0Mq3neUkaE0IYdFFbUs06xffv2eMGOHz9O74tkuK8bdOv2iNujeXBD
YJYb3vYiFugurFQwUCwsUYcMmNCL0+g0CGIClQpqJohYkNSCRAaKggMwzcVZ
DxCQ/NCTgcO/D/woO/svDuOzfkBuEHpQRbEPvzLlgyQhlHyAH5oQYkgpShRI
XD8s5nDAJqh6ygYyzX2CSfdFMtyPDbp1+7XYI3Jwgxw1zHIjEIAJXnFn5jk8
mqChxGLMKjAsoDZAJnjlrqRmzLWwICcYt9IkYQuNCAI+tmSxA5DhSUoGqgGA
AEoIBI6gH/194NjvA8efYv/FMbxzFBABY8hTDj3JECFLCEk/IB8gC8FSEPDT
EyQE+5qrYhUhRhAfGh1TiLtzB+71Bt26/brsETm4AYBAneoELhW8qm0SIaDg
0YSUb6TJBKkcubaZ2hkWhASjVHPciqkDRXGhJXORDPuCyPCjxIGnwI8zl/+L
k0+Bn3gq8BNzBoojyAcabnyvxYftMh+kdRNYy4hTdkdohBiMD1pwqA8ZxN25
A/dog27dfqV2D/8uNLL+ONMdCgsKMkhrDAkZWEAh1SV5SgEDB0VFkjkXCTSO
YKXJFgQLVC3wogMCYRd3es3I8CSQgaYRfmBhQuAoZwKd+ydw7p96KnDqD+Cn
0eH6KfCT+CgZRlXEj1w8AB94xlLFh23N5RVVyhSENh8kOCyM0SRDfX414u7c
gbvboFu3X7Xdw4Mb6jNSBsIMNzBBgQWPAgviBuywrjCGLzCM4QEFb1ogZFgu
JRubMTjw0qTMBOpBWGDlyJ0CCnYLfAhDhuMcC0QYnPwD3MELhoUzfwic5X6G
UuIpNoY86yiKB5EPByQ+sCIIy0B+y/soSIghFzrjGCIoHygcqHKgkcVCJhsa
1GRO7W5259btcbJG/11oTGpxBqYWCRaoz1RiIfgYOHljxhjweegsoIiVZYOi
OikAAVocmxPNQEIJcC0sEKnAyCBxYI8AB3Kx90mBDGQukxnNBcCJP1AmsCkf
TIaf0QU+sECDPPf471lwAfkHWT+wr4Z8gJ/tjuZEP3hpi4WKDzIcYmU40LTD
XcQUuunWaKs/ExQigbsMB1k2aKgFLhViZDJIvoCToZQHFAgHr2CQe1wjpBoo
IjapyNCSBhFe1qjwJHCAfJSUwx5Ohv0CGY6wlAKTCoQGBBE/hSDDOQUcYDzq
B5aFoHw4KhQyaHxBxcMehMNOVDVyCwSHg9D/wMKKumKKgA4H3e6DNaJJKVDi
FpkQDg6qUIJigaMAxi9QkoHKBgwoZBpI4mElxhSrmimKFKubMTgQMnzbUsIC
IQAMpljYp4SDdJOS4SDmD4/IyUYZC1xCyEmGM5QM/wkuiAd4FugHln+g+gFu
gn7A0qcUXOxrCT9hqZcS9QMWN5vJmQeadqA5B55wYK9tob6eQrf7a43JJBAm
SF4vOAh5BqYZeOywAJzBYYF8h5CBTQHod4oLLI0D8UD1w3KsU0C/UzNCCdlX
o3jYiHDYLuUWAAUwfh8ngwQHBRl+j2R4CnKPP0lBBMHCH3jC4Q8KOEhkOI9w
OMeCC3jWOSm+eIrlH47zzORhBRzgx47igXVg7pA6HyQ4xMlwWCn9QPSYQrf7
aA2KGry0a7HEpWBCaD6oEw6h4MBFgkyGBUJX8MJYOawoRT5QX4pkWKZgBboA
hy0Ih11s+sP47zCfIMuGJxkZvuNk+AHIwP7r4zjHKRZYkSKIDGc5Gaifw+Di
/H/CE88zFcEyD3La4UmelmxJwgr44QtpycDO5mJZU0o4yD8QGlMs02MK3e6L
NTi1CEBwwTszDBnqhAMhgzrhEKOKKdj7Xw4rYgEO1BdxSlAvRTgIrPDTCwKH
VQIcvkXlgNOfwWGfAIc9PP24//eQZPiByv6nwIlyoHBgLQ1/CEeGCwIfLiAZ
Lv4n+17IMCknSWsWgmyA3wKEFUrZsF1OOLAvIiYcpCKmsk7RuN+vbroFGtKk
JEcN010UC/UiQxAf6oJDDHEZCDQbiVGGf16Mb65QrZgfC74gVmQFDGa4iCPu
Jx8XxRFiMDisxYKFBAcaUBACiLJhr4IMMODQU+AkpvgR4OCVGxvqIoPkl/4z
cJnBgYUVp2hPlJSNfFKqVsBv4Xu5miknHL7lTRpiTFG/OkU9m9B0000zagj1
zpGBoPK7hwPEFB4KB69ggTkx4EgJP4KidnZMzayY6pmempkx4qNMY8yLpaDA
AETGhX8BOECDwGGZAIfNLQLbeIVCEglSwgE+5YWDA5hqOIhhBfJBIEPYaIIA
4SL3y1wtEEScxzGnnwoqZaJsOIRkONhSJRvY0xV1ijgmG1bXVzaE+RXrplt4
VSk+pBAJYZzBoS4ylGjLBvltL4kHdP9sj2+WpxZQANCoLPFUlHjKp3vKpnmq
Sjx+wodZMYHZ3GVWIBwIKND96OQmgILCYWWzwBoBDt8iHHZhhoHXKdjr+e73
4Pu5U0T8wOHAGqS5bNAkwyXEwiVUC5e5bKDZBlqnUMkGdPgV/MBLFXsFLLBU
ZDM5Falqb5CyDVQ26HDQrR7WmNRieCAovb5wKAkCAnzqAeWA7p/h8c3w1JR4
qks8VdM9ldM9FdOADGXF7jtT3benuG8Wue9McVdO8/hKPPjEGOazGCvgazJW
xPrnxPgpOigcSHCxlMNhfYvAphaED/i3mBU02Uva+6TC9zEVwUoVh0IEFHJL
g0AGioVLwvUFLGie4bLhBM82cIff0SGWjURJQ2MK7H3a3lwtG1iRIlYhG9h6
Cu2VmDoZdKPW0CYleaY3hAz1hIMMBLyW7vumu2unu2umuaunuauK3ZXF7oqp
7vKp7rIp7jtF7ltFMPhGoft6oftaAfjtye6KKe7aYk9guidQQj0mMAMcvixn
BZEW4DPw0zkCHFYgHNY2pyssAhs5Ir6VGh6eZEJiNy9Y7OM5yUNPsZZIVUAR
RAY5grgoBxdeuYIpyIbjssNv6kfIOWAOBGMKiQyibIAihdAyvSpW3TKtywbd
tKz+TUqhooZ7CAcRCJL78X5tsbtmqrt6qruKKIEp7ooid9lk153JrtuFrluF
rpsFrhsFruv58JV/meS6mue6nOu6lOP6Jc91K99dPtldM8UTIHyYxn06OP5H
McT9JTG+6TH+6TFwn8JhfizkJAkclqN4WNU8sFpafgV8wIbJlpKKkEGxl8sG
XsfUSDUIZGD5xoscC2KRggYUsmz4PXegBPyajtBNIVpiKpJmG5oHdkqyoRmT
DYQMkmxYEyt3RS6Td3rxam0Kp5Pht2kNrj9OczHXnOkNJcN0N3gYIEx3+6aR
P/eEBjC+crKrvBC8rMB1p8B1O59MedfNSa4bk1zX81zX8lxXc11XcmDkpYmu
i9nOC9nO81nOixOcV3NcN/NcZfnu6sluP+HDVO7FSAYEhb/Y4yv2+Ol9cmeG
AIfSuMCSZpB5WE6bJ5uDiljXPLChBSBiE6VES6AE9EcJsuGgIBtCkAGnv1C1
PP8H3tjwBwaHczwPeUpwBEV7XG7JEpIHWoqygcHhWySDSjZIcJB2euGpyPrv
+6TbY2mNWdogMeGewUGmQQgguKqnuKqKXBQIhAZk2K08581c8Bu5zuu5zms5
zl9ynFcnOq9kOy9nOy9NAA5cyHKSkT9nOs9mOM+kO8+kOS9kOq9McN7Icd3J
c1Xlu32T3YEi4h7i8F8TVkzxEGL4ijx+dLhD4TAb85ML4gILoabJXuoyDDFQ
QjBErG8BlKAlzh0tWYryO9bkoE2G07yR6WfeHS0to5Cuz/OWyJ8xoFC6ly63
hGoF1jFF2bBLSzYo4cC+lxViKlKdbWgv2P18P+r28K3xIkHT7wIOMhOocpiO
QCh21U5VAiHfdWeSkwKBDL6W7bya5bia5bw6AfxKlvNylvNSJsz98xmOcxmO
n9MdZ9McZOTpVMepFMfJZMdP4x2nUxzn05yXM53XJ7huT3RV5rlq892BQubw
GiZ7/JPdvkJwf4E7UIDcKEY4zIoFPsyBP6+1C+N8i2iLFJMQ2F/dHCixvgUr
YWjKhiMCHDgZvLSRSVyRLboIh5+FtZl4H26eBs0AmYejTwqyoQX2NgAZZNmg
hAP7sYsxhVDB1GXDQ7eHtSdzfZuUcO6j2L6XZBCA4KJAINcECDUUCJNdFSRe
KCBAcDIg5DhvTHQSIPwygQABpvyldMeFNNnPpznOpTp+TnWcTXGcSXGcTnac
SoZhBAjHxzmOJdmPJtqPj7WfGu84l+K4lOa8lum8NcFVMdFVk+cO5IPDiylw
+4mWID7J7Z/kDkwS4DCNheE1s2Or58bWzsNa58I4OcpYivqBKIdNmHagsmEX
b5w+IGQbjj4lwQE+lVZXqf0pcTEmkw3nZUdWPMXIQDUDxcJ3iIVdDAvCGm0W
U7CfvNzeIKUiY8TGJx0OD9ikDTYf2J7M9yRquCdwUAKBO/0KxfBoRaGzvMBJ
gHA7z3krVwKC4xeiEDIdlzMcBAgXUQz8nGw/O85+hvh45qfH20+Ns58cZz+R
ZP8pCThwbKydjDySYP9xjP3QaPuhUfZjCfaTY+0/j3dcTHH8kua8meksn+Cq
nugK5CEZ8tz+PLcvF9yf6/LnuAK5yI1CCDd8Uz0102MqZ8RUzYytnYVkmINR
xvw4lqJcyclAc5LbWdukIBt44/RRvkabhhXMn2KuyiScYYiA8UxL4HNpqeIn
qTaBcQRtdqJA4FiggkH+4auyDZoVzIUN2EtWt3tiEhke2J7M9RnJgFAMMzTU
9G80HLSBIDAhMNUVmALDagqdZagQrmc7rk1QAiHVfj7Ffi6ZzGv7mSSY8icT
bD/Jbv8pEfx4gv3YGPvRMfYfR9sPj7aRYT/E2w7G2w6MsO0fbvthpO3oKPuJ
BPvZsY4L4xxXUxw30pxlGc6qCS7/RHgB5KOPeDa4P9sVmABwACwUuKsneyqn
eMqnxVROjyGI8JVguXMWtkUtRNmwEhsmpYKFpmwQ4AAXPz2l8BNKZ/s5cFyc
foqGD6g0yE2sWh5V9kDu5jTYQS+aiViQ8wySYAiqUEjlS5AN+lG598Hq3K7/
/u3J3BiRQJkg+T0iQx1A4EwAL3IFJsNTqiY5b08EJlxOJ7LffkEJhNMkIki0
nUiAKX9slO3ISOY/xst+ON52aCRA4OAIGPb9cNt3w2z7hlr3DrF+N8R6cDiM
/2mU/UyC/fxYx5VxjuspzjtpzsoMyGD4J7h8Wa7aLPjoz3QFMuEl1U50Vee6
K/LdZYWesiLgQ/UUT+1UzFvS4sUCJAPtedjQIqRswK5IeNZhYZdIyY8L/hPv
dTzG+xZ+gjIl+3nSfgYhgmhPF2Lv4ijYrsaCFEfIWFiHWJBCieUxqpYnduad
Dod7bXVu13//9mQO1HtDZnirqJhwL+AgAkEmwzSBCVM5E4oYEwKFxJ2BApie
FROdN4laSLOfpyEDAMEGQBhj+2m07fgo29F4mPKHh1t/GGo9SCb7UO7DrAfQ
vx9q3T8UOLBviJWM3DPIunugdecA687+1n2DrAeG2H4cZjs+0nZ6lP1cgv3y
WMe1cY5byfBfV6c7azPAJazVpjurslwV2a47ue5bk9xl+e6KAndVoae2kHdB
zEYy0EVYtFUylGz4ni+5+oHvIU+XZB55SuxpBBcXRxxB5zvPI1LwDo0gMLEA
v+6dLGqAjzuaBWMBBUMcyzCoWxpiZMFAybAwHBnq8wbTrUEmbtd/X/dkrrtJ
iRMgHBy0+BAGDqHSCOwpWiIBmQBAAM93BibBlKzJcZZlOa6nOy4TqZAkAGGk
9cgI64/DrYeGARPIyP0DLfsGCE4+HWgFH2TdO9C6Z6B19wAYtqO/ZXs/y7d9
LFt7W3b0teztb/1+kPXwENuxYbZTI+0/j7JfHGO/mui4keSQvoXqVCfxKuIp
zvJ0551M181s182Jrjs57vJcd2Weu6bQ46OyYTY2PFAyrOYdDrS9Qdr7Zbe0
HpMvssDIQn0ghXQshbjUmjo9qoZ+PNQSmHCQJxZ2ww7SDAuUDCIWtlAsxBEs
0JKEhmBYFqM8tgbJsJCtWVPBQa9g3g8Tt+t/kHsyh4wa7gUcZCBohhV0vIZI
cDIm5DMmBPLQsS5ZleW4ne64lmy/mGQ7Q8gQbz1MgUAUwmAyry2ECSAG+ll2
9bHs7G3e2duysw/3vswJBLb3gWHbelu29rJs7mnZ1MO8pYdle2/Lnr6W/f2t
hwZZjw6xnRhm8wp2c6zjzjhHeTL6eEfZeMftFOfNNOd1Aocs1+0sV1m2i5Ch
mpBhioelGuZjE/UyJAN2ULPepy1YwdyBe7/wxdrsZ3WA5STVfpjDge3AgKrg
AC6IONiSfgrX+1vINYgdeB7NViw9bAuHBRpHwP21sULiMUYmA4cDe5FcNgTm
6jHFfTdxu/4HsCdzGCDcPRwUQAjrMIzpBKdKJDAm5KLnOAMTHYFs+Ntdke64
mWK/mmQ/n2A7FW89RmKHwZb9Ayzf9bfs7QdTe1dvMxn2bQ/z1m7mrd259xC8
p3lLT/PmHjBsYzfzhq7mdV3M6zqbN3czf9vDsquXRaLBT0Nsp4fbfh5pJ9eX
R9t/SbBfT3TcTHLcQr8xjjDKeS3VeSPNeSvDSchQkeuuLnDXMjLgmu5FdNW2
1BjJU5GibNgjLMxkZ9bwJdvSOXf0eDt6UhU/aQLGf9dCcvgUtndrzhILW5EM
W+KADN8qsUCYoMQCxhFYWBEzDBwOMuSJbNBjigdud7Ndf4NFwlSX7I0mQ7F6
mtefCWJREuBA1YJSJAAQOBPAJwAZatIdZSn260n2ywm2n+NtJ4dbjwy2HBhg
2dvHvLOXeUdPMrthym/uYpJez4bOJuZdiJslJw+t7Wxe08m0uqNpZQd5/M6e
lr29LQf6WQ8PtB4bbDsx1HYK9cP5ePvFUfYrYwAR1xId1xIcV5Icv2CukpDh
zgQXCSiqCtw1RR4/9jlAeWKRsCqTyoYNQbJhN85xadc48RhcelDFAQ4HAQsk
XoDxe/hqiN3NhdVSzQAIm+MUZBCxsEkDCzSOgDHyITVcJATHFLpseLRNJRLC
/EYkIMgaXuV3AQcVEBoDBxpKUMFAsUCAMJEBATzLEch0BDLkkL9OW9PBtOpr
4+qvjfUcv7y9aU1HAhAQGzt6WPb0tuzvaz3YH/hwdBDkJU4OQwkxwk4RQVTE
5TFEvTiukbAi3XkbyVCZD2TwSWRYyMsTcrO0UjbsEDZ+kTab/Y5vICmdl31Q
eS4VxcIuXoXk/Qle2rnE5z4jwzYJC3FaWIhlWEBnZFjFF02IMYVEBh0Oj6o1
pv4oQCAkHELwIRQcpDnV4GqFkgzsJRXxrCOVDUQtZMtMkP4vX5qdfCxLsl9P
sF2Ot/083HpisOXIAMuBPuY9Pc3bu5k2dTKt6QA0WN7OuLStcQn6UtHbMV/W
DoaRCzJg8Vfgy9qDfljfybylq3k7iSx6Ah++6wv6gYz8cRBICBJiUEQQPlwa
Y78yFmKKG4QMWa6yHCBDdZGnthjJMIeSge8RR7MNNKZgsgHgACN3siOuEBEt
2U4O4MKxmAfk4ywZFqSFD9Rx4ntpCXKjggwKLNBHKRNoGWIVphdWM83Afqcr
hWyDZioyLBkCOhwerDW4SWmqE11NgHBw0OKDCAf5zRM27dAgOHi1ZYNcJfSn
O3yp9tpUe00KI8ONMYQM1p+HWU9qkWE5zvqFrQ3zv2S+gHhrI/WFxNsYF7WB
MYu+gmtyc35rI7le2s60qoNpXSfzxi7Ah2+7W4h+2N3Lsg+TlkRCED7Q/MO5
kfZLo4EMvyQ7r6c5b2W57uS4Kia5qyYTMngYGWjhku4BRWXDWn70FcoGGCZt
5iCfayM4hcP3wim3e/iOjmyDBT7ZQQPEEpfggBnIODUW1nORsComsCImsBJ9
FQ8lVjPBoCDDUu0ihS4bHro1SiQ4g7whcAjiQ0gg1J8MYUISLhtUCh8CigkO
X6ajNt1Rk2avSrFXjrdXjAM4UDKcE8iwl5Khs2ktJ8PcVoZZnxtmfmaY+Tlc
gH9hmI0+pxU4GQDDvjTObWWcDZ8CJZa0M634Gviw9hszCS42dzFv62Ym+oGR
YaD1+BDIPBAyQEyR6PhlvIOQ4SYhw0RXOZKhZqqHNUPO57vDreCyQRlToP5v
Ie3hwPSDeDjmXgqHlmosfIubw28UIgI639fhvN7AyADXlAkbYtkwyDEiE5Zh
jnEF4wOLI0KRYYmWZhDIEJjjluBQz2WYD3Jx0ONn9U8jeOneGhpACMmHuuEw
VcGEcFgIA4e6KiAK7EipSJQN/olO3wRHTZajOsNRlWavTLGXJ9uJYLiF7Y6X
RlrPDrX+NMjyY3/L933Mu3uYv+1q2tjJtPpr47K2RBjArC/51DDtk2jBDdM/
ZV7yGTgZM+NzA3Xy6ZxWTDwsaWsSMw87kQw0LUnJ8DMlQ4Lj6jjHtVTnzUxY
qlk2yV1Z6KkWybBY3OBFEVPgtBVOxJNO0ZV3eqGn4CETEAtsf3iKhU2IBfrX
fxX+6V8dI8AhFt4wG0FF8MABx0BboyewxAMfEQ48fIgBGqxibU5wZ0WMOs8Q
HE1wMni1tnYJ9aZ9YIuDHj8LhdzgO0whTHESh98mXtSfD2HgIM/WqYop3Ig6
Zt1AKJZXSUDfI2Yb/LnO2hxnTbajOstRle6oTLVXjLffSbLdTLD9MgqLBcOt
p4ZYjg6w/NDXvK+XeUc305bOpnUdTSvaG0vbGOehHiA0KPooeurHodww9RMY
Rj5SJ8QgAmPel3LageUkBTIcGwypBkKGC0AGOyXDjQzXrWxXWZ67AslQO53u
Y4/liSVcNlA4iBvESb1P25jjxKcn6rZg+QcKBzhOl2NhK650WI81BWg/wPlL
Q4NVwAf6U4V3C+QVY1jgsBxpUOoJLOZkWIpRDxUPy6XggtUmvJoZyMUeUTPI
v0GlbAjzjg08kMVBj581OGqgKOAuw6HeiAiGgwwEreDi7uGgoUCk/wUDCn+B
0zfJWUvIkO2oyXRUpztIHFE23n5rrO36GNuVUdaLIyAleGaIhQiGw/0s3/cG
wbCNCIZvQDAsRcEw+3NQC2RYwQcAhzBOxpCPk9GLPwEykPhikZSQ7AwJhx09
gAzf97MeGsDIcHaE/QJNQmJ54kaGk5DhDpDBXTUFFmAyMizEVMNSvmMDPTFz
DWJhPR5qQ7OR9DjdrTy+2MbhsKsFOyhzdwt2gu3W5mxbVxoarBA1gIdqABoj
wBsJLvD+EmTCIjf4YrxeglgAPvA0o8wHuWoZqjbBfoOCbAjMddcTDvdvcdDj
Zw1uUlICIRwc6oEIygGFSAibdggHh1AdTeEzFSoyEMGQ4/RlO2oJFtLsFSn2
2+PsNxJtv4yxXYq3nh8BQcTJwTBViWA4SARDTxAMm0EwGFe0My5uYyCCYcZn
0VNw1k96Pyr//ejCD6ILP9R2MoZeFHwYPeVjCCsoGWg2UipV7OkN/yMhw1FC
hqGEDFiekJKQ6bC3w51cd3mBu5KQYVqMbybOrIVwlg2TDTymgPtrpYRDc6Yc
uOP0Z8EFoQHAYRfHwrbmsNKBrnFgWIiBaU6VQClO9iUe6jTPAHcWuwML3YEF
6ORiMcAB7peykWo+AE9CkGGxfCquItUQlG1Qvb3FT+/H4qDHz+q53CmUSGgA
HELwoQ4g3DUcwgFBhQXaD5lHlzc6ajMclWn2smT7zXG2a4m2K6NtF+KtPw+3
nh4KUuFIf5T3fcz7qWDoYtpABcNXxgVfMsFAaEDG5L4bNfEdgAPzD9ROxtCL
SR8AHAgZ5mAqUqpTbKZk6CWRwXpiqO0MkuEiJYOUhMxxl+e7K4s81dNiaikZ
FvDtIpeymAJuUuUgwmEjnrWNDgO28OTDDhpWCFjY2IxhYSUubaBMgD/luJvE
Qrfk8I5CGqB6cQXmuygZOC4YTAQ+xKj1wzL8FpYqtoqVA4qgbEM9ZcM9XBz0
+FlDRULIyd5QOAiI4EAQlYNGibPBYUWIlkiN8Som0MJlPi5vzHCUp9pvJ9uv
J9muJtgujbadG2k9M9x6cojl2EBIOR7sY/6uF/Qx7upuooJhbQcmGOZ+YZjx
KQgGohbIgOx3ojLfisp5NyrvPerRee8rnIwRP532KSPDknbQGwlk6ALly91I
hh8GWI8MQjIM1yhPsCTkZE91sad2Bk9CSrKBHqcrJRwkOGxQOIzZjEfT0phi
O89MbuFYWCNgASYpQwEjwFzm8O6a4wKf7eJwEOghRRYKPsTIfODNDOz3KMgG
Rb9TPWSD6q1+TxYHPWbWmPpjPSd7veEgz9kpwTGFdv9D/eEQDARtMohMmCKu
ucb0Yw68mFvj7dfG2i4n2C6Msp4daT01zPrTYMuRgZZD/cxEKpAIgjCBDNvS
GRKPG74xrmpPBAP0Lcz6PHraxyAYCA0IFsiYtDciKRwU/h7xaOpkjHRd9LFh
divjAkqGr6F2uUkkQ38gw09DWUuDZnmiYrKnaqqntoSnGlA2sB/L0ji+RWQz
tXJYz1sdNlLZwOHwbQv2KT1Pak0cw8ISnJ4L3AphQDgwyxWY6SQOb7MZTvBZ
TvookkoIKxYq0g4yEFYwzSD/NlXlifrJBvHdrnrPN3px0ONnDQZCkZN5/ZVA
WDgogBAiymgAHKaqyaAOGUJ1NGkyYTJnQj4rWZKR5Sn2XxJt50ZZT4+wnhhm
PTbYcniA5WA/CB/29IDEwtbOpo3fQN8CUQu0u2lxaxAMJVQwvBc14W2iFiLJ
gOTXIlNej8x6G0ChdhJrvIvS4l32KQ0oFrQ2lraFxgZKhm3d2WIrsdmJlSd4
jzRNQtLyBCFDTUmMbxaTDSjC6eaQNKyIE0oVBA7c1zXTgMNWWsUQsLAc5ymZ
m2SaU5+HZKBYICiY7gxMcxCHt1wJUEKUDQwLoZgA6UeuE4RFVYqWBhUZgmRD
/esUv1kLg02VqYEQ7I2FQ0ggaCGiEXBQM0EVWSh1Ar6SoO1ZClzyKku6ogpX
Vt5MAsFAsHBkkOWHAZbvsTq5q4dpe1fUCR2Na3BZxLKvDEQtLKGC4bPoYhAM
UTnvRGW8GZn6BpBh3KuRSa/ANYGDyiegkzHSndz3oEIx70tCBiMhw5pvTBux
2WlnT9YJSZudGBnE8oSQhKTlCZaEpDvHLooLCYfVyIc1Ahw28phii4SFZrCt
yioBCwsACOBzg7BQ7JDfeDN42Dgff/iLMANZqmhp4BVP1snglZoZhO5oOaAI
XkBRv2xDnVPgN2KNFwl1eT2nuVewBiuNuuAgf+Wp9Vh1VSzrBBhcFBQ+iLsx
8FWWPlw/dXUMieiBDN/1Ne/pZd7R3bStq2lzJ9P6jhA+LGtrWIwdTfNbGYiD
YPgkuuhDJhhSX48c/xqQYewrkQkvRxA+pL0ZmfFWlOSZ3MkY6eaEd6Imf2SY
9YVxcVvj8q8VzU4iGU5h4VKjPCEkIX0zpD0NYtme0io4SB1QEh8oHCTZQBOS
MhbwCPvFiAWcgDSTAGMQCxIQfIV2/1T4AbJsw3wXrUp4aaUS65tCC4Sq+zGm
AWTQ6nqipssG0Rpcf5Qme73JII8Py4S7DUNC9FRLQFDdr7v0wDONMFgKHwq0
Fl9PJJrBGcCN4m8m2i6MhAwDiSN29jBt6WLa2MlIwoeV7SCrsOhLw7wvIEsw
49No4iSOIIKh4H0mGAgWxr4SkfhyBBkw6sWIMS9FkDtpb0ZRTxecDEjn9wkc
8j+ILvnMsLCNcbmy2WkvFi6h2YmRwcaWZotJyBwXI0MxSzXQgALhEKulHILE
wzpUCBuknd4pFuKgkriUYgH/Ls92MZ/lkt91xY7AFIevwF5bYPdJZJiHVQki
FZbw7iaRCWvktVRsCfZKDTIwOIRONcjvDYYs8gr1mIKZFDWE72TWFAmNhIMQ
a4RXCI2BgxBiaAJBDYc6ow8eRMDg4E1aciQssN0YVEZCia1doDS5op1xSRuD
6tGiD6Imo+cRwfBWJBEMBAujX4wgTCCPjng+gjhRDsmvQVjBPYo6GUA+pqCn
vgmZyamfQFeDqtlJJgM2O50ZIZcnro5zXFcmIeVOSHqaVRg4LEc+iGkHAQ64
x7uEBdzAeZ5bDYQSFkQQLAQm26tzbTUFdvJc33SnfzYWKRYhFkAqeOgqCfzK
bOU1XK+WW6MZGUQ48EVVDA5KMnD6CamGuSHJEPhNwqE+TGjAZK8fHORpG5Sx
vHs4KFFTx8TXhsMUpfM4AgarIgiUCtJ/6s90kICCrp86N8x6fKC82xI1ohZm
fRZNwoepH0XRO0QqEJ9IBcOrkUQkjEQgkIeGPtt0yLNNR75AJEQkgQP46won
Y8jH8a9HJb9BA4roWV8YStuGbnYaxgqXF4TyxI0M120pCYn9TvzPKJJBhkNs
CDjEiTEFn7McC6UMCzIQZpIIgnaZSlhwVEywVuXYqvPh51Y73emb5fTPRziQ
IGIFX15Bd3CiH9cw2cDgoEkGYV2VBAf57REi1RAMh/or6kfcwiwH03xIM9Mo
i4TJTvAGKYG6BtcxvrFwECdg0KNBk11wGQ6aA4q0ySD+d/4sWFxJmFCb7qhN
c1Qlwzv8wgjriUHQw7CrO9QjVrWHMsSczyGCmPZxdNGHUQXvR0lfIe0NJhji
X4ggQKBMIPcH/otcRMS/GDH2lchxr6K/JjsZQC9IxJH+VtSkD6Knf2ZY0Ma4
Umx2EshwYqgiCXlV1SNd4K7CkzHZ0qo5XDaEh8NKjBpWs1IF+/nTM+tLYxRA
KHGBTihxqrBQNdFWnmmtnAjrSqqLHDXTHLUznb55SAYiGFbxVVdruVSQtm2R
yEAXXmmSQdXyFCrVME9BhscspgheDnbr1i3arxVqpZj4zYrXMhNEvws4qERC
g2ASHg6aNKgLJkFk0KSB6JODVlvzIIJioSYdvDrNUZ0KK6/vJML7/NRg6GTY
0wMCinUdIPe44EvDzE+jp34YVfh+1CSsPBKpkExTji9DVmH4cxGD/tV0IDq5
2e8fTQf8s+nQ5yC+IHCQ/VVweBZeJL0aSWIKMaCgZKAtDfv7wpKNo4NkMohJ
SLk8kQ/9TkAGKaCYqwmHWBkOkmxYhdXJNdgWtTJWBsJ8LAgSLEx3So4oZlio
ybXdTrWUZ8ArrMyzVZGwothRM9NZO9flWwRKw78qRg4f1sZKykGGAwsoYsKk
GtjT66xdzg1HhsCvFg5hloOFekj1ndYNh9CI0JzsKiDcfRgiiYrQ8qAuOLAv
qAWHYCAI2y9IJQm45qGEf4LDlwVrJSgWYDeGZFhfWY6HT50Zaj3S3/Idrqnc
1Mm0ChZUGuZ+AZqBCIbcdyC3QIaNfzUi4SWWWCBSof8/mhIg9P0HkKH335oS
J5QY9lzE6JciEl6OlP0VeG4ClDAiE1+JTHotMuudqMKPomd+YVjc1rjmG5PU
7PQdkoE2O50arixPjHfKPdKToAoAZ9PQnd9m4dk0c4WEgwQHgoVS/CjFFCAb
AAsUCOyvs4QFohaISEBnWCgCLPgm2e+kWm6nWMqQDBV5tspCe1Wxo3qGs2au
q3ah27+MraSARdmCS5TQCivkOgX7xfHyBMLBU2ftksFh1uMjG8IsBwv1UPB3
Wl84aCFCnOyhgHD3cFB/5fA5ijq+poIAmgpBrlTypdY0lMC93TgZMpAMqbAb
A2BhHGzIcH0MyIbjA2H91B5cJbGuo3F5W+NCIhs+i57yYVTeu1GZb2JE8ErE
mBcjRjzHwoc+f2/S+29Nev2tCfm0xzNNuv+1SZ+/Nx3076bDnwc4jH4pUnIy
gF6MQVCkvRlFO6Xnt4auBqnZ6TssXDIyYOHyXLxGjzT81S5wy2SYGUNPzVbD
QSZDbGBpLIWDLBKwRumlyb25ML8AC8VYMyrmzScEC4WOQIG9PN16I8l8Oxle
XvkEa3muraLAXjnVUVXirJ7j8pW6A8s9lDYAhPWywxdZz0GhEVwo94SsJxmC
AorHBg5hloOFekjz22wYHJSICCMS7hIODf3KDfn6GvGCAghBxUoYQEOJCSgY
MlAwpMqCgUQTN8bYzg+HP4U/9IW9m77tCu3QK3m2gcqG7LdZHDHqhYhhzzUd
hBGEZN3+AnDo8meAA5EQg//ddMQLkHMQHJ5OPo4ifHg5Mvn1qInvwtLLOa1g
adX6TuZt3SxyS8MgaGlQlCcShPJENh7Umw+phppij58FFFpwWMzJUCpEDSsw
jliOrFgcQ7dBYFiYJrEaIghUX45Avr0y03ot0XxjrPnWeHh5ZVnWshxbeYG9
YoqjssTpW+Bma65X4tJsMv03iM7PqBL5IJYtgvd3wlCCiZmFocnAAwr6dR6P
mCLMcrBQD4VKuor36wkHPqHuupRZFxAa//VDv2zFi6cHSRQKx0lIfU358maw
ZKQ/WyEYqgQs3EywXRvNyCBphvW44HoR7MMAPQz5WKlMwSQDaIbnYe6TOKLn
M026/qVJ1z83EV8bEQ/koSHPRhA4iE4eIh9HIiXGvhqZ+TbrlF70lXF1R1Nw
sxMtTwT1SAMWynLgyEu285sUUKjgsACSDDIQSqlsgHYmGL80lhcj6FmZHAtF
DuoSFqon2Iha+GW06XoCLDG7nWq5k2m9k2Mry7eXFzlq57jYMsxlWJtYhXAg
ENgYJzqDA91Qej1f5bFGiCzUu7iAWoAx2nkG1pnJvg5qhsdDNoRZDhbqofDf
Y33gIE4r8WadFY064RBGIdQLDqoXE/5lcxTgWzcEE6ROBtwJ1o+90DT3SLOO
sN+jgIUr8bbzuFvLAdzVbasQTcz6LHoqrpLI4mRIeIlVJQb8sykJJYhaIFKh
M8Kh05+afPMnuOj5tyb9MRs57Hnw4ejkPr0mfCAxRXBAsYMfRUFGAhk0yxPp
8I3TPSErCz01Uzw+umEsCSgYHCDnIAOBaobFVD8AHGQsLIqBuUamFS1NEixM
dkgOd/LttRNtRCdcHmG6Gs/IcCvFcjvDemei7c4ke+0MJ2uKJtHEUux7xCQk
/L8b+Q7z3GHYRs4EaXNpiQw0IalJhiDBwL6IEEown6kuYtY5cR5BC7McLPih
+nx3oeCgCQQNONSjrqGa7MEioQFwqMeLYV+80BnK4dFQUiEX9nPzIxZ82O4I
28Cm2qtT7FVBWLg4wnpuOGtp2N3dvLWzXJ6YBTu0QG0i600gQ9IrMMEJGYZj
QNH3702JQiBYIEzohEzo+PQT9KLX35oO+BfAQXJyk14QPox8EXobst9lSy+X
tIMKxXZsdvoeyXBMKlwqe6RhbmbibrF5uCdkkXBA9kyh8jgXM5C0KsHIEEMT
Dl7aMLAohvU6znSzM4IJEArQCxkW/Ln2shTLlZGmS8ONV0fCylMSUNxMttzK
sN7OttVMc7DG6YW8ARLbnKBwuQ7hsCmOnVe1me1IT+GgPopCJAOVDaVyYcIr
9DPI7zdVkmG2NhmCp8bjZ/X81lRwCA+EcHCoq7RRHyCo4VCfHIgqZAimQYHa
vbRvIagFmjABNnOb4KjFegQZpsDCWDUWzuBmsF7ckGEL7saw7CvDglZQuJQy
kCoyDPm3LBtALTz9BCVDx6cZJXr/HUoVg/8dMfhZcHKHXgxBOAQHFFu6mfco
yaAoT2ASkjxEUw1l2NVQPdlTO8UjtCJw5TAP049LkQxLkAyLYigc4CfGsOCR
so74Y3RIDp/m2SvSrL+MMp0fbLw0FFaWXRtlup5ovpFsuZlhrSERx0y2+Fpu
jaYBBXY6MTJsoY7NlvS4ik0aZ1dpHHYpbAgpvx/meegKrzBk0ISDTgZxZP0n
Yx1wCE5Q1BkmNPzrq2igxkIQEMR1Uvg2VhxIR3RCLd0UOhP2ha5GtUCGVYfG
wsnB1uODYPd4MmxzJ9Ma2L4JVlHN+BQ6nXLfjcp4Q4MMA/+JsuGvTTr/qUlH
JEOH/32C+DdPAxmgVPEP1vAw8N/wRPKR+CDkw+iXI1PfjMp9P7r4U8O81rC6
amMX8y6ppWGwLbg8Qe5fT3HezIAjq8py5WZFPw0oSmKocgAysPNwlWRYFCNj
YR6LI2C9KvmVFSANJtmJUyxUpVuvjzGfH2ggfmkIkOGXeNO1RPPNFEt1vj0w
HcfPxl1cFuCa61IPa4PEgCKwHuEgSQV+3qVCNqwNCijEVMMiHjXQHCkLJZRk
mKNBhsCM3xAcGvR9NTQhWefklaetUk6o4dDwrx9GHsg3g4EwSX2MdSDHIZ5Q
ScKHGmRCVbqjIs1eiSlHMiw8Fo4OYGTYhFvHL/nKMA8XV06ma645GWg/g0SG
fv9o2utvkIekZPj6f58g3uHpJ2jCgcQaff/RtP8/mZM7A/6FcPi3HFBM/tgw
q5WxtJ1pbSfoapDJEFSegD/cmGqgQICDaQrxPLupnAwUDnNiaPpRJkOpQAYJ
CxhHQI2y0AFMyGNMAH2VKR/VfX4ALCG5MgwCihtJ5upcWwDXUtE9W4AMfKEl
phowoMDN5/lpNex8K+m0Gi/LM2iRgdcu2btCWE7VADL8lmKKhn5TIhwaxAdx
8moDoeFKI3h8GCDUkUaQgeBgNODHWLOj6GiXI+qEqjR7Raq9HE+RqBgHagGk
uISFkQosHBkA20Qf7GuRyEA7nabDfo9RE9+J1CTDANAM0M/QHWUDYQJ5qP3/
ABykmKLn36AVqi9viOqHiCB8GPpcROKrkeLSy1UdTFu6mvf2tvwwgCchhfKE
l/cmEaNHVkGqocBdM9njowdkT0cyEM0gJRmWC2RYHIQF2r1Afi8kgsi1U5d+
NZeGmU71jj7Tl60suzLEyN8MCJBpDmifJmSY41IHFKsgz0BTju3pCXdblOdd
0jpmiDwD+18WKw+4pHAQyRDUz/DblA2hSpbhnyJdNxQOdQKhcXCoJxA00giy
SHComECBAMPwyFo/LIiwV6NOqKAny4y33xkHUuE2dkHXiQVqUg/k9I+jC9+P
mvh2ZAbmGcYJZBisJEOXPzPZ0O5/niBwoDFFpz+zbGTvv4OT6z6ICMIHohxG
vaTulN7QGWqXB/szMtAkpAQEuRNSSkLmu6sLPbW4hiIwzQNwmCUkGYLJIGKB
xxFEJwRymJMxZcmQdTzd33Cyd/TpPtHSz6Qi0xogcUQho4e0mxMjQ6lbhQXK
BBpTKI7BXS90Ta/m/dKKNkhljxNXC16aewyjGZAM0gt+LBdbidbo76ihcPAK
1gglUOdX1ogUQjFBqDzCYAoELSZQINBjrANpdh+mGVkXE/Y3SkwgRo+YEYMI
r9L2wvaPZulTsc0JdnDiZIjH5gSZDM8wMtAkZNv/foI4wOFpKGLSgiZRDsQl
SvQBOESMeCFy3GtRE96Jpnu5lLaFzd+2dWc90tKbWZWElPqdynLdlZPc1QXu
WlxDESj2gGYQkwzL8SOSwUsFuYgFFkc4gAkTmUPWcYz57CDjsZ7RJ3oBFs72
M1weZSpPswTybAFcYgkND8U8oJjDsbBcAws0iGDZSI4FqhZgDMcCe3uwHkiP
uvtxvofuLiWTYY5GBlJ+66JmCMxwPfYxxd18L/WBgyYN7gkc5K8cJo0gMkEG
ggNogEDw0jRCMBMAC/ZAhj2QbidMCGCOsSYZqw/j7OVJcqRM7Ppo29VRijvU
jhK10B/Uwv7esNXb7h7mHd3NJJogDy0WtmhgZHi9bjJ8/T8Ah6/++4l2QkzR
BeHQ/RkgQ49nABG9iIT4R9Mhz0UkvKJYeikC4ZhWEpJ1QmZgEjLHVZHnrsp3
1xZ6/FN4qkFKMiznZFjKyTCPFyMoFqQ4gmIhG34+18dazg01HusVfbRH9PGe
QIbLw03lyZbARFsg14a/NXugyA7RBK1NSFjAYiX7dQtYoHEEvA83yFgQt3OB
8Yo2Jw/bcVpFhrnSvnMKJiiAwEMJyKzOgDUgj3dMcZffSyg4aALhnsBB8ZXD
pxE0dIJDoRAQCDAyW6kTBCYEz3dqtxKg7ZkwgUiFK/HWSyOt54fD8dbkoROD
LccHYhDR3/JDXzi2kmJhZ3dojd7UmZFhzucG2gCp+fUVZPiLkgzeJxRw+HOT
Ln+R+yQJInqghKABBb0pAYEEFPQAXM0k5FVxT8iJropcd9Ukd02h21fEuxrm
YPfjElw8xckADy2MgTIlmTgUCyyOcFAmUCzcTrKcH2H6qa/hcLfoI90BC5eG
GsuSzIEsKx0QKLCDYEAs0KoEzmvEAo0RgpggH5y9IQQW1AdchiYDMgGeIjBB
lXtkTJhBF5I/5nC4+29EBYfwQNCIAhqaRpBuhk0meL1eGQj5KGupi8kEDgQY
TEUCMkGcobUpdiIVqsfbq8bBu7cs0UaZcA2YYKVMuIARxNmhcFTlCexbONLf
cghzC9+jWtjTk2FhSxe21tIL0QQjw8S3oZ8BNAOutRyFVUsyQCRDZ8wztOdk
aONVxxTQR/0XRR+1CITJypYnb5geabocO8t1J9tVnoNkKHD7JvNOSCn9uLKZ
ggwLSKBBwg037G5RJMQRE2zE/ViMuBJvPjHA+EPXqEPdAIYXBhtvJ5gDGSzm
giQDVwuAhYVYqcSFVDIWNmtgAbOOWMRcJ2zdsIqfkb28wWQIwQQBC2HJcE/m
1KNg9+S7UCuHwnuWRpB/U+FzCFrJBC9tsBGZoIWFQBaggDBB+r98qfZa4owJ
NsKEyiRbxVhbGaYUAAsSE4bDYfeECWeGWE8NhvOnjg3ADVL6WegRVJJa2N7N
tBWxsP4b0yrcNXrOF0gG3PiRkmH8q7Dxo0QGYoQMPZ+BZifa0kBQQIBA7hMy
ED5IsoHCgSqHrn9tIgFhqLrlybS6o3lrN7aLi5SEZD3S4nLsTNedCa7yia7K
PHc1CSiK+NIqKf1IyLACyOClPQw0lJjugi7oQh5HZNsDWTbi8EMbZT4zyHio
R/SBLoCFnwcaro8yVY63BDKtDAuT7bCFiyq3IKkFFRNkLMjrLtvTZdqr+f4t
uEuDNziaKNUmA3uboVpQY2GmNhYeb9lwr74LDThIfhdphLpzCBrZRd5uN4m2
2wlMEDKN3iDzpQEQaDdjdbKtarytcpytYpytPMlWNtZ2h6gFXE/NsDCChQ+n
h1gIE4hUIBHEUSxD/IBliO96wcrKXZhbIGoBsACHzpjWdgAy0DzDNE6GrLci
05RkGPJvBgdOhieCycBjiiY0ppCA0PWvTbv9FQKKwc/iGoq3ovKEXZ7oGgov
LrqkZNBIQma4bme5yggZct3Vk4AMbBcXKf1IybAcySCGEiy9gHEEwUKmrTYF
5v6FIcajvQ37OgEWTvUzXBxqvDnGHEiHlxHItUF6oRgrlbOxgWGxXImAAZt4
f6OKCRIW+F4N8CZcqd7WyeuVDrj0aJKBvdPmyGUIr5hYUGEhiAyEh3dfpwiz
A9vDsntYbRG/lBoOmh4+jVBnDkGdYJSBIIoEfO8xJogcQMFA3r0sgvCng2ao
RSZUjudA4Ey4nQBYuD7aSiIIMoxhYShg4eRgxoQfaQTRx0wiCDJmD5cK2/CA
CaoW1nbETWLby2SAnVvehbWWaW/A9o9ABtyigZKBaAYvrsIGMvwvkKEdJwOF
A40p6E+e1imIciCyAeDwTNMBWrVLElBs684Os/tpiEYSEo6sSncCGbJdFTmu
qnw3LK0q4Sdd0vQjkgHulMZCKDGHhxKFTpZeQCz4UuHHdXWY6WQfw/7OUd93
BjKcHmC4PNx0O9GMvwUb9EEVOWCXp1lYo1yETU0r+X6PG2Pp+ikGB8BCrIwF
zgQvRhCMDNq7yntUoYT8Tpgnr7kWq5ONI4M0F8LMlIsXL6alpdHrUNusPVy7
H7KnYXAQJnudQNCGQ4GSDGLgkKcGAitAyDUIu5Rs9GNRkoyhZCBYoBXJWwm2
m2OsN0Zbr4+y/hJvvTKSHXP/81ALYEEhFeBkuv0oFUgEQcZQqbAZjqMyreto
WtPBuAqxsKwtIQMEFHiyLZLh7aj0N2C3t7Evw5bRI56XyUA0A7kQyUCAQO60
/uMT0p+n9v/LEg4w8i9NEA5Nicu1S766qrQdbCi9qSu8vO/7WY8MoklIuzoJ
mea8lekqm8DIALu4lMT45+BUXcJ3kqdkWKwMJQowjiDIzbD506zVYy03hpt+
7m/4sUf07o6QDj3WK/rsIOPVeFMgDQVDjg0Sj1MxjqDphSXYBb0Gp7O0DwPw
IZbdkXQC34cBgg6uE+DtJ28Zzc/DpQdtK5lAj8cSN3YTgwhOBhfdyVaTDPL7
qoFwEMkQZge2h2j3KSCqPxxUQKg/GeQcI3NHMBnkL57jYFjIltILdlEwSGSo
TYF4oYoEEagWbiMWiFQgEcTVeOtlgoXh1vNYgFBiwUywQKQCiSCIVNjVHXZ1
8+KxlUQqQATR0Uikwsr2cErd0rbG0jbGha0Nc74A2VD4QXTee1HZb0fRZie6
mTzd7W0gNjzTaIJcSGSQeEADirbKmEKEQ+9/NFWtrlr4FSzKXt8ZyLC3j+XQ
ANjfSUpCsiOrkpEMGc47Wa7yHBfs7zTVUzMjxjeXLrJme8gjJWIVoUQRVn+I
YMi0BdKsNUkw968MMZ7qYzjYNWrPNyAYjvcxnBtiDKQgFiZYoY1hMiYeZzlB
MCxm6QV4VLl9k7yJE2NCDBu2kisE7u3pjrKcCVQqwMhFAhNCYYGRAYAAI2do
YEF+X6FgkLz+cBDJEGYHtodo9y9VUiccQimEOuCgWOaA852u7RXW8cm/OGX/
EmpXu8wEigUaSqTZ/al2X4q9NtlWMx7gUJlkK0+03SFkQCxcYUywEKlwBiMI
L7Yr/IhMOIBMwEYmONt6B48gyBiIIDrIWFjyFagFgoX5XxrmtgIyTMZDqehm
8imvQ4M03U9+6LNsb9henAwSENpyzdDmjyygkOoUHals+HMTCgcp1SB1Ncxr
DRWKNd/AtrFUNhwdLOwWO4YfWZXqvJUOZCjLdVcUuquQDLWUDMvi6LlUXjGU
mCGEEtkgGHzJ1upEy+0RpgsDjcd7RW//GgTDD92iT/QzXBgGeimQaYU2hnwe
SszGxOMSdqIETPwQzkTCKryAwMHDfBnz9nQX+iVySkF+SyxQMiF4QeUshU4Q
4aAAAo8j7p4MYXZge4h2X5OomnBQiYR6pRHUTHDITpf0CkBQlyE0VkCosSAJ
Bl+KrSbZVo3VSYKF2ySIwAji8gjrBWTC6cGgE34ayAsQYviATJDCB6oWvHig
rawWAAsGCQtEM8z8HOCQ/z6QIfMtWrjEkyZekMkgAcGLiyaIZpDI0FogQ9v/
eYLGFOQhohw6IRy6P6Nuk57VyriIyIYO0ClNRu7rYz08EPKQ6iRkivNmGqYa
ct3lhe7KYk/1zJjaebH+xRhBrG7GELE4NjA/JjDLE5juhp11C3DJCfkJp1lr
x8GP6Pow09l+hh+7R+9AMhzuEX1qgCGA+z1CG4MqlFgEiUdp4it8pcLZ71qg
AfOlzOG9x6UCAwIyAa5DNzrKgiGIBgogBDEBHE9Grg8cVq5cefLkSYkMYXZg
e4h2v8srIhzqBEJdOUYFEFQiQZF4DE0G8ucM35OKOMKXZq9JsUF6gQYRIBUg
XrhGswrDLedQJ5wCJpiP9TcTnUCYcBAXTu5DJuykTOgMZ1Zu/Ma4vqNxwzfE
gQxhsDDrc3AyRjrLMu0NIEPCy9AGKQKhO89AkmtKhjYIhy//iHnI/2ZwkGIK
CQ5ENtBUA1t3+ZGh5HPY5Wlpe+iUJsN297Ic6A+nVp1RdUImAxmg3ynPXT7Z
XTnNUzUrpmZerG8xX/i8Mk4jlMjHHoYsmz/VWjMWQ4nBxpN9DFvbARa+6xx1
pFe0fxwmHjOsgWxlKDHfxbIBEgogb+CRnWsD9gIEDsi+RA4iWBFzoVvWCdIB
u+FWRigEQ3iRIDJB8jrrFFu2bOnXr59EhjA7sD1EewCF18YlJNVwEMmgjBrk
6mT9yED+oqGUZfUIVAu2qmQoQ9xOtN5KYMlGMubyCAtIhSEgFU5ITOhjPtgb
dMK+njDxCRO2K5kAIqE9HDez5mtQC2RMKCzM+AycDMDzr6Nz343KeitKei8N
w/Mm+uEKSlhrKfRAerHZiZJBlA2EDBQO5KFv/tSEwqGPkGogAUXxJ5CHXNzW
tLIDvP7tPWAZBZENJ4cpOyHHO2gn5O08d9lkTwWSoXp+bG1pnH8FCoblcYpQ
ohjrlTzJ4E+GH+AtGkr0jKZk+L5r1LE+8P0GUi1yKDEFi5VzMPe4jO0Ey5iw
XEMPwAAkALtQAUGZWID3nhILobqgORlYekEFBC/mGOtkgkgGEQjBs+zw4cMZ
GRnSp2F2YHso1rjCa+P+I3rReDhwMiiAoKxRMjjkqQsTAhlYhoGMpEzwp9pI
BFFLIojxtnLYWsFK2xoJE4hUIMPOQPhg/mmA+Wg/8+G+lAmmfT1Me1AnECZ4
YScWI2HCug6AAgKEFe2g9LDkKwP5SK7JgFBYmP5p9LRPoEm45NNo6XdBz6NJ
fFneDZKSoQuZ5k/DEkspmqBk+DKIDO2RDB1x00hChp5/g+1k6VbzJKAgsmEG
kQ1toHxJhm3tZtndG1ZfHh8CAQUmIR1XxgIZrqc7b2a7bk9y3ynylE/3VM6O
qV4QW7skzr9SGUrMVtYryQ853erDUOLaUAglNn0FWNjdIfJg9+hAEgqGdAvk
HmkbAw0l5nHBsEKZNBBmPfu9l7q543gVEJQRBLzx5rrVPickGdgTZyprEAgB
DThoYaH+MYXP57vf867R9iA7tUQ41JcPBXIBQgZCUDQhSgWv2NekaHdUVyK8
0OjIsFAzzlYFLY7WW2Mgq3BxBIQPZ4lUwD5nkAp95QWSkm3rbCRMIBfrFUww
ECYsbm1Y+CWggDYtlLYxLGoNuz7OC8LC1I8ZE0TZkAp5yMjRL7Jjqvri8uqu
sOcbK1y29bLCJbFW/+93bf7IyYBwoB3UNBtJ4CClGpJfj8p6Jzr/A9jlac6X
IBtWdQQ47OgJ27n8OAgaG1gSMhGTkBnOGxNdt/KRDCUxlXNiqhfF1i7j0cTS
WHXrI6tX2gKp1loMJS6TUKI3IQMsEKOFCXhiikUdSswGweAV8waiEiiFzRng
0UVu5ou5l7oZK+ini/jUXoAKgeiQOXjy3Ry32mfz9RGoE+R3l1ijVIYPCjKE
ZgJx+qV+1Y2RD/iliv+dAAcH8wINVwNBK8+gCCJEOFDBoMICWzhp82N10jce
sBA864Ntf0/T3h6m3d1MO7qavu1s3NLJWJ9nERQQIJALJRaipwsioegjkA2E
EuRi0vtR2e9Epb8Jx1MmvAx5SDip6p/qgKIttjQQIFAySAFFO6VsoHDo8pcm
/f8JWzwlvQoVitz3oLFh5hfGBW1gCzhAXHdolqZdTz+TgGK0/fJYx9Vk5zVK
hgL3nWJPxcyYqvmxNaVxvpX8wMowSQYaSgw3XRhgWN8asPBt+8h92OMUwBMl
5FCCCwavGBpIZYVSeb6zdMFCpS9yM6RggtHLWhQACEAb7ggHxR2IGkIBIYgJ
ajiEBQKMqbdseGTtwb/UIDhoMyEYCGo4hCKDqumRrqbMFrFA/qLZAikKGlQk
WssSrLfHWG+Ntl6Lt1waDrmFkwMhgvihD8wdGj7sIuFDFyNIhW+MGzti+NDe
sLIdTPylXxkUwuBzOOd65qfytiQSFiQgELVAUDD5w+iCD2DYlI9AP5DrnHej
Mt+KSoFDbyNHvRhBsw1eOL1OEVBIZCD2JZENqoACZcPXTzfp8LScahjzMlQo
JrwTXfBh9LTPoB+ytB18d5u6wnYutOvp9HAbpBqSHFdTndcnuG7muW8Xecqm
x1TMiZUEA5x2TZuiNZMM6TY/CyWMJJRYh2TY3p4t+fQTwZCOCyVyqWBwyoJB
ERcwJshzf55L9vlKn8dmJZv+swQX4SA8JAHBK3Ys1FV3oNM/PBAaGlM8mvZQ
XqcaDvVRCMFw0CSDsumRpxfsUtZRtNpxtuoka9VYeJcCFkZbb46yXo+3/DJS
gwxEKuzsaiRSYWsn46ZvjBs6GNd+bVjd3rCirWHZVxgvtDYs+hL2gp73RTTF
woxPYSc3ogRKkA8SEKQgQsLCpPdB4ZMx9E6eUKSgjQ2SbOjzN9iNgQYUlAxf
/vF39NtRyQZKBqIcOiAcev296SA4RxuOvMx4C7aNnYKyYeFXGA11hv0h95GA
YrDt9Aj7pQTHlfGOXzKc16lgmOopnxlTKQgGOO2akkEzyZBq9SVZykaaLg8y
bmgTQciw+avInR2ADL5xFn+qxZ9p9U9kZJYFQ6kABIEJTAlgXKDp7OvArHey
LzjTyTSAgAh41ymZoOhYCFN3mK7mQJ1AkL34HqyneCj2sF5kMBzCAEEbDvka
HY+KBVOs6VEGAsiGDNQMKUTuYm5hrLUcq5NEKtwYZSFq4epIy+XhlovDBDL0
Nn2HNQiIIFAqrO9gIFJhVTvDiq8MS9vQlALM6/mtolVYKP5YDhm8mGYsEVRE
sBFKEDIQSkx8NypDKRtoY0Pfv8NusVJAAWT4f0CGL/4LPgaT4ev/bfI1wqH7
M037/wsOqUl4JTL1DShfFn4IXU/zsUN7fRfz9l6W/QOsR4fZzo6GHkgiGK5l
uW7kuW9xwVC1MLZmWZx/DZJhVVxgmbBVi5hkyLIFMJS4Odx0foBhdSsQDFsw
z1A71uxLtvjSLL4JVn+ezY/dTexXs1hIHSzikQIECDgTZ+OGkKLPZBc4x51A
gxLmDA4zOBwkRMx0sSJmUNTgDVV30Aoc6gZCscJ/jbLh4b5C8X+vDxMUcAiD
hRz1OkpF0yPkHiGaIGSopWRIhCCCDLs20nJ1BMPC+aGEDGaZDD1IHAEziKiF
dSgVVqJUWNLasPjL6AUIhLmfw5SfjRFEyScyECZ/EEW86EN4lIBiGuJiCmqD
wg+i898HhZD7bhSJIKQXXBgkG6BTmq6h+AdkI7v9pQkNKFRkoHlIiQwiHLr8
BQKKwc9iHvINtqH0zFbGRW1Nq7CrYVc/68EhtuMj7ecSIcNABcPNAvdtKhjm
xVaXxtVSwbC2GXQyLIUkA040ZZIhg4cSQ4hgiKRkoFY7zlybYqnNtPpybb5C
u7/Y4YceBp5aFLMHyASmJejEV3kJR8p0J/g0B0Ql9FqEA+cDGzwDlYNW1KAN
h9BAkMlQXLf/6uDQXrCH+ALotSqsCOn5ctOjggwa6yjlIELR8ZjO0o+1421V
SdaKROudMRBHkGFXRgAWzg0xnx1sPj3IfGKA+YhAhm2dAQ6EDEQtLGtjKG0d
vahV9HxkgpRSkHMIHxEaRBV+EJX/ftSk9+AjufZivDD1I4gjClkcEZX7XhRR
CNnvQA8kGZAn7O9EZEPy63DqvSgb+v0DOhw6/6kJDShaczJIsqGdlmzoTMjw
z6ZDiWZ4NTLt7ajcD6KnfmaY28a45GvTui64LHSg9dBw28kx9gskjkjngmGy
5870mHIQDHFEMPho3+MaXHy9hJNBlWRIw+gMQwn6XWzAPENNorlmvKUmw1o7
0Vabb/dNdfhKnH56BNUCOYWIvQeYOphLRT7O+ulKBw7ge6DYAQnMqbBpJDiH
A3tiCZBBYgIFArzfQsgDNRxCKQSc7Pi/1wsLjwgcQi3xrqysDF6m8YiAq75w
yFe4CAf518cEg13CgtS9IDdC84CCkWGs9U4CJB6vx8NfuksoGAgZiGD4qb/5
SF/TQUqGrowMa1EwLG0TvejL6HmfR88BJsi9SWTA1A+jpnyIWHg/Kv89OHwq
5x1QBXTKFwAiWHqB4ILczEEsEIVAnAwgnxJWTHo/OldABJUNg1E2wLkSAAeQ
DUQhtP7j71pxOFD9oBlQdPpzk/7/jhjxUuS4N6Ky3o0u+NhQ0sq4oK1pxTfm
jbgce98Q24/x9tNjHZdTndezXNdz3FQwlM2MqZgXW0UEA+1uWt+cJhloj5OX
Ruh0J9g8rFemsFCCfFzxecSaVhGV8XBdPc5cnWapmWCrzbPXTnb4pjn9GPKz
lU1UOXAmQPiAk1ox8SWnp1FMcUACswjO1FbAYZpTClJkRDBpAQ7vNxgTAg7h
QwZhsjcIDg+RDKol3rdu3aIN2DU1NTlow4YN27dv30N5bXVaHXDI13b516fa
2pHtR2oXV1PCsAweTWB5ohbXR8hkGAW5RzLsAicDtDH0MX3f07S3u3FHF8g9
bugAycYVbUkcEb2wFagF1orwYRQBQhGqAgKEAnQJC9lvR054O3IiTnyCCCoh
KBbIpxMRC1lvQT2CDADxgHDIY2usopJfixS10IB/Qu8T4UOvZ5pAQOFlAcXn
/8UQwWSDkgxfPw1kGP1qZMpbURM/iC76zDCrtXHx16bVXcxbcAuX/SPsRxMc
Z8c7r2a4bkx03ZjkvkkFw+zYyoVx1cuaMcGwrhlNMsDKa3pGg5hkyLTRouTV
wcYlnwLHykYAFqrGmqtTLDWZ1pocW22B3TfF4S/hJ9MJzn6bM/nf/SLc/G2K
Q+XwEGEC7j+vCQc+qZ30I3ix4BIcGpRD0JrvdcJB/oIPDw6hlngTGixfvpxc
lJWVDR06VFQOjw4ZAqHgUBcQGBZU27ipZAOPI2BwujYZbmKxkkYTZNhpLhgO
9QYy7EQsbOxgIIJhBVYiJJFQ8jEy4X1QCAVkyr8Hszjv3cjcdyJz3omc+E4k
wULWW3DKTOabcEEeJfOdCoNcLhiy3oZ8Y/qb8JEMIKCQxpCHUt+APgQqG1R8
6PaXJl8JZJBkAw0o6IE1FA4dnm7S+x9Nx7wWmf5udN7HhuJWxrltTUu/Ma/r
Zvm2j3XfIKgUHE9ynEtzXsuGSuWtQs8tQTDUrGjmW9fcKyYZeI8TTmGeZMBy
5B08u5aSAbCQYK4eZ6lOs1LB4Jvs8EuCYa5L9tkuYIKUQCi0M5+scPyN26Hi
OckWDAc+DTkEplLhARch4OBUAUGBhXqIAU04iEAIpRweWCBf5xJvcmfgwIGE
D+Jru9+vqkGmAYdQCmFSiI5oTdkgLJ5CODAy+JJtlUnWskToeySC4eoIC4QS
QyDoPjHAfKyfSfxLvbkjYEH6bc7/PHr2p1EEC0QtTPkgqvC9yPx3IykQyODs
tyInoGe9CUBIfwNWUBInF+TRTPLQ27AbA5n+NI7IRCykvQF7OuEAuEkzD9j1
FDUemqUjoVkaD7ymCQe4+GfTTn+CdROt/kuWDbTJIZgM3Z9pOuLlyMz3ows+
M5S0Ni742rSii3ljT8vO/tYDQ4AMJ5OdFzJdN3Ldtws8t6d4bk+PKaOCYWmz
WioYNjQXkwy0xwn/gmOSIZuFEkQwLPqYvcLK0SZJMNTm2Hz5gmCQKo+cCfAX
fwo7Jpt+BC+QHW7m2KB5Mscmw6GAEcNLQwy1C3AQ+ABvtmJJXSg4UKcS0CSD
+G6pM6aQ3uoPYA6GWuL9/fffp6am7tmzp6SkZNKkScHT8JEyNRyClk1peF7Q
To85/OgTZUBBQwkYjJ1OAShPQG0C6pUjLd4g+6GXaX8P495uRjGNINmMj6Om
fQRYmPw+YoGIBBIyIBDIo0QkEA6kvQ5OmEAigvGvRpCPKa/Do+lvwukSWW+x
OCIDsUCG8UdBPGS9zfhAQEFlw+iXoOxIBgz6d9NB/2o6iNUxIeFA44jP/y/I
htZ//J1MBtomjWTo/OcmQ16ISH0nuugL4+y2ptJvzGu6Wbb2se4dZDs0HGbW
6XTX5YnuW/meO0WeO9NiiGAonxdbuVgQDHKSAc+0neNmzQA0yYChROUoIKpM
hkRz1XhLjVIweGn7wWw1E7gksEHXdJ6NXVOnn2ZZoXlyAmxBz+AgHV4D4sEB
XiS4FH1IZOBw8NLFVsXOIG8YHOqkwUNPOIRa4n327Nn09HQCjcOHDz+yoYRo
Ihy8Xq86mgjCgtz0GCwblNFEIMNGyaBpl4aZzw02YxxhOtrX5BVChh2djds6
GdZ/bVjWOnrBF9FzP9M+HoLYBCIS8O9+2usRqa9FpLwWQYAw7pWIpFcixr4c
MfaViHGvwqMEEYQDhAaACBAMkWTuJ78OHdHkUXKd9ibgIpPzgcqGhJcjR/IT
aqhTPvR8pgndM/az//u7zzGgEGWDlx6fjf1OA56NGPdmVP5nhnlfm5Z1Nq/v
adne37p/iO1oPEyus1muq3nusiJP+bSY8hlQkqhYGFcFgqG5fwOSQZlkgEUH
tBmAJhnS2ebw8z8SsEDiiFQUDBNBMPglwTCLM2EapgjILC60szmeY5Nc9eMN
pOGCCyUcvDS+YOrCoeaDEg7yl8JPQ8BBKTOYu0QXvg77VDUA/NGAQ6gl3uQO
kRCaE/CRbcdSKIf6kUGGAyODXU2GDLv4HvMn2/zjbb5x1tokayUJKDCaIKEE
IYOoEPZ0M+7sYvy2k2FLR8PGDoYVX0Uv/CJ6DsYR5NGi9yNJHDEJ1UL2mxFZ
b8C0TX89Iu01uEh+NWI8Z0LCS7BN05gX2ZmVSa9Ao8J4lBAUESmIBXJzHMIB
7gM3QDxkviU3S0uyQYIDLVh0/XMTmmEgcJCWUXj52bheuoDiaShcJrwWmfOx
YXY708pulk19rLsG2g4Ot/80xnEmBabDtQJPRXFMxQxobaqcH0cEQ/WKZrVr
EQsbm7MkwzL1Qip4NJvN4s3tIud/CC+pCtUCwUJ1prUmWykYtJhAhAF+HSvz
iTbi/mxGG994s59u9qKEAyMJiAc78IHAoTBYOTjpi9Sa7wiHoJuKBIXypggE
ERQaZAjhD142hFrinZKS0heNXDywF3OX1ng4iJpB2RHtT7PRNde+ZHhHkVCC
eA02SJeNsUpAONHfhCUJqFHu6mLc3tmw9RvDpg6G9e0Nq9tGL24FmoGEElPe
hylMsJALQUTEhDcjMl+PSEcmpLwKH0EqvByR+BJi4UXYKD7+Bfg4+kV4NBEk
BMQIhAZEQiQjFsgd4uRRQolkhEMa50OaUjYMebYp+L+Ze3GLSEoGmodsoyYD
nEnR429N41+OzPoguqSNcXlX89b+1r1DbIfj7acSHefT4G1/Y4qnsiSmcnZs
1fy4qsUgGGpWN/dtaOEVkww0/SgspJJ+wleHGud+wBOPyZh1zLLWTLTVTrJD
axP9212CeT/KhMk4lzGj6KXBQhZO+Qlw4cMTamqSLTVjzbXjzCo4sBk6AQCC
cLBz5eAQ4SDPZUowpATzsGQQ4aBSGqFUxKMMh/rbo/NKQllIOIQmA1suIe4U
PQEEgz/D7ku3+dJsvlRbLS67rh2P77okGQiibDjWD6oS33UHOGz7xrC5o2HD
14a17aJXtY1e8mX0vM+iZn4SVfwBTGEZC29EELWQ+mpE8qusgjCWYuFFQAHF
wsjn4SM9s3IU3idCQkIE8cRXYO6DqEDxwEQF8AECCqlZmgwY+ixs3TBU4AP9
TyGg4LKB7uEgkqHLX5oMeyEi7d3oqa2MpZ2ADPuH24+OcZwd57icAe/tW9Ni
qmbFVs+LrV4EicealVwwbG4hJxmWxMAxDZhkAO09WQ4ltrSLnINkINO5Oh1z
CznY10TUwlQH607kKQWJCQFcQwEygIqBTKs/3VKbChCoHGuuSjBVJ5prkigc
LP4URUYImrGzbfRMTCYb8plsYAOADzIN1HBADyMbQikNTUTUCQdRcojZyEdK
wD8iLyO8iXCQ+RAWC+wnLyYhs+x+gAOQoTbVVpMCG8BWj2NMqEq0ViZYy8dY
74y2XB9puTTM/PNgM5UNB3oa92BT9OYOhnXto4lgWNEmemnr6PmfR836JGra
h5GTsUZJ44gMDCJSaARBJvtLcoVx1AtN459vOvL5piOeazr8OXIBD5E//SOp
iiCIIAAhGEEsQNCBcGCKAuWExAfy6RguG4Y9x+DAXIADlQ20sYHepGT45k9N
Bj4bMf6tqMLPDAs6mDb2sXw/wn6CCIYU6G66gefT1cyLrVkYV7OkWS2JI9Zw
wbCpOUsyLI+V049Sj9NE2JCBDJv1PryG2hTodYQIItfmK7D7ihz+Yt65RNTC
FAwfyBTOw7/1NCIgTEi3EPenWXzk6eOhQlQ+xlQ+ylQxxlSZYK5COPjGs10y
QDbQBZugMWw852AHOGCyAh6SYwqn7PWAgwiEemAhWGOEA8KjLxsekZdRp4mv
k8FBK/3IfvI8lEA4KFINVDbUptkkPlfxhZYVCSSasNwebaGy4YJSNpCAgowh
moGQYXnr6NJW0Qu/iJr9SdT0jyKL3ockA3k0U4GFpokvNU14EebI6Beajnq+
qfTyhuEUHvF8BIMDXoATRLwIiCBYGPVSBFUFhBKEFWNfZRmJZKxcJAuygZAB
vSn5stQHY7WCYEEqXxLZ0J7vDkfJ0PefTRNfj8z72DCnnWltT8veobZTSY7L
6c7b2a47eNp17cK42iXNfMub+Ugcsb65fzOSQUwySOlH2uNEfiN4ON2W9lEz
30MyZFhraWIBIwj/NI6F6RhEkAlbgFggPMmysmmeCmKASILaJHM1Hk9zJ950
Z6SpLN5UPtpUOcZUk8iY4EfZ4E+1BNKsNKaQZUMOZ4I6pnCqPBgOYuGpPgmH
OgOQMEmJRxkOD/0FNMjUcOBtDGog5AolS3yTiF0NEhCobICT6cZZCRwq6Sps
JMPNeIVsOMJlw/ZO0N20rl30yq8gmljweRQkIT+KnIL1SvJQBo0jXokY93LT
sYgFwgRyH6TCcygVcObSV0vhQC7IR5VTRFBJMBrFA+VDksAHXGMF/+nw52HH
J3SQIhQO9ECrz3j5ksoGWrvs+PQThAw9/9501CuREz6IntHGuKKbeecg27EE
xy+ZrvJcd2UxdDv7Spv5lzfzr24u/3i3tGBJBmWPEyYZsF6JM7TkXfiv/ZlW
30SbbxKJIOwQQUxnK5u8tAFJEgzkT/wEPrWTLb5x5tqx5poEU9VoqArdGma8
Ndx4Z4SxPN5UOZo1lvjGmv1JZv84iz8Z4UDIkM6/wgS+ppvKBlXCYbIWGYqc
YmbSS4uYyhREo+GgSRjN7IQKDg99Yj70F9BQE18w+7EHnUIlYoEKBq9QeaQx
BZUNNam4dfx4K4EDIUNFInbuoWa4rtXYEMqmvh9Z8G5kzlswkQkZxr/cNOml
pomIBSIV4lEtSFgYitkA+medUoLPa/TnFT5CykUgHxJfjpSCC+h6eiUy/kXG
Fs6HpszxKxMmSOVLUTYQMnT9a5PhL0akvxtd/KVxSWfztv7Ww6Psl9KdVflu
emyl/Mbe3CKwvWXg25ZykmFFLEsyzMUNlqdhkiEHQomtX7NKrn+izT8JEwv0
kMoZQYIhH3ML2UwwkGlOdQJhQgWusLg51HhtiPHmMOOd4cYKbKesHWPyJZj9
iWb/WCRDkGxgLxhlAyeDIwwZxKypOqYICjS0A5AQNAjLBA1/1GTDr44MgRDK
QWMnWMSCWHmU2qT9WXYfjymobAA4cNkg2bURlivDzWcHmY+TgKKXEQMKw7Zv
IAlJHiUBxeJWUfM/g4CCjs99i9Urx6NgGINYAKnwLKgFygEJC4P+xY6dGvYc
+8iDAoUP57kIGmWMfomJBylXORplAwGILDlQnIzgcCBYkGRD+/+WydDpT00G
PxeR/FbU5M8NCzuaNvWxHhhhl9/SS7DXcWOLwLaWgZ1PBna0DGxrwZIMq5VJ
Bpp+JLMP/14XvwOCQepAoBGEtIDaSxOPRRqCoWasuTLBXDEaAgfy6Y2hxssD
DVcHGa4PMd7C02oIHKpGmWrHKLBA0xrsNU9g0QRci1go4LsICnCQnyUpB55/
aDAcpoSUBw8YDvfwqNxHJxHaIBNfthoOSAZZIdAkA4YSDA4TWCrSl8GKFCIN
yjHVAH+w4qEf8upwM4kpTg+ElicIKLpCS8OmDoY1bWGpdSknw4yPIoveUyx3
omSIRywM+3eTYZgVVGGBLnmg4+X84XMR1EUyjEDxwPgAHRGRUvIhEYubNI05
8gWer0AiER/4T5inXDb8jsgGaS96Qob+/2o69vXISZ8YpJd9KslxM9sVmB4T
WImVCCIVdj8JTi62tmBJhqAeJ3hjk2mYad2GggGUQAEuYZCaFmYIiUeVYMhE
LCSaK8eYykaZbo80kfCB3DnXz3Chv+ESgcNgeHmgHEaYKuNNNWMg3CBYCPDa
BCQts2wcC3YaR3ipmKSZaoEMIhA0wgoBDqHIIMJB/mqaI+8CDuGLFDNmzOjR
o8dIbjU1Nf9/e+f9FtW19fH7Q4DpnV7U5P0H3ndyU00v1yQ3ppjEWBKNvVcQ
sCCgCKgoYAUVxV5j74qKXezG3juKKEV6Oe8up8+ZYehT9vfZD88ET86csveH
tdZee+0m3yrXGbHASgyHdB4Q2DQnlgwsHCyqvUGzYbq+fBpciF0KqzTAUAP4
PXAo8mN0zydqn07Q3o2EkxQXRqpPDVHBGYq+kAzbeihwqGF1F/mKzvKMTrJ5
P8hS/0sPdkwGgIUJn9EN/JKHBc+ITzzDP/Ec+ykXmWT4IKPbl/T6CG7go8Y6
F5gP4ABADDwNOomZFY1FkyCxX9In7yE0Gwa+68F/Aqt7q3fDUIP+Fgo1VGX6
UTuRzXC2LXWuLZWDXAkcZLBYSAW9g0w4X2lm0pwgFjJRYAEWW2PKp6zkGQyL
OIPBjKwFYCq8nqQpilEXIPPgfqjyQZjyUbgSwMGM1l8AEwKToWKKFhxPj0cU
XhBjgYkwmNm8WV79QGs+hQAOdpgNtoBgw8yoKyJhp9lQVFQUFxd3/fp19jdN
vlWuU5OBYq6fA4IVnwKTgXuhXGUnaDYghwKRAa2reh2vK4rTFU6GcABkyJuo
fRYF86XvRGiuhkKf4uQQVXZ/5Z7eEA6b/lCs76ZY00W+srN82a/yBT/JZn8v
m/ktN9iBJnzqOQ418Bl/AH/KIxEWxnwM+EAvfJjARCbp5KUvZLjhKCUc+8KG
nQvMBzOKRQj5AOMbkxg4ACBgswFPXw54x2PQux7DUaghtZNyWQ8u1JCb7F2y
2JfahKo7XmwH4XAKkCGEOhxMHQii9gVyQYYNTJAhA66iOopKv9LbRqxkSrGt
5lVNwTOVeN00z2DAWCiMUb+Kgli4NUp5Z7TyHoID+wzBPxVHw/hD+RSIhepp
cE4Txh5n8bCA3zUmAwMH7qVzloO3tYCDbZ+CDwT7sWDjYO6E9fcpABwAAdi1
k027Va4LYEHsVkiEInlAmEuvyKbhQBeRpuFQMV1fNk1fkojIMAWSAZdwyYuG
ZABmAw44XB4Nl1YBn+JgP+XuXrDrboAOhRw4FMt/Az6FLO1HaDZM6wDH4+Qv
PWO+8MTfHgEhAD8DJoAGDYaPIRkgHJDZwM9jZPgAyTDxSzoIKd06yHCoQfDL
r3HzmszMlgIOsGYDJgMwG9hQQ0Z31aYBmkOhuosxhgdJ3gULfWvX+lPZaJry
jJUgAw4/4iADP3NgGSoOz8OCoCYbNhjSOYOhbDKclCyMVr+MUueN5/warEfA
p4hU5aGqUMXR9NxERQJczV2VpKtO1teyM5V8MjAOBf2lktGGOuHAcytYINgz
3uuEA58wkg6InfMU5eXlKSkp2dnZVFNvleu8ZBC5YBJwECQ7CRwKfvloDIfa
FDrxCcJhKoRDcbyuMA6SAS+9xA4FWmZFBxxOD1MdHag60Fe56y/oWa/vKl/9
u3zFb/LMX+QZP8vmdZQlf8eRIeozz3GICWM+gj8BEAAlMBbCPvIM/cgTzzAC
R0O0CMKMlkUAOIAPwDbgWge6xTHNjCY3YfsPrwnhMOx9gdkwEJkN4SjUkN5F
ua6vZt9I3dkJhtvTTHlpPhWr/OmtbE+34YIM/IVU/ByndOMRtCcdtApWS2MB
z1TSjz2NzmsqB9ZCDJx9eDlBnTcOYuHKMMW14YobI+BTvQ8dCkgGtl4cVmUi
MBhwnqSByWHgsMC9d3ZtPs+nsG02sHDgf509AQd7yGALCMJWp9lQUFDw6tUr
8KG4uDgsLIxq6q1ynY4MNsIyfDgw3U861CAu/jYb7b2I4AA3up2uL0U+RfEU
Gg7AoQCH5UZpn4wHZoPmXqTmepj64gh1zhDVkQGq/X2UO3rCbgzMBuBQLP1V
vriTDPkUXjO+geMx9gvPiZ95jgfuAxr+oe3hz7CPOCyMbg9/4j0r4ZLJzwUN
38tE5FAkfCu3bPEoYZJNpZ6CVmwJ+UDnVIz+0HPkBx4is2H0R16Tv4FZDSt7
qXcN054cq7+WYHwy16d4uR+1DTkUZwAZQqgjwdTBIGp/IB1kgOFHX7h0eqU3
l368wpuu3G6JBTbwiFKbzFZ0aYji8lAFgAP4fHu0EpMB/1NBtOb1ZE15AsyL
hidMFpOBG3d4VgIHpdl6gJZYsD2DKfx9veYprEUk7MeICA6W3f769eu4kEJe
Xl58fDzV1Fvlsk56I8/T3LIdp+Ufhj/wLQcxHIRk4CpDMinTaBdsCIfXsJCL
DleYz4+R2LGuTrE+RfTnnhM+9RwL3IePaM8CDNLQ9jQWRoH2IaSEGRVgweup
6SbkQ+J39EwlvyUyzYwqvcBasv+Vsys6mUbDAXwLNhvA5/7/hvvfDUMLKFJ+
Viztodo6WHskXH8pznhvlvfLTN/qjQEcGURBhs0oyAAgAGiA66islMaCIPDI
zlSi4rHF0TCumD8eTkCA/zw/WH4R7V11FdgMI5V3Q+kgw6soNXA3yuO1MLYA
U5v0eKaSJQM99NgIA5sZKww/Iix4c1jgwUEEBEsy0HBYYi8c+EBosAMCujG/
24v6/6pVqxISEmbMmHH16lX8mybcKtfBpyztBILof8EfaDjYYTaI4AB9iiQY
cBANcwwHkeVwaaT69FDoVmT1Ve5EbsU62nKQAZ+CHs4oOzrqU+hQACcirD09
KTDyQwgEgAXwYQT6AH4Z8YnX2M8kGutcYE1HaU5wsTavmVGJ6QWwOr1yzk9w
Q0y86Dv+P7jBM4xHkU9c0aXfvz2w2TDuC6/pPygWdVNt7K85GKo7E2u4mWx6
luFbtsEf0AA+HEwGNsjAz3FiqyHxsWBpMGQyM5XpBjCia9Fet68mqF+MUz2L
hFg4M1B+dhAkA8DC7VE0E/InqItjNOVx2qpEXfVUXQ1KeqQQGdgSEGY0IUJ7
E2kCU0HkQcAjhVgQAcFWwIElgzA+KRrv1oDQMDhYRhtabLQ6JhYaAATR/44/
WIWDBRmYsrHCbeyA5ZBIWw44Gonh8AzB4dE4zf1IzY0w9T+j1GeHqY4PwgFJ
OuVpNYxGyoBbkf4jt5xq/CfAofAY095j9Ic0HEZ84AGwAMnwAWyjWTh8ipoQ
DmYUYwQEmNGR/pYZ3yuSYJPjxpJheVfV0i5oF5ufFSkd5dO+ZfmA4pzItenN
MxvGoFoNab8r1/ZR7xmpPTHRcCXJ9GiBT+FaP2oXcihOIm+CDTLwc5zQ6mZm
+ycxFmgyLOXNVM5itsZGgYXcSNXjcNWp/vKcAfILgyEW8K3ljVcXRWvKJ2sr
p8CsSBEZ6NGXitdrGwRkSBcygfUgkMGA4cCNX+vRhrrhYJFTbeeQr/Owf/Ek
Gg4tM2AdDQuNBILoVPiDPXAQvNlUA205zKTnMUUxh5cMHJ5OoOFwc4zmMoLD
icFwKnNvb8W2Hijs0AUGJJd0ki38STabyXAY+7FH+EceoR96AH8f/2bY+x7D
P/AEbdj7EBFmVLQtgkmC4tpndBwyAW1wjxt72TM7KnADn9N/VS7rqlrfQ7X2
T9XyrrBqfVonxawf5DO+gyvBzWhtV8wXXqxDAcyGke09J30jm/2rcsVf6u3D
tIfH6y9MNd5J83mxyq9yewBHhgOB1O4Aars/tcWPDTLAf11rEwvsmkpgMMzW
16C6CsBBeD4OhhYfhauOodDlWWZ37Hthqtyx6pJYGgtVCdrqRF3NVJjxyL0m
eqEE7UrAV8knwwJhvfEMzmYQAMHCp6gXHLizWVmZVV84SNJANBzcigxNCATR
afEHa3Dg3qyF5SCAw3Q6yaEYJTkUiGcrNA/Gam6N0VwZpT43XHVysOpwf+U+
Jia5DiU5LP0FehZzv6fhEPGxB3AoRn3gMfx9Gg5D3/MAfBj6vocIDvwG4ICj
DVPgBvewLhwsDcc0fJ6UH2gy8FkHELGymzKzs3LBLwpclzKxg1fcV16TmSQH
AIeh73tGfSWb+ZMi80/VpsGarEhdTrzx+lzvp8t9S7agjSROhVBHgyAZ9iAy
sEGGZUy5NlF4QWQw4MDjXEP1DF15PETr87GqJxGqh2OUh3vLjvcV5I5ilQEs
xEEsACZwbwo4ESwT6DQG+lVyTBAZDPwNUnGcgbEc7IGDJRnMaKrC8vfW0iHq
hIM188B2r25WtS4ZmgkIoq/AH+gnn2YSTGnZcCtmGXgBSQ4OOAOqgFlslTdR
m4vg8HCs5jZeWDFcdQrAYYByfx/lzp7MbCbMgJIt/lk2v6MXmwEFHIoRiAxD
3qN/4gaMBzPa6nrMJ3CXGREczCjfCW9wP+sncWNvbWkX1boeqm191LuHcIHT
Nd2Vy35XLvoVHpb8X9n8n+TLf1fgZGlgNkR+7jWto3xhV9W6AZpdY3TH4gz/
zDI9yPQt2Ohfsx85FIAMBwOpvYgMTJCBw4I1g4FdUzkPPExdOVpA/YzBAvh8
uA9tMDwfr86foH41UVMUoymZBA+rimcSHZP0YibMNojsBDM/F3qhJRBMLBas
ksG+SUwJn8ImSayBwozSHe0EgmSvbj61FhlaK5BCl5lNM9oVc5CEQyKXHsnC
AXgWln/ybCjlO6/Er+kZimEIC4NRovKgd2F2wVD0m1HMPKagMWZD/Ddwp9o5
P0s3cEBmFyVwJbYCMgzWZo3W7R+p3T2YzhFah/bchHtmdZKvRgvBsNkQ9onX
lO/k8zorV/RVbx2tPRRrOJdsup3h83y9X/leRIZjDBl20HWcajiDQQILAoNh
vqEqRV+GUprzxsHAAj+58Umk+tk4dd4E9csoTWG0Bm9RgYWdCBhyTLbGBMZU
YPIWuCFsEWTg2mK74MB/a3UEHOokA2r8AII1f6FeXbqZ1MJkaAEjwdr3sp9Z
y6EOOMyWgEMFHw5TBAu0YdgBxSTvhGuuhaovjFDlDFEdHaDMYvKg/u4mXwvz
oGSZv9AByWn/oeEw5F0PQIZB7zBLIN+FbgWGQ5gFHHAcMq6DbPp/5bN+VMzr
BHfKFjWWDFt6AzJoABmOjNNnR+izRmn3DuEGHTAYNiBK9EVmw4gPPWM6yFJ/
USzppf57pHbfRP2pJOPVBd6P1/gV7wqgyXAokNqHyAC8iS1od4m1Nv0IPFOZ
bqxK1ZdN0xWjIvOPwlX3GSw8CFc9jlDnjlVDgyFKUzCRvryyOG1FvK4qEeUt
YIMhhXEf5vGyHHlk4IawdPhRgAV2YsKeGUx7o5HWj6yXv1Cv/txMaplx2lpA
sLwG/LluOMyxgANKgjILRU9YIMvhRbT2OfIsniDP4m4EmrMYqT47VHV8kPJQ
P3ogbPlDDhCx5nf58l9lorMBMgxEzcyYEHgeMwzmSXrBba9Rw0nUsV/DcpHJ
P+C97ZSiBg5Y0kW5BpFh1yBN1ijd4bH6k7HG4xMNhyP1B0fr9g3j+LB3oLq3
+Q1gNgx+z2PCl7KknxQLeqjWDNPsGK87MtV4cb73vVW+L7ejUMNxhgxZAdQe
9JvNvnCnOWsJDDjwuMBYNVtfOh0YWggLY1T3UJbCvTAVxEKkOhdYC+O5/Mbi
ydrXU7SlCbryqbrK6bpqdhoCmwrzhfnPFumO3CanAjJIYMESDpJAsG0M2IZD
0wKB35kbf5JW/ApHAIJIDYMDK2g5zKAth9JEfUmCDhgPuC4cPiA/Woudiyco
LAnsB8CHK6PUF4arULYkHBF7eil29FBs7i5fB2cuZEs6cYgAWICbQfybnbOA
SQ6jWTjg9gmu5ABXWSZ9D/e3WvCrUtTMaJftNX+oNiMy7EdkOBFrPDfVdHqK
8WS04eg4/aEweM07+qv3D9cci9DhWk8Rn3kldJTP/UO5bLBmc6TuQLzhzBzT
zeW+uVv8Sw9Ch6L6MHIrstHP3f7UNj+4i/16BAe+H7GC9iNqFxor5xhKZwAT
C/oRTyJoLAA9Rh4Eh9lJ2tdx2pJ4bVmirnyariJJXzlTX51iqJllqEVhRjOO
CzEVurhRjPPZhKlNZtaVEJHBwncQnKr+0UhLMjSJv2BnN24mNdP5HRAIfNkJ
B6638CyH2hSmrizot7gG1FR9WYKuJF4HV20jPhTEal/GaF/gtZloTvN2uPp6
qPryKPXFESpgQoBjDvdXZvVR7OqpACbEhq7yVZ1pOAAm4NafB4eRAA4fQTiE
feyFGzYbYGLDd3CGAhgJi37j2kLUwAGrARl6qXcN1OwfqcuO1J+IMZxJNP2T
6n0hyXQ2wXgqFppAB0O1B0K1J6L0F+INwGwI/dgz9jt5cldlxgD1+jHaPZP1
J2aZincGlO4NqDgYWH0kiDoZRJ3AW9ch42GnP7XVD+5lv96Hthl4gcfaDGPl
XEPpTH1hgjYfrYTCOY2PIjggFMZoMBNK43XliTq4VU2SvnqmHhhptdh3mMO8
FP5cEp6GEDHBIvwoJoMVIIiZYDMmaQ0OzWQe2O7DTnF+BwcCXzbgwHUVyZgD
w4daVOylZoa+arq+kikgWRavK0XBh+JJusJY7SvEh1yU83AvQnNrjPpaKPAv
VOeHi9cS8tUfYYElA56qAHAIRcsrQj/2Ag0vr4j5CtaXntkRbmm3qLNy8e+o
dVZmoIbJsAmQYYBm/wgtS4aLKd7X03yvzva5NNP7XCK8r+yxulOTDJeSTH3f
fgN814QOsmmdFWl9VatGawu2BRTvCijdH1hxKKj6WBB1Kpg6jWq5HEdwOBBA
7fWndvjB3AYAh3U+NBmQwVC72FQx31CSoi9M1ObH0lg42Y+enXwRpSlgVk2W
x2PHQQ8ch5pkfS0bZqRLLvBeCq7nKYw6iplgmQvNw4I1FNQBByEi+HBgbQOq
BYeAU5DBiYDAlwgOXIfhWw5Cz8KM06fFcDDUgL9x0+ldbCoT9RUJEA4lcdCE
KJwkXUby0gjVuWGQDycGKY/0Vx7qq9jfW7GzJ3QxIBzehpVV2JpsNBzaM3CA
9gPKtf5SRschkUOR2QW2Jbj9Dsmwik+GCP3xaMOZBNPFZO+r833vZvrdWuh7
bS6ccwT2Q06C8XKq952FPoPe9Yj42uv5ev/8zQEF2wOK9wSWZgVVHA6qPh5c
ezqEOodWZOcEA7OBOorgkBUAfYrtflziE6rDULPEVJFmLEnVF0zTvZikyUVh
hHOD4N3lRWleRmsAOV9P1pazMUZ26oGHBe6lsDMRHBl41oIFEwS50MwcpSQQ
6g0H5siWtBBsd2BHO7mTAoEv9uJRZ7NwK6T4YEbOBb0wk3EusPFQjfhQZbHU
4vVkXdEk3cto7XMcfIjU3AlX3wiFwYeLyHjIGaI8OUh5bIASuBgH+yqyeuNp
xDfw1vb4JEPfhxmSo9pDtwI3bDZM+holNvygmN9JAQyGpV1VbINk6K7a+Jd6
Z3/N/uHa7HD98YmGM/GmizMBGXxuL/F7tNr//jK/24vg/MKZGaYr833uZfo+
Xev//G///K0BBTsDi/cFlh4MKj8aXHUyuPZsCHWpDbx98OF0MHUyGM5THEHR
BuBT7EJwYHKfwC8rFhhLZhsKk3Qv4rS5qBLLZbR28mWstnCytniKrhQ5DsAp
QzWf8R4TBmyVcaOY50eIVlhLYEFqJoI7lfU4g/1wsJ2gSMjg7EDgS8KtqIsP
1uDAdsIqZDxUoTKzFcBOBqMgTgf4UIjiDygzSoNzqgEiboahUTNSdRFZEaeH
qDAlzHAm8Y0+5jdYtwLAYQSGQ3scdkDrN7+SxX8DN56Y87Ni4W8wI3p5N66B
A0RkOB1vhGSY53Nrsd+DVf7PNwU+WQunI28A+2GR74NVfs83BeRvCyzYHVi8
P6gkO7j8WHBVTkjtuTbU5bbwxi+2AWYDdSYEuhXHodlAhyL3IjhsgblP4D+r
M0zl8wzFM/UvE7TPY6DLcHMkvCM841AxVQcoWkunLcFNhzETBECwwgTWWjDz
ZiJEWdB8LHNJTdbnJuokg/3mQUuOixYgg50j3QWMBElZwIFnPFjhg5nJpuZ3
QmYvPNp4qEab54LfV4KxkKAri9eVMYjAUYiX0Rwl8Bluhamvj1ZDSgynfY0+
CA5mlOFAwwHNY+IkKDOs+CTDC6xSf1Sk/wK9iZXdVWwDB/wNyNBPs2+YNnuM
7niU4fQU44UZ3lfn+tzK8Lu/0j93Y+CrnUF5m+HovrHU7+H6gPwdgQV7gooO
BJccDi4/EVJ1uk3thTbUVYSFy22B2UCdbwPNhhzGbDgMc5/gv26HkxTwOSw1
VaYby1L1RciPeMpMR0IgTNfTayQBE5JpJnCjGC9/qIsJbGDBLJya5NFAIoGh
vnCwsaDJzu7U3GrW8KY9N+uqQOCrDjhY8EHw1w0WoBZ5FtC5YIMPZrRdJow/
JEJElCNElCBEFDGBSkwJs5R6m9/oa+YyHPA85sj29HrtsZ95xeDEho4wsSGj
s3JFN9XqP+jGkWGo9hCPDFcYMjz5OzB/R9DrLBhUfLIp8PGWwFd7g4oOBpcc
DSk/FVJ1tk3tpbbUtXbwTq+3A3yg/mlLXUBmw+kQSIajdHoDPGArdCXgzWaY
KubCacqCKeCmaCxAIGAmzKSZwD1DLtho5KYmbTDBotwrfR6JZZWm+pLBngVN
dval5laTfJFk/XnbZ3YHIPBVJxwEnZBfRpKZv2D5gIOTcJftmTQiwJE4BAEQ
UY0cDYyI0ikS8ckXE7V5UdCWeDwOBiV6/R9dYmXgOx40HNBUBZ7KNOPEhg6y
pO/ls1EccmlX1Zo/4RJL3MABO/oiMoTpjk8wnI4zXkjyvjLH59Yiv/sr/J9s
CMjbHlSEyAB+Pt0ZVHAouOR4SHlOm6rzbWsBB24gLNx+E3ygrrWFZgN2KE4h
gyE7kNpPRyDxxbMGw+tE7Ss0H3FxiIIusYKYwD1DJqpAM2EOZyeYzUwBljST
tUijNBOsYKFOODhdgmJ9vyU3Nzc5ORl/LioqioyMtFF/XvLM7gYEviThwHU/
vuUgNB5EmVGiyU1MCXrgAP96uiBEWZ6gK8W5EChdqhAtI8JWBEbEswkQDr1Z
OKAlFcM/4Mq8jP/ci15g9YNi/i+KJb8rV3VXre+hxg0csL2vet8Q7aFQ3bHx
htOTARlMgAw3F/myZCjYH1x+FEYXC4+EFB1rU36mbeWFtjVX2lE334R3d+8t
6s6b1E1AhnbQZjjXhsoJoY4HQz8iC627RJnSlojD2ttDkOopAAKfCXz3gY0x
pouTlyRpYJY2GLwtGx8ODfYX6tWXmk8NJgOWjfrz/DO7MxD44sOB7oH8mKQI
Djw+SC27MLCI4BvPZmxaI0QAX6MS50ol6kpRulTJFN1rtMlF0SQtdDRQ0DI/
WvvX/0IyDPg3XG81hIEDXqwd+ZlX9FeyBLjASg4TG35TLu8GV1n+3VO9oaeI
DPocQIbppiuzfW4u9L233P/J+oC8bUEF+4JLj0Ay1F5s9/p028pL7WqutgN2
ArzUR/9D3X8L2gzAmwAGw/k20I84EUwdCaIznXbRmU7g4Oqlpop0Y2mqvjhR
W4ACj9m9ZDQNUumQAmMkGKzHE0zsIggREKRnJ+tDBj4QqIb6C/XtS80n+7/C
kgw26s8362NxXvHhIDFhYQURHBwsKshxfyvZ0QEcbdBmGmpRuBLnSlVOxelS
OmBFlKGMCOBr4I13i2FEgoHDOwI4YLMh6gsZu8AqHSU2rP4Dzldu7AXJsA2Q
YbD20GjdsXH6nEnG89NMV2b53Fzge2+Z/2OGDCVHQqpOwzBjzbU3a66/Sd15
i3r8P/BSH75F3UUGw9W21CXGYDgWTGXzDIYt0GCoWeVdmWEqm2t4PUNXiNZH
nOgnF1sI/BijJBCEAUYJIEiRwSLdUQILLZ9+4OBksFF/ngDBmvhPRhB2sIkI
s9ksEaK0tB8wHPBsXTLdanFEgk2KQKzAZ6hArCiPpyMS/d72wAEHdjEm+Dnu
cy/+AqvFneEMBTAYNveGDZr0gzXSZFgX8HxrYMHe4JLDIZU5aAICYOHuW9RD
hIXHQoPhQhs4X8kGHpkIA7UZBR6XmsrTYWpTEVpnfWagXNpl4C9/sDLjwAeC
BBkWSTcaDkIytG4+koPAZ/fu3Xfv3hWRwXb9eQIHa+J3oX/x60HxKTG/jhCl
Df+CsyJSeC1ZzAr+OdkcKly2cfB7sAoT/k3kp17RX8riv5HNQAuscGLD2j/h
oomtfRAZBmkOjtIdG6vPiTWen2q6nOpzM9333lK/x2sDnm8JfLUnuCQ7pPIU
IsONNwENaCwAg+HeW9StN+kIA9+VOICqNKBFE9CPWOVdkWEqnWsonqG7j/Ka
dv3hZTUtgc5jNPGLKnCPTirYWCcW+OnQLbCgqV4dqdVPfuTIkfDwcBEZ6qw/
T+BgQ3XDQRSixH3eWoVq3ioM2q7mGRJ8d4M7J6IE/lCLvA8zSnKAAYd3oE8x
jIEDzpTGiQ1pTBzy77/U2/siMgzUHBypOxrJksH7Bo8MRXuCK7JDqnLa1vzT
jvtqgIX7yJW40Y66gqYkzvKmJNAqbOBKgCNr1vlULjOVIYPhIdrAOqunzGpO
AuM1SNBAcgUEHw42sdDq6cqScgQyAF29ejU1NVX0yzrrzzvIM3RMieHA8IHr
1RZeBksJiSwpPiW4dErhGgELVtDJw4xdYUbpkWw0EpeGY5Xygxw4FDgOub4H
rM+wsx8crTQZYgznE02XU7xvpPnez/R7viageHNgyZ5gwThF3gSNBRuuxC64
BBsaM6u8yxdDg+Exqsx2pI/cBhDqYIIUFsRLqp0BCHw13/XU68w1NTUt8C1u
JcsJC9oYFsUfeHzg4GA9XYofjjAzSVNiv2OWlAOCPnMBh/c88CRF7Feyqd/S
U4SLoEMB6zNs6sWQYYT2aIT+VLThfILperL3gzTfvEy/V2sC8PGlh0LKT7Sp
OgcnK814phJj4SZKY7gknKxkXAlwZPU6nwpkMDydrruOdqzmFj1ZAQKfA2I4
SAYbRUuqFzmWv2CPmunaWuyWHfnZtq6sWQ7ScGC8DAk4CCMSVuc1xN6HAbPC
zDogswy9/+8NOuDwLu1TRH3hFd9BNvN7+VymTuyaP+EMxTYUagBkOBGhvxBt
uJFgepjMLTUq2BhQtCOoZH9w2ZGQilNtqi+gaANgAoADwMJ1q64EOKxmoy8y
GIzPkvU3URb09m5eGAhmlJBQh3nAh4N1JvDDCA5uHtiQk06Mtsp3OZck4CDm
gxgR3J9OERAsbAmWEmLXw4IVZma+wywMOIxAZsPkr72mfyeb/aN8wS+KpV3o
0kk7UKjh2HDtxXAupJk71+f5It8Xy/xerfUv3BxYvCuo9EBw+bGQyjNtav5B
cLjzJp0RzXcleGkMrMGQN8dwG2Uv7O0hE5sHlpVVpNwHs+TUpPP4C/bI2c0G
ioQdrEsaDtKIMInikyJKSBoSEplUVrIuzcj7AD/7vk0HHPAkZtTnXonfyFI6
ytN+VizprFzVXbmxp6BKzJ0J+gexhkdTTU9SvJ/N98lb7Ju/0q9gg3/R1sDX
e4LKDgVXnAipOodWWwOD4SaakriE0qFz0OLKw4G4Wgs2GCpXeeenGe/Gac+P
FGxvwfcgbDNBegJiofP5C/bI2c2G1vpGp5AtOKRLB9nMZrO0x2ENDnY6IMyH
fm+/gXe6N8M97zwnfeU14zvZ3B/lGb8qVnRVrv9Tta23eu8A+Df9zGjd9bH6
e9GGh3GGx1ONT2d5P0/3eZHp+3K1X+HGgOIdgSX7g8oPB1eeCqnBPsUtZrKS
dSWYNAbwr1XrfF5lmO5P1V0coxIBQVDjvS4m8OHgGuaBDTX57bTK83Gxl9JU
sgEHyz+a3J9Om0EJydClgC3WMWJmMhxwYuQEYDZ0kM3uKFvQSb7sd8XaP5Sb
/1Lt7qc+OAjC4XK47k6U/v4kw8ME45PpxmcpprwFPvnLfIFPUbQ54PWuwLID
QRXHgqvOhNReYlZenw0RZURDP2Kjb+FS08OZ+n/Gqm17DWI4SDHB5YHAV9Pe
mkvmaTivRHCwBgQxHOwITQgSJKy7HtbgAM2Gj2mzIe0n+ZLfFKu7KTf2UO3o
o84aCIfw+VDtrXH6u9H6B3HApzA+nWl6Ntv0Is375VLfgvX+xVsDSvYElh8K
qjwRXI19iqttaYOBcSWgH7HVr3iV9+NZ+itob4id3b1sRxLMUjFGl/QX7JFr
kIEiYQcrYp+JbSBIw0EqRsF3Pcz8NAmbjT0SBxxos+Ezz4QOXrM6yjJ+ka/o
Avea2dZLtbe/OhvtUXUtApoN96DZYHicZMxNNT2f552/wPvVEp+itX6vtwWU
7gusOBxUBX0KBIfzIbjqI3YlwG9K1vk8nW+4Nkl7criyjkiCRYzRrcwDa2rC
W271p9fqF+CAsjPmYBsO9jkgthoLk34ADshsCP/YM/ZL2mxY1lmxtrtyS0/l
7r6qg8hsuBSmvTVedzdGfx+ZDU9mGoHZkAfMhgyfgmU+xat9Szb7l+0NrDwa
VH0a1YO9gGclAqmDEAtlm3yfLTTeSNDlhDLhBTsCjAQIIjXV7TvCY3SEa3A0
8eFgJx/MQjXExhDaG/yz9X+bru4CzYb/0GbD6q6KjX8qd/RWZQ1ABZxHaW9G
6m5Ds0H/AJkNT6HZYHqx0PtVpk/hCt/Xa31LN/pV7Aqoyg6qwTXkgTeB6j1W
bPPLyzTdYraqtxpmdG9/wR65ktngINfgaOI/E/snLBrrgFgYG2YmswjvbxX+
ETQbkr6Vzf9RtqyzfEN3xba/lHv7qQ4PgnC4OkZ7c7zuDjAbphgeTjM8STbm
IrMhP8MbmA1FwGzY4Fe2xa9yp381rvF4gq4E+5AJg1gNMxLzwG65ktlAOcxl
OJT4nd/OCYsGw8EGW1g44J1zx3/qGQ/Mhu9lGZ3ka7oqtvRQ7u6jOojMhouj
tTfG6m5F6e5O0t9PMDyCZoPxGTIbXgKzYaVP8Trf0k1+5dv8q3b712QFCJhm
xXcgQGiAmuQROc5zJi9dUvWdsLDfeLDf2GDhADQGmA1feCZ96wXNht/kf/+h
2NlLmdVfdXQwhMO1cGg23I7R3ZuifzDN8DjZ+HSO8Xm6KX+x9ytkNrze4Fu2
ha7hdjVOu+tPmSUWiL/QeDX+cTnaA3e063EENeWEhZAt9T0h/h+h2fC1V+r3
skWd5Ku7KLb2VO7rqzw8EEYOL4dpro/V3pqouzNZfz9R/zDJ8CTVmDvPlLfQ
9DLTuwCZDeCw20n6Q33kIiYQ86AJ5XpkoBzyklpdjZ+wsGYeNIA2+DzTv2HM
hu6K3b2Uh/qrTgyhzYYb47XAbLiLzIZHyQZgNjxLN71gNn88MUSZ8aMXxoLZ
DRIUW0uNfIyO+RYc86paVw2Dgz3+Qn29D/5/LvpZtrqLfGsPRVZf5bFB0Gy4
gsyGm9Bs0N0DZsMMw+NZxlyUN3V2tHrVrzI+DYi/0KxqzCN12NdBuoql7ISD
Wagm9D6smSIbuit29VIeHqDKGYomKSI01ydob8VCs+E+U01uUze52ZnXOzup
XBIOlGNfW6uovrMV9TIJ7Dmb5AnxkcBsODGYjjZcG6u9MVF7ezJMUdj9F13Y
gSJAaHG5Khkoh7+8lld9Zysa4C/Uebw1YmD9M1p9JULD/ifxF1pXDX7sjv++
HP8KW1iOM1shav/iVa5jmdC6z4qIaugIcop3R/qYSALLIa0hY9mG91FfB4TM
Lzi+GvBGnOglOtGltoDEcGBbs/kLlhYCAYKzyLXJQDnb1Ta3hHBg6ipbIKJp
/QUy4eikqu9rcrrX6nQX3KySgoNltZZ62wPEX3BJ1eutOeMrJj2TLxEceEDg
g0JgS9gJBwIEF5PLmw1YTnrZzSF2zNID2VbJJkFtFuIvuJtc3mzAct4rbw7Z
8CysV3WjQUHMA/eR/W/WqfuAU198k6sBcCBAcEPZ+ZadvTM4+/U3reqEA/EX
iNyEDBSJSQolCQfiLxDxZc/bd5ke4jI30njx4UCAQCSpOnuCK3UVV7qXRgo/
CuIvENkQgYN7ijwKIttyKzJQJOzAiDwEojplu5O4ZBdyyZuql8gTILJHNvqJ
q3YhV70vO+Xmt09kp9yQDJRL31qdcud7J6qXrHUV1+5Cbht2cM+7JmqYJHuL
O3Qhd7hHkdzwlokaIwIHN5G73S9RI+W2ZKDc5jYpd7pToiaUZbdxn47kJmEH
d7hHouaQqOe4W0dy+ft1+Rskaj7xO48bdiTXvmXXvjuiZpWbk4Fy6bt24Vsj
agGx/cdtO5Krhh1c8qaIWlLsct3WvpDWlOvdvuvdEVELi5gNWC52+y52O0St
ImI2YLnSE3CleyFqRbmqu11fucxDcJkbIWp1kb6E5RqQdIFbIGp1kVKBlnL2
p+Hs10/UWiK1Q+uUUz8Zp754ohYWoUF95bwPynmvnKhlRGjQSDnpo3PGayZq
bhEaNLmc7kk63QUTNZ8IDZpVzvVgnetqiZpcxDxoSTnRQ3aiSyVqKhEatKKc
5bE7xUUSNV6EBg4lx38Ljn+FRA0WoYEjy8FfioNfHlF9RWjgRHLkd+TI10Zk
vwgNnFQO+9Yc86qI7BExD1xGDvgGHfCSiGyI0MBV5Wgv1NGuh8hShAZuIod6
vw51MUSsCA3cU47zxh3kMoiwCA2IKMcYlY5wDW4uYh4QWarVO0OrX4B7itCA
qE61Yt8g3bIlRWhAVF+1VlchXbS5RWhA1Ei1Such3bU5RGhA1ORq4b5Eum4T
itCAqFnVkl2LdONGipgHRC2pFutmpD83QIQGRK2olul4pG/bKUIDIodSc/dD
0s9tiNCAyJHVrN2S9HlLERoQOYuar5eS/o9FzAMiJ1UzdVp3HgiEBkQuoybv
w+42KAgNiFxVTdul3WGAEBoQuYmasIe76mAhNCByTzVVn3exgUNoQERENcW4
doFBRMwDIiJLNXI4OOloIjQgIqpTjRkdTjSyCA2IiOqrBo8XBx9lhAZERI1X
A4aPA444QgMioiZXfUeT44w+QgMiomZVvQZX645EYh4QEbWk7B9oLT8kCQ2I
iFpRdg69lhmehAZERA6lOkdi8w1VQgMiIkeW7YHZ5MOW0ICIyFlkY5w2yRAm
5gERkZPK2rBt8FgmNCAichmJRnEDkh8IDYiIXFL8QW3n5AWhARGRO4gd49YG
O6EBEZF7SnLgExoQERFRQtuAAIGoyfX/n26ddA==
   "], {{0, 0}, {350, 282}}, {0, 255},
   ColorFunction->RGBColor],
  ImageSize->{350, 282},
  PlotRange->{{0, 350}, {0, 282}}]], "Output",
 ImageSize->{354, 282},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->1858766502]
}, Open  ]],

Cell["\<\
Extract the terrain iso-surface at z=0.7. At these points, the velocities \
should be zero because of no-slip condition. Also extract the locations on \
the left boundary at z=0.7, at which the inlet velocity is specified. The \
velocity at left boundary points will be (Erf(0.7), 0):\
\>", "ExampleText",
 CellID->843986205],

Cell[BoxData[{
 RowBox[{
  RowBox[{"zi", " ", "=", " ", "0.7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sensor2DLocation1", " ", "=", " ", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Extract2DIsoSurfacePoints", "[", 
       RowBox[{"hills", ",", " ", "zi", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "ymin", ",", "ymax"}], "}"}], ",", "30"}], "]"}], 
      " ", ",", "1"}], "]"}]}], " ", ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sensor2DLocation2", " ", "=", " ", 
   RowBox[{"Thread", "[", 
    RowBox[{"{", 
     RowBox[{"xmin", ",", " ", 
      RowBox[{"N", "@", 
       RowBox[{"Range", "[", 
        RowBox[{"ymin", ",", "ymax", ",", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ymax", "-", "ymin"}], ")"}], "/", "40"}]}], "]"}]}]}], 
     "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"velInfo2D1", " ", "=", " ", 
   RowBox[{"0.", "*", "sensor2DLocation1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"velInfo2D2", " ", "=", " ", 
    RowBox[{"sensor2DLocation2", " ", "/.", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x_", ",", "y_"}], "}"}], "\[RuleDelayed]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"3", "*", 
         RowBox[{"uvel", "[", "zi", "]"}]}], ",", "0."}], "}"}]}]}]}], " ", 
   ";"}], " ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sensors2D", " ", "=", " ", 
   RowBox[{"Join", "[", 
    RowBox[{"sensor2DLocation1", ",", "sensor2DLocation2"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"velocity2D", " ", "=", " ", 
   RowBox[{"Join", "[", 
    RowBox[{"velInfo2D1", ",", " ", "velInfo2D2"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", " ", "=", " ", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"sensors2D", ",", " ", "velocity2D"}], "}"}], "]"}]}], 
  ";"}]}], "Input",
 CellLabel->"In[3]:=",
 CellID->748826621],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"sensor2DLocation1", ",", "sensor2DLocation2"}], "}"}], ",", " ", 
   
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Blue"}], "}"}]}], ",", " ", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", " ", 
   RowBox[{"Axes", "\[Rule]", "False"}], ",", " ", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"xmin", "-", "1"}], ",", "xmax"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"ymin", ",", "ymax"}], "}"}]}], "}"}]}], ",", " ", 
   RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->1482303985],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[1, 0, 0], PointSize[0.016666666666666666`], AbsoluteThickness[
     1.6], PointBox[CompressedData["
1:eJwB8QEO/iFib1JlAgAAAB4AAAACAAAAAELrUYHhIEBJIvPGkJAnwC/qeHcN
2yNA5H0DjVNFJ8Dsl+XzmFImQJTbHSIGkyXAyLY7nIufJ0BYqkn9F+IiwHOu
CG46kydA2m7IVqTIH8AqGoWfrlQmQC6YxnHKTxrANaitTsVRJEBHsRJIZtUV
wB+x6OdPzyFAs0gtya14EsAV1klNzk4fQJ8uwttikAzAZEuy2SCZHUCkZjgx
Eh4BwCx7HodDnR1ARUF+uMvY479O1sfqNbMcQF5Y2FRFx+s/2/JsY/tTGkAo
TEH3cgACQLIjAl8lPRZA78j7JEbRCkCVOc9F5t0QQHOWiiVpGhBAotjb1O/L
BUDII3f0Q9YQQGg5lmQmJfQ/XTgTN43IDkAEK6E2if+fP4HwIO/15QdA5Mo8
fhJw6r/vb6pzcxf8P/wi6LQVT/O/YZjXYWh30z8A4di0NaPwv0e2GSnkHvO/
+2JYSjYl2L9EGF+NFlkEwKEXjy+h8eU/kroUMNfZDMCGqeaWZfUAQFxm8aJD
yRDAi59CIfL0C0CPVbw7KlgTwLSW1dZkAxJARYszb7mzF8C2aKtjofwTQGIe
tfhEVh3AX90j17JUFUDFWvixDp8hwLT9RMhj8xdA9SpgdClWJMAI9Piv8z8c
QE7bdw2JaybAKRLicQ==
      "]]}, 
    {RGBColor[0, 0, 1], PointSize[0.016666666666666666`], AbsoluteThickness[
     1.6], PointBox[CompressedData["
1:eJxdzDsKgwAQBNAlVUoLCwsLIyJGRPz18Qw5QiB1jhiPlCOYYJW3MAyPgb08
XvfnKSKu3/z6uH47etn+PeMJj3jAdodb3OAaV7jEBc5xhlOc4DMO/HmzB/uN
feU/TnCKM5zjApe4wjVucIs73OMBj3jCM17WHU7MQvc=
      "]]}, {}}, {}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->350,
  Method->{},
  PlotRange->{{-16, 20}, {-20, 20}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 ImageSize->{354, 347},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->1103757188]
}, Open  ]],

Cell["\<\
From the above extracted velocity information, perform a 2D velocity \
interpolation. The flow should go around the terrain iso-surface due to \
incompressibility constraint:\
\>", "ExampleText",
 CellID->892375868],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", " ", "=", " ", 
   RowBox[{"DivergenceFreeInterpolation2D", "[", 
    RowBox[{"data", ",", "\"\<MQ\>\"", ",", "0.5"}], "]"}]}], ";"}]], "Input",\

 CellLabel->"In[5]:=",
 CellID->1004486316],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"StreamPlot", "[", 
     RowBox[{
      RowBox[{"sol", "[", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "ymin", ",", "ymax"}], "}"}], ",", " ", 
      RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ",", " ", 
    RowBox[{"ContourPlot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"hills", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "zi"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "ymin", ",", "ymax"}], "}"}], ",", " ", 
      RowBox[{"ContourStyle", "\[Rule]", "Black"}]}], "]"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{
         RowBox[{"Text", "[", "\"\<x\>\"", "]"}], ",", "Black", ",", "20"}], 
        "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{
         RowBox[{"Text", "[", "\"\<y\>\"", "]"}], ",", "Black", ",", "20"}], 
        "]"}]}], "}"}]}], ",", " ", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "16"}], "]"}]}], ",", " ", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"Style", "[", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{"StringForm", "[", 
         RowBox[{"\"\<2D velocity field at z = `1`\>\"", ",", "zi"}], "]"}], 
        "]"}], ",", " ", "Black", ",", "18"}], "]"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}], " ", "//", " ", 
  "Rasterize"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->486872208],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzsvQlQHOeZPq7YiWPn+OXYZG2Xs7G98W7txol2N7uudXlTW9GmskntXwq2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   "], {{0, 0}, {350, 403}}, {0, 255},
   ColorFunction->RGBColor],
  ImageSize->{350, 403},
  PlotRange->{{0, 350}, {0, 403}}]], "Output",
 ImageSize->{354, 403},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->753640225]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "See Also"
}], "SeeAlsoSection",
 WholeCellGroupOpener->True,
 CellID->1255426704],

Cell[TextData[{
 StyleBox[ButtonBox["RadialBasicFunction",
  BaseStyle->"Link",
  ButtonData->"paclet:WildfiresDoc/ref/RadialBasicFunction"],
  FontFamily->"Verdana"],
 " . ",
 StyleBox[ButtonBox["RBFInterpolation",
  BaseStyle->"Link",
  ButtonData->"paclet:WildfiresDoc/ref/RBFInterpolation"],
  FontFamily->"Verdana"],
 " . ",
 StyleBox[ButtonBox["DivergenceFreeInterpolation3D",
  BaseStyle->"Link",
  ButtonData->"paclet:WildfiresDoc/ref/DivergenceFreeInterpolation3D"],
  FontFamily->"Verdana"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "Related Guides"
}], "MoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->38303248],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Wildfires Simulation Package"]],
   "paclet:WildfiresDoc/guide/Fire-front Tracking"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->725284505]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"DivergenceFreeInterpolation2D - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "SymbolColor", "LinkTrails" -> 
  GridBox[{{
      RowBox[{
        ButtonBox[
        "Mathematica", ButtonData -> "paclet:WildfiresDoc/guide/WildfiresDoc",
          BaseStyle -> {"Link", "DockedLinkTrail"}]}]}}, ColumnAlignments -> 
    Left], "HasOptions" -> False, "ExampleCounter" -> 1, 
  "ExamplePageLinks" -> {}, "RootCaptions" -> "", 
  "Metadata" -> {
   "built" -> "{2014, 11, 8, 17, 52, 9.055629}", 
    "history" -> {"0.0", "", "", ""}, "context" -> "WildfiresDoc`", 
    "keywords" -> {}, "specialkeywords" -> {}, 
    "tutorialcollectionlinks" -> {}, "index" -> True, "label" -> 
    "Wildfires Doc Symbol", "language" -> "en", "paclet" -> "WildfiresDoc", 
    "status" -> "None", "summary" -> 
    "DivergenceFreeInterpolation2D[data, opts] performs divergence-free \
interpolation for 2D scattered data and returns a black-box function. The \
data must be of the form {{{x1,y1},{u1,v1}}, {x2,y2},{u2,v2}, \
{x3,y3},{u3,v3},...}. The resulting interpolant exactly satisfies the \
divergence-free condition, \[PartialD]f/\[PartialD]x + \[PartialD]f/\
\[PartialD]y=0. DivergenceFreeInterpolation2D[data, rbf, opts] performs \
divergence-free interpolation for 2D scattered data using the specified \
radial basic function rbf. The radial basic function can be a string \
specifying a name from the existing database or a function of the form \
Function[{e, r}, ...]. DivergenceFreeInterpolation2D[data, rbf, scales, opts] \
performs divergence-free interpolation of 2D scattered data using the \
specified radial basic function and it's corresponding scales. The scaling \
parameter can be a scalar or a vector. If it is a vector, then it should have \
the same length as data.", "synonyms" -> {}, "title" -> 
    "DivergenceFreeInterpolation2D", "titlemodifier" -> "", "windowtitle" -> 
    "DivergenceFreeInterpolation2D", "type" -> "Symbol", "uri" -> 
    "WildfiresDoc/ref/DivergenceFreeInterpolation2D"}, "SearchTextTranslated" -> 
  ""},
CellContext->"Global`",
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 29, \
2014)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> 
  "10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 29, 2014)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[15424, 486, 388, 15, 70, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->1691243387]},
 "RasterizedOutput"->{
  Cell[18998, 616, 42609, 707, 70, "Output",
   CellTags->"RasterizedOutput",
   CellID->739495163],
  Cell[64321, 1433, 42244, 701, 70, "Output",
   CellTags->"RasterizedOutput",
   CellID->1207339352],
  Cell[107680, 2178, 8827, 153, 70, "Output",
   CellTags->"RasterizedOutput",
   CellID->179508561],
  Cell[120621, 2474, 23415, 392, 70, "Output",
   CellTags->"RasterizedOutput",
   CellID->1933344339],
  Cell[147240, 2978, 58436, 966, 70, "Output",
   CellTags->"RasterizedOutput",
   CellID->143242816]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 495092, 8928},
 {"RasterizedOutput", 495237, 8932}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[623, 21, 3792, 94, 70, "AnchorBarGrid",
 CellID->1],
Cell[4418, 117, 72, 1, 70, "ObjectName",
 CellID->1224892054],
Cell[CellGroupData[{
Cell[4515, 122, 1933, 44, 70, "Usage",
 CellID->982511436],
Cell[CellGroupData[{
Cell[6473, 170, 738, 24, 70, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->843403541],
Cell[7214, 196, 31, 0, 70, "SectionHeaderSpacer"],
Cell[7248, 198, 1118, 37, 70, "ExampleText",
 CellID->1904423740],
Cell[8369, 237, 1346, 44, 70, "Input",
 CellID->669698642],
Cell[9718, 283, 78, 1, 70, "ExampleText",
 CellID->142916237],
Cell[9799, 286, 2471, 80, 70, "Input",
 CellID->1008861783],
Cell[12273, 368, 1096, 36, 70, "ExampleText",
 CellID->1650356348],
Cell[13372, 406, 153, 4, 70, "ExampleText",
 CellID->694278449],
Cell[CellGroupData[{
Cell[13550, 414, 126, 3, 70, "ExampleDelimiter",
 CellID->1204276615],
Cell[13679, 419, 1650, 58, 70, "3ColumnTableMod",
 CellID->1068258589]
}, Open  ]],
Cell[15344, 480, 31, 0, 70, "SectionFooterSpacer"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15424, 486, 388, 15, 70, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->1691243387],
Cell[CellGroupData[{
Cell[15837, 505, 195, 6, 70, "ExampleSection",
 CellID->634053617],
Cell[16035, 513, 136, 4, 70, "ExampleText",
 CellID->1827560945],
Cell[CellGroupData[{
Cell[16196, 521, 2799, 93, 70, "Input",
 CellID->828633328],
Cell[18998, 616, 42609, 707, 70, "Output",
 CellTags->"RasterizedOutput",
 CellID->739495163]
}, Open  ]],
Cell[61622, 1326, 134, 4, 70, "ExampleText",
 CellID->347150731],
Cell[CellGroupData[{
Cell[61781, 1334, 199, 5, 70, "Input",
 CellID->2051871557],
Cell[61983, 1341, 279, 8, 70, "Output",
 CellID->551384484]
}, Open  ]],
Cell[62277, 1352, 203, 4, 70, "ExampleText",
 CellID->727085783],
Cell[CellGroupData[{
Cell[62505, 1360, 147, 5, 70, "Input",
 CellID->1262823622],
Cell[62655, 1367, 243, 8, 70, "Output",
 CellID->646293822]
}, Open  ]],
Cell[CellGroupData[{
Cell[62935, 1380, 309, 11, 70, "Input",
 CellID->287979828],
Cell[63247, 1393, 488, 14, 70, "Output",
 CellID->405595608]
}, Open  ]],
Cell[63750, 1410, 162, 4, 70, "ExampleText",
 CellID->732288078],
Cell[CellGroupData[{
Cell[63937, 1418, 381, 13, 70, "Input",
 CellID->656973428],
Cell[64321, 1433, 42244, 701, 70, "Output",
 CellTags->"RasterizedOutput",
 CellID->1207339352]
}, Open  ]],
Cell[106580, 2137, 138, 4, 70, "ExampleText",
 CellID->1583802398],
Cell[CellGroupData[{
Cell[106743, 2145, 934, 31, 70, "Input",
 CellID->2033757402],
Cell[107680, 2178, 8827, 153, 70, "Output",
 CellTags->"RasterizedOutput",
 CellID->179508561]
}, Open  ]],
Cell[CellGroupData[{
Cell[116544, 2336, 124, 3, 70, "ExampleDelimiter",
 CellID->64987870],
Cell[116671, 2341, 117, 3, 70, "ExampleText",
 CellID->262649421],
Cell[116791, 2346, 2717, 89, 70, "Input",
 CellID->450761097],
Cell[119511, 2437, 116, 3, 70, "ExampleText",
 CellID->1969984253],
Cell[CellGroupData[{
Cell[119652, 2444, 966, 28, 70, "Input",
 CellID->178388260],
Cell[120621, 2474, 23415, 392, 70, "Output",
 CellTags->"RasterizedOutput",
 CellID->1933344339]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[144085, 2872, 125, 3, 70, "ExampleDelimiter",
 CellID->541634329],
Cell[144213, 2877, 245, 5, 70, "ExampleText",
 CellID->922914713],
Cell[144461, 2884, 2142, 70, 70, "Input",
 CellID->656945294],
Cell[CellGroupData[{
Cell[146628, 2958, 609, 18, 70, "Input",
 CellID->1940943096],
Cell[147240, 2978, 58436, 966, 70, "Output",
 CellTags->"RasterizedOutput",
 CellID->143242816]
}, Open  ]],
Cell[205691, 3947, 246, 5, 70, "ExampleText",
 CellID->384086542],
Cell[CellGroupData[{
Cell[205962, 3956, 1151, 34, 70, "Input",
 CellID->158754014],
Cell[207116, 3992, 153124, 2516, 70, "Output",
 CellID->188743823]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[360289, 6514, 125, 3, 70, "ExampleDelimiter",
 CellID->572711569],
Cell[360417, 6519, 252, 5, 70, "ExampleText",
 CellID->488716687],
Cell[360672, 6526, 1479, 50, 70, "Input",
 CellID->958741851],
Cell[CellGroupData[{
Cell[362176, 6580, 422, 12, 70, "Input",
 CellID->895232116],
Cell[362601, 6594, 50694, 836, 70, "Output",
 CellID->1858766502]
}, Open  ]],
Cell[413310, 7433, 335, 6, 70, "ExampleText",
 CellID->843986205],
Cell[413648, 7441, 2084, 59, 70, "Input",
 CellID->748826621],
Cell[CellGroupData[{
Cell[415757, 7504, 781, 22, 70, "Input",
 CellID->1482303985],
Cell[416541, 7528, 1824, 44, 70, "Output",
 CellID->1103757188]
}, Open  ]],
Cell[418380, 7575, 225, 5, 70, "ExampleText",
 CellID->892375868],
Cell[418608, 7582, 231, 7, 70, "Input",
 CellID->1004486316],
Cell[CellGroupData[{
Cell[418864, 7593, 1772, 48, 70, "Input",
 CellID->486872208],
Cell[420639, 7643, 70083, 1154, 70, "Output",
 CellID->753640225]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[490761, 8802, 31, 0, 70, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[490829, 8807, 270, 12, 70, "SeeAlsoSection",
 CellID->1255426704],
Cell[491102, 8821, 535, 16, 70, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[491674, 8842, 276, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[491953, 8856, 31, 0, 70, "SectionHeaderSpacer"],
Cell[491987, 8858, 207, 6, 70, "MoreAbout",
 CellID->725284505]
}, Open  ]],
Cell[492209, 8867, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)
