(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    472115,       8750]
NotebookOptionsPosition[    462936,       8475]
NotebookOutlinePosition[    466839,       8569]
CellTagsIndexPosition[    466715,       8563]
WindowTitle->DivergenceFreeInterpolation3D - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["WILDFIRES DOC SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "See Also",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"See Also", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"RadialBasicFunction\"\>":>
       Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/RadialBasicFunction"], \
"\<\"RBFInterpolation\"\>":>Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/RBFInterpolation"], \
"\<\"DivergenceFreeInterpolation3D\"\>":>Documentation`HelpLookup[
       "paclet:WildfiresDoc/ref/DivergenceFreeInterpolation3D"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"SeeAlso"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Wildfires Simulation Package\"\>":>
       Documentation`HelpLookup[
       "paclet:WildfiresDoc/guide/Fire-front Tracking"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"MoreAbout"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->
         False], {"\<\"WildfiresDoc/ref/DivergenceFreeInterpolation3D\"\>":>
       None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["WildfiresDoc/ref/DivergenceFreeInterpolation3D"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/WildfiresDoc/ref/\
DivergenceFreeInterpolation3D.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "WildfiresDoc/ref/DivergenceFreeInterpolation3D", ".html"]], 
           None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell["DivergenceFreeInterpolation3D", "ObjectName",
 CellID->1224892054],

Cell[CellGroupData[{

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"DivergenceFreeInterpolation3D", "[", 
       RowBox[{"data", ",", "opts"}], "]"}]], "InlineFormula"],
     " \[LineSeparator]performs divergence-free interpolation for 3D \
scattered data and returns a black-box function. The data must be of the form \
{{{x1,y1,z1},{u1,v1,w1}}, {x2,y2,z2},{u2,v2,w2}, {x3,y3,z3},{u3,v3,w3},...}. \
The resulting interpolant exactly satisfies the divergence-free condition, ",
     StyleBox[
     "\[PartialD]f/\[PartialD]x + \
\[PartialD]f/\[PartialD]y+\[PartialD]f/dz=0. \n",
      Deletable->True],
     Cell[BoxData[
      RowBox[{"DivergenceFreeInterpolation3D", "[", 
       RowBox[{"data", ",", "rbf", ",", "opts"}], "]"}]], "InlineFormula"],
     " \[LineSeparator]performs divergence-free interpolation for 3D \
scattered data using the specified radial basic function ",
     Cell[BoxData["rbf"], "InlineFormula"],
     ". The radial basic function can be a string specifying a name from the \
existing database or a function of the form ",
     Cell[BoxData[
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"e", ",", "r"}], "}"}], ",", " ", "..."}], "]"}]], 
      "InlineFormula"],
     "."
    }]]},
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"DivergenceFreeInterpolation3D", "[", 
       RowBox[{"data", ",", "rbf", ",", "scales", ",", "opts"}], "]"}]], 
      "InlineFormula"],
     " \[LineSeparator]performs divergence-free interpolation of 3D scattered \
data using the specified radial basic function and it's corresponding scales. \
The scaling parameter can be a scalar or a vector. If it is a vector, then it \
should have the same length as ",
     Cell[BoxData["data"], "InlineFormula"],
     "."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {None, {None}}, 
   "RowsIndexed" -> {}}},
 CellID->982511436],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[Cell[TextData[{
   Cell[BoxData[
    InterpretationBox[
     StyleBox[
      GraphicsBox[{},
       BaselinePosition->Baseline,
       ImageSize->{6, 0}],
      CacheGraphics->False],
     Spacer[6]]]],
   "Details"
  }], "NotesFrameText"],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 WholeCellGroupOpener->True,
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->152840225],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[{
 "The divergence-free interpolation relies on the property that a scalar \
function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalPhi]", "(", 
    RowBox[{"x", ",", "y", ",", "z"}], ")"}], TraditionalForm]], "InlineMath"],
 " can be converted to a vector function satisfying the divergence-free \
relation  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"\[PartialD]", 
       SubscriptBox["\[CapitalPhi]", "u"]}], 
      RowBox[{"\[PartialD]", "x"}]], "+", 
     FractionBox[
      RowBox[{"\[PartialD]", 
       SubscriptBox["\[CapitalPhi]", "v"]}], 
      RowBox[{"\[PartialD]", "y"}]], "+", 
     FractionBox[
      RowBox[{"\[PartialD]", 
       SubscriptBox["\[CapitalPhi]", "w"]}], 
      RowBox[{"\[PartialD]", "z"}]]}], "=", "0"}], TraditionalForm]], 
  "InlineMath"],
 ", where the functions   ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalPhi]", "u"], "(", 
     RowBox[{"x", ",", "y", ",", "z"}], ")"}], ",", 
    RowBox[{
     SubscriptBox["\[CapitalPhi]", "v"], " ", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y", ",", "z"}], ")"}]}], ",", 
    RowBox[{
     SubscriptBox["\[CapitalPhi]", "w"], " ", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y", ",", "z"}], ")"}]}]}], TraditionalForm]], 
  "InlineMath"],
 " are defined as:"
}], "ExampleText",
 CellID->1904423740],

Cell[TextData[{
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[CapitalPhi]", "u"], "(", 
      RowBox[{"x", ",", "y", ",", "z"}], ")"}], " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           SuperscriptBox["\[Del]", "2"], "\[CapitalPhi]"}]}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "\[CapitalPhi]"}], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["x", "2"]}]]}], ")"}], ",", "  ", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "\[CapitalPhi]"}], 
         RowBox[{
          RowBox[{"\[PartialD]", "x"}], 
          RowBox[{"\[PartialD]", "y"}]}]], ")"}], ",", " ", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "\[CapitalPhi]"}], 
         RowBox[{
          RowBox[{"\[PartialD]", "x"}], 
          RowBox[{"\[PartialD]", "z"}]}]], ")"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[CapitalPhi]", "v"], "(", 
      RowBox[{"x", ",", "y", ",", "z"}], ")"}], " ", "=", " ", 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "\[CapitalPhi]"}], 
         RowBox[{
          RowBox[{"\[PartialD]", "x"}], 
          RowBox[{"\[PartialD]", "y"}]}]], ")"}], ",", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           SuperscriptBox["\[Del]", "2"], "\[CapitalPhi]"}]}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "\[CapitalPhi]"}], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["y", "2"]}]]}], ")"}], ",", " ", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "\[CapitalPhi]"}], 
         RowBox[{
          RowBox[{"\[PartialD]", "y"}], 
          RowBox[{"\[PartialD]", "z"}]}]], ")"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[CapitalPhi]", "w"], "(", 
      RowBox[{"x", ",", "y", ",", "z"}], ")"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"(", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "\[CapitalPhi]"}], 
          RowBox[{
           RowBox[{"\[PartialD]", "x"}], 
           RowBox[{"\[PartialD]", "z"}]}]], ")"}], ",", " ", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], "\[CapitalPhi]"}], 
          RowBox[{
           RowBox[{"\[PartialD]", "y"}], 
           RowBox[{"\[PartialD]", "z"}]}]], ")"}], ",", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            SuperscriptBox["\[Del]", "2"], "\[CapitalPhi]"}]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[PartialD]", "2"], "\[CapitalPhi]"}], 
           RowBox[{"\[PartialD]", 
            SuperscriptBox["z", "2"]}]]}], ")"}]}], "}"}], "."}]}]}], 
   TraditionalForm]], "InlineMath"]
}], "Input",
 CellID->669698642],

Cell["The interpolant is then defined as:", "ExampleText",
 CellID->142916237],

Cell[TextData[{
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"u", "(", 
      RowBox[{"x", ",", "y", ",", "z"}], ")"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"j", "=", "1"}], "M"], 
       RowBox[{
        SubscriptBox["\[Alpha]", "j"], "(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           SuperscriptBox["\[Del]", "2"], 
           SubscriptBox["\[Phi]", "j"]}]}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], 
           SubscriptBox["\[Phi]", "j"]}], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["x", "2"]}]]}], ")"}]}], " ", "+", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"j", "=", "1"}], "M"], 
       RowBox[{
        SubscriptBox["\[Beta]", "j"], 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], 
          SubscriptBox["\[Phi]", "j"]}], 
         RowBox[{
          RowBox[{"\[PartialD]", "x"}], 
          RowBox[{"\[PartialD]", "y"}]}]]}]}], " ", "+", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"j", "=", "1"}], "M"], 
       RowBox[{
        SubscriptBox["\[Gamma]", "j"], 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], 
          SubscriptBox["\[Phi]", "j"]}], 
         RowBox[{
          RowBox[{"\[PartialD]", "x"}], 
          RowBox[{"\[PartialD]", "z"}]}]]}]}]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"v", "(", 
      RowBox[{"x", ",", "y", ",", "z"}], ")"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"j", "=", "1"}], "M"], 
       RowBox[{
        SubscriptBox["\[Alpha]", "j"], 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], 
          SubscriptBox["\[Phi]", "j"]}], 
         RowBox[{
          RowBox[{"\[PartialD]", "x"}], 
          RowBox[{"\[PartialD]", "y"}]}]]}]}], " ", "+", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"j", "=", "1"}], "M"], 
       RowBox[{
        SubscriptBox["\[Beta]", "j"], "(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           SuperscriptBox["\[Del]", "2"], 
           SubscriptBox["\[Phi]", "j"]}]}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], 
           SubscriptBox["\[Phi]", "j"]}], 
          RowBox[{"\[PartialD]", 
           SuperscriptBox["y", "2"]}]]}], ")"}]}], " ", "+", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"j", "=", "1"}], "M"], 
       RowBox[{
        SubscriptBox["\[Gamma]", "j"], 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], 
          SubscriptBox["\[Phi]", "j"]}], 
         RowBox[{
          RowBox[{"\[PartialD]", "z"}], 
          RowBox[{"\[PartialD]", "y"}]}]]}]}]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"w", "(", 
      RowBox[{"x", ",", "y", ",", "z"}], ")"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"j", "=", "1"}], "M"], 
        RowBox[{
         SubscriptBox["\[Alpha]", "j"], 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], 
           SubscriptBox["\[Phi]", "j"]}], 
          RowBox[{
           RowBox[{"\[PartialD]", "x"}], 
           RowBox[{"\[PartialD]", "z"}]}]]}]}], " ", "+", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"j", "=", "1"}], "M"], 
        RowBox[{
         SubscriptBox["\[Beta]", "j"], 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[PartialD]", "2"], 
           SubscriptBox["\[Phi]", "j"]}], 
          RowBox[{
           RowBox[{"\[PartialD]", "y"}], 
           RowBox[{"\[PartialD]", "z"}]}]]}]}], " ", "+", " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"j", "=", "1"}], "M"], 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Gamma]", "j"], "(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             SuperscriptBox["\[Del]", "2"], 
             SubscriptBox["\[Phi]", "j"]}]}], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[PartialD]", "2"], 
             SubscriptBox["\[Phi]", "j"]}], 
            RowBox[{"\[PartialD]", 
             SuperscriptBox["z", "2"]}]]}], ")"}], ".", "\[IndentingNewLine]", 
         RowBox[{
          SubscriptBox["\[Phi]", "j"], "(", 
          RowBox[{"x", ",", "y"}], ")"}]}]}]}], " ", "=", " ", 
      RowBox[{
       RowBox[{"\[CapitalPhi]", "(", 
        RowBox[{"e", ",", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "-", 
              SubscriptBox["cx", "j"]}], ")"}], "2"], " ", "+", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"y", "-", 
              SubscriptBox["cy", "j"]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "-", 
              SubscriptBox["cz", "j"]}], ")"}], "2"]}]]}], ")"}], "."}]}]}]}],
    TraditionalForm]], "InlineMath"]
}], "Input",
 CellID->1008861783],

Cell[TextData[{
 "The function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalPhi]", " ", 
    RowBox[{"(", 
     RowBox[{"e", ",", "r"}], ")"}]}], TraditionalForm]], "InlineMath"],
 "  is a ",
 StyleBox["radial basic function",
  FontSlant->"Italic"],
 ", and \[Phi] represents the various sfhits of the basic function. The pair ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["cx", "j"], ",", 
     SubscriptBox["cy", "j"], ",", 
     SubscriptBox["cz", "j"]}], ")"}], TraditionalForm]], "InlineMath"],
 " are the centers/coordinates at which the data ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"u", "(", 
       RowBox[{
        SubscriptBox["x", "j"], ",", 
        SubscriptBox["y", "j"], ",", 
        SubscriptBox["z", "j"]}], ")"}], ",", " ", 
      RowBox[{"v", "(", 
       RowBox[{
        SubscriptBox["x", "j"], ",", 
        SubscriptBox["y", "j"], ",", 
        SubscriptBox["z", "j"]}], ")"}], ",", 
      RowBox[{"w", "(", 
       RowBox[{
        SubscriptBox["x", "j"], ",", 
        SubscriptBox["y", "j"], ",", 
        SubscriptBox["z", "j"]}], ")"}]}], ")"}]}], TraditionalForm]], 
  "InlineMath"],
 " are given. are the coefficients \[Alpha], \[Beta], \[Gamma] are computed \
be solving a system of linear equations. "
}], "ExampleText",
 CellID->1650356348],

Cell[TextData[{
 Cell[BoxData["DivergenceFreeInterpolation3D"], "InlineFormula"],
 " takes the following options:"
}], "ExampleText",
 CellID->694278449],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->1204276615],

Cell[BoxData[GridBox[{
   {Cell["      ", "TableRowIcon"], "\"\<Solver\>\"", 
    ButtonBox["Automatic",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/Automatic"], Cell[TextData[{
     Cell[BoxData[
      TemplateBox[{Cell[
         TextData["Specifies"]],"paclet:ref/Specifies"},
       "RefLink",
       BaseStyle->"InlineFormula"]], "InlineFormula"],
     " the type of solver to use. ",
     Cell[BoxData[
      TemplateBox[{Cell[
         TextData["Options"]],"paclet:ref/Options"},
       "RefLink",
       BaseStyle->"InlineFormula"]], "InlineFormula"],
     " include \"LinearSolve\", \"LeastSquares\". ",
     Cell[BoxData[
      TemplateBox[{Cell[
         TextData["If"]],"paclet:ref/If"},
       "RefLink",
       BaseStyle->"InlineFormula"]], "InlineFormula"],
     " Automatic, then the solver is chosen based on data and heurestics."
    }], "TableText"]},
   {Cell["      ", "TableRowIcon"], "\"\<Regularization\>\"", "0.", Cell[
    TextData[{
     Cell[BoxData[
      TemplateBox[{Cell[
         TextData["Specifies"]],"paclet:ref/Specifies"},
       "RefLink",
       BaseStyle->"InlineFormula"]], "InlineFormula"],
     " ",
     "a",
     " ",
     "positive",
     " ",
     "value",
     " ",
     "for",
     " ",
     "performing",
     " ",
     "smoothing",
     " ",
     "on",
     " ",
     "the",
     " ",
     "rbf",
     " ",
     "interpolant."
    }], "TableText"]}
  }]], "3ColumnTableMod",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {None, {None}}, 
   "RowsIndexed" -> {}},
 GridBoxDividers->{"Rows" -> {{True, True, True}}}},
 CellID->1068258589]
}, Open  ]],

Cell["", "SectionFooterSpacer"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(2)", "ExampleCount"]
}], "PrimaryExamplesSection",
 WholeCellGroupOpener->True,
 CellTags->"PrimaryExamplesSection",
 CellID->395219763],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(2)", "ExampleCount"]
}], "ExampleSection", "ExampleSection",
 WholeCellGroupOpener->True,
 CellID->291636570],

Cell["\<\
Consider a flow-field given by a closed form expression. Sample 100 random \
points to get a sample of the velocity field at discrete locations:\
\>", "ExampleText",
 CellID->1101217418],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SeedRandom", "[", "123", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"vectorfield", "[", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "2"], " ", 
        SuperscriptBox["y", "2"], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"x", " ", "y", " ", "z"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["x", "2"], " ", 
        SuperscriptBox["z", "2"], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"x", " ", "y", " ", "z"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"z", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"x", " ", "y", " ", "z"}], "]"}]}], "-", 
       RowBox[{"x", " ", "y", " ", 
        SuperscriptBox["z", "2"], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"x", " ", "y", " ", "z"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"y", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"x", " ", "y", " ", "z"}], "]"}]}], "-", 
       RowBox[{"x", " ", 
        SuperscriptBox["y", "2"], " ", "z", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"x", " ", "y", " ", "z"}], "]"}]}]}]}], "}"}]}], " ", ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"data", "  ", "=", " ", 
    RowBox[{
     RowBox[{"RandomReal", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"100", ",", "3"}], "}"}]}], "]"}], " ", "/.", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x_", "?", "NumericQ"}], ",", 
        RowBox[{"y_", "?", "NumericQ"}], ",", 
        RowBox[{"z_", "?", "NumericQ"}]}], "}"}], "\[RuleDelayed]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
        RowBox[{"vectorfield", "[", 
         RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "}"}]}]}]}], " ", ";"}], 
  " "}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->1376748249],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VectorPlot3D", "[", 
  RowBox[{
   RowBox[{"vectorfield", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->573577489],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnb1uHM1yhj/YDnwbvhQ7ZXZ8BecApkMDxwYEBhIEMWJGi7oCpQzJRAGh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    "], {{0, 240}, {210, 0}}, {0, 
    255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{210, 240},
  PlotRange->{{0, 210}, {0, 240}}]], "Output",
 ImageSize->{214, 240},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[2]=",
 CellID->771933767]
}, Open  ]],

Cell["\<\
Generate a 3D velocity field using only the data obtained in the previous \
step. Inverse multi-quadric function is used with a constant scaling \
parameter of 0.2:\
\>", "ExampleText",
 CellID->1134302722],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", " ", 
  RowBox[{"DivergenceFreeInterpolation3D", "[", 
   RowBox[{"data", ",", " ", "\"\<IMQ\>\"", ",", "0.2"}], "]"}]}]], "Input",
 CellLabel->"In[3]:=",
 CellID->1326946098],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"DivergenceFreeInterpolatingFunction", "[", "<>", "]"}],
  WildfiresDoc`Private`dfun$28606]], "Output",
 ImageSize->{290, 14},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->684276299]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VectorPlot3D", "[", 
  RowBox[{
   RowBox[{"sol", "[", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->1970788469],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnbtuHctyhjdsB34NP4qdMjt+gnMA06GBYwMCAxGEGCmjRT2BUoZkooBQ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    "], {{0, 240}, {210, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{210, 240},
  PlotRange->{{0, 210}, {0, 240}}]], "Output",
 ImageSize->{214, 240},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[4]=",
 CellID->942110442]
}, Open  ]],

Cell["\<\
Visually examination does give favorable results. We can perform more \
comparisons using 2D stream plots:\
\>", "ExampleText",
 CellID->1964372303],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"StreamPlot", "[", 
      RowBox[{
       RowBox[{"Most", "[", 
        RowBox[{"vectorfield", "[", 
         RowBox[{"x", ",", "y", ",", "0.1"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"StreamPlot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"vectorfield", "[", 
         RowBox[{"x", ",", "0.1", ",", "z"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3"}], "}"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], ",", 
     RowBox[{"StreamPlot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"vectorfield", "[", 
         RowBox[{"0", ",", "y", ",", "z"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3"}], "}"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], "}"}], ",", " ", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Exact flow-field\>\""}], ",", " ", 
   RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->922263678],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvft/VNeR9jvn8sP5N86f8p5f5513Mklm3iT2JE6cyLdYTsCWL1i2sWUb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    "], {{0, 186}, {500, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{500, 186},
  PlotRange->{{0, 500}, {0, 186}}]], "Output",
 ImageSize->{504, 186},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[5]=",
 CellID->653269363]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"Quiet", "@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"StreamPlot", "[", 
       RowBox[{
        RowBox[{"Most", "[", 
         RowBox[{"sol", "[", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "0.1"}], "}"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"StreamPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"sol", "[", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0.1", ",", "z"}], "}"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"{", 
           RowBox[{"1", ",", "3"}], "}"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], ",", 
      RowBox[{"StreamPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"sol", "[", 
          RowBox[{"{", 
           RowBox[{"0", ",", "y", ",", "z"}], "}"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"{", 
           RowBox[{"2", ",", "3"}], "}"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], "}"}]}], ",", " ", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Interpolated flow-field\>\""}], ",", 
   " ", 
   RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->1381700594],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvWl/VFeS7tt3eHG/xv0o576t013V1a46XVXuKtdgeZbdYAs8yKNsY+NJ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    "], {{0, 188}, {500, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{500, 188},
  PlotRange->{{0, 500}, {0, 188}}]], "Output",
 ImageSize->{504, 188},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[6]=",
 CellID->1561780477]
}, Open  ]],

Cell["\<\
Checking the error at 30 equally spaced points in all directions can be used \
to get the average error of the velocity magnitude:\
\>", "ExampleText",
 CellID->1922042136],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ng", " ", "=", " ", 
   RowBox[{"N", "@", 
    RowBox[{"Range", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1", ",", 
      RowBox[{"2", "/", "30"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"randompoints", " ", "=", " ", 
   RowBox[{"Join", "@@", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Outer", "[", 
       RowBox[{"List", ",", " ", "ng", ",", " ", "ng", ",", "ng"}], "]"}], 
      ",", "1"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Mean", "[", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Norm", "[", 
      RowBox[{
       RowBox[{"vectorfield", "@@", "#"}], " ", "-", " ", 
       RowBox[{"sol", "[", "#", "]"}]}], "]"}], "&"}], ",", "randompoints", 
    ",", 
    RowBox[{"{", "1", "}"}]}], "]"}], "]"}]}], "Input",
 CellLabel->"In[7]:=",
 CellID->2037707888],

Cell[BoxData["0.018719515381697225`"], "Output",
 ImageSize->{69, 13},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->994958956]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["\t", "ExampleDelimiter"],
  $Line = 0; Null]], "ExampleDelimiter",
 CellID->205296802],

Cell["\<\
In this example, a 3D velocity field is constructed in the presence of \
complex terrain using only boundary conditions. First, the terrain and the \
domain of interest is defined:\
\>", "ExampleText",
 CellID->1564614132],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"hills", " ", "=", " ", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], ",", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "0.02"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x", "-", "3"}], ")"}], "^", "2"}], "+", 
           RowBox[{"y", "^", "2"}]}], ")"}]}], "]"}], " ", "+", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "0.05"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x", "-", "9"}], ")"}], "^", "2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"y", "+", "9"}], ")"}], "^", "2"}]}], ")"}]}], "]"}]}]}],
      "]"}]}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"ymin", ",", "ymax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"zmin", ",", "zmax"}], "}"}]}], "}"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "15"}], ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "2"}], "}"}]}], "}"}]}], ";"}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->1976135842],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"hills", "[", 
    RowBox[{"x", ",", "y"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "xmin", ",", "xmax"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "ymin", ",", "ymax"}], "}"}], ",", " ", 
   RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->1357116328],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvXV8VNf2939/z68k43NG4gHae7//P/d750rlVqEtLYWiLcU1uEOCxd2V
EAgSJAQI7u5SXIu3OMUJEaIz8+y199GxKMkkOeu1yGsyOZmcOXPOm89n7bX3
+WDoxB5+/+cvf/nLVAn60mNIwJdTpgyZ2fM99M1XM6eNGPr/owcd/r+//CUF
/YPHZjFaX/gJo6l3RwwxxBDDdhBA8TElsksMMcRwwmCJZA9NIrvEEEMMZwgL
TVWT7UV2iSGGGI0c1sypLYJEdokhhhiNEDYJUx/siOASQwwx3kU4qFM1yIuL
7BJDDDEaJBxgpMEJI7JLDDHEqFtUy413ShWRXWKIIUYNo4Zjf42wJ2aRXWKI
IYb9qCEWmoQeIrvEEEMMNmrOgSYnhgguMcRotVHba995QCGKLjHEaFVRhyvd
OeEgsksMMVp21O3Sdn4giOwSQ4wWFvVsU2/APXmnIbJLDDGaddT/4m2m174I
LjHEaF7RIFdrc7/kRdElhhjOHw11ebaky1xklxhiOGE04PXYUi9tkV1iiOEM
0bAXYGu4nEV2iSFG48e7uOJa2yUssksMMRoh3tH11ZovWxFcYojxLuLdXVPi
1WoWRZcYYjRcvNOLSLxCLUJklxhi1C0a4aoRr0oHIbJLDDFqGI1zjYhXYg1D
ZJcYYtiLRrsoxKuvDiGCSwwx2GjMC0G86OoTougSozVH45/54oXWUCGyS4xW
FU1ynosX17sIkV1itOxoqhNbvKDedYjsEqOFRROeyeJF1JghskuMZh1NfuqK
F05ThQguMZpXOMO56gz70MpDFF1iOH84ycnpJLshBgmRXWI4YTjP2eg8eyKG
RYjsEqPJw9lOP6faGTHshcguMRo/nPBkc8JdEsNxiOASoxHCOU8w59wrMWoS
ougS4x2F055RTrtjYtQqRHaJ0VDhzKeQM++bGHULkV1i1C2c/5xx8t0To54h
skuMGkZzOUOay36KUc8Q2SWGvWhGp0Qz2lUxGipEcInBRvM6DZrX3orRsCGK
rtYczfFzb3Y7LMY7CpFdrSqa6afcTHdbjHcaIrtadjTfj7X57rkYjRMiu1pY
NOvPsVnvvBiNHCK4mnW0gM+uue+/GE0SouhqdtEyPqmW8S7EaMIQ2eX80WI+
mhbzRsRwhhDZ5YTRkj6LlvRexHCqENnV5NHyDn4LeztiOGeI7Gr8aJGHukW+
KTGcOURwNUK01MPbUt+XGM4fouh6R9GCj2cLfmtiNKMQ2dUg0eIPYMt+d2I0
xxDZVbdoDYerNbxHMZpviOCqYbSSQ9RK3qYYzTrEs9RxtJ7j03reqRjNNER9
5Tha1cFpVW9WjGYX5PwUz1Kb0QpJ3trerxjNK0Re2YvWeUxa57sWo1kEe3KK
Z6lFtNoD0mrfuBhOHvwzUzxL+dGaj0Zrfu9iOG2IsLIZrbBgZRGt/O2L4Zwh
8so6xONgFg+CGM4XFuekeIqaxYPAhHgcxHCqsD4hxVNUPAJsiIdCDKcKkVf8
EAtWFiEeDTGcJ2yeja32FG21b9xxiIdFDGcIe+dh6zw/W+e7rkmIR0aMJg8R
Vvxone+6hiEeHDGaPERekRALVtWGeHzEaNpwcAa2qpOzVb3ZOod4lMRownB8
+rWek7P1vNN6hnigxGiqqPbcayUnZyt5mw0S4rESo6lC5JVYsKptiIdLjCaJ
mpx4LfvkbNnv7h2FSHgxGj9EWLXsd/eOgr8kmgguMRonaniateCzsQW/tXcX
7EH7CxNm8e5vYrz7aOW8aqnv650GH1bm+TqSf+GFWRRdYryDqPnp1PJOPPFq
qkPwDxofVhYpgkuMBo9anUIt7HxrYW+ncYJ/0BzAyhpcBoPBLLpFMeoXrZZX
Lem9NFrUAVYkAVaiWxSjflHbU6XFnFot5o00ZtQPVnouF0CK4BKjVlGH06MF
nFHidVG3qD2saDrRsFpgN8WxRTGqjVYLq6behWYZFrAy8MImo1gdBRvYJ5UD
cJlF0SUGL1ohr5r7/jdVOFZWPHDpLXRUrWDF314sc4nBj7p99M36hGnWO9+E
YdERak9HEdrQ4KofrES3KAY/6vxZN9OTRDy96xzCJiu9TUzZJA8fXPWBlegW
W3nU5/NtjudGc9xnJwnbsKoNfARlrvrBymJ70S22kmhVvGp2O+w8IYBVQ9g6
e+Cqp23kgwv9SGRXS4p6fo7N6zRoXnvrVMGHVYPbOj64GqrGZbAKEVzNPVoP
rMQTtT5hraxqWI+qA3xqVeayuSV5heOjFejrlanKqwGq67PV6PHOITKL6T9N
elDFqHW0El41l/10znBsAx0Qpj5KqSZlLptGEnNJfmik/NQ44NVv01XXZqpu
BKpvh1Hkpxv7S+mXFccWm1XU/zNqFp9ys9hJ5wz+hVxtzcqCMA1l6+wh0Sas
Vv8i3TJItm+4/NhoxZnxSvQMElc3ZqtvBVO/R1B3YjT3EjToybMTFat/lrAl
ev6bFc8W54wG+Vyc/8N1/j102rDsCG10W1ctEi2ez/1Zur6/bOdQEFcnxoK4
ujpddX2m+iYSV6HUH1Gae3GaB0naR+k6sv2JUbKlPVwNvIFFcWzROaOhPgsn
/0ydfPecOeoJq1qBq841LjYyf5Tk9JKu6SsDcTVCfmS04iQWV9cYcfVHBHU3
RnM/QfswRft4ru7pfP3zRfA6NyOpA8Nk9B5m61HyRZfoFp0kWjyvxHOsPtFQ
sKqJ4qqzbSSvFvOta9oPkuweEiSuNgwAcXXAT3FsDK5cTQNxdSuQ+j2UugPi
SovE1eM03ZN5umfZ+hdL3F4tdyMvciVItXOQlCCLBZfYieok0YDH3Dk/Pufc
q+YS/KNXK09XQ/hYSKM6wIr84qzPXcI7uiZ+7zoPiaveIK62DpbvHi4/NEpx
YhyIq+sB6puz1beRuArXIHH1IEH7KEX3ZwYRV26vlroV5LoXrvEoXu9BXvDc
DOXGvhKWV2yKbrEJQ4SVGA7CprKqIVvqY+tqC6vp/20T/JULiKsukoU9pLl9
QFxtHyrf66c4MgZgdWmq6gYjru5Gau7HaR8ScZWpf56tf7nE7fVy9zd57kVr
Pd5u9Czb6lmx0wv91r252pOTFdbIsmaXWXSL7z4a9sA64cfkhLvUjKJaG+gA
L3W2dTVEIgurMf9uQ8RVxNdIXEnmdZMsReKqn2zzIPnOYfIDIxXHxuJhQX8k
rqjfg6k74Zp70Voirp5k6J9l6V+AuHJH4qpotUfJes/SzZ7l270qd3ubDniz
u3FkjMwBtUS32DjRgnklni31jFrVrCykUT1hVS242L8y6l8Aq+mfuiBxFdsJ
i6ue0pV9ZOsHyLYOke8eoTg4GmB1forq5gzqdiD1R6gGxFWs9lGS7s803VMk
rha4IXFVsNy9MM+jOJ+IK6/KnV7Ggz7wV371NR+BB8+Z0pZNanFPLhTd4ruK
Bj+GzvOhOM+eNNPgN1k5Y+sCXo905L/ajP0PFldfgLhK6ozF1U/S1X1lGwfK
tw9VsGbw8nT1rVlIXGmQuLofrX0Yr3tMiyu3lwvdXi91f0PE1TrPss2eFbu9
K4/4Gk+3hT90uq35qI8ZC603q90fZmnPzVZaUMsGwRbSKbrFhop3cdCc5INw
kt1ovlHzjlCbSKkVuOifWq9CYyc5WP3zvdHYCfqDuHJF4iq9K4ir3D6y/P7y
zYPlO4cr9o9SHhunMkAbA3V7DnUnVHMvUvsAiatEJK70zzL1Lxa4vVrsTsRV
Sb7n261eZXt9Ko75Vp1tB3/oYjvzKcyrQyCxKrd7vs51u5+hvRqu+nWS3CAc
PbSRC22DyyyKrtpHS+WVM+xDs476wKpGissKPjhrcfcc9NXvn+8hJzjuQ+DV
bEZcZXWTInGV11e2bqB861DFbj/lQSyuLk4DcfVHkOZuuJaIqz+TdU8z9M+J
uMpxL8z1KFrnWbLdu3S/T/mxtpWn2xkvtoe/daGd+WRb8zFf82Ef836QWBWb
PV8u1d9L0VwJVp0YX01Fy5paBrETtU7xjo5P0x528XOvf/Bh1QCezpY6Etq6
mt46h4UVyhEYVmMYcRXSAYkrCRFXy3+Wre4n3zBIvn2YYu9I5eGxIK5+86d+
n6O5EwLi6mGs7nGi7kkqElduSFy9RuIqz6Nwg1fxDu+3+3zKjvhWnGxrPI/F
1dX3zecxr05ACct80Nu8F5BVtsHj+SLdnQTqEjaGO/q7Vo8s1jYutCu6RHDZ
i3d3TJrwaIsfdP3DprKqhaezASi75BFQK0tXbbKbkbIVcoLjGXEV+Q0WV92l
i3vLcn+R5Q+Qbxqi2DlCuX80wOrcVPWNmSCu7oVpH0RrH4G40j9N179A4irH
4/VqzzcbvIq2eZfs8Sk75Ftxoi1ygqbLWFz91t58rh3Ur371NR/1RZbQvA94
Zdzi+Tbf/dl83e8x6gsB0OqwtW/1yOIX5K1TLHPZCxFWYtiMam2gbXAJPJ1D
Z2dFHv4zjsFlDasxuMzu/xmIq7jvQFwt6CHN+UmW10++bpBiyzDF7pHKg1hc
XZpO3Z6juRuivR9BxJX+KRJXC9xfLPV4ledZsM6raIt3yS6f0gO+Aid46wPz
Fcyrs1hiHceW8IC3eQ80ZVVt9CjJc3uSqb0VoT4/VS44Jo5hZcsk2gSXKLpI
tDxeteZPs0GCf0VUX7PieToerKphlANY2QXXPDrhW+YBKVshWI3/CIurL12R
uEr+QZLZTbqwl2xZH/nq/vINgxXbhiv3jgJYnZ6ivjqDukPEVZQOxFW629P5
7i+WeLzK9SzI9yrc5F28w+ftPt+yI20rTrarOt/e9Nv78BdvfmC+1N58ASPr
FGsJfYglNG3xrFzrXrRc/zhNczNEdXaiEFlW7LJb5rJDLeIcRXC90/fb+Aez
FX6CDR41arKyPVTHw4tDRtmA1bxqUuAWM3Uo0QO2bDX2P20mfeyCngnpCOIq
tas0q4d08U+yFX3l+QMVm4Yq+b9+czYRV7qHCfo/U92eznN/vsjj5XLP16u9
3mzwLtrmU7LHt/RQ2/IT7SrPtjdexrC6/YH5OtJX7wOyzrczn0GWEFfdD0HV
3bwbJJZxo0fFavc3S/SPkqjrc+Av7h0ksSlB7cLKDrUMFmWuRa3ULb7rN9jI
B7DFf16NEHZhZQdQNqvfFvUoR7CyRlOmVc6lk3415sFww3vECSJYTfgIYDUH
iatvJYmdJek/Shf0lOX8LEdmkGy800+1DxevLvpT7I49TkEOzv3ZQo8XSz1f
5XkVrPMu3OJTvMv37YG2ZcfaVZxuX3WRwOqv5j/+ar72PtTbEbKQxLK0hN5m
PFWnaq17ea7b62zdgzjq6gwoZEHt3bpVzL5PtKaWJax41LIAl7lFi65GeFON
edxa5GfUyFEzWDkcqqvW02VZejqbaOIyg07YPkMLmQ457B/vsWWrcR+2mfwJ
8Cq0o2vsd5LkLtK53WULe9MrwKwbrNg8TLndD2B1dKL6jD91OVB7K0L3IJ5m
yPMcz5crvV6v9X6zyadoh2/JvralR9qVn2xfef59428fwN9FsPr9r+YbHwCy
fsMSi1TdT+Cq+0Goupt30RKrcpV72VL9q3nae1HqK9PwNMP5AmVVK2rZhZWQ
WnxwtVS32JJ41ZI+l6YK/jEU+BfHsKpBDcqBp7NHJz6aUML25HEapAHKVm1G
MbCa+DEtriK+kcR/L0n9kV7KeNkv8rz+irWDwA/uwLw6OEl9NEBzOkh7KVJ3
M0F/P9392QIPdpcKt/kW72n79lC7shPtK86+X3UZwwqR6t7f4OutDwBZSGJd
RpawvflMOwtLaN5BS6yKXLeyxboX6Zo7YfBHjwyXwkGgkW5ntKLamnzNqAW/
0hLdYuPsfOMgsVl/EE4S1spKwBabsHJQMHdg8Rg3x724FZ34aCJ0oh+nQqJv
RxiYstWHUGYn4iqko2tUJ7peNK+HbOFPcsKrdYOVW4Yrd47keHUySHsuUncp
QX8j3f3eAo+nSz1fr/J6s9GH3aXy0+9XXvzAeO2v8Kfv/s18/2+0xELIuo4t
4UVsCU9hS3gEWUKouiNLaN7qCcha5V6+VF+6QPcsWfNHEBSyDgyRcEeJvc+1
TdFV+wFEFlkEVvxsGW7RCWFlNBrf9Z8Qw17YtoG2Wjodwco+oPjyyRpQ3Iun
aQXJ0Ik8MKdAGnDZahRTthrPiCs2En6QpnWTZfWULfpJvryvYs1Axcahyu0j
AFZ7x6gOTqaOzdCcDNaei9JdSnS7luF+K9vj7jLPJ6u9Czb6FO/AlasT7bld
uoNg9T/AK0StO4wr/I2pup9uZz7Rlm8JzduBV8a17pVYYr3N1D6Np27PAle4
a6CEOz52wGWPXTUdQBTCyia4mqNbdDZeXbt2LS0tzeLJrVu3hoWFhYSEPHny
pJ6vL4aDsAEr+0V17lLiw8oaUzb8HTDKwNq6dK01nQSXKkMn9NWUjFJjTNKQ
H7E1duQESZkdReBXrmHfSGK+kyZ1kaZ3ky3oJc/pI1+JzeDmYcptI5T2eHUb
8+rRau+nG31e7/At3d+24nj7qrPvm3Dlit6ZhxhZ97DKuomrWJdx1f2MYG4O
VN13eJm30BKrAkusknTNn9Hqm/64kDWXOT7VgasaatnpduAbQ7u5uJm5RWer
KR09ejQgICAlJYX/5P3799EzVVVVV69ezcjIqPOLi+E4agEreyX0akglrEEJ
tROXKVxiOgnYVZWgqYynYeX3T67GzsJqxheuQR0k4d9K4r6XpnSVZjJmcNUA
xfohYAZRAq/Gqg9OoY7N1JwM0Z6L1l1Ocrs21/32Qo+7y70erfF+usnn1U7f
wgPtSo+1N57Fw4K3/gqy6uH/cMhCEuv2X+nGhotMI9bxtuYjvpwl3Aa8MmGJ
VY4lVnEy9SgcBN4JPykcE3J87IPLICzF22aXw26HapEFv7K4GbhFJxyw27Vr
1507dyx4tW/fvgMHDpDHM2fOrNsri+E4+B2hcNLaLKrbKZ6zpBJcTTZJxdag
bAGK0AlpJ5RViRpAE0OnijhNRaymPJZuPxjyv+/RZav/kLIVwGrKf+HrzC9d
QzpKojpJWDO4+Gf5in6KNbjSjvQV2ma7nwrx6hDm1Sngld4ur463ryS8uvFX
8IMPMK8e/w8g6+7faEt4lVjC9mAJf23Lzs2Bqvt2L/Nm7AqxxCrDEqsonnoQ
DLtxeKiE9sIW4MrkHVhWcVkNIArA5aDbwSGvDMQ5LibphtI53aLTdkMhx2fB
q/z8/NOnT5PHQUFBpaWl/Jd1kuPZrIMPK8dSyrp+bmBH92z1RxmEY3kCWDGM
sqBTRbymPA6hSVMWS5XFAKBKo6m30VRJFFUSSRVH0sjiyla4lX3SJy6EV3OI
GfwezGBGd1l2b/lSptK+cSgk2mYH4tU49aGp1LFZmlOh2nMx+svJbtcy3W8v
8ri7wutRvvezzT6vdvkWHWxXiutX5isfIF6ZiMR6hJH16H9oS3gLWcIPrCyh
r3m/D20Jt3qaN8KwY1WuW8UiXWmmtiSZKoxR32eaSOnjk8EkAy76wFoqLhvz
egT/TVQ3aGgDVkJe8dN53GIz4tWWLVuOHTtGHgcGBppMJpsvK4KrbsEeMYPF
2J/jYb55vGvKpvtLtyyh0xcUwlQyziSNicFUOWYUAlRpDEXo9BbTCW1fFEEV
RlBvwtUFKMPU5EX4ZSv07cSPXciwIDGDEcgMdpam/iib14OutK8eqNgwRIkS
WUJrXp3HvLoOvPK8x/GqLeJVGcOrsosfVP72gQmprD8YV/jgb6C4iCX8jbWE
uOp+xJfMzYGq+zZP8ybsCle5Vy7Vly/QvU3XFMdTbyLAFZ4fI4UmUgJztppH
invWVjHLEbiqoZYDWNnnlU1wmRv9Wmv8i7o+vLp8+fKyZcvQgxcvXsTGxlb7
yiK4ah4Wyoo74WvQkMDByg6pSG3KhBIzygJcpgRNFVJTWEohTL2NoUqiqeIo
UFCIUWQbBKjXoepXIeqXIeoXwWpkA4f+4z30PFu2IrBixdUsZAa/lkR/J038
ASrt83vJl/SR5/ZT5A8CfUWS5tV49aFp1PHZmlNhuvOx+sspbtfnud9e7Hkv
1+vRWu9nW3xe7W5bdKhd+a/Aq7Iz7xedal9+4f3KKx+YEJ2QDXzwN3j793AV
i0isK0KJBZbQx7zbGyzhFk/zBpBYRiyxyrDEYo/DqZFS7rCzEpQvuuyBi+cT
+a6QGENLdjmAFccrR8iCX2kKt+jMsDILeVVYWDhz5kwkqJAlTE9PDw8Pv3v3
bs1fXKSW47BrA61L6FadCZwAsMBUmtaURjPKxJSkTHg4D5k+YwKkKV5jjNPw
r6kSjCmso0BKoWcIphCjngepnwWpngaCGiGwGsWD1QQMKySupn4KvArs4Br+
jST2e2lyV+ncHmAGSaU9f5ASIQsl2gZZwp0jVfuq49Xr3W1LDrWrPAm8enmg
beGxdqWn25eff7/q8vsmRKfbTDsWsoS3P6Db3S8Lq1hsYwMjsfiBJFYhllj0
cU7RkDFQPriE1LIDLquavHUFnn7NGvHKNrIIrAS5pDHcYvP1nhUVFXV7cVFu
WQf/gFjDiq+suLOdRyoOVhk6U7oWkjAqlWaUEapSuHKeSHOpMh5qU5VxmqpY
TUUsVR5DlUVTpaQkFcGJDRIvEaaC1YhRj+eoHs5S3ZuhJLAabgBekdZQgNVH
NKzoSvsXrsEdJZGdJPE/gBnkKu0D6USuEG22ifBqgvrQdOr4HO2pcN35OP3l
VLfrWR6/L/G8t9Lr8TrvZ1t9C/a0LT0M6/K93NP2yU7fgoNtixGyTrYvPwsT
CU3IAN5kOt5v4enPZDohNz1HOFC4leYVkliVWGK9TaaKYpB6xKsxT5QdGCIx
J2uqBxehluOa/AJbrQ6LhKLLapTQAa9swoqf784tNl9eOXjxGh4cEVwk+EfA
MawsSlXc2U40VbqOJZUxBTMqmWaUERemUAKp4mjTV87D1NtI2vcVhqvfMKYP
qSmDnRhmeG8Y4wTJLSRoWP0Xkoir2V+5hjJtVxndZQt6021XSF+xCbwahnk1
EfMqUHsa8+qKkFfPt/oW7m1btBfuKPFgvfdjJLf2+hYiZB1tV/pru/Iz7asu
tDchOt3AyLrJzCVE+uoiWbGBaXc/jNvd98AiM+bNnuZ1uPC+VF+xQFearilO
oAoiVc/xWOHlcTJoIk3SIGpBYmrx+9BsOkQDEcBZNhyiDWotckgt+8iy5NUS
u9mwbrGpLtXGsbc1PzKtGVx2YWWvui6cO8P2pZMAUjGwqmKG+aricWLHV4kw
FQPDfKUEU1hQYUxRBFMvGB31YBYojT8ClLenK29MU16dorg8SXFhAhAGySqU
I/7Zhv274z9ymfgxyCqS0z9zRU+ylfaUH2V021VfRV5/xUom0TZIZW1GvBoF
vDrsj3kVoTsfr7+S5nZ9vsfvOZ738rz+XO/zcpvvq22+AKvVXr+v9Hq03vvl
Dp+CPb6FB9qWHGlbeqJdxal2Vefamy+9b76Oux2uMeLqAqOvyDrJvKXdwRVu
9DDnu8NhWaQrhyqW5k2s+kW46k88Vnh2tBQhHR1AkxW1BOBi7KGBFb2OO055
JtFg5Qo5cNnhVc1hxSb8Sr3dYhNenk5bjmtt4KoeVjarVUx/Atudzsoq/n/W
dE8CNn0IU+iZClZNMb4PMeoVzSg1YdTdGao//OkFqa5OUV6ZrLg4UXFuvOLM
OPnJMbD8ywgCKwMNK9JtBQOCDKyQuPL/HHgV8rUkqpOUtF1Bpf1nqLTzE22T
j1vcd41W7ZukPhygOR6kPR2pO5+AeOVOeHU/z+vpBp9nG3werwHI3FjkcWup
54M1Xs83e7/c7lOwy7dwn2/Jobalx/DyfWfbgaC6hpHFiisyl/BXrK9wLxb8
dC/ubWAklnGpvhIPFBYmUi+j1c9CgNV3psp/9ZMWR8EgaXkcVUnAlYKTdIAw
1XiOM1b20IHcMvBr8lbld+41a+ME7cGq/m5R5JXjF2nx4LIFqxqRSgArQiq+
B0zSElIZhFEeDbBCpCrGagpJqefB6ieBqoezVfcQowKUt6Yrr09V/oZv5o50
FGLUacyoE6PlR0fKD/vBCjAj/vkezjYj8W1POVjhAjtJIq7YtiuotDNtV8v7
KvhJeLXFilcXEK/S3W8s8Ph9qefDVV6PVnvfXwGrK9zIcr+U4XZzkcf9XM+n
a72eb/R+udW7YKdP4V7fkoO+pUfbVvzatgpZv/PtzVeY2+Wcw8v3nWLE1REG
Vru82IFC8xqQWFWLdaXztEWpmoJ46kWE6gmeCn1zMiD6dZi6MEJdjI4ectDx
VCXy18mc0OIGEDN4osuq19SCWgb+yg82OxwYZWWPXXWDVd3A1bRX4rv+6w34
+i0VXPx3RJ+K8+1bP2GLAg2rdAZWuKjOVqtYDwiyCrrQLYvnKIigejRbdX8m
TaprU0FKXZgIDDk1lmbUIT/ZgeGyvcNk2wfBEL/fP9/z+2cbBCs/7ATpSYIE
Vv/leEXEVRCptJO2q56yRT/Ll/2iQLmUlzSvhit3jVHtn0wdnqE5Eaw9HaW7
kEjz6s4yz3vLPf9Y7HFzPiDlXIL+QrL+epb73RyPx3meT/O9nm/werXFu2CH
T9Fun5L9vmWHfSuOtzUiOp0DoQUH6ixjBkFcYVixje5bsB9cR/PKuExfnq17
O1dbmEy9ilE/D6Nd4W8TANTPg1UvQ9Wvw9VvImlwlTHgMtgaPeQIY6vtwWAx
gGivL4tnBm1Qq36wqkmZi5ylTX71NSNe8V+zxYDLprISnJD2J/3h/8p1Fo0K
9PBfItOXTibLYPeHticVqjfhVEEY9E09C7JbRUfx6xj5sVFITcn3D5ftGiLb
OpBuRhr5z/dGYlL5MWUrMkmQtFpN+5RN1wDMq1DSdtVFmt4dzGBOH8tE26zo
p1g7SGmLV25XMtxvZnvcXuSBNNXVdLj0zkbrjodpz8frrqW73VnojqTdjI6u
Ed2lz9d5vdrkVbDNu2iXT8k+fNOcY75GBKizIK7gcJ3Cd8w5BuUvcgcKust9
Ew0rc56bORf+hDEHCu9vMzSFSdTraPVzPFZ4d5r8wlhA1tM5yhdBqtchqsIw
dXGEujRKXYG7/aEnJEljQibRRsMDD1w8ZNH/PdnvebCmFl9cca/ZELCiMwf/
Sk4Td6JaRyP86UYYf3x3r/+uw5ENtFo6z8YynmxXFdNSRUrrlQn0xJky0u2J
58sYcDv6mzBwf0CqYPWfuCHh7gzV7/7Km1BFV16epDiPq+gOYuS/YL1QkrZh
9RlKV+QE/bEZDMQTnGM7IzNIV9qX/CxfLEy0WS7i1WDlVsSrsar9U6jDMzUn
QrSno3UXktyuznW/nun+W6rbxQT9uWh440dna44Fac5GaX9L1iNmTvzEZc63
kpiesozBipxxqrUzqIKt3kU7vUv2+pQd8Kk44mtEBhApK3KT+hMYVviOhKSZ
AWC1Hort5lVu5pU4MbJMS/QV86GQVZRAvY5Sk7HCP6bKT4+iuf08UPUyWFUQ
SndqwbAFNokVSNMmaYwpGlOaVY9WptV4rp0ZiPaohWElLLwzULLHrpryKodO
Ait+EmpZDJ81/qXX3HnF/onmCK6awMqiqE6fjSys0mhYYUxpkSWpwNNnyuI0
pbEaaErndaSTdnREKlyqUkOpCgyg6ibPAJ4dD7A6MlKOrN/uobJtg2Qb+0vz
f5Gu/Im7HcOof7UZxcBqDNu98DENq+mfQc2KJBFXwR25SntWL/minwS5ECfh
1TqaV2qWV2ei9ReT3C6nuF2I15+N0p0KBYlyyJ/aM0l9ZCZ1JlQz3AC2dOpn
LqHfSRJ/ks0fqsidoNo0m9oXrf01XV+03btkt3fZfp+Kwz5G5AGxuIJDd4jX
LLrZA8pWACssrni8Mi93My3WV2RpS1NhHvTrSNULXMi6M01+bLj0wQwO7K+D
VW9CVYXh6uJIdUm0Gv0fURaHqAUmsSpZY0yFLjjrBi1Latm7rZi9tbOskMUH
FAuu6mGVY5nWvEIJp2tONW6xMS+Z5vsn+H+ruYCL3UnekguOYGWhrNgwpmgr
k7UViZryBE1ZvKY0DmFKQ+bOFOGmdLIZDPxhTfU0SP1oDpSq7gSomKK6Emmq
U2MVR0cBN/YOk+3E1m9DP+maPtLc3pKcnhysRv8b5gYSZJFn2O4FDCuaVP44
Z34BvKInOHel266ybSXabCWe9bxthHL3OPX+qdSRWZoTodozMfrzcfozkbpf
Q7THZmsO4ztQ7ByDtlEdnqY+FUiNwIstB3zhGvmDNLWPfNEI5erJ6m2B1KE4
7dlM/Y1l7o82eL7BHVaVB32MpGZ1GH+FVZE96Rr7WnfzagwrllcsspYhMugq
M7WlKZqiOHUBXm3mYYACIYs9Jn/O4u7pU0CoFaEuiVKj/y9KcWkLfTqVyZqq
FI0R/eeCqMXOQRBWsWjC2KQWf4WHGvDKJriqxVS1sLIpuhrTLTam+BHBxQYf
VpZ9C/bGAS1sIDMIyGfX21hNcQxVFEUVRlJvIqiCcLi6yeS+Z0GgqUiXwp0Z
qtv+oKkuTVKcGa84MVp+yI+++rYOlG3qL13XV7rqZ8ny3pIlPWhShXzZZuy/
YVljwivyJGkNZQcE/RlM+X8OicTVrC+BV2zb1byewKsFveTzhYm2QQ4R8Wq9
kFe/hmpPRehOBGuPztIcmk7tm8SV2naOVB6cpCLiatxHLrM7uMZ1lWb2ky8b
qVw/Vb07RHM8QXcpy+33XI+nm7xK9mFAHcNzcI5wN04lizOY12FYISe4ys0C
WQYsscxLESt0lXO1ZclUcay6AK/0/sBfcRcj6850xf0AxaOZSkStZ3M4cBWG
qYoiiNyCgnxpPFWGTHoSUMtExhCR1rLRlyUEl0V3lkU5y6J31GHZyhJc9YYV
/1caDVwtRsU5+NPOBq5awMpyDqAAVlVIWSWBskIXAsiqWMumBQMe+2NJhQwg
IhVyf1emgKA6iQXVgRHyXUOggLwRY2p1H7B+y3pJ+C8S+EWbcRhNYzCyDMyM
ZnJPeQIrZANZTJGc8QXTdkUq7dgMQvbkch5O4FUfWFVm/RDlNj/V7vHq/dOo
I7Ohn+HITM2BqdTeiepdY+ga0Zr+8rUD4FcOjFWSVopJ/3UJ/kaShMTbAMXK
MarN/tT+MM2pZN3VbLf7eR6vtnpVHMS8InMG9zCtVnixPoDVGsQrNwGvLF2h
3pyDBI+uKkNTlkQVR6tJwQoh69502JM/pinu+SseYGo9wdR6GcjNPSzB1fjy
aKoilqqKp+WumRTkiUO0Qhb6W4KbXGTbgpU1r2y5QgeKyxpNNmHlmFcWv/Ku
3WKL5xV/H5wBXO8OVsXRtLJCsup1mI2+hVpF6veusd8IlltHaooIKkQqdkYz
6V5AsArgkSqAJ66g0g5tV7K5PWSZPXH2sEyaVwNgVRnCqwPTqEMBmv1TqD3j
BcOXub/IFveSruoLv0LEFeLVtM9dw7+TpPWSLRmsyB+n2jGDOhKpPZ+qv7XI
/c81noXbcfs6meOMZ99A98ImaA1Fsgp+tJqnr6yQBRuscANXuAR9UtqqdHTA
KeT10PNPZimQMSTIMmCh9XCG4vFM5dPZyudzlK+CVAXBqiKmFF8epa7EA4im
BMqciNvjU3nIyuTmR7O8sl621E6Hg22VZRNWFsrKAlw2eVWtuLL3o3chuloP
r9hoQnDxYcWdKu8GVs9xqepP3Fh1byYYwKtTlRcnKU6PUxwfLT/oJ98zDMrp
aEsiq3J/kiztJVnUXZLZxTX5O1d29ybiBfeQviISi1CLXeIYYPUpDasZJL+g
c/ZX8CKRnaQwwbkb8IpkRndBom2ycIfDKsyr7SNVuyeo902mkCskO7B+kGJ1
f/mKXwALWd2lC3pIV/Qh3aoAK0TOmV+6xvwgzfxJvnyocsNE9Z7ZmhPR2ssZ
+js57s/XepbuYnhFJjjv5vEKt1phfWULWdauEJEhS1uVpimPp0oiAUR/zlQ8
ClDcny7fPZBWpNcny8EYzla+CFRCET5EVRymehvOUdcUR5kRspKYxvg03lxp
PrWEvLKxmMNiu5N0qqmx28EOH1z1h9W7AFejXbNOxSs2Gnlcw5ay0lsuDlMT
WCUzsIoXwOoNhtUrvGgegdXjOTAIeHem6pa/8rcpygsTAVbHEKxGyMnYH9py
LZSqpCtwUX1hd0lGF9fETrSsmvZJm8kftyG8ItYPYQo9oLsX8M1upmFYsYxi
cyYWV6HfSKLxUqLp3WVcduOSr50QrzZiXu0cS2uStYMUef3ky/rIF+EbqqZ3
lSR8L8n8URL1Dbw4EVcTPnYJ7ChJ+FGa/Yt81Qjl1snqg4GaM3G665luD5d5
FGzwqtrjw/FqP+bVNsyr9bjbiuCI8MqOK+QkFnKFixFStMYUTXkcHOdXgcon
GFkP/OX7B0uODKP7HC6Ok4ErDAJkFYaqSnDJqyJKXRVDgwskVhIzCdEhtQwG
wdpZllMLbSGrtrDik8cCXDV3goJcajsNwkpXbd1iK+cVG405qPEX/q0iHNyi
tGawKsGwKoyC6vprBKtQuByeBZOCFYYVLlghWJ2fqDg1ji5YIViRv5L/izTv
Zympqy/oJkn/gZZVMz9rM/2/baZ+0mYShtWED2lkTfgI1jdGycLK/zNMJ6sk
4iqcqbQjfcVP9m2m/giP5/eC6Tn8t79moCK3nzznZ/nCXrJ53aVpXYED0d+6
RnztGt4RXpmIq1H/bjPlU5fQbyUpPWRL+ivWItZNo46GaC8k6G/Pd3uS61G8
yQsxCg7gibb0Msi7WF55mvM9zKvcCxMpuxIrz0piLYHhQnOm1phMlcfC0X4x
R/l0luLxDEDWkWGS4yOk/CX+2HgbriqLVFcCsihjHOfWedTSWFPLwPY5VDe1
kD9hx+5wYW2UEvyP4OfHZ5ej7e0AygJW/G/rILpEXvHjHcmtamCVZdsGCtiV
JoBVOYbVWwSrGE1RNPaAGFYvebB6NEdNxgEtquv7R8h34ur6un7SNdBVJV3W
S7K4hyTrR5pUQV+4zPqsTcCnwKspjLgCZH3UZuLHcAPBCaR7Aa9v7P+Zi01Y
IXE1B/Mq6jtou0K8YpO8WnJXGZvo2wWYV6sHQj8DUlkr+sqX/CRf0FM2t5s0
pYs0/nsJgVVYR9fQDq5D8MI1RFyN/ncb/89dI7+XZvSSLx+k2DRGtc+fOhkG
TaT3st1f5nmWb8VmkNx8EPFqH8OrzV7mDZ7mtcArBCJDDV0hK7EWos9IY0yi
KqI5ZP05Q/HQX454hZ45M1p6EbfB35oivzddgRwicoWlEepyhKxoQFZVLFDL
FM8DlxW1DAaDpUPMtjdJRzgnut6wslBW3Cvzf6UGjHLAqzqAqzEx0iyQRaIB
wVU3WFk3WZGoQLBK0JTGYw+IYfUGw+pVGA0rumCFmxb+mKG6MV15ebLyHIbV
kZHyvcPl2wczHhAKVlJSsCIvHtkR3w/icxckrvw/bUPMoAHXrxCpkKAiyS7G
DrD63HXWF0x+KcigDvCyuO1KltSVE1TwbRc6E7vApZ3WDZocyP2d0ddFP8mz
esjSf5Qm/SCN/U4S3UmCSAW7941r0JcugV+6kFVMibga+2GbWV+5xnaRZv0s
zxuq3DZOfWim5myk7kaq26PF7m/WeBq3M7w6zuPVdm/zFi/zRrrkbs51K0oE
btTIFbISKxt9RhoT/sXCEOXLOcpnCFkzoYP0pB9IrHNjZJfH02/8YYDi2Wxl
QbCqNFyFkIUoVxmjroylquIoYzxlSqBMidzYLuGVgTQ8CHils+SVVQnL4oRp
EFjxFRT3yg0EK5vgsucWG5lXzQhZJOoJLruwsnCCtvqsDPyJgVhZIVhZnI0I
Vq+tYIU84P1Z0LV+fRrA6uwExYkxikN+8t3D5FtxwWoN4wFJwQo9k9DJNfpr
vF7xFy6zP3eZ8ZmLPzaD6JlJHyNqgZqaglcKpRc3xuuF0rD60kYScRWBlxIl
u5rQRUrnD4JEP0rvBss15PSBrtHM7rLUrtKEzlLAFJAKYEV4NRsJv89dkLga
ZqB5hcTVxE9cgr6WJHaTLeyryB+h3D1RfXy25lK07o8Mt2c5Hm/XeplJ8eoU
5tUhzKvdPuYd3uatXMndvNIdqSbYDDGqWmQt50msBQgsGqKRCoIAWc9nK55g
ZJ0ZJT07Gt7d1QkysqoDfECzlK+ClEWhILQqeLwyYl7RxjCVBpetWpbOupBl
sXSD3WbRWtagBLyyRZ5agasOfGPlVoNciXW+eJsdskjU4XDVFFa2xBUDK53A
BvKVFa6uW+CLFKwQrH4PUF2bprw4SXl6vOLYaMUB5AGHygx2Ign6FvCsmS9d
5mAmBHzqgswg+ekUTKdp/4WvUxhYTf+MXt949pe28ivXwA5c+xZCFpedpXHC
BF7hGdAZ3WXJXaRx30ujOsHdCaO+ZdMVKavgr1wDPnMZzNzPgoir0f9pM/VT
l7BOktQespwBig0jYdbh6SDttTj9/Uz3V8s9KjZ4mQ+1pXl1DPNqvy8imHmn
sISV525e5lZCJFaemwNXaOD3NhCJNV8LDg7X3t8EK18FArKeYmSdGyO9MAZc
4ZXxsusT5bencAW610HYHkZhZNG8ovi8Yu9bZM7UWvLKDrIMDstW9sBlk1cc
rGoAH/659O54ZW50dDRTUllEDcFlA1Z2aux2F7PCvCId7NY1K9YGvsDK6gke
CrRHJDZW/yLN/Vm6rLdkCVZWmV0lKZ1d4zrhgbyvXIIwr2Z+Brwi2xNSTccr
LUwlyMLf2oDVV1yyfy62s1SQ3wsSWUW0DZlUiIxhzHcSK1LBOGAkZikBJl9c
kbtaBHzhGtVZOre3fMVg5ZYxqsPTqfMh2lsJ+j/nuxflepo3YTN47n3zyfbm
Y+3Mh9uaD/ia9xJeeQtKWIhCTAmoemQhiQWukJFYWVpziu1uNwSrS+OAV+jx
jcmArDvT5Pf96VmHyB4Wh6vKkDeMB16RZUvh9dM0bNWdQ8ECHZ3WkwoFM6D1
jstWfHA5glWdyGMTXHWGlWMzmJeXFxMTk5SUdO3aNfLM1q1bw8LCQkJCnjx5
0iBXev1fxHmihlVBQZ9VDXhFwyqDFlfM3EAt6bMqicUF9ihcYLesWUGB/Q8L
ZeUn3zVUvoVvA3HNChfYJWk/uCbgPquwDi4hX7mwZhA9Mx07vukw/AfJIgu6
F/AGs7Hps0jyNud0kIR8jSvk30shv7ObBqy+EKMiSX7Ly29QAqwivgZlhWwp
EVfD8UKmRFyN+9BldgdJXFfp/D7yVcOUO8arj8/QXAnX3U12e5HtUbbKy7zT
h+PV8XbmI23NBzGvdvlwJay1dAkLubzSBCyxkHxaKUQWzxUahL0NFoAqDlUV
BiuRfHoxR/FsFnAJweq3CbJrE5HEkrG8ehRAV7pQQINWBPd/De571/BGCWl9
JQBXts5yUqH1Glk1aGBgwSWAVUPYOv4xaRBlZXGh3bhxIzs7Gz14/vx5dHQ0
enD//v2UlJSqqqqrV69mZGQ0yAVe/xdxwnDwvwCnrLC44j5BBwuwC2FVhWFV
nsC2LmhoWEHrAlxcMBqIxBWUrdR3oMCu4mpWI+V7hsm34QJ7PimwQ9lKmtML
WhcyukiQE0Q/ivzaBfEqGPMKmUH0DNFXiBIzcAbwkIUekCnMtkmFHneQBHUE
WEV1krIZaSfhr9siVQSkawSGlQEPTQ76+3tYXLUhq8QTcTXpEzwNp5tsUT/F
2hGqPZOoU7M01yN1D1PdChZ7VK3xMu/HZvDs++ZT7c0n2pmPIl61Ne/z5UpY
bMl9JVhCxAH6A0I4ysWkslXIMjC9DRgUWPMgiTVXY07Cy4uFqQpDAFkvA5XP
ZgOUrk0AWN2YRFty4NUMKHM9mw3+kTxZGgH2ENaHR0Ir1Qav+CuR0jtpMa/Q
AlnVdYfaANdSR7yqA3nqBq6aOMGCgoLXr1+jB0VFRdOnT0cP9u3bd+DAAfLT
mTNnNtSl3SCv45xh8b+ABawYcWW3QdTA77lyWLYi4gptT9ZbIGbw7kzVTX/V
lSnKcxOVv45VHB7FjQau6ydb01eahwcEl/WWLuwhmYedYHwnjlfsLgGjMLVm
fu6CEj0mvAJk4QFB9KPAr1zZJL8V2MEVpySQEVcR30ocJIJVFNZXgue/YZOD
1cSPYMaitbga8yEssRX+nTStp2zpQMXGUaoDU6lzgdrfY/RPM9xLcjzN673N
R/ECfUhfnSa8amc+1JYrYW1lSlhrcAkLIWiRrjyB2jVIgi8uPegoa2St5CsT
pvA+H1EFEQbcXFkkdIcWhipfBwOyns+2sZgY4dXz2TSsSDdpOfBKXQHrlFKw
BA1SWSyvLO/BCsntBr+WRcNKX624sh7782O7rRqIVxa/Ug24lkFaw8psnxtl
ZWWpqamHDx9Gj/Pz80+fPk2eDwoKKi0tbZAruv4v4rTBDijQ4MrW2+KVoI1B
8L8POzjIrGdFYEX3hcaAuKIXXiCrLoRSz0PoGTf3Z6luB6iuTlVemKTETaGK
fSPkO4ZAgXdDf9nafrLVv0hX9pGu+Em6pKdkfjdwgkRcRX/DtF196UIG4GZ9
gW/E/AX+9gsGWZ8DrwLgpzSv2N3mk4pk6DdwvYd/K7FOTCpYCytaCKvwb/jp
Gv41ZBjuCx35L9viauyHLjO+dI3G03Byhyi3jlUf8ddcCtHei9e/zHQvX+5p
3orN4KUPzOcxr361KGH5cCUsUnJHdFoC023ojwMJJ4Sj5XpczhIgi97Aorch
C7MljUFWOLS1F4TAgCB65vZk+e/IDE6V30V+EM83JMOISIYhMVYCrVl0S39V
PFWVROGF/jQgsTIxCW3xilWDzA7rLUtYNYEVgwu+srIGS/1hZRtcy9z4WStY
FRYWxsbGHjt2jHy7ZcsW9nFgYKDJZGqoK7pFBvvW6O6RbD0HLqG4sjaDBFbc
h4hr7HjxPYZXsWRJK8wrvJ4VLl5RZNINcoKWA4IwNxAuis0DZev7y/L7ylYh
Xv0sXdpbmt1dMrerJLUzB5wIaMKki+1zvoRET84hVXQhspATZK1fUAdXXkrY
DMZmMOwbiUUCrMD6Aalivqd5FW5JKglNKh6sBv79PVZc+eEVt4i4Yvd/wS+K
1cOUOyeoT8zQXA3XPUp0K5zvYcr1Mu/GZvAC5tUZXgnrQFvzXl+uhMWW3HMx
fxboKhKo3YOlWLfoAEfLcTmLqb0bSEGeX3hnexsYiVUZpy6LUpVEqIrCVG+w
NzTghZTvTZc/8Jc/DIDOUgPuMiW8ehumKotQQVMWbpg3JVEmfhWLIMsWrKxn
6HDiqjawsucEBTysJ6+W2UgLcNV8TBDBKjIy8saNG+wzly9fXrZsGXrw4sUL
xLGGvahbWPBhRVcVeMqKA5etuwcaSA8ze4fTNMsmK2alULwEH+5hwJMEKWIG
H83hylZnJihOjFUcGaXYPwJgtW2wbBPm1RpcvELiahFygj9ynQax37pGfQPT
W0I7uAZ/5RIEie8NgY0eQdYs0q/+uSsZELRNqo5chmIziCQWSZpUjAEksIrt
DEUtAda+JukaxsCKlXAgrv6XFlcjGV6hr+waMuzbOT1bezNK9zTF7W22hznf
27yPdDK8D36QLWEdaScoYQm6RnEJCxrXca8mJg8IJ4QjppxlID1ajMriCu98
iZWOkRXDIQt5wzd4IWUEq0cYVk9nKV5gn1gQpCzCvCqPUEHfe6zamMAsOJNq
B1mMGbScoSPscq8/rCzIUytwGay0k+M04HmFDq4si8jLy5s8eXIYE5WVlUhQ
IUuYnp4eHh5+9+7dhrqum2PXqOOwASvbTpAHLgtYYV6Z4L6BOmMarL1AKldI
X1XEWy5pVYhX4XsVCrxCTpAtW53H4uo4lNnhQtg5VE54xRav2FdI64J7RL9z
JbyKwHwI6UAn+lHwV67WyCKwgp92dMUpsZmkeIWoxSOVhCPV99BzRToZ+KQK
hXSF7AhJdgN5QCKuiBkkN7YgSwWOZYtXveRQvBoNxSuyey/T3SsXe5rXI8eH
eXUUO8EzpITVXlDCortGvczrcAmLlNzRVT8PeEVLLEQJJJyYcUDrQpZlb8M8
XHhPI/eiVZdFq99ib1gcCrx6HagEWEHlSkEq7QhWxaGq0jBVRaSqKlptjFXj
1WYoUrqn/2i6xgJZNEity1Y8cWUNLkuI1QZW1ZehhPCpFawslJUfL2p7MVZU
VDTYhd3i9BX/kFYLK7644j4OtpOBgZWRrBWTjGGFV2Kn7xkRbWMtvlrF4p7S
Bd1hcQP0OKmzazzmVfQ3rpF4BnFYR9qCIVYEdwBeWSCLkIrhlW1YBX9N8wo5
O36piiVV/A/wlYirUBpTTHbkYEVavAb973uDiBk0tBn+T+7eFmP+44L8YMCX
0HklKF6F6u7FC6fR7UZoamc+3M58vD0ILX4Ja48vV8Jiu0aXQ1cDaBgMnBU9
ONdpWqQz5ehNKzCpbEqsxZYSy5RIIWSVR4PQKo2gl2gowBX4l3MUoKyw6IIZ
OkhcRaqM0WoT4lWc2kS3Y1GW7e4YWfCY7h3V2S6z2+lbMNgSV3VvYLByc3WG
Va2cYGOGM+xDQ4XdJqsF9nilt6i088EF4ipNR2DFrMCg5WAVAydtSRR9H67X
YRRxgnihGNXVaaqL0MMAw4JHRoO42jNcvn0ItF1tGCDL7ydb2QeGBRGv5uPZ
N6k/SJK+lyBexXVyjWEkVgQuHAFGMDEIsgJJu8KXHKxCkIIi+bVlEgNowFUp
rlT1HUOqzvQEHMQuhDLCK/p34QVd6ezgSgr+iFQD/v7eIJ64Ys0g4tXYj0jn
lWz+LwrovJqgPjETF6+S3IqzPCqXeFat8rbANSirX0kJq52ghMWW3EnXKCIP
TAzkJBaQZ67WNF9rXKQzImSx5Sw+skjh3UpiIbFUFQdTBSuiVGWRMHnQgD0g
olZhsLIkVFkaxpTZo9TAqxiGVwk0skz0DGje7EILb8jOKHRYuRIcipo5QcGW
1bk5Fly155V7rZxgI4eT7EY9w7JvYSG3zrYAXPNtI4vAiq63Y3HFgotzgsxt
bsowrN7i29wQM/gylHoSpH4wW30Hm8HfpqougBlUHh8LsNo/Qr5rmHzbEDmY
wf6y1X1lubjSvqinNKsbzavkzpJEjKzYTjA7j20jJ6NyoRgdwR24mjx6HMoY
Pesk1o98NeCWKn6pKg6TKvEHWAULxNV30jCMNYZUAKtg/OdIkr/Y//++x1Ta
QVz5MeJqNBJX/3GBaYPfSBK7484rP9x5NVt7I0r3JMWtcJ576SLPspWwPLtx
i69pu69pV1sTrmXRnwu/hCXoGvWAEha6NtG1j5iAW81X9gR4mtI0xrlaI0LW
Qp1xid60TG/K5fEKPV7Ok1jzsRAi5a8kMHemeChMEWrBRxkG5axCcIJKWGQm
QkWehx0W6itTMkWv2IAFG2lvMJD+PU5i6QS8clC2sjJ0lrCyolBtZZKAivYB
xU9nhpXZmfakzmEDVguFtzLB4or74ITIMvD7RTNpJ2hinCALLnL3wHK8JDsy
gyU8Xj0PoR4Hqu/NUt+GYUHVJdxzdXIcwOrgSMXe4fKdQ+VbBzO8+kW24mdp
DrRd4cl6XSSIVylIYnWGte/iWGThOcUR39AqiwShVlAHV1JlQs8whXGcvAoV
SvIAbWNhAAFWXeDmOOgrejICb8NzkRyp+LDiiyt+pZ3waupnrmGdpKk95TkD
FRtI51UQdF79mez2OsO9ONujJBd4VbXRp2qLr3GHr3F3W+O+tqaDuB2LLWHt
FpawVvNKWOgDwkZs1yDJql6wV8ZUTdVcTVWWtipbZ1ysMy1lvKGFxFrEzNCZ
y0AmBdk6gI8Raa14egQQRVEYrDtaEq56G6FChpEbHIxXs+IK/SIrrnglLKbj
gsBqER9WNnhlsOPp2G4rm2ypG6zsiC53B+mcTpANp9qZOoRtWFnwil/CEoIL
w0pP84pfuUqlu9lZcUWohbYvj4Hi1dsoQBbilT1xhbY8PEqx30++B/MK+cHN
g+Rr+8tWYV4t6QWwyvxRktFVQpBFJFbCdwhZkthOgrtLEGqFfU0LrVB4LOhS
4JWnJGRmDW5ipxeQ4RtAIFUXaXJXSPQM2jL8G45XwqFGwMKof0MDg31xRfPK
/wvXyM7SuT/haYNj1Yf9NRdDdIhXjxLdXqS5F8z3AMiv9q5c51O5yadqq2/V
Dt+qPW2r9rc1HsbIOkxK7kwJa5MX3TW6EpewlkBXA5lxfHu6YnVvmqJVqZrK
DE0lgyzsDZmqu7XEIoWsuRg1qRRQKwX0kjGJqkpQV+D50SWRAKvSSOBVebS6
AmmwOGb1UQIrnhlkeke1rLKitxTAyopXdmpQnLKyMnR1rkHxfktAJAfgcnJx
ZXaynalt2IWVQ16x+or74LJ0Fj0MRnLDU3zP06pEbWWCphKPDLJyi0is17bE
1dmJAKujoxWIVwf8FHtHwNIxO4bKNw6E4lXeL7LlPwGs5neXzOsmIchK60JL
LHCF39OwisHrt0QxM2JoZH3tSjqjDGwV/VuCKQl/vI+dD2hNqpSustQfZURc
IaYRX4kbIRhS4dr+nC9dyQ0s+lmJK8Ix+Ep49aHLrA6S2K6yrD6KvGHK7RNg
2uClUN3NKP39eP2zZLcXWcCrkpVeFfneFet9Kjb5VG71rdzpW7mnrfEAHjQ8
bKeERbpG0WWOPtC5tCXcOVCS/xMgqzKRqiTImqetWqDjl7MMFoX3hQJqwU/T
NGyaUihjMjSxA1Rx2wPAKgZgVYmcYwJlTLScPc3cRge/IN8Jsm1XOUJeVVcw
hzO5ukpUzQtQBEqOdZQ1uKxXjDE7Hx+cbX9qHrWAlS1kGVhjmCUYwzKlAa/I
3eQRsoxJWmMiIAv+Q4/XVMZpKmI1SGKx4AJxNUf9ByOuzk8CWP06DjoZjoyG
Zob9GFlIX9HF9l9kyAyibbJ7SOd3lyJkzf1Rkt5VkoqRxe5GPHhDSQxedSoK
QymC6eEkc2QMMCUQY+o7CV9BxXemF1uIZdZbIKUqllRp3WQgrn7A4upbGlZ0
V7xwXg+SUkhZCcQVnoBDVmPAvHJBvJrwiUvg15KEbrKF/RT5I1S7J1G/ztKc
D9JeC9fdQZYw0e1pJlwaRcu9yld5l+d7l2/wKd/sU7HNt2KnbxVyhURiWZSw
6K5RD/MKpoQ1j7aEt6YpCK9QVCRSFSmainRNZaa2ilfOom/7tcKNaW9gqaUl
U3UMdFsCk+kw3aYKr+pQEU/WwlIjt2hMUBuxEySqjIGVhieutHxYscqKQ0EN
RvfswYovk2oALgGIqoWVNbiaygnaW8YhKSnJHwd6wN+l5tiC5QhWNnm1wNIS
ciWseYKl+QTsStGakrUmvC6fMUFrjNewyCLi6lkIxR5AJK4uTwFYIX11ajwM
Dh4bozg8WnFwpAJZwq2D5esHyNb0AzOItkF+cFFPuLNMVjcpSCyMLPQ8QlYy
plZCZwlBViymVlQnGllEUIH6AkxJ4r4XyKdEvP4eu5KVQFYhUv0Id5RAX5OE
4oqFFX+6NCESVK7+Lyeu0DN+zI3v0QaEV5M/dQ3tJE3pKV8yQLF+lGrfFOpY
gObsHO1vobrbUfqHuKXhabbHmxzP0lyvslXeZWu9yzCyyrdjiXUQSyyLEtZG
poSFS+7c1ZpIlUeqdwyUrPuZRlZ5AlWRTFWkaSrnarly1jL8EZM1Z4jQIk1Z
TOu7gbRyzdVwmakxzdUYcY2rKhGGEY3xalMi2yxK4WZRDV23zxSKK4CVjhkQ
1HPiaqmwncNWFb0msHKouGzzp1a8akInaG8ZB/RMUFCQzV9pabCqjlcG/lih
VfGKWZcP/W/OdbYjZJkStSaCrDioX/ErV3/MVN8KULHgQhLrzATlyfHKE2MV
R8coDo1S7BoGxat1A2BwcCW+9dXS3tLFvaQLecgy4NvNgDHE7aNJP0gScQUe
USsWi6hoUp7qBN+CAOMN82HtBAnIwhKLrCPKkorIKgSrjO4ytBm0MWBxRWbr
CNZ2wM0SyAkiQWWwGBZkefVvAa+mf+Ea0Vma3lu+fLBy81g10leHp2tOzdJc
CtbeDNfdjYUD/meWx+vFnm+XeZWu9Cpd7V261rsUIWurT+UukFgcr/glLF7X
qIFUs5nlp25OVaxneFUWoy6Pp8qTqArsDRGykMoirVkGtvs9F1FLT9vDJZgt
C+E/JgDOPMs0ZeLOhxSKwAqXrThYIawxPVd2xJWQV5YtnVZEcsArx2qK95rN
FVZm+8s4PHjwIDU19fTp09euXbOYe9i8eMXfW/rzqhZW2VawsskrPrIwrwiy
zMmWU3LYeBwIZvDuLPXvM8APomeuTOXA9es4aGk4MFKxY6h8E+aVvddBkdlN
OvdHafqPwJnULlJELSS0En+QIKFFa63vQVChBwmdGRZ1AUal/ggr7KXBzSOA
TkldaLmFtsE/5Ug1tzs8ptsYOklIGwPBFKzs9yXdMz/pExcipQawZvAf0CNq
wDfBseTVhy4zv5LEdJHN66NYOVS5cbR65wT1gSnUiQDN+Tnaa0hiRcMxf5Tp
/jLboyTHs2S519uVXm/XeL9d5122yadiOxTeTURisSUstmuUWaiB/pQZS4hi
xwDJhj4CZFUkUZXI02XiWhaWWIJbgxFqLRdQi8ZOFlFKkBYfCinLW8CKbGzg
BgSF4sqKV3zsWIALTublbvbSFq+qKUPZgNXy6rMJxwTtLeNw6dKl5OTks2fP
rly5kqys1fj7Vv+wVFaLhPesdMCrbCGs+LyaZ8WrDIHEQryCTNKaE7XIDL6N
1rwhS4mG2FjE8iq4QhgiRK6QBRf703X9AVkrf5Gt6CNb9pNsSW/pol5SKGQh
lQW1LOncbrjJAXEGJVALoJSMVROiFqipH1gQSdN+lBIQZeB7CCI0oeeTsQGE
bRgDSEiV2UMgrpCvJK3vLKkIrKb+1wURiYirAVylnYbViH/xeeWCeDX+Y5c5
X0viu8my+ypyhyjX+am2jVXvm0Qdna45M0tzJVh7IwoO+8N09+dZHkWLPItz
PIuXe5XkeZWs4SSWkayLRUpY/InP+Z6khGUg427z8fr5zIS+jb/ADhfj+zUD
srAxrEzXVM3DhSxWYq1xp9OaWnheDzQ84KQfZzO5gJ63aA0rQir46WKdcDTQ
EazoZFhkB1Y0Q+AXa4AafnIXQm1+q2nHBKtdxgE9M2vWrJKSksbft3qGTVjx
k/u8bPGKft5SXOkFsBJaQvgVpLJSaF5VJmhLY2FZhsIoTQHyg2FQv/ozSP0Q
L31MXKE1wfb5KfjgWttfthpX3Zf/LFuKkYVcYTYxhghZ3QE1czG4MrDcQpna
laYWwldqV3JLCGlGN5pC83rAA/RtGkYW8YYGfJubdN42KC3EFbljDjsP0YCX
BBzznzaIToMIr/7OmUEDI65IMwNC1kjMq0mfuoZ8K03uIUe8WjZIuWa4avNo
9e4J6sNTqJMBmotz4JK/Ga+/n+L2dK77mwWArKKlnkUrvIpXeYHE2kxLLAOx
hNzEZ28oYa0FXhlI5Wcx7mqYiz4IkFhFoart/SWb+zISK0oFa1WREcO5tMQy
LtObiMTKd+eSTy2ElBz8KWdjNC3U0bmISQIlUukisFqg5WQVO41xqd5WWsGK
xyUCKwYvbjCsICRPbWHF/62ag6vJGxjsLeNw/vz5HTt2oAeIVEh38TnWLHhl
A1YkrYtXtsDFPa6huCI3RU3V0bxKgao74lU5WakPSaxIzetw6kUo9TSYehwE
vMKuUI1c4bXpqstTVRcmK5EfPDpGeXCUYq+fYtdwhYFph1jbX84iKweQJVvU
i6YW2ga0Fk7ErszuAC6CrDTGLbIIyuopm98LvmZiZKXTrlBG7nkKsordrCds
gJ5nJ+AQcUViFnObwvEfgRMk4mrg363ElYBXLoRX0z53Df8eiu1ZfRQ5AxR5
Q5Qb/FQ7xqoPTKJOTNecmwVsuR6jv5vo9mea++t5HoXZHoWLPQuXehZjV1hm
IbH2t6VLWFu92a5R+qpfgj8+9GGl4JbdcNXNKXLCq6IQGOaAJoR4RmJlaasY
iWVajS/kte5cCqlFnyq0rWNyCfeY1l20stKysIJdWsoV1UGzQdoqQFnpKDif
V+CxgBU8vCBqETGJH9QNVjYVlz12NdS85jqHxTIOhYWFpIpVWVmZhSM4OBix
yx4KnDPYPaQXsxLeUdcetWwrLpZXWUJeWd9uHvygjtVXLK9AYsUQiaV5FU49
x8sgPwpU34eWUSSx1Nf9Vb9Ng8aG0xOUJ3jIQpttGyrfPFjOnhW5v8iWYZVF
qIU2WNRLthBndk/Zgp6yrB5wM2XQWlhxZeLVWgh/FqDNesNX9BhBidi99G50
tQptBkzrSTMNbZBO2hhgAg5HKv49VSd94jL8n22QlGJ5RcQVejwct10RM+j3
bwGvZnwliewsTURCrrd8EbKEg5Trhqu2jlbvnaA+OpU6EwBsuRqp+yNO/zjZ
7WWG+5ssjzfZHm+WeBYhV7jKq3Sdd/lmn8odvsY9vga2hCXsGqWvtSW4CysL
lk8klrAAT0/e1g+Q9ZasCIolFhTecRWripFYCFDwIuvcucTUos8N0vxABhBR
5thIA7F+LKyW6BjHp6cxxXKPsXvsY8tcIYAVPy3AZZm1hFW1brHJxRUb9pZx
KCsrs7nQnzMjiw8rG6SqAbIE4BKIK70NccXevSuNyVTglTER8wovflXMWMJX
eBlkLLEouvA+U30zQHV1uurSFNW5SapTE5THxykPj4Yra/cIxY5hii1D5Buh
9g4SiwXX8j4ALrQNgAvn4t5ALYSs+cTNdQd2ITShbbKRHustW/wT3Mk0GyMr
qyfjCnESWBFSAdB60eKKPQhIXJGmhRlfwM3rZ3zuOu1Tl5H/ghHAIf94bxCf
V1hcDf9nG4viFeHVuI9dZneUhH8njesqS+spX9BHsWyAYs1Q5WY/1a6x6kOT
qJPTgVdXwqDq/jDB7Xmq2+u57gVZHgULPWiJlY8klnfFVp+qXb4mIrH4XaOw
UIMnff3muNElrAzaEhaHqm5OlhNe7cVrJsMKxozEqmQklpGVWOs9cLpDrmMI
lo9vbpjH3C2ajyB+ksXhSfcpCyuGVJA0fxhS5bpxuUKQDKwYCuXi5CGrDuCq
Ca9sgMv+tebk4Zz7yZem1cDKDrUMFkX4BcJ+GDv3nedKWIRaKQyv4oFXb/FK
yIWRwCu08fMQ6kkwBfoK8wpXsdTEEp6fpDqNeYU22z9SsWeEYucwxdYhMFa4
fqB87QD5mv7yVX1leX2F4OojW4p9IiCrtywbKygELvQABBjQTJ7zs3zJz3KE
rIW95dm9BK4QfSUaDJEquzdswL5fPAEHOk6DOkpm4bIVIlUAJJStEJGIGWR5
RR6QnnaWVyysUE78ryvSVyHfSmN+kCZ3k83rLV/SV5E3SLlhuGrHaPX+CWCT
T5PGhgjd/Vj90yS3V2nurzLdCxYQieUpkFh7scTil7A2wKxDKLmTic+khJWJ
FK/GFEchS/iSuT0ECrK0QkWMuiKBq2LREivPzUQk1gYPkgy+aHYBtcjqfytY
/vByOS2fWHbZhhWmE2zGX1Ie33SMZRcHq1wbiUEnIJhdcNW72OU84qoO0STW
1XHYLVjVmFocrBbaqlzx2trZe+LAY57QAl6lYl4lMbzCK4sWRwGv0MYvQknJ
HfGKejgHLCFC1q0ZDK8mq4glRFsewJZw53DFtqEgsTYNlm/AKiu/P1BrdT+g
Sl5fzioiauX8jEQUSCkktLCgwo1bfeTLcOb0AWQtAmQxrhAjax7WYAt6cWqK
iKvEH3CP6LfQI0rEVQANKyhbgbiyMoPoAVnqisDKmlfjP3aZ/rlrYEdJ5HfS
xK6yuT3lC/soVgxQrB2q3DpStXcs8OpkgObCHO31UN3dKP2TeP3LFLeX6e6v
57m/WehRtNSzhEisjbTEMrAlrB24hLUR84p0jS5zg7tiZdNdDSZsCd8Eq25M
lu8cQDvccrzoOsyjSaKq0mCgENpHkcTKBYlFa6qNHnxwQRJqrYUxREwMPU4+
Z8gzegHQlvHJJoAVd+8edm35PHfIle5wVq+sAayEoosFlzWyWiGszM63qxZN
VrWDFbN6to2OLJurYM0Tgot3W2fWDAKvEoBXZbHQz4B4hTZ+FQ5DhM9DqadY
YiFL+DDQild4LuERXMLa54cl1nDFdqSyhio2DwZjiIQWohbaJh/LrdX95Xn9
5Lk8cBF7iAQV2mb5L/IVKPvK0QMErhwssfiuMKsnhymivtAzbOWKiKtgRlz5
f+7q/xmUrUb9G0BEzOBgK3HFN4MCXsEyMq6IV3M6SMK+lcb9IE3rLlvwk3xp
X8XqQcpNw1W7RgOvTkyjzs/UXA3S/hGuexyjf5Ho9iLF7dVckFiFSzyLV3i+
XeVVts67YrNP1Q5fE5FYvK5R+Ba6Rj0EJax0rRk3cxaHqZ7NViJe7RkkOTCE
phZMpUmgqpKpqgyNMQuWyYLVG1bSEgtecJMH5EZeArhoamG8uNnIldy9eBij
x5GK7vUS/Io7LOGFkyALzmoGXHQ65pUdavHBJYBY64CV2cn21lpZcR9TzWFl
YQ/trTWaxVtVhnd/HOAVzwyaE4FXFXixvhK8sijSV28iYIjwJdzTGVQWQtbD
QOrubPXtGVByJ7yCCxaX3A+PRshSIlcIY4W4kIWFlmIjFlpos/WD5GsHyhG1
CLJW9gU0IR3F74VY2Y+mGULWMowsg61ABFuMDSOCGFJcFrObA7+CmhXw6jMo
WyEniHhFzCDLq0FEXOGedgGv2OIV7hSd8qnrjC9hFVOkrxK6yBCv5iNL+Iti
5QDF+qHK7SPh7R+bTJ3111yZrb0donsYqXsep3+ehCVWFiexSvO9yzd6V27z
MRKJxXSNwuP1XtCFlechKGHhuc/GOEDWqyAlklh7cP3qyDAaWTD1L4kypmqM
czWmBVrTYp1pOe8s2uxB5yYPAbswtQyk/2G1myBXCRK2WcVBzBJWsA0HK3yb
V3fyCcK3ebxkwGUXVlbIqlFl3iHBWF7xLzSnIkC14Tx769gG1gRcgp/aa323
WqiBK78zC7lbRFW8tjIO/GAZvbiopggji77ZBFZZjzheqa9Mg6sV6SuYmDNO
eWysEqmsQ6OVxBjuZoQWQhbabDOAS7F+kGIdg6xVDLJQIkAhUll3n6LguUJQ
WaRahZ5BKENPInGV0Q16RPniijRcTce3Lxz3ocvo/7RhzSDilQGve4y+Dv5H
G5tm0I8ZGRz7EazZPhuLq5jO0uQfZXN7yBf+JF+G9NVA5YahICz3jlEfmaA+
PZW6NENzM1B7P0z3NFr/PAFcoUBirbaSWDDxGd//a4MX2zXKlLD0IIORJYzH
ljBE9ecsJeLV/sGSw8MkJ/ykVVGg62CecgplSteYMrX0zWuQClrjThevtnia
t3hA8sHFUMtA+h/Yli2245T3DH0eMrecpnnFJ9VqQcKJvZr5LbIBQy14xpbi
qhZZtQAXgy/rRRicqgpUw3CSHbaEFVkE2w6UbILL8hkHU3Us5j5nsSOGep4Z
1LHN7XxKlOMlkUui6UIWNDaEWfIK6Su05blJqjMTYZTw1/FQeD86liBLuW+k
Yg8uZ6FtthF7iJG1AZClIN4QkIUFFfmja9HzAxWrB9Ddp7nYFSKVxSILJSHY
0l/gGYQvJK4sZjcHdnAl94NGymr8Ry5jP2zDmkHMqzYsr9DjYXaKV/SyDB/D
sldBHWGl5fgfoI8iq5d8SR9Fbn/F2sHKzcPh7R8Ypz4+iTozjbo8Q3NjjvZu
iPZJpO5ZrP5FkturdPeCLPfCRVYSazdjCXdgXpGuUbqE5c6VsNK1pkQ8Shim
ej4HJNZ+7AePj2DWTI5Xw4qgzMLF0ISwDN+7kDi+rZ5cEnYJwQXbrGc6H0iu
s8q1PFysoXWUJakw6Ais2ORTy8BWt+z4RAfesLaKqwU4QTaafLetYOXG3WTE
oZpiGWWNr2qmFtqY+4yvBcEsQh3bf2WkV5Xh2PWWQdarcMyrIHqqyI0A+C/+
CiyHBa7w7CTV6Ymqk6Qda6zy8BjlwdHIG3JjW45j3SDA2vrBCvSAIGtVf65n
nkXWElzjWoYhhthFekSZCTicuArAt4Se/InLuI8EZpDlFYrB/0uLK2teEVgh
Mzjpv2AGQ7+RRH8vTeoK4iobF69WYXG1zQ94dXi8+uRk6vx0zdWZmtuB2geh
uicRumcxtMR6TTrel3iWrPAsXe1Vvt67EkssA1PCggf0xGdPyxIWbnRnLeHD
GQqWV6dHS43ReGlQMmE5HbemZ2uhk4ovsbZ50mmTWnRZHhe1NpD0sE6MNfx1
Ha8TlUcqGlZr3AXTgnjUYsElsIoOwGULVjUEl8ird/HXGVjZzxrLLce8omFl
2fGut5r4jJClM+FZz/RyWAnaCtzbYM2We3OoO7PU1s+fm0yElurEeAGm9o1U
7vFT7hqh3MHW4XlCCznEDYOxYRyq2DhEYYGslcLKPMIU2nJFX6jDI3FFekRh
As73MAGHL66m/hfUEd8MEl6RXSI97cNYXv2LLV650Lz6ENbom/Kp6+yvJOGd
oNKe2k02r5d8cR/Fiv6K/MHKTcNUO0nxaiJ1BpnBAM2N2do7wdrH4TrQV9H6
F3ig8HUGLbGKl3q+XelVlu9VsdG7apuPCUssjBRv82ZvOyUsaHQ3MpbwySzl
9UnyQ0MBWadGSS9OkJnwasawukIanvo3X0vfuBBLLEQk+Ol2TzoF4KKpZcCD
iVxu4iW7AeMi6R1e70F3RzD+EU5s2kV6wMABl8xwpDW4qqOWgS12OXR/FuBq
SbAyN+me1w5WthKTCp3JvL6X6nglgJU9ZPGoZUrVAa+YFfwqMbLK4rQlMZqC
KM2LcM2TUOpxMEisB4FwEf0xC4whElrXmFoWGyeBWqpj4+DJQ2OIPWSppQRq
DVMgQG0aAl/RY7TZFvwMQdZaK2Qtx96QBddiJK5IjygjriK+FYirSZ8IzSDm
Fdk3pKxAXP2DhtVwa3GFYUWKV4Ed4U4WiV2hSXVBb+RDFXkDFOuHKLeOUO3B
g4O/YnH1GxZX90N1f0bonkbpnscAr14lu71Od3+DeLXQoziHJ7G2+BixE8Q8
8QFeWZSw0AdNSlhpYAkrY6gSbAnv+SsIr06OlF4YR4+TwjrGqXi2chZuTc/R
sxILoQk22OEJaUEtprRFv8hmjlGQ+KcGuggmUGX09ujF13kQuQXn9loPyHxh
kr59Fl+rPSyrW6uE1HIwklhd2cpQy5ufNotoqspbw8CK1l1uNhSXLV7B8/bW
SeYXsnhCC/0KQpYJCy0jvUiytixeWxSjeR2leRkByHqOq1hoy4dB1H0ktGZT
0O6Oy1m/TVdfnqa6yNrDScgeYgUyTnVkrPIgotZo5b5Ryj0jlbv8lDtHKLcj
uTVcuWMEfIs22zZcuWWYcpN9ZOXiMhd6kMMbUkzugifg0LObQVxN/ww00sSP
BWZwOF7imOgr4NU/ODPI8QqLKwKrMR9B55X/F67BX8MizCk/yub1lC/6Wb6i
n2LNICSulDuwuDo6kTo9lboYoLk+W4PE1aMwhlex+pfx+tfJbgWIV/Pci/A6
M29XeJat8ipf6125CSQW/dnt8OEmPkMJy0NQwspAJl1TRVtC1aMZCiSxjg6H
+tW5sbKrk+VmvPo6LAiDLGEmtoRLdNAxxZdYO70gbVKLSYwmDyaZZwTlL15u
9qR11wYPDlYWmY//NAMuIbU8uFPXlsqyhFXNkNUiedW0f7S+sBLyit81KgAX
H1Y2hwsFvKKRBb/CE1qIWkZ8K4rSeG1xLCDrTbSmIFLzOkLzMhxM4pMQ0FpI
aCF7CEJrJi20MLXUF6eqz0/Bo4eYWkhrHR2nOmxFLfR17yiAFXqMwOUYWXn9
QYYhS4jE1QJGXLHgCu4IK1zNYCpX2Ay2IWaQrMfO+sHBuIplaQbxUlfop0RZ
oZxIF6/ADKZjcZWDxdU6LK52j8aNHJOpc9OoKzM0t+Zo74doH4Xj4lW0/nkc
5lWS25s098J5+O45SzxLlwOvKhCvNnobWV5xE5+9bJewGEtYiC3hH9MUhFdn
R0uvTJLf9odjQlvCudgSkqr7SqHE2uUFCeDiUUtoFQ2k3sXia5sNrPHZZSDL
xZAeifVYbq3jeMXBygJZq5lkSvE0tera9sCHlYUasXm9G43GRrjqGySaVlnR
H019YEXzygaybICrNrwyGAxWS48CsshNVMsStKVx2rex2uIYTRFuzULUehGm
eRZK/Ynt4X0YNKR+x32kN2Zw1EJbnp+iPjtZdWqi6tcJquM0tVSHMLX2j0b4
Uh3AEw8Jvhwja80AuDaXMJWrtB+lZFiQiCt+LwThFTKD5FbyBjw9kPhBRCoi
roYJxdXIfwtghbTZ5E9dZ30lCf8W2q7m9gBxtRyLq41IXPmp9o2Bd3dqCnXR
X3NtluaPIO2DMN1jhlcv4vSvEvQFwCu3okz34gUeb5d4IF6V5wGvqhCvtjK8
otfu45WwlrvTt5+Yj4dx05A3B0uINiaWEEmsE36ArMsTZDeny03xWGJZWMIV
emipWgcSCxEJNtjtJaAWyR2C5M4fFlYWyaMW23bCtNALkAXPr62eV8QSGnjB
aS17Y4jVKSsHNuratWtpaWnst/aWVXeeaExk2VRW3OdSB1hxvLKilnCGjg1w
2ecVDSsLXjHIMiXrjPQNv7TlcdrSWKjJF0WB1noF9lDDF1pgD2dRt2ZSiFpo
s9/8aa11bor6jBW1joyDPDQGhAqruPjI2jCYQxZKA56qs6i3jO25SoAJOLDY
e9jXYAZJ8Yo9Xcd+SC9uTPwgyyu+uCK8Ig0M6KcsrMZ9DMWrOR2gTTSpK5hB
6BHFbQxbhqt2jVIdHAdv8CwWVzfnaO+FaB9iXj2NhMFBKF4luhUkuxWmAq9K
EK8We5QtA15V5ntVbfA2YV6ZyYoN233IREKyFhYuYblzJax0sISV2BK+DgZL
eGsKzauL42Q3psrvzlSQxRxoS7iAZwnz3UH/EL20xwtytxcHLuvc6UWfNtYa
bLsluOD03uxp3oRffKMHn1o0rKrhlYd17b1u1KqhEzx69GhAQEBKSgr51t6y
6k4Vjcaram2gY2pVzzRb4DIYLFdO5k4AO7yCH1ktNcMiizGGOrachbYHasVo
YYGsKLCHL8KR0NL8GUI9ElILbQlaK0B9Zbr60jT1BUItZA8Zap2YoDo2XnVk
LO5iGq2yjSxGZRFxRZwgHhaEhZETOkOlnUwYRLwic3CmfeoC+uojFxZcFrwa
yucV4wRHf0jzisCKLV5F4+LV/N5cj+h2PxXpEUXbX8Di6vcgqLQ/5BevEvSv
ktwKUoBXxXOBV6WYVxUrgVfGDbitfYePmTRi7aQnEuK1sLAltChhpWiqiCUM
VT2ZDZbwygTZ6VGArGuT5XdmKB7jZWcElnApYwnXu0OdHGsn814vmlp2kpZh
u/EDUvKyphYGF5zeW+laFkEWq7UM9BiiHV5ZSyx+T2ntwVXzstWuXbvu3LnD
8sresupOFY3AK74WpRezcqigrNFUQ/VlAS4DPYBo5ROF96yHzXiTCrEfxDnX
ilqMxMK8+n/tved3m9ex/3vfnLhIJNEBkmp2/B/wrnvuXTk1J8lJ+yU+J4nT
7NixE9fYsnrvvVMURZGiSEqUSKr3bvVeLVmyrN57Lyxix90zs9tTAAIgJMv2
M2sWF/hgP6RIAh99Z/bsGS8N/KIdQxYbVo/2VApk3UWhdROo5QZqDXRdxA1E
0loneru+6qmodbBL2v5PwRm4dmFCnmktDAwjImvRm20peUW8yvufF6f8+gXK
tNPO4JAfwewbE6+ysAE7VCmgKV5pwSB2j/keTRhkz0pYdf6BSF79As4MFr4G
mXaqEWXiajOKK6oRZeLqwiAou7pq5BUkr7L9lTkBxquaguDjomDdLOBV4/z0
5sUZXFatb8eRxXthYQqrwpTCggOeLCSsx5DwzoCUSxgS7nsPePVV5zZne7a9
OiCFDhtCSDhNCwnnipCQKSKi0MaMSM6f3aCxi4LHNUZfnQ4v71VaLms5p5YE
FxdaJmpFlVgKVsZSBxtwJQQrMhb3SV5Faqv+TNmT5lXC2XUDTxLLyRdZRJex
z4zUV+obTdOzWBq1dF4JZGXB+E5PncpleR6N8jxgvMIk/D2e0WLhofvaIMhx
QVKrv+tcP9eZviw8dB3v5YLwsEfaF93TMKnFkcVWgspigeFHqZs/TDVuIKas
fCdl+dspVE1KwWDBb4BXlLwa9wsYpjP8J88PJl6JsvZPf4Bi6Z95MQPpKym3
3hG8kpGgCVaf/OA5PXmVi8mr8jfaUo0oE1fbPsbUnKgRZcEg8EpPtk/w35/k
f8iCwSmB6qmBxwXB2qJg/axQQ1l6k+TVqszwOuBVeB3GhivsqhoKeEjIkEUS
C0LCPiksJGTB4KEPoaThTPc2l/ul3B6aGp6EyMpzQ0goC7EW8Kw7iCWi0OYM
5Vu48+ub0IFaAC7+IuEpL8UueJGvTjeWocpNQwu1FqkdQztecWrZ8CoSuJLE
qxbbqj8L9kR5lZStQP5HKUk0Jx+dVxqyIoJrqs8qsdiaxolennsf56keS5uG
gCzmDymdRbHhUIDVtcHuK4PctsjSw0O2kiFrt5bUYkJr0wepG95PWY/UWv13
QJbk1Yzfib7Hv4KxFGN/DrwaJniVhQecu/0rwOcTrfhKr2dg4kqCiyJByrGz
Zz8WsGLezZK8mvsXKGNY+17q5o/SdnYGMsgaUeCVKdnOeJWNyfbcQHVe4HF+
oG4G8KqR8WoeQmNZBvBqbTtAFlW5q5DQUtWAWffmye4GRNat/inne7Q99kmb
g8irU13bXOzT9ubg1DDNPNVDwjIREi5DZK0VwklgKrwVHK7gA7hCHNskdNcG
fHa9Qha8yNdyoRVela7n4WGl1FpLtSBRF1p2vII1AlyReKVvIBK1Eihg0HkV
qa36M2VPrgQrQViVKOeYEo9j1Fo2a4hXUQ5B69NULdOfucqy8KphoreOeIXI
qhkL1KpGoVXJqDXSI5HFFt8Y4rYi6xTGhlJoHcYNxANd0vZ9mrYHY0Oj0Epl
Qmvtu8Artqzi9TbEq/z/fXHqq9DsfQLyaqSZV0CeTzEepP1BE6+kuJJxIrN/
CF598gPgFfWQGWhMXs1/EzLtn32QysTVni5ABqoRZby6ZE22T/Q/mOx/NCVQ
lRuoyQvU5gcZrxpmhhrnhJqJV0szwiszIYWFvOIHCXl7ZGNIWOClLBZTWU3Y
1/3h0NRr/VIYppi+OoJVoxd6tb0+MOX+iNQwjm/GsznYI5RCQiaxFmO1JwML
E0sonDigtmUyh0/Zg62ZHFlbzODKonT9OoSVKUhczcGVRfVaK1RSi6gVXiLk
1iJ7ammwQm+JV1ZlJd96Lb6vdV6Z2qonmwdJs68HViUtuA4r0/Uo4IoIND0w
tC0lnW5u4GDtlMW/bw6Kq2xv4yQvQ1Y9qiwWFdZiKSnFhtUiPHw4EnJcd4fj
vqFE1kDXhQGu8/1dZwW1jvdmyIJ3FsSG3dIOdk3b3yVt76dplIHfocWGTGVx
Xv25zazfQ6NRxqvcV2E+zgSYSq94RQ36svAkThcLr7KwLx9krrJkJPhPlLb6
h5aZJ1hR5dXgn7wwRkteLXoLgsFNH6Xt6AzdGNgXPNEPMu0XGK+GeHiyfQRU
tt/FynbOq6mBmmmB2oJgfSHwqmkOipCFLPTLCK+A/gwGXplCQjqYMx2RlSeQ
NQmQdXdI6sU+KV91aXP4I+DVuZ5tr/VPuTsstXpsWhiPP6uQsAw7KizEqHAF
1DYAcBBBhCkOK/KtRmpJZG2C9fAi/0wvilDggi9CcmtlusrDL1fIUtQy8soM
K1uJVW6DrGQ1YYjUVv3ZsaTzyh5WLQEqFlhFB1cs6kujFrmxlNT+nA6GhBQV
YtG7tCZMZBG4GiYIcElqjQZYMWTdH+GRyMIMPFHLLalFQost/rKntnXIhVYa
E1pcZX0AEisLT0MzXs1EXsHm4K9h7Bfw6mecV4N+xGHF9FULvPq/VXUoRYIU
BrIFTFzJlz0lr8bJ5NXrkLxa8x6UMexGcUU1oucGQkMGm2T7JKwUzQ1U5QVq
8gO104P1M4KNJaGm2cirBcir5QZehVejjNGH1FO70Rn4B6La0VzwxknuqlFp
Nwelnu3d9svObY58DMi63KftnSGplaPTaNwqL8QqEbWj8xBZS7F2fQ3k3oFC
FAluz+RuopaOLKQWFVyFP8swlnIhrGR4GJlXIB0XieM8IpEFj825LIvEsvDq
21fKHsWS+3OZYMX/HMmGVeyKKzq14C4BLvt5OjL3jsiC9cZhhWRQlMXARdQa
763DTUNGLfZUJaosQhalszi1uNZyE7LYypN9XF/1cn3Z03WEkvAotCg2lIHh
eiOvpv8GhukQr8b/AsbWj8TiKwOvaH9Q1LfT4UHiFYkrduV93BMkWH0iYEXK
6tN/geSVBFfeb6CBDCWv1r+fuu2TtH1d4R9/vC8Eg4xXpmT7HUq2Z/sfTglU
Tg1UT4Nkex0TV8irZuLVfBb3ZYSXZfIUls4rMTGHF7rP1JA1DZGF1GIrH4xM
uzow9XSPtkc/fvHYJ4Csq33bPhieWj8BzubAlyoQyJotahsWiUSWzL1vzTQg
a7sJWYpa8DpX6SyBLAmrmHklj+oocFnT71FDwu8UrMJJ/dHMysqIlCcBK/0u
83eJaw9xhnCJLJu6dyolJa3l00vfs6Ka2DokanmIWqLagYQWvKEgCU+xYS/X
0R4uQhaprN2IrG1mXsFMijzk1STBKyoWpe/b5z+eY7zqrnjFmzOwp5isetsu
EiRYRTEJrhV/g53BnZ3TDnYHXp3q7zk7gCfbr1iS7Q+svCoKNpUgrMrTgVeL
MiDlvjITYEW8WsU+RRroISGTWBJZFBUispqnALLujEi71D/lZLc2X3V+8cSn
cLjyev+URyPTGrNd4VyBrCJR21BhQFYWpaRAZSGydliQpVELXueb1dYhf+Eh
sqLxallEXvHThfM1cJmRFXR4RZasHy0SrGyE0BOAVcTvEt8eokCW3YHoLNo3
zNMjREYtn2pBw7vQeJsnAsEaQGh5H48z9P0zUev6EBBa7PrFAe5z/VUSHpEF
KksGhrs/AX3FVq58py3xKjpY+v/wOZ1XnS28ekfA6n0BKwoDO2PxA5NVXf7l
ua7/CuKqDz82CN2PTeDa/Sl0Y2CfsmDw7EBzsv22nmznwWDw8XRMthcHm2Yi
JcrSw/PSIYW1FFNYa0hcabzS2/cpZOF/K/k0NMTDnK2sGue6OSztQh/oM3Py
0zanu8Cv6MaAFBYVNmGtexYlsghZsxWysig3rgJDgSwrtbYirJjQMm4asqiQ
v+pk+j12XumnoUVRVgvU+q7CKpykn65FWLUIrqTAKsY40faiWWsV+vXwMCvL
0pLUTC2fbJyVhREiFjx4a8d7H4/31ozzUs1DdMhIoww8bRoSsvZ2TiNeSZP6
Kkfoq9GaviJe9bLy6v/h4wWtkSC73gUxxR4AqRBW3XG6xPCfQg8ZFgwW/wHO
OC95O4W6XUm5RbyiZPtVY7L9vuTVNKgUrS0M1hdhMDiL5gymh+emG1LuGq/C
K6ijO4aEFRqySij37uXtrKGjNfxu7491XR+cer5X21Nd2pzp2uZcN0DWzcGp
leNczdgRC77aDDFPEJEFVxbxczr2yNphQBa81LdmGuocNqjAkL/k4uQVh5Wl
9F29hu2QZQurZL2jn1lrfT1DXLCyIuVJwCoKuOxhFUlrIbjglkK/TSpel1tE
rRxwWI9lD42TYAOxdoL38QRvzXhv9Thv1VhP5RjPI4wQ748EoQVvqKF86/Ai
prPO9HOZ8EWlWWQr3+b6atbvYUBh3qtmXrE1g/7rOQOv/uV7sp9MFg6aF6Xs
EAl+hOJKMepfsb8fI9W/QRmD4RjOb6Gb6Pw3oaz9sw/SdnySdqCb61gftw4u
mWy/ZUi2+x9NDVTlB2qmB2tnBOuLdV6FwhUs4sMU1nJMYVl5tQSGqILSkMia
pUWF+RxZbOXjbPe9UWnXBqac7d7mbLc257sDr670antzWGrVRFczDpfHlw2W
Y9GEQVBZfo4smX7faI8seKlvE7mszZmGCgdUWZDLWicqSyWyrLxaLHhle7rQ
Uv1uAJdA1ndQXJG1BlkJwyq63EoWrJTHebZaB1cWpeUL0af7bQ4ealoLFgtw
NU32NWR76yZ5ayd6H0/01kzwVo/3VgG1vNVYX8oW3xvhuTPcA8gaYkCWrHM4
0gP74GHpO9YzQA/SuX9uU/oHGFMYhVd9/wPmojJedRW8eh/FlejAoNJWBKvu
/8adfQqk+vfnev3Hc31+SKO7XpzyPy/OeK3NnNehgQxVMshg8FR/j0y2S3Dd
GuU1JNvzAtUqGAw1zhSwYvqKUliLM3jVqJFX4eWYFFpkRBbPvYuoUDhbWT3R
fXd42pV+KeeQV5ewwwxZVbYbCrGKYBkf31yO5Q3zcbtwsUDWaoGsLYisnRxZ
8FLfbky/C2QZeZVhOCvNkLUiPQKv8JewyNwpy/7AjiglJTMVXD25Qspn0L5e
WCUArlbqsTjAVWSXllfg8lu1Vhbl5HPBm6f4GnN89ZN9ddne2knex5O8NRO9
1ai1Ho/z1oyBN87DUZ4WkXW4GyCLxYOfvZey6h3onDz3dZj8Bbxi8eCv6PCg
La+ek7xiOoqCQZoqyNj14T/zUnYWA/b8d+5ZOKaQkYp57/98Xpa1084gCwaX
vp2y7v3UrR/DzuCRXopXpsp2+Q56IHlVEHxcGKwrCjaUhJpkMFiGvJqHKXdZ
NSp5tVxMJFwSQmQFFbL0qLCAu/zL3h6Serl32ws92lxGXt3o2/aWGAwNhVgz
EVlzfIJXAcWr5RgYGpGF1GoHr/YdmVZkwbObVCKLI0tksfjtElk6rxaHOIoX
Gc/pROYV6avvZiQoLbEfM7mwsiquaHfNTM73ahFc/Kkiuzhxhk4tdJmT1xRX
c66vcYqvPsdXN9lXm+17nA3UYhFi3Xh4y9SM9VaN9hiQpQJDt0QW8Wqb5NVb
bee93mY2nh+cRrz6JecVWzb0x8+ZeMXiwY//P0heZcGwG0i5vy8iQYTV9xSg
8MghkarPfz7f94fPU0PRya8ayto3fABlogfxgHOWtjmoJ9vZdUq2S3BBW4YZ
wbriEFSKlopkO4NVhTGFJXm1gvOKD302IUtO+5rBkQVr8GP9FEOb/Wt9AFm3
B6bcGZJ6fzSPrMOlQl/Nw4r3RVhBugyLSFdhVLgOTzojsngkuLOdKZfFY0am
sjZlRkEWlbvDyuWG/FUWpeYWhQwSy8Qrm/IGe159R2AVjv8nNSnP5MLKXm7N
5M5hZfVkfa9Y9hAjyy18yzBwoQvF1TTV15jra5jiq0Nq1WX76rHElC2uYypr
rLcyKrKolHRvZ6hn2PAetE1e+lbb+a/DmMJiPI9jy6sBGq9IXCleAaz+iQ41
f/qD7/WAHUDl7CKRqt8Pn6c5zuN+Cd3aZ/y+Tdnr0Kp99btwZhCDQc4rPdkO
le20OTgGgKAn2yW4WDDYXCqKGSoEr/Sq0VWZIhhEXpHEWppuQFa5iAqZxKJp
g4xa0zm1aie7H4xKuzEAxuhc69v2Zn8QV3eHpt4dmfZgnKs23wPJdho3b+YV
HgBck654RdVW2yk2ZMhqJ1VWFpZs8cAwKq8wiyWoJerbZVQYB6++87AKx/nD
mhZH10IJA0Rnkf5/pT2sohIsrn+e4XtFz8Zb2JVFaflCXXGBN0/zN+X5Gqf6
GpBaDTm+xsnwTmnADUQTsm4PMyNL8mr7R3AkZ83f2i5jvHoDefUa8urXcNh5
3M81Xol+Mj3/7TkSVx/+8z8Rr5iygkhQpK26I6z6IZ3I2UUiFfMBP9LOOIsy
URYMbsNg8HBP95fEK0xeGTYHRwpeYbK9EpLtwZpCbMtQElLJFimu5hlTWCZe
LedvdgOy5qqoEH/zXvAZ4ISsx5Pc90akXeuXcr1fys2ByKthqfdGpt0fm/Zg
oqu20Etnc2CxNRhci338NvA6dpBSjFE7xRAf5BU80HPvLfLK5uBzZF7Zd5v5
rkeCZLH/sCZZJZVVXNSKuDIqfxJBlkmPJYtakXLykUPF5nx/0zR/I2qtplxf
E+4hNjChBYemvbW2yKJc1gD3ceTVvs5Q4o68Sln2V5ivWvanNiWvQX+GKYJX
bNkIUd9OM+iluKLQ7wOklowEu/0rrCE0SWfXiVQDf/T84J88P/oXEAxOx2Bw
wVvQqp3KRA90A15l4bFBSrbLkzg3cHOQKkXZApW8mhGsLQ7Vzww1CnHFqTVP
8EpWjVp5RbVYy9MVsubjNhlGhfDUDOMI3UJvU76neqLr7vDU6wNSbg6CYBD4
OQr01cNJroc57rpiLyWvEB3BlnklXL02FKwyLbDKMIkrlb9CZMkjhFmUwmoF
r74FsIrUijnS9Vh+5NZXhJphlRB24gJXtGWx4TQmcEWqltfA1YzUYlqrGc/1
NKHKasCCBwOyRhqQRaXvh7ul7fsUDj5veh8aYS3/a9uFf4Hh9VSClWvlFTZD
ZuKqK4qrfwhefQiTT/+JHrOneiGsBv5IObtODwb9+PnBP5YNr14sEsHgmneh
O9+eLq6D3aFVO1t/sp/hJI6hsn0i/FoeabyqKwk1zBLHBoWyUnJLVo3qvFqO
D4hXkIEXyFrIo0K4TokszQlZDXmeyvGu20NTbw1OuTMUeTU67SHy6tEUd+U0
T90sHwWDsF4Fgyp5xauttps9Bl6Zg0FdX6kSLJF1zzJVNdgl27+tsIrUijlK
i+YWN0NbXxEaLolKj/iZ0yK4Yv12sQWqNj+UNdMVKS1PXsDDQ+BVLmwdNkyG
XFbdRCwrFch6oCHrQn/et2H/pzC+cPMHMLJwxdswWbVcHMnJfdXAqyE/BnHV
B8UVjR38ByKLPfvR/8t78VGOvd8PnyMuSWdP8cc/gZr2kT97YdKvYC7qzD9C
92N5ZnCvhVfmkzhaZTtbA5Wi07Gn6MxQQ6ngFYWBpKwWQP5KgUvnFcIK0u+r
jchazKNCuDib/o4+6fjfB0SIdbmeh2Ndt4ak3hmWen8kJNsfjnc9ynZV5rqr
pnmqCr31c/yUvMIvrosrbBezGQqx1JGcbVraaqugVmzJK1nPALfoVaM8JNTk
lh2vbDswhL8VvIrUijlKi+Ykwsr6HicplVxYtQiuJHy7WKJFibjoRacztLxW
PtzSjIGhDbLGKGTdxF5/J3q7jnSHEvddHyOv3kVeaSWjU1+Fega2EpohY3MG
EFf/DuLqEzy/TMgiXmWJHHvf/3xu0I9guLzu7Fl6MPS/X2DiChrIYDA4G7sf
s2BwIwaD+7rC3C4qZjjZz/4kDlWKPsgJPJoK6gUqRYuCFAw2zUlXvJqPmXbm
TFyxeBCqRjVwEa8QVuE11DY5A3NB6fCWp/qlCuwBBcjyScc/ig+QNcNbO8V9
f0zaneGpEAzigMLKbHdVrruaBYwzvDUzffUsKlwqxjcLXsF330RN/DJ1V7KK
118JakXhFYkrNY0iZMsrGRXyLxiVV7G8bb8pFqkVc5QWzVF+8FZtBcYfwbWG
OfK7JJ+NphgWHgeYa+CCT8PFmpuPJXJewWKMCpuw1KGBCrSoppRO7ghk3RiC
QOgNB3MOIq+2fJiy/l1Lyej/QH8GthImef34eRJXNCbVap1/8D3KsbOgb9h/
m50twAcvDP/pCyN+qkZ36Q1kdn3q0nl1KsLmIK9sx2AQeFWIyatZocbZoeYy
5JUtrGTKfYURXMgr3nqUkLUsne+yzQtyZJX6ITBkIR66RFZzobdmMtS9QzCI
vKqa7K6e6q4u8NQUeR/P9NXO8TcsCFAHP7gLg0Eurni/vkzpsEAvbt+k+r3D
UxGTV+mqQ7LOKxOyFhpOQPOvOe/bDKtw5FbMUVo0R/rZE4RVBA7ERa3EmNMC
HmdZPO5vF5COt+DjEuPMOCu4BK/gWSh18IfzfICsKUJiZfvq6OSOQNbDUZxX
p/qYeUXxoGzRkPtrgBU1b4fmV9pknG7/AsWiLPojWcVgRTn2Af8FMwqH/xR8
BKKJnC0jUo342QujWDD46xfzfwtD51kwuJwFg9hNlHgFxQyCV7abg4bK9gJ4
99WVhOpLQ41SXM3PsIHVElE1usIQCUpwwb1rUW5hhJVFaR9CFovsSpXDU7N8
hKzGAm/VJBdTWY/GuSqxr3v1VE9Ngedxkbd2lq+2zF83L9CwmFdeZVEvvo0Z
htbu6PA1jZiiw4Mgq1BZ8ReAHa+yqP5qWciMLAOvQuYUVgRYRXnPfuMsUivm
KC2abX/2uGEVG3ZikVutgZXNN7Jiyuj2a2KEle6a6FKKqyhAIWGWrM6SvMrV
eDVJ8apmrPf+CDitc7YfNMU63C1N1jPI+qvZf+T1ormvAmcmYP3V8J/wZjL9
fwjFVz3/jQktfsSmK7ILc+zPsYhv5M9esDqINHww6ufmUTir/g5ncLZ/ApVX
+7sBr7Kw7RW16TO2veKbg/cn+x/mBiqnwQAv4hUkr6S4igQrSrkrXmEF6dpM
GKW6PlPLcVH3hhBPZElkzVaukFXsbcj3PJroejTeVYW8qsnzPJ7uqS321pX6
6sr89YxXiwKNy4LUkh1u3JRhcIJVZFKJkzggrvgLQOfVihh5ZUm5f9vFVdiu
FfOjR4/69OkTvUWz6TcQB6wSxU4kcLUKVhFwFIVasQANRnYaHe/Cx1ZqCaAZ
RBfxilJYwCstJBS8IonFvBqP6lwZ5D7dF8QVJa+2yOSV2BxkwWDB/0KPFyrB
Gosp9+H/DSpr4H9BVNgbvReesmHgYg8Yx4b8GNqQjv75CyZna+TjMb94YQIG
g8V/aCMbMmyOwKvz1s1B2UZGVF49LgJkNcw28soWVstkmh03ClcLXq3PDH8G
Drfr4FLIwi4rDFnCYWWpTyKrLg+QVZ3tqsEC+Nrp3jrkVX25v2F+oHFxsHF5
sGk1DhPcIOZ5bVINkG1Itd5wYFA1cl/NT+JgfwYJq/Q4ePWdgZW0SK2YI13X
fwkxwSp5AZ1OrbhhFTN2bOVW1LvMjLKBle624OISy5illxIrl4eEUNuQDU65
dzoKfWmgmwWDX3RPU8Xt4jDOnD9Csr34dy8W/gZ4RS372INxP38epk7gyFSG
pn4/hNw7u07gYo8H/5gFgM+PQSKRjxXOlqkrv4SGDBQMioYMkLza8QkUM2Dx
FfZsZ7wybg6qGROQbEdeFQRrsPKKrW9kvCrHN+98AatFtrDK5FUNqw3iCni1
AXm1gV2h7UJRxLUI3+ZzqZ+5Xzqsma2Q9TjXXT3ZXYPt++oKvXUl3vrZvoYK
f+MC4FXT8iB8KdwcVI341CxCq6Yy9m83jpyQx3DgdpHCsudVhGDwWx8Jtsbk
L8H629BLQ+PlT1zqKKYbE9dIZnDZ3RWRUTBSCh3/1xafRlmv8Yr0lZ5yl9aM
x6IZtagiqzHbV4tHC28MgWKGE71ch7pBsz6qZKDKK8Yrpq9m/+HFma8BrApw
RA57MPlXfFAOCwyxizuoLObsKUYq2hBk6ovBatwvXhj3S7MD7sTj8f9HNGTA
0RI4xNnEKzfxSp+Jc924OfhwSuBRHvKqKFhbAsl2+HkrkFcLIsEqk8NKiisD
rNqFN4Lzv926DLldqOQWIQs6rvjD5fjCgCARkTXT11zkrc5xM2rV5uO42xJv
w2xfY4W/aUGgaQnCShZfbTAm0u0DwBZ4RfrK8HqLJ3n13RFXCZj6i0ew/0tY
smRVpBvN4Eos+xQ3tRSRorgBViaPwCu4pchc0iAklvpnMGoxZxKrZizw6tpg
97l+MAn6YBfV/GrpWxAMzn+jTcWfucSST+X/L8yeYODKxkHPtFc4BJ09OwDA
BRAb/TMAGvj/MTtbxj6Oh8cvioYMbaghAwsGN3yYxni1s7Oh+IqK222S7YxX
lGzH5BVVXtWXisLI+VokGB1WUlx91o7DahM4/zqfZWrIwrf/oqABXDQoudyv
I6ux0Fub56kr8NRjY5nGOb6muf6mhXC8UdVfachSL5JIvGoJVrq44l8qhmAw
WSNvvq2mV6BF/7VEAVfrYaXrqAgSKDmwUp+Wigx5K3llYpctr0ynC6fxwJCG
WUQy6Nz+LpwcNF2f/QfoR1fy2ovF6DN+B8jK+TXgiHq5D8cShSFYAjr0J8+P
+tkL438Jk6DBf0X+4iThbCX7lK6Y5gyuex8qr7Z+rHiVhQMHT/Zznx1AA+g9
qk2fbHtFyfbC4OPiUN2sUIMeDJphlclhpZOKwwqHPktebQbnf6+NKLrWCmQt
C/G69/mB8Dx1vJojq0whq57BqsDTgLxqKgNeNROv5HkcUln6zHoZHsbDKw4r
SzCoGBhBXDmRYCwWL8NN1EoOrGLLOyUBVnzj28Ci6OCCp2YH7N1Wa9E2YnGA
F5FajxZqQgs6OeC5wgejPDeGwrSv431ch7rDsAkc5pWy4T04jLPyHTjvDCrr
dYBV2Z/gICHTWrP/CMcJp+O45+xfgcRiUeEoPAHNZBVzprjYRfZUNsMREkl3
tkz/lIJBOoOz6u8GXlHxFVv/leCVdSaO7NlemY+8KgnVlYYa5qQ36cHgEuJV
pj2sYFBOOzOsNiGvtghesccKWaKGXCKLXAMXR1YpIKthuqex2NuEZVrN86Dp
jeonI5AF32I9Cq3PVDCYRUVWCfNqqbmlDKyJjVcOrCJZAtRqMU6MBqt4Irgk
wKrUBlYtgisarKzgkml5UeSgKkgjCa08aEbKbrk70nNliPtMf9fRXmkHuqXt
/TSVRhBu+TBl43uQxVr1Ttvlf4WSUbZ4wRttyMv/zCc+00TCiRgVjv05ryMd
8dPnx/7ihUm/eiHn1y9yf9XgbBn7OBmdPcCGDG3mvtF22TuQvFr/PhQzYPGV
gVensLjdsDkoT+LkiM3BGZi8mh1qKEtvmit6qixuCVbrBKzWm2DVPry1PXyF
be0VstYbkbWYAqsAdzrRPFd14iJkNRV7m7ELFlwxtcCiiTmrsbEMhYfr07my
UqMlIu4MymS7ViyaHmVnUL3eHFi1wqxyK5Y4MQ5YJcScKHKrBS+NCVa24IoV
VrMNEiuLthH1jUJZPmqhVjP2Un44xnNzOIuw3Cf6uY72dh3ukfZ5t7T9XVJh
CuE/Urd+mLLpfSgZXY2xIaPWMnTGLto0BIn1Wy6xJmKeKgvO6bww5udAsCmv
vqj8f5Tn4uAb/QpvyPAmlIkaecWLRTmvRPGVYSbOeNocFMl2xquZwKvG8nSa
Pg+/lhZhRbLqM6O4krDa3p45PNjaTiALq8pXYbP0pQJZ4IAsWMm01lw/JOHL
FLgYryhghAXUVQaRhbooBEJrVchALQAXF1f8rhZhFc/OIP+aEd6MSX57f3st
rjixZbnVOoEkb4wDXKWJwAocEdQyteYI16jF5Zmefi+JQK3poK/Y+uoJ3ruj
PVeHuc8Ncp8e4DrR13Wst+tIz7RDeH5wX+fUXTCFMIXFhjTomYWHa1FuLX2r
7QI8AV2KTUfzmcTCIfVszQRo5cdhxTim/H8NzlbSg1z8KBsyLP8b8OqzD7Ti
q66q+Ip4ZdgcNJ7EqZqOm4OMV3PSGykYXAiZK3hgAytLDLhBF1ftFa92tGfO
wQXIgjoHwMgaI7IWCV9oRhY0Q0ZYwau6nDfCQuGHK5ei0Foe5NTi4ErX5BYX
VxxZRl5laZVXNryKujPoiKtkWWLZLQWuZKSebG+MSK1SywGNhGClo8lMrTl2
Lu+ypLMihofY+P3hOO/NUZ6rw92XhrqZxDo7wHWqH2SxvuzJZxHu/zR19ydQ
6M4WM2oxrbURO8yseFtIrD+1Kfl9m+lwqBBEFFvGYkAGKxYA5uEGovLfGJyt
ZB/z0FkwiA0Z2i75a8qKv0EPGQOvugGsjvZ2y2LRiCdxaHOwOAjJ9jk8GOSZ
q6VYRhUFVlC30F5uCBpgxRi1E32XhqxNElmocJYLZAnnCkpHVhkMTpW8okaj
+C8UQmtJUIArpMktQae16Ya5ErHwKkolgwOrJ2bx7qtyaj0ZWNnHiaWtg9Vs
e1iZqAXP2vHKfFckakmhhRVZNZO8D8Z5747x3BrluT7cfWWo++Jg97mBrtP9
XDiqPu1oj7RDXdMOfJq65xPgFQsPd2CHGRYersImfgvxUCFIrNdezP8NAIot
m/zrF5izx+yKwX8L5aDMC9DZSvo0/zdtoCEDBoNL3obNwTXvmYtF2eIvJa/E
5qA8iXNXnsTJF5uDpSp5hbzCSHAFIgtg1c5GWW1qD75Z863tec6KiatdHcB3
MydkQRKeI2udjqwgxw61i0GhhUl4BBQ6vJIrEFbzOaxQZakb4YtIailwpSu5
hfqKvx6orF0UM7SQvDKKKwkrkzBweJUUS1huPQlYmeI+/uJ5MrDSlZUtuOxv
tFKLhBae06nPgVEUVRO9D8d774/x3BnluTnCc22Y+/Jg94WB7rP9Xaf6uo73
cn3ZI41mTzChRVprGx4q5BLrrbbz3mg7B47qtCn8LbQeZSspDGSKS3gb7r9T
zpbJx4xd1JBhwVspS99OWfm3VCi+suOVLBZlvIp0Eqd6htgcLE9vwuQVZNqX
YiSIygqViR2sSFDpLiPBnQirPdzhItNa2wSyPsvgyFoZ4sgi15ElfQGWMcBO
omiMDOJK5JEkqZaFFKxkhLhS7AOuNpzB4fcmQ1zZvr8itdx0LEaL978Dq9xK
AqwsgsoCrjhIFSOsTIxS3y62bDwXWoW8HVbjFF/dZBj4VTne+2Cs5+5oz60R
nhvD3FeHuC8NwglffXFUfU/gFYWHezEJv+VDmJuzWpdYf2QSCyhUgCqr4Lcv
zvhdG4O/ZnC2kn0sJP8dBINz34AzzsCrvyOvsLjdUHzFeCWKRc2bg6aTOCUi
2T6fhp9ycQW8QmUFFw11C+1l9Kd8m4wEhbLaK5yQtYOQlamQtVogC7SNyKIv
CeoOr1WIFkUYKCNBJBVc1GWVIlVIkWq15czgKlXTnoC4sr659E+jtNx0LF5L
MLvVGljZYcoWWVkt1nnGDqtIaasYqaUji47qTMcG73lwKqdhsq92EswofDTW
c3+0585Iz83h0Bj5MvRyd53F0c+MWiw8/AKT8AaJhacL57/RtgwlFltZ+DsI
/Ri7zP577sXobKW8UoRncOb+hfMKiq/ew+Krf9gUixKvTG36gFf6SRzaHKyw
iqt2wCtUVvw3tqG9AVbbOjBM0VYg3w3c0QF4tRuV1T7l8NSu9jC5hpC1kZCV
zpG1Qqij5WLjTzjViHIuUfC4WE9baeujkErk282R4ApNbiUpcxWl5aZjiVmC
RadxwaolTJGgMjEqGrUs6anEYKVvEUYEl7GsFMRVkb+50N+UDwMpYPJXDvRq
eDwBJkE/HOO5N9JzezhUkF4d5L40AFhxrp/rZG+IDQ91hb7uOz82Sqw321Zg
txmg0Gugpkp+b/E/GJytpAfFfwB8lf0Zku2L3oIGyHqx6C6tWFQVt8vNwQgn
cWpnaZWiizO4uNLTVlxZUT2VBqvtHQBQwjHuE5HgXiTV/g7hA/hRRxZtF27E
Wqm1GrJEwjyLCqvQefX7KkykA9b0bFWQ7sLgTiTbraRay7vz4ZfVTuIYM1f8
lRCPuLJ9B0VpuelYK61FaunPRpJbBljFhCm/Ku+MuRa09eLKBCv75LyJWlSg
VQIp9+YZ/qbp/sYCf8M0GPsF81WzoeNo9TjvozGe+6M8d4d7bmF75CuDoPT9
dF/oi6VLrE3YbWblOykksdhKqHj/fZuZfwCfZfI/GpwtnvnHNuDwVNuy15FX
f01RxaIfYvEV8ootPtLLzYvbsfhKbQ5GOokjebVE8krLsSOsmLKCBTqsdipH
HGmRIMCqY/hAx/BB9P24YA/sGELufWsmR9Z6gSxjGRX/c1DTY1mjvgaJxENI
QzEDZ5qZVOmy4ZU9r1YIXglxxb+vUVzFdfQmSstNx5JikeRWJJTp4MqKsNkX
nVRRYGUPrmTBKgKv7MFVKmBFW4SFfIZOI+PVVF99LgxXrc32PsYmyVVj+Kiv
LOzbcHmgm0usnmmHYHROmpJYf09Zht3ds/CoDkNT6R/t/E9QDsp89p+QbPiA
nAWDFW+0nf8XLL6yFLfv13h1qr/7nOCVatM30bA5yHsgl6U30+bgEhEMrtZz
7BgGYo4d1khltauDZBTiSOTY92qw+hz9YAeFrJ3tFLI2CGSZytTFQeZ3qY8o
HA9M581hIBMVMkkydoX/4RSpBKxEgz5DvWgEXulncOCWOMVVOGrLTceSa/Fu
0bI/KPwp4yRVjLAyVVgRQ1qGVYRMeyywsgUX3FusVY3C9BwxD5okFgaGNeO9
1WMBVvdHeG4Nc18drCTWke7QwGEPTifc9EGqlFhsccXrsFeo/M9ty9DLmb8O
zhZUoBKb+wYk2Nnj8td5JLj0bYDVyr+nmouvkFdHe7mP91HFolcjncQpxGR7
KfAK356YvJLiSsJKT1tto+S5kFL6JuDejuD70CWsDqHryNotkLUFx9bwxnqG
lgu8WehWnDIPwyMyeJdjWCzk1uoQjxNJmK3hpVYKVqJZH79o4tVKjVeyTNSY
ueKvcLt3SqQ3RfSWm44l3RIvOm0JU/HBKsaoLS5xZa1yj5xyl+LKwK58Y1/3
bC+075uAo3OwycyDkZ7bw2D688UBfFT90R60UZgGtVgfpq5/D2qx2MqFb0Jt
w9zX0d+Ax+B/AeHEfAHzN8Fh5Vsp4G+mzH9TyapVuC24HjJXAKutH0MxgyoW
7eWWnZAZr2BzkNr0jTdsDvKBg7IHMvFKF1cSVlTAgMqKh34Aq46cUXs7wkWm
qaQfELA63DH8BX5EZCHW2nNkbcvkyNL7gkpYbckkXiEeM/mk5s1iMSFOUkiT
VRhIZuinctSAiTUt8UomryBzFUp4RFeklpuOPTlLsOg06oGamGAVQfDEBK5Y
YBXdJayo/krWt4s5X9KaJ/uasr2Nk7w0tp5dYRLrwSjIvUteHe/tOtIj7WBX
pq+QVx8oXjGJxaLCRW+BL1aewnC0BH3pX0FEsZXsI3N2hcmqJeIADsWAW/4B
YeDOzkCqfV2h8oqS7V8ai9uvmU7i5BgHpJaGmstFpegyxiujuJKw2tqe56x2
UWSn1BSHlcxWkXNYdQof6WSHrHa4XSjmcPHxW6Kz8RZ+HV6BOK+ZRsyDbxUr
iW/rhdzSDg/Cem3AhA2vjGNxIvDKqWb/5lkr5Fb8sIocnUWJ2pIJK3lUZxbV
t/tl5ko0dYdGWOEp4BJcRC3klZfzaoj74kAzr7YLXrGVDFkr3klZ/jZ8NPvf
UlYKX/V3WLySFr8D1DKcvsGE1Z4uEAMe7A5nBmmA13HMtLNgUBaLWjcHq/IC
NQXB2hk4cJCmo1LPq2VaMGiJBEUY2JFHf/u4lIJPIfrrhC5yVocErI6ic2Qh
r/a3B2TtQmRxRxZt0wYI4hRU4hVbyZGlLZN84xElwYowtUFr4icHeK2NgVeL
Fa8cWH2jLcEqiBhhFTWVFGuSPImwshNX4Wk+zivmuZxa4ZxoffystukDOKrD
qLX2XbOvezcl0l2r/57K2MXApZeyU/T3ObQShdFdx/pAQTtbfHYAyCo5cJBX
io7kM3EeZPsfEa/EgNSm2aJH32LsILqKahiMkeBWsSG4uyMpK66pUErBY0aq
Q53Ch41OsPoS3YqsPczbgdAiZ/jaiVzanilHNnNe7Wxnjyw1bl4EiZZGWPy1
sdYy0HmlXb49KqzCDq++gZZAqbyt3IqOqRhhpSsrHVyJwEryaqYQVzYdkn1W
arFbGrK9NRO8D8d678DRQgYK99mBTOS4vuzNZE/avq6MLVBssAPPFUaxjR+m
bvxIObvy2YcQ+ukLtupN2nuwb8FLFyhbxdYYMDXCe4cpq5GYvBK8qswNVE8L
PJ4erCsKNswU05wXCF6tFuJKwkoXVyIMhFsOgqCCB0SqLzQ/IpyR6hg6IIvn
svDeDoAs8n3oewFf8NSudjxhRbzaznklkNUuArK0ofN64751POWeRfUMlhmp
jrh6xq2pqan1X6S1cWJsm3QxksqqrBLhlS6uIrUbVU2SkVqiT3Jttrdygvfe
WOjecGW45/wQ96mB7mP9XId7uw72SNvfPW1ft7S9jFrY6Z1Ra9vHRv8kTXln
8K2dYeXmT9I2fZy28R9pGz6CGHDTR6pR/MFuIKvkoRua2MWuK0yN8t4b7bs/
xnd/tO/eGNgZhGBwov/hZMWr+uJQ46xQs+TVEtwcXK2JK14dqomrvSKdfpCT
Cj4e7mQI/XRnpPqqU/g4flTIQon1eQflDF8H2nPdtQ+zW7CHKPTVDuTV7paQ
tVkhS4eVTF6p/9HiF1cOrL4WO378eE5Ojvy09WczE0zLP0lYWeVW3JFgiR+Q
ZaKWqeMoyi12V90UX1W29/4E7+2xnmujPBeHe84McR8f6D7Sz/VFX9fhPq5D
vV2f93IdwJ5Ue7sBtXYxudVF866ad3Pt7OragWUJ27qkbf00bUvnNAauzR+n
be/M7sUYEL8UGbU7pgp29ilTUwxTD8b4Ho31VY6Dj8wfjIcyhnvZGAxO9lfl
BmqmBWoLOa/gB5+bDpuDxKs1pjR7B4O4glqFTqSsCFZwO4/7XlJ+7CUuq5gf
fyl84iUzsr5AlfVFB+5EsEPELkTWHkCWmVcSWTsx67WdyzATsmDBhowomSv+
z7YTV04k+OzYjh07evXqlZ2dTZ8m8Wxm4nIrqbCyjQTN4CozurxrtjgzaGgp
I6hl6pMsxn415PlqpvgeZnvvTPBeH+u5NMpzdrjnJOPVIPdXTGINcH/ZX4GL
rT/Q07WfRYjdXft6aN5T+d6erj09XbuRSDu7u3Z0c23v6mLg2tHFtbsbu9d1
qJf7aF/38X4wWPDcII/86e6OAl4xOlWN99VMYO6Hj+N91eN9lSir7k8JPMgN
PMoNVE0N1OQH6wqDDcWhJp1XVMwgeQXiqoMqZZfiSsCKySr+iz0qGPWVxQlW
J9F1ZDH/EpH1JTxgnyL3OhK7eLS4F3m1sx333TEhC57aqM1LlaPnLZkr/o9f
4oirZ9TWrVt3/vx5yasncTYzrlL5sJ3cSi6sbOLESLyaI764POxsaN9nkVvT
gVe1eb7KHN+9Sd6b471XxnjOj/ScHeE5M9xzapj75FD3CQauwe6vBgG42OIv
+gG1Pmdyq4/mfcndzA/2dR/o497fBxbv6+3a08u1u6drVw8XA9eeHq4Dvd2H
+wIATwz0nBnsuTDUc3mY9/oI720W+o1Raf/6SX7mdcwngj+e5K9mMeCUwMOp
gYfTApX5wer84OMC5FVJqAlneIXn4ebgUixmWIunbzYhrJS46qjE1eedZADI
f6XHBJqOC0Dpzkh1Cl0ii4JEjBPhdvr4VcfwMc4uQNbnECHCK4diQ8xfqfy8
AVntdGTB9U2ZotpBiwcjlF3xH8Eirt7VLClvDceiWHNzc5Nm8jqL+ySvntzZ
TP0PHcufW5dbLfMqIVhJZaXkVpm6IsElw0NFLXOrZE4tiATz/VVTffdzfLcm
ea+N914a6704xnNhtOf8KM85Aa7Twzwnh3oYuNj6YwPdRwe4j/bHj+hHmA/k
/sVA9+EB7kPM+8Pig/3cB/q69/Vx7+3N3MVQ9kV/97GBnpODPWeHsqjTe3Wk
9yZm0R+M81VOwCZd2f7GyapIrJF9mu2vz/HXsgAwDwraH00PVhViD5kZwfqi
YGMJwqo8nfNqmdgc3KBFglZxdYhg9RKTVfw3yXXUy+GT5EJQnRJ++qXwGUIW
5rJOdIIHzE+B8y9yEq8D0BBZTGgd6gAvHooNKR7cIzwCsrKodovS71JirctQ
8aB+zNl4BseJBL9G27NnzzDNzpw5Q9d1Xj2Fs5nx/vfEXzZxkip2WOluBZeu
uAxyy9ItGSLBQn9Nvv/hVN+dHN+NbO91hqyJ3qsTvFfGey+PY+Dy6uBi608N
85DcAmcPhni4D/V8NdRzbIjnyyGeo4M9R5hjlHd4oIex62B/94F+7s9ZUDnQ
89Vgz6mhnnPDvZdGeq+O9t0cCyn0hxP91dn+uhzAVFNuoJH5lEDTlEDzFP4D
siv1eYHaAjh9U1UUrCoO1ZSEameGYGdwluAVFTMQr9ZhhysZCdqKK4QViwFR
HeFHhqlT6KftnMHq7MscWYQvIhhcF9A7gxdPdeJMY0LrSEd48VBsKJUVbiPa
IiuLCrckrzYKZJkkFiHLlGaPkLlyYPX1ms6rp3Y2MznZraTCSldW9tQqs1Cr
VE0Bayz21xb6K/P996b67ub67kzx3c7x3ZxsAy4mui6MgczS2ZGeMyM8p5ni
GqH5SM+pEZ6TIzwnhnuOMx/m+WoYwOrLoZ6jQ4Bdhwd5Dg0EjjGsnR7uPT/S
e2m099pY3y1MoT/K9tfk+OtzselNXqApL9DIPk4Fb2aeGwhPhaeaCoINhcG6
4tDjmaHq0tDj0lDd7HToyUA7gxXEq0xRzIDJKxkJKnHVSYgrA6yYrIIHRKoz
mp81+rmXObLOop97Ca6cB4fb6eM5fOoMUut4J3jByNhwPy94gI97tdotDVnw
YJuxwmGjLrEyVApL11eR0+wOrL5203n19M9mJg6u1sAqAq9MjIootyzggkiw
2F/FeFXgf5jvfzDNfz/Pp4PrFoDLd32Sj8DF1l9CxXV+NPoY5efGeM+O8Z4Z
DX56lPfUKO/JkbD++AjvV8O9x4Z5GLiYnxjuPTMS7r081nd9vO/2ROgJU5nj
f5wbaMgLhPORVwXBpvxAY36gaRp487RAGJ4KhguhqV1TMQiqOgarsvTa8vT6
cpiGw3syMFhRMcNyUcywSdQw2Iqrozy1DvdSDHgaaUNQsnXkknpwAf0iONx4
6WVyeMyun0dqnUJeydgQ01m8TGufDbKyqM5hezsDsswSi5qaaiks5JUTCX6D
7Gs5m5lgFcQTg1Xs4IJIcFagtiTwuDhQU+SvnoHgmu5/VOB/kO+/P81/L893
lwWJub7bU3y3UHSxWxi4rkzwXmaKa4J036UJ3ovjvRfGe8+PAz831nt2rPcM
irFTo70nR3lPjPQycDGCMZpdGOu7Mt53Y6LvTjYcWK7KDdTmAZ3C0zmRmguD
TdODjdODTE01o4eZzwiGi0PhmTyr3FiWXl+RXjsvo2F+RhN1P16EyorBaqko
ZiBecXHV0UZcfUnZ9Zd5GEiy6uz3USZ9X/kF8peVI6AQTd8PX0a/gndd+b50
ji+2+OxL8Ao5SVuKEBtCtQOLDc3IgmItkljqD7fNGBV+piXe9SwW6StHXDkW
myWeln9isIoMriBzwMKcQNPsQGNpgFGrfqYEV8AOXP67WE16awqFiuiTwa9P
9l3L9l3N9l2ZBH55ku/SRN/Fib4LE2D9ufG+s+N8Z8b5To/xMnCdHeu7ON53
daLvZrb/bg60rqrOC9QxHVWIOJqBPYGLgs1FwaYZ3Bm7munZklB4Vig8Jz1c
lh7GQ82N8zPqF2Y0LMpooiGDS+WQwXb85OBn7cObMRhksIokro6/zMNAASsG
KPj04vft/ZLmlwWdruItV+FB+JpyuHgZyAYviTMiRX8MkSVjw/0KWbBeHOeR
iSyeeNd5tVZMP+TxIPIqgrhyYOVYFEuW3Eour0zgIl4RuJg3lwWb5gQaZwca
SgP1swJ1DFwlBK6ABNdDbOmA4PIzxXUn139nqv/2VP+tXP9N5lP8N6b4r+f4
ruX4rk72XZnsu5wNvLo4yXdhku/8RN+5CT7GLoaya9n+Wzn+e1P9j6YFagoC
9UxKFTHhxB3+VSWh5pJQU3GQnLGLEQxgVRoCUlXgDiDGfYCsJZmNSzObl+Fu
2sp2xnFdWNm+GYPBXRZxdUSIKwusQEpdJHWkccnkElZXNVhd0Qimc4x4dRaT
8BJZemwokGXm1bZ2srAhSy8cXWMjrpxI0LGELfnZrWTAShdX/C1QHtQdwRVU
4JqJ4CoOVBfB92LgeoiKi/w++r1p/rvT/Hfy/Lfz/Lem+m9O9d+Y6r+e67+W
C3y7kuO/nOO/NNl/Mdt3ebL/+hRA3P1pgcqCQE0h1CE0lzAWBVmURw7/pFmh
5lmhppngzTOBXQpWc9MhPbUIdwAx7oN01kqMoXifq/aAKb3V1RYMBulo875O
IK5kmp3E1Unk1ZnvA6zOKV4xImF894qBP9IlrKSOukoce1n5ZXTMZXF9dQrr
HExRoQFW7a2wksEg/5OZxZVN5iouqe+YY9ISk1tmcCUNVgGDsipX4DKxS4Ar
2FAaJHCxBQSuqhngleiPCgMPCwMPpgfuTw/cKwjcLQjcyQ/czg/cwpH3N/L8
16f6r031X831X5kCHLszLfCgIFBZGHhcFGxgmJoV4l4KDv+G2SHmzbOh+JN5
c6l4VsJKTr0RcR//xxOm+NGbDqpAdLvglRRXh23FlQ2vwpdf4V/86ivg117h
gd5VDVbXEVbXBMQuWnJcmHWH14BVXB2iGRbAK/gie8Rhwx2izbKpnmG9dt55
ZcviyoGVY4lZAtXFBmolDVYBDqtyG7cHVzkHF7tO4KpFB91VEqguDlQVByqL
Ao+KAg9nBB7MCNwvDNwrDNydDt/odkHgVkHgZn7gxrTAzWlAsweFgaqiYG1J
sJEohHQKz+GO/zZAU3NZelNZqHkOODxVrsFqmZjPpcV9cONGxJTOKMpZkbKS
4goyVy8JXlkyVyZeAZQAU7Dm+ivKZYbqOj0lCHYJAaXvHpJjvh1WWsWVCAYN
4mq7GBZmX3yVQWPo4ZZlTiTo2BM0nVrxpeWfMKyigwuS8wguLrpmB+tLg3Wl
wdpZwcezgjWzgtUzg1Uzg5UlwUclwYfFwQeYibo3I3B3RuBOYeD29MBdpsSK
gtUlwbpZwSZiVJnw8hDlzyE3hd5cATNumsvBsWQdjwRKWBlb8MGNmzvwf/AO
jVF7kVHk+zuZa670YDCSvhK84ly68Qp3Ca4brxjEFe0GIqCUn4MqLPhbn5BH
FLF3lo24am8WVzqs1lvKGJZxajniyrEnaonLrVbAit/bEqxaUFwV4MCu8mBj
WbChLFg/J1g3J1g7O/h4drCmNFhdGqyaBTc+mhl8WBJ8UBK8Xxy8VwQcY1ir
Z7EeB1RI0gm0E1VPzUsnbybH6xxWSzRYrddyU1uxGcJ2rqbg8T6M+w4Y/aDo
wxBJXLXEK46mm6+AC3BxiF0TGXiK/s69zFPrsvT9NPLqOB42pNPQ1L0BeQWf
Uh94XVxtlSdxMm3KRLWaK0dcOfbULPG0fLywKo8bVoQmlD0cXHglFJ6rvHlu
qKki1FgRaigP1ZeH6spDtWWhx2UQ2VXPDlXNDlaWBh/NClYyGTY71MBIBbdz
QEk6heeDw9dfkI6e0Qye3ozXOayW49hTCSvVbAHf/ruFmjqAx415N2Phh4Qz
WNmLKxEMSl6p7T/FK0Yq/nsgat0UceJVLXNFwSCdx9FOHWK9qIgEZZe/Ax0i
iKt2Wo1oplZwlaGO4WANgwMrx74Wa5FapmfjoFZ5/LCqUC4wFZTU4u/ZeaHw
fOXN80NN80KN80INc0P1c4FXtYxd5cCumjkAMcY0nU7gRKeF4FlU7Sm8WTh8
KmG1VjSH2aJKFJSgkp1hPu+k/pEMUMQocnFUEMTVcf3ojW2y3cgrwajwLcTU
LfGAeEXi6rwQV/JA9Anu8Oc7JvplYeZK/SO5uGpvI65MBVer0500u2PPjkWS
W5FegS3IrXIdVoFWwio8Nwiaal6ISKXebgtCOnmYLmIXm+anN85Pb5gH7Kqr
YCgz0Al8UTqn02Jw+DpLMnRvpgdLdVi14zEgwQr3+7iakgrqc9XPigFK5IsE
pnhjq5cN4ipGXsnklUAWF1rXRKZdZq74YeeXRIsGcPgLCnElepBqyNotJlbo
mfaNIhg0iavljrhy7NkyE7VafAWawVWeEKwqYoUV+AL0hRq4FhGF0uXj5oXp
TQvgo3wqvDidAKXQtBQcblmWITyTeTM9hp7GGqy2imOAeztSJZUQURqsDipe
yUYxHFNEqhMCVupcc2y8uq4CQy6ubghe6eLqtGiQdUI0yDomzjt/IbcFxcRV
FFdis4DEVTutmj1Ty1xl6OLKBKu4NnEcc+xJWOJpeTOsYuBVFFgRr+xgFdZY
pMC1ON3sRjqBSzotR1hRPRX5SvBmesxgta5deIMGq93iTA3B6gsBq0MCVlrL
UB4AHhPHmelE8ylxqPm0OjDYMq+uU/2VIfeeJctEL5oiQSGuxHAK+CPq4krC
imeu2lNPBri4pZ0h077O7vSNXSQY70vFMceekCVcdBqTuKqwcXtxFQlWHEqo
rJZo4FoCFw2AWi58RYakE6xciUEf+Wr0VRqsNhthpXVc58O2dFgdNISEMruu
Z6vgMQPUmZftk+22vLr2ijgeKMobsBALHlz+Pt8WtEaClLOi5leHlbjCtJuA
lSFzJaglxZWlhsGJBB37Rljr5FZrYKWJKwWrkC2sdFfgUozKIPmkowkWsAdr
hK/FQtA1Gqy2idZV2oQIuOtQJ3MkeMDEq048cyUSVnDXue/TR44svVI0Eq8k
rOSRQFnljsd2EIAv20SCYiYF/NUOdRQ1DJq42sXFlYoEN6ujN7BsjchcRYgE
9ZdHkl5ojjmWTEv8jE+CsAoaxJUdrAy8kheXpsuID0VUhsIURxPCai2iSfp6
4Rs1WMmR8fs5sgyZdimuDnQ080oevaF2MedErxgDr15W4sqWV1cNxwbhK1wR
NVeihgEDTC0SlNMojmiwkuLKGAmKGgY9EsykSFD86qJFgmEHVo4982aVW3Gk
5e1IFROsiFeLjLxaLGBlyFkJXoGmAtc0QyYyCjAFn67HdLr0DegMVlukstJ4
hciCuw5qFVYSVjRPMAqvzgo5JJF11sirixZe6bC6LALAS1rB1VkeCcJT+hyK
o3xD8F3qhCyVlR4Jqj1BI6yMkSD/NzviyrFvviUeJ0bhlYJV0JK2MiPLkGPX
RdcyEQaSslqtNJVilw4o5pswtb4JZ5vSeIidOC5wt0FiwY0HaIK8jAQ7Kl4d
1HmFISEebZa84h2uOLKocagxGNTbxVzReshc4v1hVGmoMQzkPxRTVkdoNxBk
Ffxp9ncI7zNWhxrTVlrBlXFP0IkEHXsm7eua9yrBZRZXOqwkr8zICvECBgkr
qbuWarxalSFhBbJqfSZpKpFbJkxh9EdTmEFZMV61503XdxmQBbfsF2ji1BKw
2i+ufG7k1TGcxnVK9jrmTfl4IguOJ1uSV5cNskrBShWx66R6Sd8N5F+ZwQpl
FfxRVDs+QaodGqzUUUG7anYnEnTsGbOvcd5r2Cq3dHEVHVlYf6W0loSVKRgk
XllgRZpKaS0i1VbhJmTtJmRRSCVzWR2VsjLx6pA2Wf4YTukiXp15WbVnJ6HF
2ylYklcySUVB4oWX+WITqVRqvRMvWkBZxX+ovTR5EGFlQ6p2fJTzRkPaShUw
GPcErX9Zh1eOPX17avNeo5iSWyZeAbKCZmSJYlFNaAnRxYPBdBUMMqkgxRV7
S0pYcVnFlZUCl+SVFVnEKy2XxRm1XyMY8KqjgVewRYj5JX32zVne+AVjw5dV
sl2GhBcVqfgyGf2dQABGIBVVWEEAiJoK/go7kVdWUklZZU5btVAdGu//Svrg
Tscca6U9nXmv+sUotxjAFRVZnFe6L5LiCnnFxRXyisQVe1duQF5tamd2AtcW
Ue+teKWQhfkfoFZ4bwe1Y7hf4Is+lbw6LHnVScwWfEkNFjyj5nOJJLwceaM2
/sgVrKya6gtJqo6KVOpUIOgr8RPZkYowtV4ffKOlrZIRCR4/fjwnJ4cetz7t
4JhjT3Pea7ztIIzIUtTKosODJl4t1nglg0H2HlyreAU3ygS77pJaGBXy9/h2
gSzMvWMKiAstRFYHRSp6rHjVUecV3HhczJQ/qU87VfgSGS05YVA5ajMaQ/+S
qFWITCq9sGp7O+IVwxT/+iZSSUytMXZgSNI5wR07dvTq1Ysm3yUx7eDYd9me
2XmvYV1uadTisJLprAXWYDBdCwYFrxBZuC2YaXRtl1BDFtNX/D0OEgtDKkP6
XVBrH4ECP/KSBsGrLzRe0ax56Sc0lxA7LU5JywzVSTrOoxUqfIkY/EKQ6oAk
VQdzCSgKKvhtS0El27CbBZWVVBGVVTie/3TWrVt3/vx54tWTSDs49h20r2ve
a1y3KGoRryzpLOCVCgbTqeyKx4OCWnAjz7obXVJLIaudTGSp1NZOpMEuQwae
C61IvDqCsKKoUPdjmn/VyQQx/u0oiuT1VAJTUlYdRFhJUvH6z/Za/Wc7nr9S
gipTb8MOX1zHlEaqKPNPI/3h2KuoSTN5XU4WfnJpB8e+g/b0570mJreyqAev
DA+JV4twHrrOq+X4NtSolUUHTNZmmn2dRi0Tsoha2yhf3d5Mrd0WoWVIuRO1
sASCEeaLTsqPGP2okWCCafzbmUM/xBTJKoOmam8u/kQ1Bb/eyKEf/xZEKoLV
0gSHNe/Zs2eYZmfOnKHrkldPIe3gmGNPwVoVJ87XyrEW43tNUmuZgVrwxpRa
S3mmHi2akYXUMqXfFbV2tbePDfejY6kDrDwoCCb9kNEPo2o6oikodAId/3a8
I6jQciSoeJm6Tqp2MkOFcV8m/FZNod9KoamErFJyK1FYRTHJq6eWdnDMsadj
OrVifGtwai1ogVrwZpQZeN1lgmutjqxMPQOPRQ4YZBGydGrtQmLs7mAOEgW+
YI0kGOeYdE2Mfa7JJ+Fwr0hP8W+3W1NTElP0b9NIxbcVEFPwa1wjgmI7WOnK
in+XpA5rlrx6+mkHxxx7CtYquWVHLXgPSq0lThQaElxrzNuIiKxMKijVYkN7
aqkgUTpyzLCfuEfjmJ7y2icgtl9L3e+VtROqMoHKqIyVCZYyKi1DRZoKfo2x
wco2bRXXEdFY7OmnHRxz7OlY4ml5eWYHqYWRjhYhSl/RArKyzJWlEcC13Vj/
IK5wFbTDzDHlFNMRx2R8R6CzFVEiiw4LNhiz6JShWmeAleJVQrDS/wpOKbtj
jsVirZRbFOCobLwEl57dMmwjZhiLtZTWiggu4Zwk4rF6aptwDWhmmu3Ai7iM
37vFmJLSt/nkqGXBKPhnr+VNYFR2bjXySi9XiAorRnjnnKBjjiXFEvhfnm8m
Sq2lU2upjqx0YzpLvPFVtUOmBq5MA7gsroJE67NbNNdRpuI7Kr83nZTJVFzS
0CRbVOmMUtsKKKuQV62CVdjhlWOOJWpWudXiu0nJLUUtY/HDCk1oGYofCBGm
Si0NXHaOUaRWnGm7bBO5jXzinLSgifsaO1+tl1Sp+k/4zcQWBjqwcsyxJ2qt
ihMltZZaS7bSbYof1oo4cZ0RXHaeZSyh5xj5TOaaLLevFwpqrUg9RUWTjSOj
sjQjRsEvZ4UxZWcLK4dXjjn2VCyxbLBBbi0R4DIUPxiDRFtw2XkWldBzN+TA
DSyyk0ym1FMkLmmezmO9lbz4k+uoFbykCn4ty7V8nQyElziwcsyxr9OSJbd4
8UOEONFSbmpwA3DsdJE13aSjyZR6sqHTSjsXgLLqKH7Y2cQoianFvPbDgZVj
jn1d1iK1rM/qcgve4LZxoggV7UiiIjLzRb3QSytS5dQyRnPGu+y5ZHZRoG6r
o+AnXaJNldUYpZqGLXR45ZhjX7NFkltR3oM2cst0tGd5BGhIhRPpWYUdM98M
GacY0GSTjFqWrkSUUUfBD6sxSn0vrQmPtR1fi78oxxxz7AlZ4md89M1EU+GW
xVUUaVOVagsuczRnwF1kNBl8qajejxDrwc+r6Si9jzRRK1K1lQMrxxz7Gq1V
2S09LR/BDQonFnBpaJKpJ6V/IqDJ4PL7WvJR0uHnXWjpaqhRy4kEHXPsWbZW
bSYu0g4nLlbqy6BwdKREApfmNnRaKkf+2YR4Jh0FyxaZMRUjrxxYOebYN8Ja
K7c0cKk8tkmDRQKXBU22wskmT77YrKOiwQqJFIVXDqwcc+wbZwnLLQkuBQ2j
6LIHl9HNqSdTAmqxElFWNEWElQYlh1eOOfbtM1u5FeMxH+P81qjgsqa8rMLJ
koPSAaWDy55XC2PilQMrxxx7FqyVo+4ktWJ/5xpab0UBl51qagE4UcEVnVRR
eOXAyjHHngXTR92FWzHtrlVnfGxpY1FNHDiRk+FRwEX32hZTObxyzLFvhOmj
7sJJmnbXqrS8iTbGQoJYSRWhDsH0aSRwWXnlVIc65tizYPqou3Cyp90lQW5F
GUvdClhZwRUXrxL70RxzzLHWmxxtEH4y0+5aJbd0XlknU7caVrZyy8CrBU4k
6Jhjz5DpvHqi0+5M1Irl/U7U4rAyTXpNKq/0xfAPE9/IgZVjjj1TpvPqKUy7
S4rcip1ascJKfE2ClZRbkY4KJu/34ZhjjsVhOq+e5rS7VhWdxgauaLBaYO+O
uHLMsW+WPc1pd62qgmiJWopXEegUkVdOAYNjjjkW2ZIpt/QUfVyuJdudSNAx
xxyLbpHkVnRQWKkVH6wsxQyOuHLMMcdiNx1cMVJCyq1YYWWX12LfS4dVvBua
jjnm2HfZEogT+b5ePJiKxKtwohk2xxxz7DtrSaiCiK3+KtK3cHjlmGOOxWtJ
OOMT2dky2y/uwMoxxxxL2JJzpNrhlWOOOfYULeHNRCu4KG0V71dzzDHHHIvL
EthMDBvjRJljN93uwMoxxxx7QtaqolPxFUxfMGn/OMccc8wxi7WmAsEpuHLM
Mce+FosRXPoa6wPHHHPMsadp0aklE1+24HLMMccce/pmK7esn8YYS1ZUVIwe
PXrixInHjx8Pt2JOh2OOOeZYFIu0mRj7DuPJkycLCwvZg9u3b48aNSopczoc
c8wxxyKZVUrFzqsHDx7cv3+fPaisrOzRo0dy53Q45phjjkUyXW7Zwqq5ublJ
M3m9trZ28uTJ27ZtexJzOhxzzDHHIlmUtNWePXuGaXbmzBl28dGjR2PGjKHx
HE90TodjjjnmWGuMwWrEiBEnT56kT5/CnA7HHHPMscSsoqKiS5cuQ4XV19c/
tTkdjjnmmGOtt6c5p8Mxxxz7lpmpRCrsVEk55phjz6SZSqTYA6dKyjHHHHs2
zVQixR44VVKOOebYs2yyRIo9dqqkHHPMsWfW9BKpsFMl5Zhjjj2rZiqRCjtV
Uo455tizaqYSqYaGBiaonCopxxxz7BtkTpWUY4455phjjjnmmGOOOeaYY445
5phjjjnWov3/BNEW9A==
    "], {{0, 323}, {400, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{400, 323},
  PlotRange->{{0, 400}, {0, 323}}]], "Output",
 ImageSize->{404, 323},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[2]=",
 CellID->151859658]
}, Open  ]],

Cell[TextData[{
 "As boundary conditions, an inflow is defined at x=-15 with the velocity \
components (3 Erf(z), 0, 0). A second boundary condition is defined at z=2 \
with the velocity components (3 Erf(2), 0,0). These boundary conditions, \
along with the no-slip boundary conditions of the terrain can be extracted \
using a wildfires utility function ",
 Cell[BoxData[
 "Wildfires`Utitlity`VelocityDataFromTerrainAndBCs"], "InlineFormula"],
 ". The input to this function should be presented in a very specific order:"
}], "ExampleText",
 CellID->2011104659],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"nXgridPoints", ",", "nYgridPoints", ",", " ", "nZgridPoints"}], 
    "}"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"10", ",", "10", ",", "10"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bcs", " ", "=", "  ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "15"}], ",", "y", ",", "z"}], "}"}], ",", " ", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"3", "*", 
            RowBox[{"Erf", "[", "z", "]"}]}], ",", "0", ",", "0"}], "}"}]}], 
        "]"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "2.0"}], "}"}], ",", " ", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"3", "*", 
            RowBox[{"Erf", "[", "2.", "]"}]}], ",", "0", ",", "0"}], "}"}]}], 
        "]"}]}], "}"}]}], "}"}]}], ";"}]}], "Input",
 CellLabel->"In[3]:=",
 CellID->819734006],

Cell[BoxData[
 RowBox[{
  RowBox[{"data1", " ", "=", " ", 
   RowBox[{"N", "@", 
    RowBox[{"Wildfires`Utitlity`VelocityDataFromTerrainAndBCs", "[", 
     RowBox[{"hills", ",", " ", "bcs", ",", " ", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "ymin", ",", "ymax"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "zmin", ",", "zmax"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"nXgridPoints", ",", "nYgridPoints", ",", "nZgridPoints"}], 
       "}"}]}], "]"}]}]}], ";"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->563410882],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPointPlot3D", "[", 
  RowBox[{
   RowBox[{"data1", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", " ", 
   RowBox[{"ImageSize", "\[Rule]", "400"}]}], " ", "]"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->1691007375],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.3315753, 0.4561011, 0.6388182], Point3DBox[CompressedData["
1:eJx1nHk8lH0XxoeiRfVMaSyjZUymppEaokUxvwpJtCilUiQksqaNJEtFhZRs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    "]]},
  Axes->True,
  AxesLabel->{None, None, None},
  BoxRatios->{1, 1, 0.4},
  FaceGridsStyle->Automatic,
  ImageSize->400,
  PlotRange->{{-15., 20.}, {-20., 20.}, Automatic},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}, {Automatic, Automatic}},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 ImageSize->{404, 323},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->618516509]
}, Open  ]],

Cell[TextData[{
 "In order to get have the flow go around the hill, 2D velocity data can also \
be extracted at a specific z-level at z=0.7. For this, another utility \
function ",
 Cell[BoxData["Wildfires`Utility`VelocityDataInXYPlane"], "InlineFormula"],
 " can be used. The input to this function must be presented in a specific \
order:"
}], "ExampleText",
 CellID->1801291156],

Cell[BoxData[{
 RowBox[{
  RowBox[{"zi", " ", "=", " ", "0.7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rbftype", " ", "=", " ", "\"\<MQ\>\""}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rbfscale", " ", "=", " ", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bcs2D", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "15."}], ",", "y"}], "}"}], ",", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"3", "*", 
           RowBox[{"Erf", "[", "zi", "]"}]}], ",", "0."}], "}"}]}], "]"}]}], 
     "}"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"velocitydata2D", " ", "=", " ", 
   RowBox[{"Wildfires`Utility`VelocityDataInXYPlane", "[", 
    RowBox[{"hills", ",", " ", "bcs2D", ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", "xmin", ",", "xmax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "ymin", ",", "ymax"}], "}"}], ",", "zi", ",", " ", 
     RowBox[{"{", 
      RowBox[{"nXgridPoints", ",", " ", "nYgridPoints"}], "}"}], ",", 
     "rbftype", ",", " ", "rbfscale"}], "]"}]}], "  ", ";"}]}], "Input",
 CellLabel->"In[6]:=",
 CellID->758114674],

Cell[TextData[{
 "The discrete data is 2D, and can be verified by using ",
 Cell[BoxData["ListStreamPlot"], "InlineFormula"],
 " to plot it:"
}], "ExampleText",
 CellID->1059278774],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListStreamPlot", "[", "velocitydata2D", "]"}]], "Input",
 CellLabel->"In[7]:=",
 CellID->692842189],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvedbVdf6/vu9zjkvzr9x/pTze3tSdozJTnayE5PsYEdjxYIFsWBERZrA
oiNNepXee0dAkA6CdAFR0ZjN+cw5krVX1pplrEUR98/nIl5kMdecY45xP/dz
P6P+Pz8e2uH2f/zP//zP0f+bf3b8cPL/PXLkh1Of/1/8z/86deznH/9Pfpnj
v0X+U35fW4e5fbAPtp1sPWAWeHbhT1tzwYcCvO/3d7YAH/D8oQDb+f7OFmBT
8bwF9m6fbmrbvHhr/3UlfN/x/ME+mK1tCJ4/QPqDvXPbgnzwg32wLbYPeP5g
/032Ac8f7L/JPuD5g/032Qc8f7D/JtNF49vJ1F/dRcIYUz3GB6tj1Z7q/3pa
qldl7vDBPtiWmx4aJ4s83dwT5t+uLT3OcnPzHnq7lODuFlw9ubY6aQHhPUum
d/hgH2zrTQ+N84+rqx/PK7+ttri5uXfMdLi7nehReflxwgm3mA7TO3ywD7b1
ZobGacDrbml4u9Lh6W5R8b221GE5YfmA5w+2Hc0AjauTDd6o5ZiGt/zPSscJ
tz/x3BJsh+eNGpoxsJn5pbdvf3f2W29+e/v77/+Wv3719W/OPgLr6B136vqX
r14PP5l14UGO9uLl6tLzlxtyq8Xll90DExPTzySvn5x5Vts20NI90jM46VQl
b4aZgnB1rEjJBBuUTPDtWxA96efmljWE4FjN83TzzBuyvdWmFpUaO+qTnJTX
6NS3FhZXQpIqItOqZS5+8+a3kroe7+DshaUX8o/47e3bxs6hgqqu8acL8t9q
6Bj69nhYa/eI/Fcc7fmL1Qv+mf84Fno1NA/vWM+tRifm7j9oOvHr/S8OBVNj
i8tGNUBFgd7Ugmbq6tvjlv9vt9+VkFynXn+zTQeNq0W/2kLes2Nlbakn64//
886aN7/Dxph/bMnu8zHljX1Ofevp7OLhKwk3Ih68ev3G9GK4xT+uZNepiIeP
n0jeHyQH3Cv96kjI7nMxQEvyW89XXkHLvpEFfcNTkl9xtLHJ+cB7pV8eDvaN
KEgranHtJoQhWH155RUw/ulMZHBCWXPXMLFM8+KVl6u4bWRq9fHryTsOBlKx
wQnltMjE9EL/yLTLL7JJ5hwa366urNg338bieWh8Njylyicsz9Mvo7NvvKN3
7N//di6WVbf0f30kJKO4Tebi+cUV2tTTLx0XkH9Eaf2jPedjvj4a+nTG/Fuz
C8txWXVHriXhmDxO/il21vRw+Ozt9G+OhcZn1xNHnK0W7MWr13cTyj7a4yd4
lcI8mbKnVqDOg4iJ7Y/GcPCGziEwzHN5aNujsVer5vzgrNm9CO7zeGSqoqmP
iHw7uogIOzW7pPddR9s+4ylPpp6lFDRDArs8wg9cuudCFFt8/pL463YuenBs
RuZ6aOeb42FEW3lsACSvwKx9F2PHns7LPAXSS8xtOOgd/6+zUXPPnks+5S93
ePNbXkUnvsBN8CM9FjUwJASi6Lx/xk73oIsBmd+dDK/vGHS8DCle1z4YmlRB
5QN43Bz6hcZdSFtkjLA4PbeEj4Qklv/zhOXotaQbEQU88UJA5qHLCbhbRGpV
bkUnKt2p224xngVyIAr0LXigAiFS2JhK/u6khUja3DWClH39xum8DPyjJ+F2
mZwOkIQmV3zvEd4zMCH/iPKGXvAfk1H721spUCGVgfGloOymziFYWv5Btka1
4EHyWshquE9mSZuHbwrC+LolH8aj2kmPX9jobbyDZDY6vYbwAQ+fuZ12/0Fz
dEZtTeuAa6XVNBqd8AfnZ5e1hySVg1g459P9ARAXxbsVVUjDUauzC674u51t
MZ4RkB/vufO5exAuud8rjldDuxbVdMun1Y6GLoVp8ysf9g49lbkejt1zIRYm
J7RJPgKKA5Z7L8T2j0opRuI4eglShX8kH2G1R4OT8TkNFI/KIWY5S1CoiPTi
Vuju77/cvRlVSM28cSAHbptV2sb9aYhfriYCYKSdC8yvaQiVgLiShNyGguou
lAMA/psK3dM3U/kczU+RSEKtlEVccCyhy7Z99IazhtejT476JBNG5elrZn6Z
b5U19Mo/iItRrTS6TIu/fPWa1Aks0XCQofxThOGSiHmo8uSNFPmOOAoGG8MV
cwvL5A4wHvmd3tO9grLh/NsxRTWt/fLJrJ5xB2IcZAJuz9xKI85+tj8AuQID
I5OIlYiKDYSrqb2neAbMxbU9MDxhq7V71PR6mhthA2s51ScAOIVaHpCjZZD/
7fEw4PTMmX4/YSAQyfrj6UiCMgQrKWlI0H4NfwB+Pt575152/W98zUzuyuSw
BkZ0Q8bjs+fuZCDYIBO0ColbamELrwBdLD9/iT53IV3dEHvv1ltRUUhBMEbm
CMxaJDpyaWRIj0YPTiiTfxBxML2oVQGJBLRevX5Dedy94yU1j9XE6+CYZGHo
c8mBCbi36eGwjyUfbQyeETab1HWGv9S29iPPiIMXA7Kqmh9TJ2ihpLxGQIsq
fle4dbT3br0VuCqs6abtqFuoQPJb3f0TfIXwSrIpg5bllVfoebRlXFbdokTE
B8lAq61n9EHVQ6eGySDSgqqunz2jjl1PbuwclvwWoiIsuZK0FFbMKesgdyCa
u5A+6xmvg3gjluEmwHjHAaXDefe5GO/gHMleo3dr7wWeEWmk6mizs7fT5QeX
QSNxkJiIUJT8CoA8qzK5b2SB6cWVTX1nbqeR7IAryfsLg9MQFRSM1+nql+pg
AbdkcPA/lYCSdzZJNLah8VkEsF9M8b6LcSJDJJBBHfiOUC/kjxv4uE21bY5n
1NrNyIKdh4KJrZJ9C2tqOM4p7yAzgsrkh4P7hqcOesfDS/yYqtCewckDXve+
PBzslCDHX8aeznc9foIsl38dkIZMvW7Jb3/k9OiSo1E5sVl1sZm1iXmNwLjt
0Ri5G5VM+oZo2aTe5i2z7YZnVGtUWk14SlVocgW1TdKXWtDs1JQb0kPiI8w5
MjEn/9C7ieUE8XK138MYM7jYjYiCf56wlDf2ITMkH0F8OXkjBceMz2kwvRjP
4nqckdRybHIe/SPftahni8svqlv6Q5MqxOAO+SMCbGEd45Xb07YDngmmhF3Q
6x9bQlpEVKXdyfGd5QrC4qmbqbCN5viXngFLwOkfV0IxjK+kPCkFzX//5W5k
WrX8yC+K9P6D5t3nooEQQdz0+uaukbO30z7d509VOI5HO2UoLjI4cLv3QiyZ
43n/TMiByFLXPrDdJASaDTKhVJAJ6UBd20BJXQ+qrLL58bJZu9jaFuN5dmH5
ZlQhP5eCsuEr8vodBwNBCNnNndjirNJ2qAld6ixvQLDEcXIWnEI+KYP6ztxK
AzaPBidNLyYDxVOAhHx/F0hOLWz5+mjotdA8WspY+RODgP2PpyNxZ96CbNTl
LK9nYILohhiGFryCslFEpHJbPKUTQA4/mRNdQ7xIZ9840YH3SsprtNyvJD2n
YCd+vU8hd3mEgwGSYtKWb46FRqXXjE8toMdQfcEJ5aD6hTMTCLcYz/gaHIWK
qGkdoH15ZadKa2ekRVfu5gIzMnGnZq1Qw0gaBDYMYDrq8XR28UJAJjFavlPl
zZvf0otav1Hnc46ayR5UK/IV/sTNXet2Ay0AmNYnj4MQ+Dc5v6l36KkLAzpO
GT6C+iIREPNmE3IbePTVkFyAKvCJ7EdfUSQ+gW0IgoQ2YgQYqG0bePj4Cako
FEeOU1TbQ3aw/gJvB73hghGV0Mmnb6YevZZ0/HqyUyGJSguMLyXJkhn1qGjq
A/bIDMkBjje/vcVHvjtp8Q7ONp60zw2JsASmn85Ecn+nXkEYohqx5BtZ8NUv
dz/Z63/4SsJ6ZqIa2Pziim9EQUhSOa+GHBoYm6HY350MR0F9ezyMAHfuTgb1
GZ1eg+xH4cBUEalVsPH6xx+dtfcOz8tqz9XPnlHkNQSjrv4nknGZWIAmvxiQ
RXQwnR3KPfEXESLlB/seVD383iMcMjftqoWaEO2ofeKys10WE9PPkBAevimf
uwfxLEo4NbdUUN21/q6P1de/4YMwJzIpKL7M0y+D2LfjQCCSiaLyOBIc2BhZ
jkKbnl/ehp0h78v4IGzW0DGEEN2pjog5NS9uTY3pe87HEAFzyk36itE/olcZ
upPvVVhSmvgp8UJPisPbgBxCjs2sBYFgxlSH2BpYhXshQJTVN8fDSPGoDddW
hwnLq+gsrX/U9miMYuAgwBW+BbrcH5cPTaqAisXEIfEUrlznQpjNtvdifBCF
RsORKpIzoitoBWd7rkgtoZqvjoTcL2jOreg0vhjOQf5dDMgEzDKxsqa1H9H7
s2c0ynDF8Prmh8PCoYCKUyoRJL94tYqA2XshFvGJKnaNhxeXX4BJVP3t6KJf
riYKfXvocgKKZWFphWA0PedEArJtbbvhmUCfmNuQmNeIpCRHQIwRWDOK22bm
nZ4/jDIhWf7ycLAlpYrfjWHw4uUqkg/Yk9TMLTyXAXNbz+gvVxM+2uNnsEqR
iAwnI43gvfic+iKJ/ro1FcMkd2SglIdgNPfs+djTefOv/dXAJ3oJSkfconKp
B0iY2xIdiG5II2eX8TplvAJEZNdPRZB9tfqGtiCLpEGfziyOP10YmZgjcg2M
Tt9NLI/PrkeJEctevX5DeshP/4hzGcE7xzPxnSS3rn0Q6iDNhxjJNchuyD5c
XrkMhxPWofSAuBLTVSFADt7+x7HQ2zFFkuthIUmwgYavaR0gamteQ5hG54sp
642dw/9WzfTOxHe8Y9epCDQPqhVAypRnTVlrM0w2QbwgX+OVeR0wjHLAPanb
aefZwM54HVwAzSOyFSQ0lA7b8CFiPjarLjS5gpTQJyzvvH8mr0wIoCkJAWS7
XNDUOSQmAe50D6JdKBvy5sfTkYS2fReVuVhECqqUa/B9yjw6Oefhm3rmVhot
uJ3XWyHVeNOj15LgKxIiUgw0G5GUSiAQF1R1AZXShkcuz08QSP76SAjglAmg
ABJYevql41My94dMvAKzaAuYVk82PF95dS+7HkR5B+dIdjjgR7gzzUo6GZla
TWG4ifFSa2FUFCVBQlCHKnii8C+lG82lgT+wyg1hyIqmPmIinkU14hQwDMFi
9zlFL/HuYLiufQCwXQnJ5QLCH+8LaGH+yqY+aLmjd4x2pFRZpe0isFIk0w5w
PHH945VbjGfiCBkTLwswZheey6y/lrfOvnGQDEvIIJlWo5mAkMz06TW1F5rw
AWemF7fqTVAnoFjuV36lepPMihviLxSHL5Pk0vqSAuDJ1AJ5BKmxynIWKDGn
rKOsoZcPJTscVC09Sj6CmIFacWpEEa/26T5/PAJpTRIBvaD6Cmu6ofeewckn
U894NRT4O99qw9jeud5Yj8EnUEFOeQfSCz5p6R6RDKwDY9PEdD2pYGcioyRK
xuc0GOT4gPnEr/eBgeS6VwSV6AcDiqY9FchOLsOhIHB+AD/JhYzbkghAIHA4
qcTluzn4LzGR5xLfoXRiPb6A5APhMpNjt7+9v3hWUq3GXnfveIIgkdGUNwj9
UOvV0DzIE4qTHB/hMpAcllypKeZJ08giT99MBSdEHOMskotr2wYoA6WF7eOy
6gy8DyfC3aBHtD0MycWgEc/VU2J4BIFeEClapX9kGgUuFB3QhYeT8hoRA3xu
7SB67GSq9V7Y+4hn0mFo8JvjYaQMGcWtNJPpV4ABaT7IJ0ybIhmyqmsbCE+p
4uLxyXm9pdnk5tct+QRoUhjTjTWGn8xeCcmhAAhR49VbhADSQBBIukReDK8a
qDJ4G+GEduX6/V5x3J/EBEcYmZxrejjs8qJyTXNW3A4/mVtPD7lr9r6Mp6yp
C99SC5oJkT+cjkD1SeaMfAtChmMRJNCsKY2jjVEvf9sfQJ6oF9DHJudBMlod
hYkANhAhYlAbHYLQTc5vAnUvdPrP4X91lwxlzTWuBxXfy67jQY5XwsDoB3X6
fexnBwLE9HswHJZcgRKW7J0mmYUWbFf4Lq+8ImpA4Eg43JkbEhpSCprjs+tJ
UVFHJ2/cR6TxCuSDI09myRPP+2eQSpMY8gO38EOoEv8SHSgY1cgFhKSZhWXf
yALKTFFDkytwUiIOFUIWjOwvVjtmSeQD4kqsOzVRHqfSq/diPGVNnTnPm6Ir
/nEsNPBeKXQk2WTEdyqf7IzsW2YURiyAIn/3Csyi2jX77gAYpI3+vP+g2XjK
KF8HCQQRFDIyw6AzJL/yIXggJSQLq1R3yXC8jFfOLGnzDs6mEnZ5hPtY8rPL
2gGkZAKIW03NLnX3T/yn4yK6CI0E/8MPgKq+fRCXJ9ZQz6BRTG/zjysRfRcK
8IpbPf0y+JzSEozE5jONnUPAj4Ra9BXzgy/wb1vPKLnMrxEPbkQU4HrQAgVA
8PNd5DrR5P6DJvCMmxBnaVMuQ015BWYTX3AZnjszv/zTmUi8FbG0nfvrTI0X
F+MpVGBJXU9DxyBhlBfv6p+Qz6x7h56CDVCHaNTjQ1vjztAR8R1W0VvQKpCs
7qdkgmRgBhd9eTg4ML7UYFC7o3ccfvsCGIfmwavGoZlq8Y8tger1hA2cBq4o
pHAHlHl0Ri1B5Oi1JFQ0uMULjqsdF8EJ5VQvMPMKyo5Or9EMAXplkLzSNesf
nV7/ljLvFs+AjdQMrOK88AC1DV0c9Un6eO8df3UoxNmtGyANZcewUxGwmUy0
gvdqWvt3n4s5dj1ZbxMPFAt8+AcnG94TbHj4poAcrnRcHcDroGkLqrtw2LZH
Y7yvTM+GscFd9R2DuC10etBb2acLAodv+4afEh3U+VoTPHebd7JtoG0xnkcm
5pCdsNyOg4FUPuxEfoS8FB2h8M/Q+Ky6d6Vz4ym0FxEK1Ud4ImRLTpDgesj/
8JWE5i7tTQ+47bOlF+hA4qMBJ0OGjZ3DJHGEcl5B8+k4heia3nEgkLAr+V6O
Rs0QSpCgOA4SBVl+ISCT1BW+JRzgLFu5ecs2tC3GM229uPwCkJBDbcDSzre/
w5xu56JpWUAiM6BmtaPqYIrmyixEAoEYGYmYBIcGnDw9v4TMwzFBl+YEZmQA
/oWEht7Bc0hShfxMDDJE4tfrN7/hVlQXSSISF/InipEXoy5cmA+gzG56uYrv
E0oej0x19o3jy+UNjwhqOEVDx9DzF6sDo9OI86zStqxS/m1H8ZKcUr04C67E
69S29l8KyiYoiBWaeDoNahy5NlurWG276WdJI7+jnsHbOb+MH05HyCzrILKj
jflWUHwZDaG3xpAc/1ZUIVGDmxvMfCbdAwBfKcORRaTtju2FI0SkVgHjs7fT
Sd6d2h0O9EL4R64l4SlIXxQvKRXRxHR6CU+h/MgY8BkQVwImewYm8io6CTH4
HZL+oz3KmhH0GBKLWEZkxE0uBmRSTj6E4YE3P/xCRnw3sZy6Il/jVvxQLYRR
vIm0lK9/us8fTsit6CTb5evkbh/vuaOGjPC9F2IpPPmjT1get0LJUwl8l/yR
iqIhnptND3PZ3i88QwJQxMWALJqG7AyOmppdlFnZAcXFZNR+uj8AitPb8gIt
CjK5AGWLbNBbCAa0aFwuo7lnF5YddTIimUQPqJPGyk9EoYS4G1m/2Dbcwzf1
ZmQh4NGTXvA2iWdFU198TsPNyAL0/7fHw8AYsDzmo2wWCoYBG3wLFXNnSgIz
awppCHb4iROTscEkuYbjMgoguvIn+fcMTlIPVCNlSMhtQNeRliKNkGQEBSpH
rG3ZdzGW4EWQVbLU3IaCqi5iBOyEwAP8LqwXeC/wjEClWqgN9Db/Amn5VYew
AdETDkcS3Igo0NxWGiSLPmo0vMEYH9/lDuh/CEcz1oMKQewkYpI6lhcBk6Jf
kcaF89sfjQmo6N2B1+cpf9sfAA3i1EgjlAAAm19cEXCF3uV7LbbAxDJDuw/B
Kh8OP5klNRa9iFHpNfAJVEDgOOqTJJbHJuY1OtsLvc7Sbnh/HWKAoLmgamx+
R+USzgASb+3UZH4gR22Q7yP2RC+cIzspoy3RRUA0NrPWYL8Cqv1qaJ4YQLF1
JdIBkEMmCAWlFra0dI3ILBUXBgt5+qV/7h5EC8JL8mN5yHtE+PrXOvHE9c8j
3QyD55WNbnpGXZhut03GB+EigIFoFLvZK755PAxefTK1ABSd7W56MvXMP64E
TYK/6+VfcDKCEFYkxBu7CVCHKNKKWhyJom/4KWRCaRGKpj1vi89fonlQpIRX
GLWmtd94bNFZq255jPZQZjurw5rljX14GRqeJ+KzhIArIbleQdl/DOrdTjt7
O01sbEusp5Jx1euWfK5E8aKUuFV6USvlpJDoOpLH3qFJ4pcLKwu2xt7J+CAe
F5ZcSQ3fiS2mhqlV0EvOjvD72TOa3IT6B4rJ+U2uTSUlyxOHjIBSvWwOUuVP
qAKaTA/J8DbhwJJS1dw1DPActWJL94hYc0eab3r2FgIVkQCKDl9JgORlJpzo
GfELRCEys0rbKR4Cm6QMzUwFfu9hEf3PpHJwOHWILkotaOZK+B8pCzLJ3dCl
4JPyE+LBNn46ND4LJaJ4KSRXQiMpBc24XmiSMkX/8t2cM7eUwesfT0eQ8fEI
foc8uTNezDX3HzSjr5BJ6DHbXs03Epv3brhtMZ4BEnGZGiagkIZTq/2j02QQ
tgzsQuaLtBgYnSbRoKoV7arVmQDD3IouAlH88EQDf6lvH0ThfLTHj5a1+xNl
AxX4AtqV8tNexqVF1oq9NbwCs3AQfuSPhKPAkC3ZK5GLnBfaRDZ/qk4sISPm
fwESN0ThIM/wOGqSFGzzIARcC2u6SUJFZw5uRQjAHXArqOm0umDnswMBvCwS
8bx/JpSl7B6ZXuPUgPU6bbvpZ6eMtiOA7jgQyE9RTbdB7Babdfx0JhL2NhgB
J+wSI4gXhGC7M0SU2R3VXURn+BDYGBdscfkFYKN9gT006FTHOBILl6QAJ3+9
DxmCkJCk8tmF520qAbrQkQvUt3JptjiWjkAZnVFD0rr7fAz5C3weEFey3yuO
3y33K8nuobLJmWcbvuPNe4pn2BhaQFeQ4IMZvWkSYjkqdME1gKSubUCPvmA5
9MAPpyPEKg/by/g9p6wDqkEdmR5s0d0/gTxGuiNEJRdbEZt4HYgO31RGTE5F
oGOJYgQC1Jfp7h/gH/CUqT1j3ATNjMygcu4mKtslQePoN8IN7sw9oXpKiIvh
m3A7jtkzoPA/UcP2lde5b54wEgrbsItb8Zrkzng62KY81DaA/+mMst5NnVXS
YDx3S8beLzz3j0wTv3afi/nxdCStRt6nN6sQYUy9fXfSQr0Z0yntiz7khkgg
R7STqAbeKwVppuB8/kI5dxJOBi0y3YkUG7GKAAbD+y7GAjza2oUDCtGxFwIy
cSIxHY5qAdIAm2JklbYpp1cUtX6vjiry+8jEHEIXqCOMr4Yqhzwev55MfaK6
UeBIBbKYkzdSRBiiQohlFGl2YXmTZoBQ4fhOY+cwRRUHZyDzKBJeRnYTmlxR
7sxJN2tmaFx5nOXmniDUz+pYtac4LNZSbRuwNxvPxC9C/+2YIhiS2o5MqzaG
FvUDNgDJjYgC432KOnrHQTtIhqxsOWHx+UuxvzdqHLowWNbEt4ieHr4khpb7
D5qMufSFOlG/qLYHtifzelD1kBbkf9dzyKaMyStqqlokm0Q00kBSQiKa2H8V
3U5FwZ9UC5kmsYMs0sokG7LvLl5DImAVVGg/XJUI5dRRpwZonGxJUOB7IlUt
61KCu1tw9eTa6qTFzS2mZ0nmDi4YCMksaSN0EkChO+K76KHlQ9MtXmFIJME3
x8Nis+pM0y4chPSquLbHrrkJi2mFLSg9NIOxusBxSHnEydemB0b0qwLpgJcy
Bc4/tmT9+zk7GnggTdjAsydsjVqamH7G/XHD8JQq7+Bsqgi1APMT3YhKvpEm
7LE1povG1Z5fT/hlJXjDzwqeVzrc3U70qI3wOOGEW0yH+R3M7M1vbyEEpG9H
7xh8RXwBY1CimLdAiKd+iHfG9EJaAfij0muIs33DT/ECvYwJegSf+AVP4Zfm
rmG7GIreI0wTea+E5CpLlvSnLhMgyGtQ7/ey6ym/wVG2cAvvRfgmFeViJFBn
n+wuLtPzy7iwta8GrUUcgRvDkivFhsMACVUgOluIXPAn9aYuCclAVMSqhywT
gLgSsIUmVVCSnPIOqJXXxxkXn78AnOtJFalAXrCoRlkEcehyAk1W09qfmNvg
4ZuCdFc2rhmc3Iwjkg3MGI1vh6DoP/Ds6W4RPelLHZYTlr/gWb4rm9bfeSj4
U/WIuk/2+qMKEG8INiKvMm5b1YWaLazukplfREPArqd8UwX4jXcjxymQkV8f
CdlxMJB4avdXOI1cCSQTZI1nMgiJAilllbYbMCF/Iv3kvdTe4HKnDr2CBtFX
aOCLAVlCT3If7oDD4omRqdUUVWw4DGjRmdQVZeZbeCjMD1zFWPzM/DLfausZ
FZve8PpiNMc7OAeBCv4RzMQ+fogyeCisQkDEN9fZ40e78ND04laUCSD/7IDS
wQhFJOY1EsVQJsQmp6aLyJgkCFce/wfPJ9z+xHNLsB2e5Z9LXa2ocyBdnl6F
v9Nk5DI0BDAurusxPnoejYde3XVKmb+B1rXzFGXL8YJmJAoVblzJzV0jR32S
YdoiB4liazAqWQx+So4GWclgA2nElagRpIuY/AajKvskF7YgtMDAJuViY5Pz
PKWophunEDv5Q+xoMBD405koMa26sKYbpxA6mfjlgphBQOIjpHV4ImrwqyMh
sAF+imKRP0FG3kzw3PMnntcm/dzcsoYQHKt5nm6eef+huK3p36DRiV9UAi3u
6ZcOk5tuMQcVwPlwMqwrGNLWiWgaMrh/qFuOG5+0QrujgvZciCUzMnBD/tTZ
O45rIH5kdsYg84JOwQ/g9wrMgr6gtXXq6jdvfns8MoVPPftr/5tTJhBIIpyU
14iwOegdL3rVLgVn83Z42TolBB6En5KtI4EoLe+OH8Vm1ta1D64/NTZG4+rj
1D/0M7Tck/UHoXtn2Q7hbyqe4Q3iNfqQRvex5COPZXZKpJbEqBwqTnPGJi0i
+rgM1vfRrKTwBHGaFf7URDLMSWClaQiscN3k9DMDFPEuNyIe8FAiPrwHHxJZ
KMAGzgQGxpQEH1E2O1InxxJQPHxTkXMUL6+ik4Qut6ID5Dh3VOLvv+N94SmV
5MgA+9ydDGoY9YKYR6Wsc7AGdSQ2GAHVsPc/TyhbwSPCqXMXEkzn0Ph2dWXF
Hk4bhWfyOERgffvQvotxvBcJFC/1aPApORS1J1P/AAOhePhKAiGbzM4O+ehJ
EiLq6sCleyhPg/lsJKFgAKW9+3yMwb6mcCkl3HsxFiFKYmVQMNoFOPFGpG8/
nI5Appq+y4bYstr/huZHzMP//nElp26mnrxxX+x0hydOzy4SdPApF4YwQDKZ
KRppx4FAmiwgrgRV7+xCOUebml3C05E6YrrU1ZDcjeqv24w7wFGoWSQr+Q4O
TiYCwMh3dnmEkx6SoeOkYgWE5AaJNMTcs+fICbKe/pEpAhnpnsa80NlFUqED
XveAurG6IPenjbjPkWtJeisFoEHwCVkRBR72jestECB6wu0kvGCY64efzDY9
HJZfAIvEsovs/C9sxm155dmF51xAFmztz6FUMkfUFamhgRrjPsvPX5I4UEI0
M+8bGF9KdoC+cipkUAAIJ7us/VpoHtr4GzWtFkOQdW0D5t/XMejChTlpW4xn
GgINQF5Gti7OcySsACHwZqUI03PTrIZ3iF2P4HNiluY1ZO4+YXlfqZPwq1oe
G/T8PxqcPHs7HRaFZ6Z1JiyBAZHu3U0s16NuvKm+Y/C8v7L6AIXsVOcGDyVL
gjMJ5WSFYr9ZFP7A6LSybuWAchbYdyctYr9ZxD8+ha4gQIAiIoXYojyzRJkx
0jM4Ccwkj2XBU8gKYWzk0M+eynpMquJedj2SHn0if+LGmtIN/pwoSSyApigP
5EANiFWQ8jdx2d6v8W5hAB7fh8l3qgqZGnMUD3hHdUv/MXXvArjCWOP1j0wj
p4kRpJl6AhgyDEkqB044o55TvFFyzGaeSP5Im8pQMS4J+EGOV1A2XyTz2u8V
B9ERcCNSq4/6KEcSmKYMPBcAF9WqW2pk1FY09T2ZWkgpaCaVo8D48jF1OSEU
SiiRyeZEqUhsRc/e5+oxVfia/GwoGB6RQywg5aEhBkencT08FF9z6qANZ+09
wjOZHbUBIe90D7qibiUEYGhKO+2nzm1rgsTAOTVpTAso24sBWeQguRWdektW
eYolpQpgwMx6w464GHxIuJE/c40oQKDfqRxzmRGdXoMGQDralnaj5p5R5s6+
8ZzyDoIFDoLL7LkQSw6bnN/IJ8ZdCpAtOQKuASfUtg2IsRICq2RGY1eM8oZe
FObPnlFEFrGoYcMPudgm61P0DIzh4AQvmv6b42G3Y4rQyXqyCmolkSfKU2mm
qTHKxytQQXJWaZvBWj8wlvKgGe2tycnwFVoR3wHtbY/GjJ9IGvjjmUieuO9i
LL9z/QYec0lMRzDIbNWLmww/mSOBJUlBD6BhoPQXcmMcvG9j53BoUoXI2cEk
Ycip2bDCptUDuWgsgP2vs1HEDmQnKYa81HS0bbh/nbL4YnIBIeHhm0ptk0y1
9455ByvJhR4+W7uVoaiI1Coq+cn0AiHVtAsXiJLyx2fX6yEZJ+KeAJXshtit
N1+a2I3IhF0hHIMJlmghCG33+RhgjwBAIG3G5A3wichBRZPZHbh0T2yQi2Yw
QDj5KTQLjMUWuwfVHQL5IhCV2dmD9+KhJO8QCI8mwUfkK7dy8sxBipFe1Hrm
lnKmGLSQVdpuN1/XKdtiPNOUaAA4FnEl5usSyn0jCzz90n88HanuD69sIgdC
lJlChgF3SZ0FR/iDZE7dTDWlJuUgtltp1BgPMlgEB2HSTD+cjgAYehNNkRZi
Yh76kKxQbycZgCGeCP+IrHALVmq8VodUimp7UODkpF+rPboI14ScBtO+LyBK
leLIKDqUMzJD5phvWKj90RjtSKsp88GOhZLPOlts+IpqJ38RI5IkAghLWMXZ
mXtbjGcCDXxLjVm3rySBAhXNXSMTfw5GwBgGSJ5R9y4ATihP4l1dWz9q2Thq
81fC2dFrSQgMmMQgW8fXxAAESNacXEe1AxIyR+X8FP3MMS6rDq6jRRD5LmzA
haDiNVG8gfeUDrTxpwukV3VtAzS3mLnR1jPaNzz1dGbR9uZ65cGJKIZPWB6O
/+n+AOocVjEGNs7Y3DXM04kpSAuSQQKQ6XHPFPJmZCFpy6HLCWTNEC/16do6
UJJWvksBbkUVyh+Yvvae5IO8HYAPS64k90e23YwsMN2QU9jLV69zyjrEQAbp
DI2oV72oWaBOzNWTwaACH4R8uKFe5kjUJh8k/kLI8uugybkQpUnq8mrK8PXR
UDTtdyfDRX/XT2eiYNrRibl72fXkBeRxkC3uzJUEESIa17t7x5MgW+5X8RU9
1MG0OCMYE6tRgBx3DkkqR3oZs0F3/wSXfXs8jAdBCPLrHxefvxQbMkC2hOOt
Oft4u+GZuqVxu9VFoBDpxMwzMUcLXYFCk9+7ALYH/8R6gmyP4Z4YEJ1QOFXN
jzXHEUCvuBXZvV5nF+Kns288s6QNWEo2XEv3CODcdSoCH6EA0CaZLzmdNcIS
p0yzWgosToRXDvKOKFAYeJ//hYBMak/stW4Av5GJOaqU6iWUECs7eo3O+uGv
uAzlBKLq6FW/ZM82sQDdRUQG2KQbyjaDm3lQyzvHsxiTJbcikpKjEV+O+ShH
l0I+6AoYlT/Jb/5GzIW6xeF9Uek1xqdwQlaIH0KqUbfz4kphTVdQfJmmSqFg
BAsxp8j0COah8dnojFryQTgceIgDzgzmTjsaSBC9IghdxwIDXdtMU/RgfHk4
eN/FWKI/T9RTcdPzy0jlw1cS8CzSanEchnHSGpNRy52ha4At2TpERvwL2UNd
oegIc0PjM04NNsnYFuMZ6BL9IUPilzIRep8/1fKzZ7Q4O4zmLqjuismsLdRX
p3oGU5EKEUNhcojOtJKpSZpP8/A1btXYOUSQBQmIcz2+JQP1iykW06GNxwi4
A9SNKuCt0efOHj5uNUTsKfXsIXyQqkOTIFZhgPSiVjIyQZh2hAzlEoCILMAV
IJF6N3QM6VUOmgRVQ56LZt57IbbdsAeSUEUSQW2jAHFS40NhbI2nkwvQ3D+o
G3oQmDbwmJUtxjPvMjnzjB/AsGK29kTGwAntSwpPLIONDToQQCkpHk1PTcJX
sJyeliYQe6jalVxV8wKakowPeESn10zOLBpMbUIziJ2aAFJr9yiEvFHroXgd
kmvUL8FFDJLylN3nYgC83kG3fJhV2g43UnJKdTehTDPV4s6ENrGUAB42Hdah
GOgWhBMNwf1FH7LMYFB6UQvRjSBCuoGrwtjy4lzP3rnecM0I04TIoz7JIBl1
nVrYYjqFBhUtlIx/bIlebRPQaWh4G4YH+ZrXoAahR/BpLGZgRTFeg4iSbyZc
jCjsE5aPK+F9/C+KiyciooAuPggP6L0pn+MyBAv0sOjw5CuatIkDRqRWIWhJ
XREMmncTW+9SBjKRI9eScso7jHsqeDp8DlcQdglbeI1Th0fwODEWhj/yLBfG
aIRt8/FBW3uh7Io8BBfBQiAq8F4pzaeOdhnNxCPgVrf0Q1+EUSqKyKt5GfWJ
oBWD2nrSEWwcvZZE4DbedBEke/plgKvssnbTAEQiCVZRrafV3cPEBiyEe37B
HUDyw74nok/j5I0UEYlQGih2HkGUAbRInXKdcysAGFqOi/Epuw46IE1lQomR
qdVk37y7QQ8eKQyJBrqCyjEdoYafb6iZKdc7OzMW7VfXPnhd3cAEjyiq7ZGf
XL0NxwcdjReksWg4xOeOA4EkehCX5DRvKhb1i0g7dj2ZTEQveYdYKpr6CJfg
R2/4AAFMSgjvIewNAgFOcVU9hhgNYDx1hwfF5zSA253q6Wy8lHK47dySOLYe
eWkwawjFQnhqejjM28FpwJWUZJdHuN5WFY9HpsDh10dCkGT1HYOa5QfYSl9Q
aJ5B3eIC4eo8lqshucZ5HEoe3weZEAiSBnzqTanVM2qytm3g8t0ciuTUnOrt
g2el32lEqYRfribSOtBgbGZt39BTXoqGI4eSnNylrHvqGxebFJErGS9Sg5p4
0KHLCQZbE+BT3xwPA88GHXHwMHfo7B2D/42zG4oHzXLDu4nlLmyd6mi4xt2E
chCL10P1uAmq3jFm8Ra4LW9KQvqg6qFjFoycIBnBGc/7Zxj0cOJoiGTcH7GH
38mUP6O4jYeSXPNFmePG1mNbjGc05+3oIhz2SkjuxYAsmHPPhVhiKOH166Oh
B73jIcmrobmIKPjKhcLAnyI9zyptM+4HBlfwFRdDa3qUOzQ+m5TXCNUY7GDT
0DFELEY0JurvMoos53WS85uQ7hNTz9qdOdXd2dVMqFa0MYRAxaYXtzpqJ3FO
HLglQSCg2/0VYsyr6FSOrruVZiCrKD8hD10NUMUmvaYFw9+vheaJ2WKbsRJW
2BbjGQ1QVNONLKQ2EFeEoZGJOZrAtgfJqf52kAYvgRMiL2QLjI3ran5xBQSC
vfGn85obfAlr7hpGoiMCS+rsW9zW4EZoihAck1Grdw3ygPz947134DTNbfPB
xtTsknJqVVIFyhP5QYRCLZ/3zyTa4vj8KzkH1dZAoxCiPN2x2wfVjWL/dL9/
YHypozuLSSw4xYWATBSIwdAJjYjg+WiPHym5TKmeLSmzecUUcchHmfHrzMky
prZ99IZTRhrY0TsWlV4DP5B3EMFlRDWoU2ZIHgw03s4IBvvZM+r49WTir0EB
EL08mhjquKGH1dCrCHiCzs3IQs2pNegEqPJbdcME6JT8jrKpu2GMc9vKpj5i
jdilJCG3oXtgAtmjzJjVUtdcfDumyO6UeVRcrNq1iPSyQzUKHDBzf/60/EJ7
ShW6Wtn0MiyP4KL5ggBSTPymYPg+hZc8wJSn4ywU7GZUYUhS+Uah+j3CM/qZ
hgZFMJiYoxiXVYcENRjdE4ZWhP2QjoRgD98UAwKHPeB52AMcGuT7qFPyU5JT
g2RfzK/+2TNaKHM7DnwytUCxyXSUzQ30+/1od9uGfvHqdVpRy5+nVGSiFmz7
0HhNUIf7INvsFqSjOnAHwJNW2Eyl2T0F+oXMvYOzNUuCg/BFeICi6pXTagRf
LuYRkjOZqQGqSOyRviGTD7chnsVxz+J3gnVBdVdwQjlsKWb2kkZBUJLVRXId
nVErDk0jMtLEumsB1H3z/nEsNDK12qCjlcvI+KBlYx0CzX59JARh6Ug7pXU9
lIcWdNws3dGQXpqFgQPLG/vwF8ADx9oug+UdEUs4794LsXZbWONiVCOPTi2w
HyfiWwLw5AuOeTduRfhDyxE1QKzxjEF4AIXMrcC/zDxqdSnBLMGorKEX2omW
271Ez94tnqkosjbKP/xkjlYAumDghLqgnhCs5OnjM0hKSImalN/GBB6Du5Cg
gAp1bdrhw6MJ6PCe8b7HqF9wgmsYjBTAdcjd/V5xmuvTocFvjoe5X453TMQ0
jXhBVRhM1aMk4FAsqUZj22Z/vBTuTzyyKjFAS4BDfvAWmmfU0hCXgpSzBbv1
u9fgE7JFO0/RuNX8Mrodxyc5lU+IwLaY+kX0kew8sbMtHk8BEmLmIWVGM5BH
8C95BwAAJ0gp6BQ55xdT7NoWZ7Td1ZDcne5BRE9irmkX38DoNGkRItxAAwtL
L2qldYz32QAG33uE40Gaz4V88K/OvnGnTpXiW6gL48lsiFi093cnw33C8m2B
Ch5yyhUBDFU+f/HKNlgg5lEFmqiubumnjQLvlertYt3+aEycG2g8krWmuhu6
WllEnFIlv2XTa1UfkmjjOMZx0NbeyXgKDU3U49VooBc6Rx47NaljRuUB8A+N
kxApaxyqzbcCEwbg/3nCovRymE02gGyJ1MZz4CkJ3KuXaYIolK3dtCXJOdI+
lnw9P6I+rSTW3a/sLQxF2A2sUNV493VLPjLA9nOxmdIlra0s4Un/2BJ8U6/X
lKfmVXTCS6gdU+03v7gSnKCgGq42PTvJ1tp6RpE3MmtkrLYN9bOMQXFoVNJ5
sgkydBzZdAfmNZXHatuUEQc4HA3TO/jUeHYQ8Zf0EzgRVgxiH7el2lu7R/XW
fNGOhH47MVnV/FjyYHoiV3OXNq54NJmUVT/zOk0Ph5EExClblcWLkOQiXQCh
7dfxBuI78VFz/K7t0RgVC7A7Ho1rMg9IBqgkHbkVnabaQJlaeTbKeP7M+u19
wTPcWKeul78YkEUFEhCRqeIABYAhM+FQOd+huuvwlUQYDDCbXk+k5kqeZUDL
pORiCFiPdoABgdvdO94udsOZyjo7icMUuANf7+j9Y+omQLXLMXEKkXvagUSM
zlv/F7zhFL+GP3g8MmWXY0LCFCY5v8kRtKSj18PzQTVpsl4JCTonfr2PwxoP
PK2pIoesnKJSZuU48k04mGC74ZmkLyy5AtIATuIIJGLil4eVU87P+2cQtVF3
8keprv05TRQmF/PPC6u7TKUyrJVa2PKVzcakepZR3PrTGWWPMr0RRv84ZcsL
xz6KsPuVn+zzr+8wH1ZDt5PYWgU5QpQfu2uQqSRQR64l2XZ5EVNQufHZ9XZP
5+3Anl0fAncQu5w5SjXiDhzy6T5/2MCgnIi9g973dhwMND0ySRjvTouoZ6A7
MQ3P1LYYzxSeJkbIoXjhCnQdwZSapOah3E/2+u9UVuWk8cuVkFzyDuANolzY
lgE64uuhScpoBc2XUtAsyQY4EekhEAUbBh13yjlB8aU/e0bVtQ/o5e/3sutx
Rs0Ba/IdryDd6U+2dyBA2wYIcIhq1cw3xYbtRCvbQlLVvL7d1Nas0nakvp3G
oMagEahYc2RqWd2TqrVnVO9kcDw6NrNO2SHHPch4gZvVEPAoMbH+faM2ltli
PKMh0VqEGyqH1JWMjCDY3T9Bpoz4FJGU2OpyJAKBBNkr6qFRh68kqOPasgua
hp/MeQVl/3QmypTAgfpB73gEj8E5VpXNfdCd3uwLvObMrTS97+L16UUtZGpA
0bGX0sM3VW+fQ6BIvCCK2apZYg1ObbcohkrGL2zBL4zw97V6BrQmwGgXKta4
55wvVjT1ibWQBpdZbUk9BlqMYK7/nLjtpjecNRB1LTQPaN2MLICggCK0T6ro
1EoHOMc3sgDByR1MB17BAEjIKjUaCuev5Y1GOxXQ1mBV80/EI+D3vUd4RFq1
Jg/DBryj3p2JZR6+KchdcgqrCiJJ5O3sZiMDfvVYLvuxFZKLzw4EHL+erJm1
oQAhinN3Moyn3HMZNweikns5KpsP5zUq28uH5IqlQ67NPHzv8AyNd/SOZxS3
3VYPL6bmIbo/ut2cX70llsT+Q82GTGeyQZU8FI1hMFcE9bjfK27PhVjTFP7Y
9WTbtBTwt/WMQpuIfGQSr6MXggHS3/YHGPgd9RCcUI7SsFXalNlxpxd0CFUX
+9cRcL4Ou5KEonb07g+jfqvfOSmM+kROqFNc2iQ7NJSO9CKlI90vpuhCQKbM
MY52tg3xTGVCs09nFqEXWjmnrCM6vQa3pYbJIMAe/IN2zavofDQ4SQ2gA+UX
VKID+0emETko2M6+cXEfma+DNEK5f2yJ8TBleEoVLibTeQiW0MZnbqcF3itV
9kp1D4pM0+1DsLPrlvzYTN0ZfWuqNN3lEf7RHj/bySrIWp7IF22XDRLuqdiQ
pHLHm+CbxXU9eqM/hBgeQUJnHNHGns7zjvsuxhmMOdrZq9ev3S/HU1SyKqc2
M1/b8vFB6jkhtyExt4FapflIQJT1+5EFl+/moDZ/uZoI+51Qz60W3e9PZ56R
LCTlNUIsfcNT69yThMpBW35xOPjjPXfwEfndX2FLBIDpsd2wIgkgElTytrAW
bkVCgRJwiovAEpHC+BpEOOH+6LUk28AN++E4PpZ82yt5NJfBEo4rIolfZI56
nTw0BzxDPDLdAheRtutUBDJJPjPCj6jwoppuybUt72R8UDmjJ6MWMMdn14NS
UhXoV+wY39w1TL0p63zVM/I2agIhbVRU23MzqvCH0xHEVsiQWjVeAGg1uOVB
1UPiBT+ms0fwQZ+wvK3ZBWhN1Q8yl5Hk2o5C4sIoqx0HA+3WyaJXIRM3z2jH
jIxYY9dtYmdUr7KffNuA8ax+giAqhVvdf9AE88sfAeDU9pXbUG+s055MKef3
Qb+efunUHjKPhBEOtDarTE0+W37xL3UwC3Vt6lncUGzVtXnDXusxXBKlZEuM
U7NLdvms2ttWiyw/75/peAdYGnY1GKoef7rwy7VE3MTUywiRF/wzd5+LIb5s
xo797y+eaQK4F1VGAiUOJ8X9xybnfzwdySdxWXXGu8XqGW0dmVpNkPWLKUYI
mUIU3r4UlO3hm7oZB6GCE6KJsxrS0eLVnnDbEg6Nz3Jnu83MyUCvhORqztnA
HQ56x9+OKdKsELiXNATRgqI27dAgbUFbitNnNhzS2xDP6M/2R2MiyvC+iBDk
ZWFNd0pBM2kLZIvAVrYi3B+Afjh+PZlPUN3ZZe3rQRTIh7KUKaZHQy33KwES
ysGUySdnnpGz3IktdmETURlDj23UFru4p91MfnibenMcq6pp7dec3IgmuRCQ
eeZWmoEAQK6gTzKK20xzE/yChIh6RgHKTJOWtK1fD4tXomYhB7Eq1js4W93A
PAXvJgsmMh66kiB2dg1NrgAwfI478xXSQ9KZ8oZe5fygmUVrjYll/i6UXN37
op8kjowGGPMIg72wHA0dSNJqN8NnKw2iI44Q5fmXvMx44ST4wfftNINyZuut
NDuSfPFy1d07XnM1CleGJlXsuRBLsmmAWKoUMpecFwdHqaK6eUM4QRqNq9UW
TzV99Cwf+0uQcmE9LBlESV1PeWMfWQZ5BGlsR+8YPEwQVA5JKW7lmg1PrOYX
n9PoAXEl97Lrye94tDpvPAPa59HOSl/yKfT5hh//YWq4W1vPKBhQnH36GYKB
WD+7sJxW1PLdSQsJqcHk+cXlF3YDheATJnHs+qOZ4BYcVvM+mSVtbudjyCwM
1IKYTSo5gXBi+hm09r1HeGn9I5nrDUwSjUsdMW5ulsnVtclqi5t7gm0rbp98
kOqlNZHQbY/GcJbUguaw5MrLd3PEzpmfuwcduZYElZHgK2fbrU/uurDpK08k
worD6Vx+rjif7vTNVEc2e/3mN5AJqlu7R/W+Dnv8dCbKdl4KchfZ5rhr9MLS
C2KlJiB5NGpcWbdluKYbLQFLk1xIbt5FKkROzZ1d26pCmCQae2Lc3WPUlQJv
e064uXfYMPQ2wTOy7eM9d746ErJXWfSaipgBzOgTcXakGP6mojZJ6Noa5Gbr
LPhXQm4Dqoni0V7wIUkTP8EJZTAtUdtWO+kZgorCkzic8k05ezvdwBm5DKQZ
TEG5HV10N/EvoyfKKrBjoY65M9IdqGv21FGNMPDu8zHGJ3jyXugWOMS0695q
KEBxREJn77gLx3lL49kzuEH0dy3FuHu2/BXPG9WVvR5Tz23blBMbjYfRUZu0
O9q1uWsEGUNQuBVVCKKItkhTOAfZzw8Zru19yJtQjMeuJ3+hnFyZBqkie2xX
+gPgl69eDz+ZFftygCu4jt/53Bb8UJ+jMMODdh4K/jU8X3Mq5vLKK/Sq3TaM
8TkNp26mOqYhJIaoMj3CF5sHot+M85eu/gllaDWuRHJvHG5bUNV1RD0bWnKG
krMg7Ig58See5y1uJ1q2Ez/LD/MJQ/rC2LbfwhHEUcLT88uAAXCSajV2DlU0
9RVUd4UlV+w6FUHqip7ku9EZtdDs7nMxIFZMcFVy2MvKFB2SXLL1yLRqYkRO
eYdM84FGhCjEi7aPyah9Mr3APQE5HsGdecrV0Dyeq9msynZ5IbnPljRIjDJ8
tEd7v1++dSe2mJvb9pwASMqAMzp2NfQMThL1DEagfCz5jrOs7ezFq9e3Y4p+
PB2ZX6U7L8XW1H3p+0lXeUG9GaqaJonG6Wo/txNZEMHqWJ6bm/eQDYKc3f+Z
8IqAVP6dWSQRIAFEaFFmIhfOzk9MRk1sVh2ERqaDqyKGiaGgC+1H7ANj5JKF
Nd1Iu+yy9vTi1puRBXAXMbS6pR9ZS1MCKmrvZlQh+RFo8QrMIkYT6OFDMncx
nv7ZgQD+NDoxJ6TgjgOB4JOUBAjxiZjcDpb8YorF6nvCNAxMPfePTItxTGWB
p1YW6ax/OVaR3spKO0PGUDzNP1EGamDfxVjNvxL98Rq75Gt6domAQl05Xs+L
I0hae0Y1B+WpBJ5FpZnKA1iXSIRKkTyrwgWTRuNS1q/ugs9Te/7iL87uz4+T
kpKIf/n52ZOfaFC050Is9X/g0j2wB8D4BOk1NbdEHPT0U475o6pJ7mADaBCs
Er8C40vJ9G9EFHx3Mpz/re8YhCUgxpyyjgdVD4tre8rVw3YRk7RIR+8YVAMa
+RPSmrxMoNG0ZwMKXSdEN8Mo9rfHw4zla1pRi+a2CWvqcpKg+DLbT4hNVP6n
+wM0V0887BungaL1tzUjFsD5xrv0wwB56tlkJ2+kbNS+7nbmFBpXV1ZWHRp2
w/UGzOzUIILLe19vqhFx7GJ0eEqVf2zJRt2f6GYwp8Jq4EdvppPjfHvYQKzK
dLz48cgUKougZrDYDR9xVOaaJrqhoKANH1TdhuODm21IBWc37XTBkFLwp+0n
pHvEEZS5U/dRJrhqkV55Y5/jXDVIz27wDiey3K/UvHNj5zCh0PFzvb4IJJAI
bQalhZ95R8lNCcSWCDJ7k8rb/4Z4djsXjVomOKrrBNODE8rRJ21/jrBvoCGf
7OY6Enr+ecIi2XdN3LlueYAec8zRcA2cxU6FokBgV7sOSZIvpK9mzw/43Hcx
znGq9uDYDPmInhhGs5HCGOR0eBlMfi00j+KZrrDAu1GbXkHZTq1xNrBtiGe7
fas2yXgEIa+5azi9qBWi8PBN3XEwENGOMo/JqF3/QNWauo+348IosdunzKmp
BO5dpyI0D5nCB0kx7KJMa8/IkWuJjhcb7NZOcnH4SoLj54jhoz7JemiEpXm6
AaRJaUlqeHeDXQ5sL47PUbbOI7Vf/wTFLcYzEKKN+CEfFCkh/EPCu/dC7H6v
OGoe1z53J+PjvXc8fFNSC5pJUgAYeR9xEySkFDTnVyoTkhs7h5B/oxNzC0sv
mh+OiINU1vki3AFqQnDu84qjvS4EZLowPc/WwNvXR0Mdu5t8wvIuBmQZFzir
tI0yTGlhBs3pG1Hww6kIuyyV5PdSULbj9SRxBnkcFO24WQ3UTfZtN+xia7TC
T2ciDUiVpvnHMWXbSZmlOmuqPDvvn2l6SJypbf1+X+R64kf016Fmx58uiLNQ
EYrkUKCXTIHWAU5cX1jTTYaSWthyL7veklIVEFfiY8k/759x/HoyjkDYPXwl
UezfiFDkK1yDp9e0Dgw/mXXh8GhlQ+OBCTQkApXAytMhGclFnY6GkiTy2n0I
WoD04csJegPfJHo/nI4wkCW4g2MyiBD10sJzR+84daV3K6LAgUv3HLsHn79Y
hWrK9He8IfpQSINDvmg7GpGiyh/9XNc2wD29g3NAtVO7/FntPTrfSs+KansQ
wChVoVLQD6HJFdDLnguxf9sfAM5P30wliymu7QHhsCIVJT8fDzIMii/78nAw
d3Dh7A9xxKcjR1GAuOy6j/b4EYzsxABRnq8YLzI6ci3JcQ0UuRi61/FiwgTJ
gkE4ICbiuY6fE1m+OhJisOURPEOQnZwxmUc3NbtIc0guKEP/o3b2X4wjVXTq
8Nz34nyrdRqwISaiRu4/aILVCWe07OW7OUevJdntY29sqJrAe6XfHA8z4Cs9
I9OEcxwjBcxGbuU4skB0cNeCpa0hbh33bCGy8HaaXTfkBQZ7geI7350M14xl
cP53Jy0GWxihpakW081gkS7/OhsleWqGMiiWWn3sejKQdvakla0+P+WFcjo5
qBCTRWvbBuCutp5ROAoeGJmYQ4dQReQpLkgFGSP7Jvii/fhJyG0A1fJHiVFC
PAK/cDZdxRdQHZL0jsIxXeuKS2p28wIYzTAt9iQxuCEvpXcETFpRy76LsUY7
5zT1IZVNzzsWO9VklZrv4m41UsUR9XRF+a9sMZ6p7evqAN819aQblBIBFz0A
xoh6KARSRTEeveNAoJjPz5+4zF+dt0waQiY4ND5rW73rWTmLhuehYDs5v0lm
VzGehfzY5REuuUubMCQEWS0kKTMoVlDVdf2v668djezY4AQiRwOTxlu7EIAA
W0KO9mGj5CxklI36c/ZoFDLf+Jx6Y5+FrES+71Q+4tRM+G2oN2CS+o5BMcPz
99+V3RRx7dyKTvDsF1NMbZC/gPa//3L30OUEiOWWegCc5HpnTYOluTMiOTih
TKZPg5hCkC2p65HcdB0YXw3JxUlzJRazcLHedl5WI8XT7GfTM/9Y5Qxxg6Ec
PA7G+GjPHc3uBdjDN7LgswOBBpUTklTxyd47dltMaz4IT3TcrGmjbBviWdJQ
WQgAQAWfk1h9cyw0IrVqdHIuNKkCMeNC/zxSJCq9Ruz7YcoJqN9friaQLmke
6a5pCAk8UWZS6+jEHJRoEHfIC3AoeRdGPJMaG3eq8yLodu9gjR6SNXU4kica
jNejD1MLW7jGYDWB1cgRyHnxEdT+xg55v794thrBywoSciKyY5QM0ZMagy7Q
mU6Nbs8vrgTGl0Ig4ogTvW4BeCYitRrSU8YdpLu+xaxCmStxUhjYoM8KIXre
P0PyuWvqicaa00dt7c2b34ITyvUeStZAWmd8GA31T4XjOKZuy5VEQ/IRXtOF
xT569q7wDBkihpEWZBOoi7ZHY5Dtk6mFxeX/TMJUutec35LOaqQSNLqnX/rO
Q8GefhkF1V0ij5OBH2k1YsYvuhjda3AZgRhSKqrplt/E2JJSRZFMJ+yRMhPf
DcI32Nvl5IK76hbz+Utr6kbuBvPBxNlMxnfAcS4GZMnsokZmhAxT9nvfoBHh
d4VnakwceoKw9ArKPnUzFfwok+SPhHyy15+gT5qGVP5GPeXq6ewiUcmF1TfC
qNiKpr7Ld3OUw1LvlZ65lSYz/5Yn7lcHChNztbMkqxH9z9xOM9753PZiwgep
rvFliI3K5j5EVFJeo2ur1x0N76ASTO/WPzJNK+h1+xANf/aMNqZ6yPl2dJHj
rumahrjibig9nrv+ebnbczxlSZ1PeCkoGzkXmVqN8oSryaB3ugeRIOMI2WXt
PepmjE7dFn4WhPDj6Ui9icG2hop+UPXQwzfVdGZmd/8EEkVyqhgZH2+ht3un
rRHc8XS0h2lvmIwRmE7eSPk1/IFpXyhZIa+j12UNsfzsGWWwY7AwLuAm8h1B
TQ+HkYimubCevY/jKc9XXoGcvIpOEhMxHRdWD0kqpxLAqsyudFwGkaJzEvMa
xdx+GUmDfyE8jJtGbKcsc0qmuOGuUxGmp/itqXzOPYlT4NCp8TJNgwC5D+5s
Om1VnNqmp5ZJt384HWEqyDt6x75RD76XLB65JIoaF5bc4d/RthjPKGTC0EHv
eNBIJkWY9grM8rHk+8eVEHHQoiV1PQiMlIJmmS5KNCTwTi1oPns7fcfBQLdz
Mfxienqm7deRsm7nomV4FYb8h86hOVYjk+JukWnVMgqBAEFYl1zvifhBeIAN
BMN6eiaFNXQM4XqJZkqGjBjk6+0IOjO//MWhYNMZdEgOMj4kpeR4N0GEcExq
ADCGx51+0y3GM6GWduxXV6QCRdJAqJXch9yQ6g1PqYI9cE8kwd/2B0SkVo09
nQftcVl1RHzYySBrHhqf8fBNIZ7yLwkm10vG6Oau4X0XldM8TechEGfxQVSQ
QYcJyvz49WTeQob2eWu8W140inMzoU2fsDy7+xv0hGtWGnn30WtJhDZjmNEo
JBF610AIiMBYhwPB7YwX5EE/nYm0bhxhaqQPOWUdh68kosOdEtXbUG8QdMgR
RO+rOEoeqXlJOdkkEhI+dj3Zcr+yprXfeJlVrbpxCkklVG/aHQRNERpIQnmQ
ce2BosB7pZCwwWZWlBluoZVl+gl5L/ltzIWJjWft9L9ySKLWNDbSEL0JRbxp
cEIZgs34lXlfcnY9JoelqefMEhMtvabOnfvqSMi+i7Hy8YWC4afyPfxr2xLP
BkYiQ6oCaQCYnYeCoY6w5Eq0tN7RMyTpJI9fKJtRPDCdgIQm9FKP4DE9xreo
phupYDBwACVSKqAyNjln3BOLkIZvC6q67C5Dq7f1mA9MWI3Q9q+zUY79Nsrm
ZoZ9emJvBIN5VrjwKXWCol78ml14zqMziltNA2JUWs2n+/1RTevfMVXP3i88
2xpCiwQwOqOGkKecOhpX8vzFqub2R3yeUdyGJPPwTTXdSwqsopNNz3fDg/55
wkL0N7gm7H6lu3e88QwceA8JCqjsErTQpAr5NGpNnSTw+cFAx00UYzNr4wz1
AGx/OTjn4713DJT83MIyuv1nz2i9Cyqa+ngF0iJTlYV0KW/opZyPhp5uVJ+z
rb2/eBZG2giVgVLCWUfvODCAitu0JiFQ1dTk7vMxaGCkuwGwIRw0MKmi8enz
hFqEd3x2vd6K5sbOYTQSccS451w5qed4mN0JJnkVnaaz7GwN/YNHByfYrygp
b+y76rCgwM5wpR9OR9zSHzkC8zcjCyANvU5pvJIH7T4Xo7eFo6MRLuENMoiN
3Qvifceznb1afYOWgyhgY2SJo3ImrINqMm7yTcdNCK3W0DmEnP50f4DxKMny
ysujPkmf7PXXC7U4EU1mOnpC/CWm234yPbdEczvSHW4Yk1mrqWZ5Wcpsl1aM
TMwBM+Onr6m0GRBXYrDYZE2d6myA+TU1YpKGw/OSUzJwZE+/jB9PR5bU9axn
INjW/svwbDXyCHHGMSxnl/tT7akFzeCHEGmwTyC8Qevw9f7RaT0NzOdcg6gg
8TSYCzowNpNd2m48KAmA7UbTTt9MdRzOhiq/PhpyMUBjF6M1ZZ1smd1SQV72
zK0069Qm4w667DKjkW7ssXIkk8nQKsGRHER+MJfwig7cdSoit6Jz/btlbvH4
4MLSCxQdSUpyfhP6EJcHDyQ+uCp/ErVt3C/nlJFtJeU1InQBgEjzbSdvgEAC
KEgzHv6De8/d0TjY2taE4DHI3AkKiAqDrdh49yPXkkgMrZ+Qb2pu2EXlKHvV
FmiMZYjTkPU8Cw81nruCBqCQBoPUeJPbuWi7QwwdjeyDJNepbW9Jhc77Z/Kt
1MKW5yuv/q2a/NfX3tX5VksvlMPasupIgtC6/rElV0Jyz95OFzvkE98RnGCP
f0mjNmomodKZWd6BAiGkegdn283DhElgVx5qQClk9xTJdIgcXjIY8qts6sOz
DMb40AZfHQmxndp07Hqy5roSkKmncLyCsvUOjpdBCK2jucmM1cS5nKbTcWFd
XpZU1KnVFtz8ZlQhcfNuUjlhxYWj6reV3oA+aG7IEDFAWkdygdsi/3wjCyCu
dW6GD7eIlS/n/TPsGAx4xOc0fH0kxGC6Ghz+leGxZWvq1JrvToYbdMYW1XR/
7xFuMAs0IbeB17f+L6/P9U75dUPHEAmv/PV2BoEfupxgvK8+sdVO7WsaSh7n
giucnXzCF33C8sQZlDJ7mtnatsKzpsGKEM51Sz75ESR5J7a4tm3Atd38yHrI
AQkNiMxHg0/tqANy2HcxjprUWx7IBci86PQaA6IjpcIB4/W3RM4ua//ZM1pv
mAyPRo0X1nRbPyEFC0kql39fAElFmY5BEAtQDprkSUJHrDRgYAQPzGA6eUMY
UQkVQRri1GYmQJp2R3HBME5tXLD98Wxr6pTmNhKlnYeCESplDb1AVH57B1tr
7hqhQe2m8tK+pFSAVm9q0+LzlyQviBMDzkT+0dzKkLeOWIWEUSZ6g8hilwDr
4AUP8vRLP3ItUV5PBt4r1VTXdvazZxRRSTNLRRBeDck1+O7C4gpywrg/02qk
HpFp1ZBtYl7j3cTyjerK0LT3C89WI9GDxLwCs/51NmrHwUDjxct6Vtc+KPpd
7XK9pofKiahAAiJyRJFYageTG3QFkKeT3UBKejMzgZxyBoqOtiR3sJ5TDOyF
TKrvkN23sLFzyMM3ReZKy/3K4MRyzaNYcGrNbnyr9Y9MUyr5QUwiF47JV07e
SHF5fx5Te0/xbLX4nPp9F2PJIG5GFkA1zs6IBm9B8WWIXru+aKItKjQyrUpv
gIAEk7QIgtLr94CcKdLx68l6PEx8uZddr7n+FCdC5FtSqv641dvfYzNrJSG6
puqBFoctvPQM8aY5+tzYOYwuMuZSZVL6kRDldDA5ykVIlzf0kiRGpFYh3tDG
/zucp+maARsUGpEabSw5ictqXf0TuzyUHdFt6ZRW/uZ42Md77uhNe8aVvjwc
7Ljjoq2hXnws+d1a00um55bP+qV/d9KiCQZ8kyJVNPVZe10o5ND4jORaxcTc
hvWvakFWaZ5CaGtUDnI9ML7MdBGWnZGk4KFwQkBcibPfNbD/GjwLQ3bCt6A6
NLnCqaCGOyA8UNS2fcizC88hRhI0zVuhecRmoZVam2VZ7Ub4A/zCcUwcakot
bPnb/oAiHbEE7x30jrfdbxnweAfnyKweRaI4dv86e8rD4Oj010dDTLvmyhoe
Ifl2HAh0YStFSIMIyGuixv1iilGA6xxS2eLxFMrvFZRNqL1uyb8TW0zcSc5v
okGRYU+mngmmWv8Jv2TH5B1/7DzgTCMSDUnt69sHbccNUbkTU89wEE1ufPnq
dVFN9+D4jN48BHC190IsQl2zj2J0Yg6G1wy7408XDl9JACq2+z8HxpdSQtNe
LDHz3+5Dp6oCXFEw5K7dxBJNo6gIsBsRBf2j067NMno6s5he3HqKTN896Myt
NEDuH1vi7EzRrR9PgQZr1WN9yhv78isfUuzo9BrqgRdBrX26z5+kmyzvl6uJ
BpMrJA12Fa2fXdYuv6XAxPQznr7zULDdOpezt9OpZz1I8EaIYT2pzNNzyjpo
cc2/Ts8tkdtqTpbGweOz6xP+uiCXCLLfKw51pDcDkGKQrlLa9Q9I9Q1P8eJO
bSK3zg1vKTyZ763oIiIXeAhOKHfqPJFtpTegOPjqqE8S7UXETMxr7Owd543E
QT+u3XNkYo6W3X0+hmAtswcjGMgqbef6A5fu2TIqFArb/+tslN5MfiICXzHo
Za1t7SeeamasuRWdcLieO7Q9GjVdO2Nn5KHyPQ/ER2PC56WIqsNP5oy3uHGq
hMYGhscm5+FnHu3U9inbCs+ORhPff9B85nYaYZeUv6Cqy6mgaTU84oDXvc/d
g7qld1/s6B1T9or8K9sgLUhh+JPmV1ILmkniDCYSW1KqIH/NBkL2e/plaMYR
Qv/JGynIJ8mSA350gnxSzP2P+iR/dzLc4Jqyht6fzkR+std/16mIfRdjxZF2
5+5kEFtDkyoSlZPjihDAegsrtsy2OZ6tBrDhEIT3F4eCvYOzQZpTXT3KfstZ
dYiZLw8Hmy4/sbWj15Li/7qxgMjo9Xq84Tq0q0GARgIhsRyzHjERTk+sErnw
o5uRBXY0SLAgAFl7SPgrtAyYnR0mJhIp2+vpKKI/SkgRf/836ogKRIfADLQC
9ZBe1BqTUXv6VurHe+5Qw0QxmPynM1Eevqk3owqRYdQJlYb8sy38xvK51d4X
PFsN4YHwhuW+O2mJzaztGZx0atYKrY9YrWjsk6Sv5ZVXR64lRWfU2uoEGBiy
0ttAQ9ls80iIXi+f2Jyf8O1IxSsvV3efi9GbOwHkoETyaFskkGUoecf+gIPe
8RAsUUwciyzzana2+Pxl2P1KyVXYjkZKaOukOBpRrKC6Cxohr6TkuPlnBwIQ
9tARmIfPw5Irncr4ZMwYjSuPs9zcE0R3w+pYtaeaP3paqm0z2HfVXwdLIFmP
/3r/nycszu56DdjIE6tbzE/KW1PDMVH18JUEWxeg9fGp29FFjodPralaBQ43
OPaaSB2cUOb4J6XT+1io44EmwoD0hYDM8/6Zdn0IfD4wOj0zv4z430De61HP
/nCW6g2M4tFq3DApr/GYTzIR4asjIbFZdYNj0/hpfE5DeUNv/8i0yz61ZojG
yZYEBb4nUtUseinB3S24enJtddLi5hbTsyRzh802mjUooQxtCTXVtA44ta1f
79BTt3PRSD7JIUVq+4fTEaM257HyRXJ/T790zSNv+JD2auke0ZwWSJTBHaK1
RiuQoOreRNr7DxD0Udpwsvw2I65ZVmnbt8fDaiUOx3TBcDpq0opbaqOkrodo
ezU0j5yaNAe2QdL7hOXTrE6d9KSLxtWeX0/4ZSV4w88Knlc63N1O9Kis8Djh
hFtMh/kdttZIhBG6EKb8TrkAklBIdiO571B5Yx/1bLtwFelCiCcH1EzxiLY/
nIrQW74HsaM2NfdTEnsTjUzO6w0ukBcjacCAs90+XG9wHorVLPcrqZZ3ePDu
wuKKspA/twEyd2rrY4HG1fnJoaGhMdX4ZX7lj26Zt0NQ9B949nS3iHlsSx2W
E5a/4Fm+K3tsch6W+9fZKKqLVOu8f4Z/bAnFJq0gRovY7bKmovVhPEIYXCo/
zAQ24EPTNRfCOnrHudg2BNPoockVmtsEoU9uRRV+tEd3Gen0/DKRBSZ0nBIJ
vbt7xxtMk6Mm0aJB8aXGy7ftDHonagTeKzW4hmTB8XDDbW52IBzK83NzPyHM
3c096/EfHfUrj/+D5xNuf+K5JdgOz/LPJU9HIoqsXByLllvRGZVeA096+Kbs
PBQML5E7HLuucd6NpOHOV0Jyydfkd4CnMD+ejgxPqZIRn1xMITOK22wlwfzi
CrjSZJLHI1NIZb07t3SN4N2O++K29YzylL//ctegf3JyZlGc8We8bYKdQdHk
AmlFLZp/JcxlFLeufx2fphHO2h6NiVGe33//N/Fxw3s5TPLBnj/xvDbp5+aW
NYTgWM3zdPPM+w9UNlZvjE8tHLqcAPPwb2phS3vvWGZJmwvrbmB7IH0tNE8y
aC6vvDpzKw0xPDQ+a9oTWNbw6At1J3Pb5uCJhB7NuWpo3ZAk7Z3A0fz48id7
/R2/iLwMTdJmfqsBzrr2QdyhuWtYfrfG5y9WLwfnaNYqoW1DmBnBUNc2QN5H
Kk2Cg7Iibh71SVJOxjkYiFQeGJv+2/6Aj/fc4V9U3E9nomjxM7fTfCz5JAhc
QFvgp84eaWqMxtXHqX/oZ2i5J+sPQvfOsp1Av6n6mTq/HVMETUHa+ZUPnapq
sn7A8M0x89kOwsg7ghPKD166Z7rygisfVD1EKuT99TwUpAsfag4gtnaPfro/
QE+7oi70doFDRgJUmU0qTt9MDVA31TG9ck1NpR2vBMzrWav1Rj35BQFJsKPJ
vAKzCHmIfDydVyDQZKjnnNo1Iiz9bOkF7kwgI32uaOrLKm0nZO86FXHqZmpE
apVT83mcQ+Pb1ZUV+0rYgnyQ1mzoGLp8NwdB4hdTLHkKj7D+0WnIAZfXmz5h
a8rcoYuxAE9mzAV/AcC0gi1LE1KBtGYT8ArIA9seEltDY/Ndx0BPsPBV93Ix
9WUuQNiITVpciOP3HzTxFIOTkQ0MB8dBvvcIh2DTi1olN001vqFrX9zi8RTK
SWTHVV1bAIgjU+3iyFf5eS8INuqZxtJb+GxnxG6IWnIYEf65GVlg+0lkWjXP
0tS9kA+Nrkc4lvuVx68na/Yf4o/kFDJT1yg2V6KQne2Tz1d2bk9xajYRr3PW
Lx39j1RDYGzeqhN522I8k0wRib48HLzjQODn7kEEpl+uJnoH50ALpfWPaII3
vylTkozpBboua+j92TOa1iceyayXJPe8GVXIo+WPhc0p65DZNvONOlJ8O7rI
tsypBc3fnbRoTiIiTKAV9abGUUhQrTnDHxdDYcqkA5SkqLbnW/U4Ks3hHkdT
1sAeCcHRJGcREAsSchu+Phqy0z0IUeEynW64vcPxbvKdpzOLjwYnq1v672XX
X1P70sH52dtpR68lmZ6NS83H59R/fjBQLwtztJWXqwT9h4+fyHTbUjy3c9HJ
+eYbsnE3kHbdkm/brMQCFKDmYEpiXiNvqrmKnDvg3d7B2ZqQjsuqgwEMtur9
S/lfrpKEglIck7sZ9JPAIZADl8ncllvlVnR+czwMFYTDmu7zb2B/KOeZRQTk
4NhMffsg7lze2Cd8kD/NzC9L+qPVttv8jdmF5WM+ycCDH2q4tWeUFEMvGwIS
9R2DYcmVpB5PpuYlUyGQtu9irMwMTCrzyLUkElJTOSrGCkk/ba+k/MBPc5IP
ZY7PrteUFrzsef8MApYmVRaq25/KnKwhjIB47k7GL1eTfjoTqbl9E2Amvnj6
Ge0hY7Wmh8O7z8WgLmT2cLarNBIEMZcDOUS1QFw7DgZ+fTQUubL3QiwOTot/
tEfZx577kz7HZtZCCHy4ifng5tzBwPBcktxvjoVGp9cY7yfz+rffIA3Jrgwy
JsmjaoAcWj02q850yScZAUW1nQIH2SKHPt57x3E+BtfAb6CovFFj42U0DA+F
WjXjOEkrMEC3yM8wRA4B2s8OBKD2bYsHV6CZDU7JtBoR8Lx/Jpm15C5eC2qH
/GcHAmkUZGFH7zjijU8QQt39E5CJY3oLG6PeXUusrLbF661cs/GnC6FJFbTv
lZBcgzRN2UzpfMzFgCyZxKSjdwxU2O7comcwGALgRkSBaVVzAfBIymu0fgKP
HfVJ3u8V54i9xecvL/hnkkRoSmKxTxHvqwlaYjQhJiaj1ngjI7uykZjUtQ+O
T85THsC5yyMcpJnmCATB0OQKsYGDabchOhxdTU5EinQ1JPf7k+EItq0Zanwn
660mpp+dvJFy5nbapaBsv5jiqPSavIpOvFJmO0pYK62oBa4WayU0r6HCIQGu
kdmtAiFKamZ6/Meaii4fSz6KwjTxoe1oTbzPKo/hQ7ymQesw95rW/u89wjUn
2q2pSpWKilU5zfGvo5NzhJhP9vq7oGDxMpSDweaQtoYSCIgrMc5DCZ3glith
Y8BPg1J4frZ+0HyL8UzqROhRduNsH4RbqARQ7eGrxFZASJBNL27NKG41kBbw
THZZO9RKJaNvNQe5egYmUGgpBc2mjModoEGkrKmcELt6Hr6SYLpKGolyK7IQ
nWlbNiCdWtji+JRXq28MpNTi8kvkJZJSE3uwNM5LkTb2+Ib+0Wllqpu6Tya/
G0zkI8dE9kDyXx0JCYwvRb9t0ix9eds++plMEL5C6dGCO92DjCMpqR8cSDgj
MdecJvri1WsUAoxh2tbAD4lyISDzN2UBhlFz8GcU78XArHL900bWVEKmbKIT
z/ohd/YJyxNPcfzKvax6vXMkGzuHIXx+9EIDjyO6UbARnZEax7fQ+xzeflD1
8GJAJsyPm2hyBZUEV6MA+esPpyMIW1D9Zmzh5dpWM9sHz8JICnIrOhPzGi0p
VSR3/A6Ta3o9wABaH++5Q1vrLWTOKm2DyYGK8WEoNCV5d1R6daKN9NU0bkVW
hfI0nTVN1nPQO95WF9HoOM7V0DzHliJMoIdhRb27EdFgP4OB0YJqZQYplWYa
ksRahqPXkm5FFUKqt2OKyGER+bwX2QdZKqEkv7LT8T5QBNfjp/wEJ5QTal1b
P879lbGGkWm+joYkbEVn1IYklROpaYXLd3PQk8h7tBahMzxlM8e7N+cOBvZ4
ZAqiIK1WDnLVIhbIuaCqK6u0XU9G9gxO7jwU5HYu2lgnkMiQwtCmprU3Pb9M
LDY91HtNBXBz17Bto+ODNJPmDE9eRHRbGdzwa8MNe6FNkPndyXBIwDhxw7u7
+ieKarpRblSsOsViXE/r4kTpRa0AjKDpfTcHTtZbDqxpeAHPyinrALHn7mTQ
lMfUWUmUE/9FaIUlV5JBozOJyGUNvbxgbdsA6QZlI3EwJiJH2+Z4FgYm0dhU
BS+rp9Cok/P+GY7d77SsT1j+R3v8jDfmWlO7pMTKPpkitfaMLiya96IQl4nd
tTZaQmxD7R+n0UUG49HQQfFlenf7Y8PejFqD+N479BTtAergQBeO2qEMoxNz
SAicDnX0zxOWn85EUtrqln6QSWQxTfGQgs1dI0Q67+Ac5cjIA4EEUJIdcnlQ
Sg5e2vAIN9/wneuEvRd4FtbaPeruHU8M0hyzpn5IrL73CNcca6CNroXmaS6M
srO+4Sm8xhQJXADb4COmGZDY0N622xbGpok1d3oELbwjYd32Q4SBdRYTDstz
j1xLMl61ASUq/fbHw+5l18P8poOtwnjxT/cHEMs8/TKoTNIZmbkElU19JNSp
Bc0wKtENF4B8UD7ljX2gd5Nwq2fvEZ7X1NyH2oPxwnWEYn3H4DfqBDPNryM5
4nMaTBUmQg6eNJ0pIRZcB2gxrZ3hYkgFW0X04uUqOoqnOF4sNsiFHq0+RXz/
6kiIrTPCdWhg0+lVeAHF+/svd0mxr4Tkmk4jlx/LoHIaO4eIFKdvpv7zRBgv
giCXGZ/abHsvxlPsDMJBGNBG9/ObHMe4kQ0wTEpBs6beDk2ugD1MJ6pFpdeg
Zk275qBTYBn+58a2BiayMNtFN2iGb4+HJeQ0OI4egisyRwiW+4vEk6iB4IQz
rXQ3MjGH2EZimXbg8Ojj15Oh9JM3UsSO92S1BtM5eKhd1VEGoozgYQr23UkL
uQaqBgGMl+Gt5OymNbDZ9k7GUzbQItOqPzsQ6BWY5RjxV16uEjGVXfS15h3d
TSwHhKZTkgCPcly7GfJ51n6vuCSzjpE1dQmV3dSL9kdjXx5WyFNz2nNoUoVv
RIFVaUOJ5JKA3Ko08Ij7D5qVfe/VdaOSkb2mdYDKAZBfHArGIy4FZfOauCQR
ARJA9/JE8mIU0Z3YYnTLzahCRAjejR6OyahFhKxnw0yZnj0alHfBg1xYkPv+
4hlmJikmSUzRWjQKw9yIKCB31tzMgdYBBqbhldSM0G/aNUcO/tOZKJn1AmIT
A9vtjonaFCZea2uamflltKjtZkc0NHiD5ytsduidnlsCk/84Gno1NE/+MClu
RfRBV5PoZZW24Rdx6qFjBCZLSiVZJ7+IDm0uW6cGBsMUsmdggheB0inqmVtp
lvuVuHNCbgMtKFZK4jWk7bzvx3vu8C8BRWTx27m/DgmHv4MTpFdGcRvtO/50
YT2DSnwXeVlc16MZdtXNSx/EaK25oKKgIFP6vRlZoExINhvmps6JwsbjLMIA
iTg42DrJhJuXNfSOPJl1TELBZ0ldD5xs+3YDo9O4wOW7OfiRoDscBJ0M2UK8
vJFBfQ6Nz5pObsHN5VuEx9n6O4yKpCF/oeZ9LPnqtniWv+0PIE8Hn5Q58F4J
IYkMt+3RmLJ72Pzy5MyzuWfPCXN29ELWL38op9W2GM+k58W1PVml7TgmYQ4N
JvaUI2cH3mIOp1Mn1gkbfqKsuXZckYFK/PlsFG6uuVgjOKE8NqvOWHgAtvP+
mTL9GGOT8+rWRsOm29oQspGyvn9d1QJRn72drhcLaHHbg7fQJzgpOSbawFaT
v1QPKSB9yKvo1Hwvap7a/uF0BG+UnN9ESYafzNpeiY8Yz6QFhHgEYgAuKqjq
Qrx9vPeOWDEEkhGBeN/tmCLiCEIdtyXK2Fbdq9U365xBZ2zbQW9QPyQUVALV
Ameie53aMlEY1Uv7Oi4XejqzCC0cu66xzFNM2sSVjHvn8C9UBwrZdB8qkAAm
j2s9y9Z4u0Nq54btvhwUhhqAxPTcQZzzYqtVimp7ELqfuwfZdSzwvygQIjjJ
r+NEZR5ETOS7aGZxPiB32HFAWRbB0yk8BUPS4+wUD/zTHFTR0WtJu8/FiAM4
cFtSBmIBBUaWKIn5gyanNqfaPNsOeLY14hR0utM9yOBkbT3r7FM2e9GcoKsO
Fmv4CI1Lm/JQvekTwmAwkL/7fIzxbr1wEf4IHmRW4dW2DVwNybVTMrDuj6cj
9aYA8WooaiBkpbjRibnssnbKhpCwm79BKL+XXb/LIxzscVvj5YTQJpKmd+hp
fmUnQRN8Kqf8/P47/0I1zV0jqF8C0MLSC7sCm0562WLbbnimcp5MPSNxID2B
RpzdKhNKAU6a64tTC1vO+2c4Dm+NTs65X46HnQxEMn9C8nFngykW1vKTGJ65
nSZTWrCA1LRzQLHFtJ5HINiuKrvlRDkepsaHl5SZtH9xWxz20eBkRGoVug4R
GxhfmlnSHniv1KlDKjfVNnZK3nbDs51BdwRBmdU9VkPFATzN6RyIvdCkCkd9
/qDq4c5DwaaHGMKoSFOZDdXhsd5hqVPM0Fqg1y6RpPB8aLCgD3EF8ULLtlue
IqozS9rIvzx8U4lujrQJmXOBV2AW9fPpPn+09/TcUkPHENW7ni097QxPscvN
iSZinSAPgudpoPqOwcqmPlLdguoulDbpLe1CBgHbcAENUa5O5CBoTjk5FXab
43lN3RAAYWy3c4uxtfWM8hXHYXGa2Ds4x24LZWFIBRSjaT/Gc6WPS2qFeHpR
q95cVjsbUU/9Rqnafjg1u4ROALF6GSISCNZFJCPse23ObsaJyhp6D19JAPD8
acaBhwEVUYwMenZhmZsAJLEM+asjIbAHaPePLUGopBW14OagLjG3gYhA6ieG
F/tHpgkNYBKw8VcAmVXaBibJBKnAGxEFF/wzxUa4CG/kCjdE5H99NBQdxRuh
z8/cSkPjcU9yUr+YYt7xk73+ym6rGcpu3jQ3NyH5Jeu5FJTFbbe+v07+Jjjv
lZDcm1GFJCNwBaJOZqk7CoQ658UlV7yuqSs3yS7RfnY0RbtTpZprUmZUwWm6
zzloQZzILOniKYcuJ8hsmkG1IM7Bp62jgWRemRdHJOhRPaSHhwIGD98Uu8oB
t+gKAM+f0NitPaPGh0HwRsCPGJRb0RmfXU8uSboHrryDs8EngYm74Xog8NTN
VDQ2QOWv4nhxJD2+w1Og1ozitgsBmcBSvLgMRbh2hoidvZPxQeq8prW/sKb7
/2/v7L+ayM44/g9qT7vH7dm6re1p16lvO7pq4/qSuiorelBXUEQxKgQkCgYw
vPiCCmIAI4LGZaOixmNcw8Et0qxR021s+pkZQJqZSW6AkJHO9+wPK4TJnXu/
z/N8n/vy3IaLtxmmlWpyrR04zXwMn5hFf67aUSu+ZoTHW7qhsmcwPdHjCX/a
fNJwrpgYB1ezOtW61gBEFSkczVhv2HNWZJ9w/G3CUdKAU0pbK9yuujvD/Xga
SBZ2lPv+svUUnalXxeRrBPf96g5nnkNsyrUYIM/PtYhcAVFwvQHDUYMYOApB
LTswnmEz2JG6TgZFcAKTPIgUCd+l/xWp+tKNlYYpv7u5FweedX/dgVOX0qoT
mAEvxzNFJtX5UkItDZ5OuZ/j7xDS/DDrwVW8HAoZz+lpC+itHusmmaUl9Rf6
yRlx2oQDjH3Ob3woLArO5yng7oh08rd1v11XkSEBJA6qR/N+Fsm2yC+Ij4b7
vpAiKExDb49ZGS4pTgfc27TvnKuhO/PHUmr+jlckGAmaIZELpUQPpDlSiFd/
sT9rnWo+VlZz5dO1FZiG2cZ7moQAhvbo2D9+fYJcGHvh88hgIhT+BNPgi3K9
JM4KsA6fU6rWOt6gbB7AeWao6XfZP7R2tyfrdMQUCLiGK6f4K0J89+10hiAP
MJmObKUMiCwZru+ZDt4LIUFaJLj0eXvoKXIaCZFmbsT9VTtqth9qzioAICT+
nPzri21V5FmZj3IjdZDWiEA8NtkNih2G41gIhYQqskJkM/KYMHHt5v1b98KY
Cbl2ZGSMTA3VTQShx+iHQDAsfgLrvnKR09zPGVqKz1MgINJ1+CjD0xD+gUeo
bkZccOqS4UDM6NdTiM4IcvJu/XO0em5Zi92NqBXFze79mQ6+gsTq72XNz0ey
VwnA+ZP+L15R9vV+r3794kxbgLadu3RbxDroQ1JvIhGmh0AKPYk2dgxk3VtI
a+E2+V3wwXOyCcwHoyB/IdDsOOxDq5A+rPimBs/zubqVaIl8ZKO6sPjJmnKk
Y/jHnxggfkiopX/4j4hDIODz2NdyZxVjpy08YXHVTT1j4693HWnZ67pAMD16
pksTRa1dwZZrd3M9uj7/9UWxSsFzQMQ+fIXhJmSIhOsQvKAqpV7MTR/qMzic
0q9XH9avTaRUr05umHULNJ4NdkUEWMq7b/nOyzNFbjBJqd4YSYDu1UvcF6Pj
8IrsQKTMiAZsE56s3nkami3b5LrkH3r//j9zuLSn+eepyRxMRikxHX+HObyK
veFdkE/4c94FX4EnqWr0H6/vRvVpkxso+c7AA1rVfEWd/fP6yZUIFjW+Pivv
r8NVYqeLV5b9weEic2GwMu+h4o2wYsPyFIyFIQ/NQAY3vYDAFB4/GzXbkE+v
bjvYlHWSkIH485aTDFDWNjRdGcSb4dzEiYSrpOWGJdaJCxgp3ShoICl19hj3
jm+nJaQVuMSt3zXy+tf7H+b7wqz5QUH0BmOEtaLE9p+6REhCxE7f0JsGDB9/
Yhh3kIXLNp0QHAicM5Gu12ifBlrOcNeHskeouoO/MqwFOgX8D3HkVysP6Rcv
9MA6XOduGJY8MkPs9dstB7z0kn5KU1sxp3+I1zjzXCfW8KLK2dW2AFoITYLr
Xr/nLEEf7Y2GVyt//pTTae6Co+DnrdAe/d8rdzmtVw+gGTqutuv3SI4MPfml
G0P8rWA9kwfhEbScfsUE3sIW7+X0K3Jom1bJMG3xTg/0xrrdngqP8W3FemAg
vFRO5bB81+58tv5YU8egvot++eXftef7kD0QO9cy5mmtGnr0goYhYrcebETu
Ss5qbTGF70V64YL4AAJgBnt68w1LnbeCUVd6Q0iRk17/Y6MRqfX1kUwZ/q2z
tNkjUA1DQ8353qKKVv3PkTSfGeWMKTVAoBCyPhl5jEWIL3XVtQYwgZy2WRKk
Nh/w0hh9F9F+MmiSuG+PtmK2sG5O9vl03XpAfoesxdWMx96geDfsVardohgx
n5Xf1EB7ksTK+utoGHxL4+WBA1WX8fn5qJgkAovwWUNbV3DRX0tRdPpfwRYc
OF5C/6tX/4zTt4KqA8dCYm4ob+ADssHQ85BMCW5IO1x7VbxAYnVzL64v1wU7
tApRRjlKZq6C0A9fbKuiuzIrpdkAFYT53wkpB2wxZHINYpm2mvnJl+XqTr9/
bNp3jqQVs8XnQPsKTyf5HcGOjAPOI+YHQ88wBBGdJghL8Tk1OatgeIE1Ye53
GypxTXrPQ7pEvi/4FWRPZKOGtxPuLPeZXYhTcuLixRvZp5qfj7z6XKyytAby
MsK6yPTIdMClQzVX+aLrtx6aHfIKPYnSZtJP0sl5qyRAvs+7TCmiN+/+hZ8h
XpCeQHsk0+mWm4gZrVgrgQYPrxUQ4584DYyCNrsauhsu9nf0/IAQzXXjn9X4
nFITN7OqVtduhjbta9BTEaeKOzK7xj0NSuHlw+fxIXpXTEjFZAynC/AhZr9K
g3asQPyOJ5wVn5/B/aH4t4176xetyHTPES+Ll161o4YEpLqpR/yOwvkBVIfn
WIGmT6A0/6TBJ87dQLcUH2sn3ll5vo4ItXpnbVnNFfxwhvVf1CAf0696t3YG
seXTRqehITNCQnAejE5bvKLMcB0EU8JpGM6Q9915TPQUSeKu9oX4pPjWKVqC
es+1igWN7O5/WF6nbNOiZzJfNaItrJChwG1iUHFl+wxOm1ofpmxMRr0lspYw
uv3KjE0i4neq/3S6/AmRJ5gAG2ztCn5ZVLfcWZ1hCKAcgln/c1IeM2mxYc9Z
hlXwrt6ewUc8yvBXO4+0kDYaLqIR5dPOsZoBo6P94mc/4duyTa7zV+/MrGgn
PdnYMbDv5KWsC2qhxy8Qt7iFJWsrWjrvzu2qSsFhxsZoh1OSPWPJVGzYJ0lF
4WTMI0sV/mgqEXXB8FAs6xOyAsbSq2b3SyKScTv66WJ+brYL6FSjf+mGSvHb
Np88e2noh0dejm892GS4+ALJyeAEL69HCpKXxV6Lzni8VHdB7z7WRhQW/JPp
4F3qWm4imInRmTMstBCsvns/cuve0+jLcaQIX4poESnmiaY9Utd5oft7pJfI
NWHzDDM2jg37/cNqkpIYkCQ5+DIoS46Q6peHPQ7JPcP76NOAOyIFNvstXbfO
aLcnJmCY4ESiY0vkIzhewW/HJf7+b8f1GYe2FRlvaTjl9ePo+FfFZ0QmMfB7
5aevGr6CGVo77y5aUUYuMDMvnVL3l6KTYTU6RHB5BY3d0RvaU9mO5kHmVTX1
BB88N5twg/PksIhbuajuN2sOI6sIZ+7mXtJS+pOUhE4LP8/5eP5cQWNjYiwa
DocjKvifsfiU1xqFvLIrkIwHnbJLS8JjQZfDNTd8RhtsP2Q8q5xSHc4uo+q1
b94miJWGWqVn8HHW27enA1djuDVUK9pvlv3VX+g/Xp99p2hKNZk1u07/8CjT
wZA04DAP1V49dlZ0acYQdA6shpzECPG1DwyQtLTW14fBfrq2orhSORKVYRdc
8v17Ekz/wCPiQvGxNvIOGL7cWYUr2HzAS9oOt2dQs3c20NgYbi+VZIcGWZJ9
w0rcSUQDRahld0BpUDzokCb5PFCRxufZLM1kzrjNZglI7c1mX80EjBnMnAkO
KoOfEZcEPGcoFz5reBV7I7JtLzMePh3RNnnO4G9fv0lA7K0HG5FM4tcdwnCi
6vriMwgYTJKs/5TXf3R2timCrCRMRDqUTDCgZIJJxcSipZLkC0OhRLtTcraH
pz8q3639/4RFKrTMErjoGZRVnDFM2JjoKJlOeWcwnoqFfBP/KvKNZX+CDRsF
QG5sTCbi8fQob/PZhnVgwfVBGzZmDJvPNhYSbD7bWEiw+WxjIcHms42FhIKf
t7JhY05gqfNWNmzMCT52PlvcmizevNSCa6HN57zC4s1LLbgW5pXPWR+e7w/Y
DfjYn59rA2w+2w2w8vNzbcBczW/YsGERzJLPNmzYsGHDhg0bNmzY+EgQ9zkl
d1ArnpDwuyYKhHRFLFApJRFxO9TmOFyRfNWQmzniwz5J9kx0nElllUJhdMA7
UfmlyKN2ncVGNk+IR7zqW3pDyjvGgm5JckUTqajfNTVSBUTQ7ZAroAdjIcvu
HKo9zwOiAx7V0LwqOUwrqxQIkSJJ8gTHaBjOyukLW21k84Rhb0mJx1fCu6tD
EHJP0iYZckhysMB2HPco3FCPyQ/zv1YahUSoxFHq8xTBDaV9cdPKKoVBcszf
EdAOqAYr6MSgxUZ2TpD4n/ogkbHJmg4JIpN7gs/OioluiLll50CB3zrmcTgC
GonjAw7reZVkWLEyjc9mlVUKi1EliMiB0aTFRnYukBgulSfrgzhkuaR98p3i
nkk+E98n33rMJTkK/db0/CSfYwGH7LYan+PDH/hsVlmlcEgMeJTSL5A5ZbmR
zSs+8HnUXyo5fEp9kEi7WnCvsA1L+ksU7ZdSavUUSc52K+RZ0xEPTfLZvLJK
gZDookEOt5oJKqVfLDayeUXc65hKYWK+yYKo3lBu5cHzglhosoRJSdBq3lmJ
eN4J/ZwyraxSEKik/QCnJ2S5kZ1HKPVBLGS/yXg8bqHmZIBRZRVLwWIja8OG
DRs2bNiwYcPGwsF/AWpbFFY=
    "], {{0, 236}, {240, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{240, 236},
  PlotRange->{{0, 240}, {0, 236}}]], "Output",
 ImageSize->{244, 236},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[7]=",
 CellID->1094699370]
}, Open  ]],

Cell["\<\
It is assumed that the z-component of the velocity at z=0.7 is 0. This gives \
a second set of velocity data for interpolation:\
\>", "ExampleText",
 CellID->1887014198],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"data2", " ", "=", " ", 
    RowBox[{"velocitydata2D", " ", "/.", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x_", "?", "NumericQ"}], ",", 
          RowBox[{"y_", "?", "NumericQ"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"u_", "?", "NumericQ"}], ",", 
          RowBox[{"v_", "?", "NumericQ"}]}], "}"}]}], "}"}], "\[RuleDelayed]",
       " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", "zi"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", "v", ",", "0."}], "}"}]}], "}"}]}]}]}], " ", ";"}],
   " "}]], "Input",
 CellLabel->"In[8]:=",
 CellID->880636427],

Cell["\<\
The databases, data1 and data2 can now be combined and given to the \
interpolating function. \
\>", "ExampleText",
 CellID->857776213],

Cell[BoxData[
 RowBox[{
  RowBox[{"finaldata", " ", "=", " ", 
   RowBox[{"Join", "[", 
    RowBox[{"data1", ",", " ", "data2"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[9]:=",
 CellID->1284466213],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rbfsol3D", " ", "=", " ", 
  RowBox[{"DivergenceFreeInterpolation3D", "[", 
   RowBox[{"finaldata", ",", "\"\<TPS2\>\""}], "]"}]}]], "Input",
 CellLabel->"In[10]:=",
 CellID->1163735594],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"DivergenceFreeInterpolatingFunction", "[", "<>", "]"}],
  WildfiresDoc`Private`dfun$37298]], "Output",
 ImageSize->{290, 14},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[10]=",
 CellID->47987162]
}, Open  ]],

Cell["\<\
The velocity can be plotted against the terrain to see how the flow evolves \
in space:\
\>", "ExampleText",
 CellID->1044528818],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"uvwXYZ", " ", "=", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xs", ",", "ys", ",", "zs"}], "}"}], ",", 
        RowBox[{"rbfsol3D", "[", 
         RowBox[{"{", 
          RowBox[{"xs", ",", "ys", ",", "zs"}], "}"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"xs", ",", "xmin", ",", "xmax", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "10"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"ys", ",", "ymin", ",", "ymax", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ymax", "-", "ymin"}], ")"}], "/", "10"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"zs", ",", "zmin", ",", "zmax", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "10"}]}], "}"}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Plot3D", "[", 
     RowBox[{
      RowBox[{"hills", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"xmin", "-", "3"}], ",", 
        RowBox[{"xmax", "+", "3"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"ymin", "-", "3"}], ",", 
        RowBox[{"ymax", "+", "3"}]}], "}"}], ",", " ", 
      RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
      RowBox[{"ColorFunction", "\[Rule]", " ", "\"\<AvocadoColors\>\""}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", " ", 
      RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", 
      RowBox[{"FillingStyle", "\[Rule]", "Black"}], ",", " ", 
      RowBox[{"PlotPoints", "\[Rule]", "100"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ListVectorPlot3D", "[", 
     RowBox[{"uvwXYZ", ",", 
      RowBox[{"VectorColorFunction", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
         RowBox[{"Lighter", "[", 
          RowBox[{
           RowBox[{"Hue", "[", "z", "]"}], ",", 
           RowBox[{
            RowBox[{"Norm", "[", 
             RowBox[{"{", 
              RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}], "/", "10"}]}], 
          "]"}]}], " ", "]"}]}], ",", " ", 
      RowBox[{"VectorScale", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Large", ",", 
         RowBox[{"Scaled", "[", "0.5", "]"}]}], "}"}]}]}], "]"}], 
    "\[IndentingNewLine]", ",", 
    RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
    RowBox[{"BoxRatios", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "0.5"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xmin", "-", "3"}], ",", 
         RowBox[{"xmax", "+", "3"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"ymin", "-", "3"}], ",", 
         RowBox[{"ymax", "+", "3"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "2.1"}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{
         RowBox[{"Text", "[", "\"\<x\>\"", "]"}], ",", "Black", ",", "Thick", 
         ",", "17"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{
         RowBox[{"Text", "[", "\"\<y\>\"", "]"}], ",", "Black", ",", "Thick", 
         ",", "17"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{
         RowBox[{"Text", "[", "\"\<z  \>\"", "]"}], ",", "Black", ",", 
         "Thick", ",", "17"}], "]"}]}], "}"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", " ", 
    RowBox[{"Axes", "\[Rule]", "True"}]}], "\[IndentingNewLine]", "]"}], 
  " "}]}], "Input",
 CellLabel->"In[11]:=",
 CellID->183657036],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsnQeYE0Ubx3P0eqmXXHqu90oXEFCxdxBQei9Sj6N3kF78AAXpoDQVBUQs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    "], {{0, 330}, {400, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{400, 330},
  PlotRange->{{0, 400}, {0, 330}}]], "Output",
 ImageSize->{404, 330},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[11]=",
 CellID->1119907741]
}, Open  ]],

Cell["\<\
To get a better idea of the flow, vector-plots can be viewed in different \
planes:\
\>", "ExampleText",
 CellID->1627383004],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GraphicsRow", "[", 
   RowBox[{
    RowBox[{"Quiet", "@", 
     RowBox[{"Table", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"uwXZ", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"xs", ",", "zs"}], "}"}], ",", 
             RowBox[{
              RowBox[{"rbfsol3D", "[", 
               RowBox[{"{", 
                RowBox[{"xs", ",", "yi", ",", "zs"}], "}"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"{", 
                RowBox[{"1", ",", "3"}], "}"}], "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"xs", ",", "xmin", ",", "xmax", ",", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "10"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"zs", ",", "zmin", ",", "zmax", ",", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"zmax", "-", "zmin"}], ")"}], "/", "10"}]}], "}"}]}], 
          "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"ListVectorPlot", "[", 
           RowBox[{"uwXZ", ",", " ", 
            RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", " ", 
            RowBox[{"AspectRatio", "\[Rule]", "0.8"}], ",", 
            RowBox[{"VectorScale", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Large", ",", 
               RowBox[{"Scaled", "[", "1", "]"}]}], "}"}]}]}], "]"}], ",", 
          " ", 
          RowBox[{"Plot", "[", 
           RowBox[{
            RowBox[{"hills", "[", 
             RowBox[{"x", ",", "yi"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "xmin", ",", "xmax"}], "}"}], ",", " ", 
            RowBox[{"Filling", "\[Rule]", "Axis"}], ",", " ", 
            RowBox[{"FillingStyle", "\[Rule]", "Black"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}], ",", " ", 
          RowBox[{"FrameStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", "16"}], "]"}]}], ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"Text", "[", "\"\<x\>\"", "]"}], ",", "Black", ",", 
               "16"}], "]"}], ",", 
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"Text", "[", "\"\<z\>\"", "]"}], ",", "Black", ",", 
               "16"}], "]"}]}], "}"}]}], ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{"Style", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"StringForm", "[", 
               RowBox[{"\"\<y=`1`\>\"", ",", "yi"}], "]"}], "]"}], ",", 
             "Black", ",", "16"}], "]"}]}], ",", 
          RowBox[{"ImagePadding", "\[Rule]", "1"}]}], "]"}]}], " ", 
       "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"yi", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "10"}], ",", "0", ",", "10"}], "}"}]}], "}"}]}], 
      "]"}]}], ",", " ", "0", ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], " ", "//", " ", 
  "Rasterize"}]], "Input",
 CellLabel->"In[12]:=",
 CellID->1152745717],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJztvddzHUeS/8sb92/Yt33Yuy/7squIjV/EjY0b+6J92giNhiONpBlJlBlp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   "], {{0, 0}, {500, 145}}, {0, 255},
   ColorFunction->RGBColor],
  ImageSize->{500, 145},
  PlotRange->{{0, 500}, {0, 145}}]], "Output",
 ImageSize->{504, 145},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[12]=",
 CellID->686856408]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GraphicsRow", "[", 
   RowBox[{
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"uvXY", " ", "=", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"xs", ",", "ys"}], "}"}], ",", 
            RowBox[{
             RowBox[{"rbfsol3D", "[", 
              RowBox[{"{", 
               RowBox[{"xs", ",", "ys", ",", "zi"}], "}"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"1", ";;", "2"}], "]"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"xs", ",", "xmin", ",", "xmax", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"xmax", "-", "xmin"}], ")"}], "/", "10"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"ys", ",", "ymin", ",", "ymax", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"ymax", "-", "ymin"}], ")"}], "/", "10"}]}], "}"}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListVectorPlot", "[", 
          RowBox[{"uvXY", ",", " ", 
           RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", " ", 
           RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
           RowBox[{"VectorScale", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Large", ",", 
              RowBox[{"Scaled", "[", "1", "]"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"RegionPlot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"hills", "[", 
             RowBox[{"x", ",", "y"}], "]"}], "\[GreaterEqual]", "zi"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "xmin", ",", "xmax"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"y", ",", "ymin", ",", "ymax"}], "}"}], ",", " ", 
           RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}], ",", " ", 
         RowBox[{"FrameStyle", "\[Rule]", 
          RowBox[{"Directive", "[", 
           RowBox[{"Black", ",", "14"}], "]"}]}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"Text", "[", "\"\<x\>\"", "]"}], ",", "Black", ",", 
              "16"}], "]"}], ",", 
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"Text", "[", "\"\<z\>\"", "]"}], ",", "Black", ",", 
              "16"}], "]"}]}], "}"}]}], ",", 
         RowBox[{"ImagePadding", "\[Rule]", "None"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"Text", "[", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<z=`1`\>\"", ",", "zi"}], "]"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}]}]}], "]"}]}], " ", 
      "\[IndentingNewLine]", ",", 
      RowBox[{"{", 
       RowBox[{"zi", ",", 
        RowBox[{"{", 
         RowBox[{"0.3", ",", "0.7", ",", "0.9"}], "}"}]}], "}"}]}], "]"}], 
    ",", " ", "0", ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], " ", "//", " ", 
  "Rasterize"}]], "Input",
 CellLabel->"In[13]:=",
 CellID->568356856],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzsXQd4XMW1Fh0CgRAIvFASkkACj4QSQiAJJZRHtw3uHRfcuy1bsmRJ7pZc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   "], {{0, 0}, {500, 180}}, {0, 
   255},
   ColorFunction->RGBColor],
  ImageSize->{500, 180},
  PlotRange->{{0, 500}, {0, 180}}]], "Output",
 ImageSize->{504, 180},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[13]=",
 CellID->1006231805]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "See Also"
}], "SeeAlsoSection",
 WholeCellGroupOpener->True,
 CellID->1255426704],

Cell[TextData[{
 StyleBox[ButtonBox["RadialBasicFunction",
  BaseStyle->"Link",
  ButtonData->"paclet:WildfiresDoc/ref/RadialBasicFunction"],
  FontFamily->"Verdana"],
 " . ",
 StyleBox[ButtonBox["RBFInterpolation",
  BaseStyle->"Link",
  ButtonData->"paclet:WildfiresDoc/ref/RBFInterpolation"],
  FontFamily->"Verdana"],
 " . ",
 StyleBox[ButtonBox["DivergenceFreeInterpolation3D",
  BaseStyle->"Link",
  ButtonData->"paclet:WildfiresDoc/ref/DivergenceFreeInterpolation3D"],
  FontFamily->"Verdana"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "Related Guides"
}], "MoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->38303248],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Wildfires Simulation Package"]],
   "paclet:WildfiresDoc/guide/Fire-front Tracking"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->978149536]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"DivergenceFreeInterpolation3D - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "SymbolColor", "LinkTrails" -> 
  GridBox[{{
      RowBox[{
        ButtonBox[
        "Mathematica", ButtonData -> "paclet:WildfiresDoc/guide/WildfiresDoc",
          BaseStyle -> {"Link", "DockedLinkTrail"}]}]}}, ColumnAlignments -> 
    Left], "HasOptions" -> False, "ExampleCounter" -> 1, 
  "ExamplePageLinks" -> {}, "RootCaptions" -> "", 
  "Metadata" -> {
   "built" -> "{2014, 11, 8, 17, 52, 14.584639}", 
    "history" -> {"0.0", "", "", ""}, "context" -> "WildfiresDoc`", 
    "keywords" -> {}, "specialkeywords" -> {}, 
    "tutorialcollectionlinks" -> {}, "index" -> True, "label" -> 
    "Wildfires Doc Symbol", "language" -> "en", "paclet" -> "WildfiresDoc", 
    "status" -> "None", "summary" -> 
    "DivergenceFreeInterpolation3D[data, opts] performs divergence-free \
interpolation for 3D scattered data and returns a black-box function. The \
data must be of the form {{{x1,y1,z1},{u1,v1,w1}}, {x2,y2,z2},{u2,v2,w2}, \
{x3,y3,z3},{u3,v3,w3},...}. The resulting interpolant exactly satisfies the \
divergence-free condition, \[PartialD]f/\[PartialD]x + \[PartialD]f/\
\[PartialD]y+\[PartialD]f/dz=0. DivergenceFreeInterpolation3D[data, rbf, \
opts] performs divergence-free interpolation for 3D scattered data using the \
specified radial basic function rbf. The radial basic function can be a \
string specifying a name from the existing database or a function of the form \
Function[{e, r}, ...]. DivergenceFreeInterpolation3D[data, rbf, scales, opts] \
performs divergence-free interpolation of 3D scattered data using the \
specified radial basic function and it's corresponding scales. The scaling \
parameter can be a scalar or a vector. If it is a vector, then it should have \
the same length as data.", "synonyms" -> {}, "title" -> 
    "DivergenceFreeInterpolation3D", "titlemodifier" -> "", "windowtitle" -> 
    "DivergenceFreeInterpolation3D", "type" -> "Symbol", "uri" -> 
    "WildfiresDoc/ref/DivergenceFreeInterpolation3D"}, "SearchTextTranslated" -> 
  ""},
CellContext->"Global`",
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 29, \
2014)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> 
  "10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 29, 2014)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[20789, 639, 387, 15, 70, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->395219763]},
 "RasterizedOutput"->{
  Cell[24187, 756, 9901, 171, 70, "Output",
   CellTags->"RasterizedOutput",
   CellID->771933767],
  Cell[35364, 977, 9872, 170, 70, "Output",
   CellTags->"RasterizedOutput",
   CellID->942110442],
  Cell[47097, 1208, 64593, 1067, 70, "Output",
   CellTags->"RasterizedOutput",
   CellID->653269363],
  Cell[113544, 2335, 65464, 1081, 70, "Output",
   CellTags->"RasterizedOutput",
   CellID->1561780477],
  Cell[182619, 3546, 62458, 1032, 70, "Output",
   CellTags->"RasterizedOutput",
   CellID->151859658],
  Cell[264863, 4988, 41357, 686, 70, "Output",
   CellTags->"RasterizedOutput",
   CellID->1094699370],
  Cell[312310, 5864, 57035, 943, 70, "Output",
   CellTags->"RasterizedOutput",
   CellID->1119907741]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 465827, 8534},
 {"RasterizedOutput", 465971, 8538}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[623, 21, 3792, 94, 70, "AnchorBarGrid",
 CellID->1],
Cell[4418, 117, 72, 1, 70, "ObjectName",
 CellID->1224892054],
Cell[CellGroupData[{
Cell[4515, 122, 1975, 46, 70, "Usage",
 CellID->982511436],
Cell[CellGroupData[{
Cell[6515, 172, 738, 24, 70, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->152840225],
Cell[7256, 198, 31, 0, 70, "SectionHeaderSpacer"],
Cell[7290, 200, 1379, 44, 70, "ExampleText",
 CellID->1904423740],
Cell[8672, 246, 3300, 100, 70, "Input",
 CellID->669698642],
Cell[11975, 348, 78, 1, 70, "ExampleText",
 CellID->142916237],
Cell[12056, 351, 5312, 161, 70, "Input",
 CellID->1008861783],
Cell[17371, 514, 1363, 43, 70, "ExampleText",
 CellID->1650356348],
Cell[18737, 559, 153, 4, 70, "ExampleText",
 CellID->694278449],
Cell[CellGroupData[{
Cell[18915, 567, 126, 3, 70, "ExampleDelimiter",
 CellID->1204276615],
Cell[19044, 572, 1650, 58, 70, "3ColumnTableMod",
 CellID->1068258589]
}, Open  ]],
Cell[20709, 633, 31, 0, 70, "SectionFooterSpacer"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20789, 639, 387, 15, 70, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->395219763],
Cell[CellGroupData[{
Cell[21201, 658, 195, 6, 70, "ExampleSection",
 CellID->291636570],
Cell[21399, 666, 196, 4, 70, "ExampleText",
 CellID->1101217418],
Cell[21598, 672, 2096, 63, 70, "Input",
 CellID->1376748249],
Cell[CellGroupData[{
Cell[23719, 739, 465, 15, 70, "Input",
 CellID->573577489],
Cell[24187, 756, 9901, 171, 70, "Output",
 CellTags->"RasterizedOutput",
 CellID->771933767]
}, Open  ]],
Cell[34103, 930, 216, 5, 70, "ExampleText",
 CellID->1134302722],
Cell[CellGroupData[{
Cell[34344, 939, 215, 5, 70, "Input",
 CellID->1326946098],
Cell[34562, 946, 278, 8, 70, "Output",
 CellID->684276299]
}, Open  ]],
Cell[CellGroupData[{
Cell[34877, 959, 484, 16, 70, "Input",
 CellID->1970788469],
Cell[35364, 977, 9872, 170, 70, "Output",
 CellTags->"RasterizedOutput",
 CellID->942110442]
}, Open  ]],
Cell[45251, 1150, 158, 4, 70, "ExampleText",
 CellID->1964372303],
Cell[CellGroupData[{
Cell[45434, 1158, 1660, 48, 70, "Input",
 CellID->922263678],
Cell[47097, 1208, 64593, 1067, 70, "Output",
 CellTags->"RasterizedOutput",
 CellID->653269363]
}, Open  ]],
Cell[CellGroupData[{
Cell[111727, 2280, 1814, 53, 70, "Input",
 CellID->1381700594],
Cell[113544, 2335, 65464, 1081, 70, "Output",
 CellTags->"RasterizedOutput",
 CellID->1561780477]
}, Open  ]],
Cell[179023, 3419, 182, 4, 70, "ExampleText",
 CellID->1922042136],
Cell[CellGroupData[{
Cell[179230, 3427, 882, 27, 70, "Input",
 CellID->2037707888],
Cell[180115, 3456, 178, 5, 70, "Output",
 CellID->994958956]
}, Open  ]],
Cell[CellGroupData[{
Cell[180330, 3466, 125, 3, 70, "ExampleDelimiter",
 CellID->205296802],
Cell[180458, 3471, 232, 5, 70, "ExampleText",
 CellID->1564614132],
Cell[180693, 3478, 1519, 51, 70, "Input",
 CellID->1976135842],
Cell[CellGroupData[{
Cell[182237, 3533, 379, 11, 70, "Input",
 CellID->1357116328],
Cell[182619, 3546, 62458, 1032, 70, "Output",
 CellTags->"RasterizedOutput",
 CellID->151859658]
}, Open  ]],
Cell[245092, 4581, 563, 10, 70, "ExampleText",
 CellID->2011104659],
Cell[245658, 4593, 1287, 41, 70, "Input",
 CellID->819734006],
Cell[246948, 4636, 631, 16, 70, "Input",
 CellID->563410882],
Cell[CellGroupData[{
Cell[247604, 4656, 271, 8, 70, "Input",
 CellID->1691007375],
Cell[247878, 4666, 14908, 255, 70, "Output",
 CellID->618516509]
}, Open  ]],
Cell[262801, 4924, 381, 8, 70, "ExampleText",
 CellID->1801291156],
Cell[263185, 4934, 1343, 38, 70, "Input",
 CellID->758114674],
Cell[264531, 4974, 181, 5, 70, "ExampleText",
 CellID->1059278774],
Cell[CellGroupData[{
Cell[264737, 4983, 123, 3, 70, "Input",
 CellID->692842189],
Cell[264863, 4988, 41357, 686, 70, "Output",
 CellTags->"RasterizedOutput",
 CellID->1094699370]
}, Open  ]],
Cell[306235, 5677, 179, 4, 70, "ExampleText",
 CellID->1887014198],
Cell[306417, 5683, 775, 25, 70, "Input",
 CellID->880636427],
Cell[307195, 5710, 145, 4, 70, "ExampleText",
 CellID->857776213],
Cell[307343, 5716, 199, 6, 70, "Input",
 CellID->1284466213],
Cell[CellGroupData[{
Cell[307567, 5726, 210, 5, 70, "Input",
 CellID->1163735594],
Cell[307780, 5733, 278, 8, 70, "Output",
 CellID->47987162]
}, Open  ]],
Cell[308073, 5744, 139, 4, 70, "ExampleText",
 CellID->1044528818],
Cell[CellGroupData[{
Cell[308237, 5752, 4070, 110, 70, "Input",
 CellID->183657036],
Cell[312310, 5864, 57035, 943, 70, "Output",
 CellTags->"RasterizedOutput",
 CellID->1119907741]
}, Open  ]],
Cell[369360, 6810, 135, 4, 70, "ExampleText",
 CellID->1627383004],
Cell[CellGroupData[{
Cell[369520, 6818, 3407, 86, 70, "Input",
 CellID->1152745717],
Cell[372930, 6906, 32866, 544, 70, "Output",
 CellID->686856408]
}, Open  ]],
Cell[CellGroupData[{
Cell[405833, 7455, 3236, 82, 70, "Input",
 CellID->568356856],
Cell[409072, 7539, 52350, 864, 70, "Output",
 CellID->1006231805]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[461461, 8408, 31, 0, 70, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[461529, 8413, 270, 12, 70, "SeeAlsoSection",
 CellID->1255426704],
Cell[461802, 8427, 535, 16, 70, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[462374, 8448, 276, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[462653, 8462, 31, 0, 70, "SectionHeaderSpacer"],
Cell[462687, 8464, 207, 6, 70, "MoreAbout",
 CellID->978149536]
}, Open  ]],
Cell[462909, 8473, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)
