(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     92386,       1778]
NotebookOptionsPosition[     88325,       1660]
NotebookOutlinePosition[     90903,       1727]
CellTagsIndexPosition[     90781,       1721]
WindowTitle->Extract2DIsoSurfacePoints - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["WILDFIRES DOC SYMBOL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Wildfires Simulation Package\"\>":>
       Documentation`HelpLookup[
       "paclet:WildfiresDoc/guide/Fire-front Tracking"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"MoreAbout"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->
         False], {"\<\"WildfiresDoc/ref/Extract2DIsoSurfacePoints\"\>":>
       None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["WildfiresDoc/ref/Extract2DIsoSurfacePoints"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/WildfiresDoc/ref/\
Extract2DIsoSurfacePoints.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "WildfiresDoc/ref/Extract2DIsoSurfacePoints", ".html"]], 
           None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 GridBoxOptions->{GridBoxItemSize->{"Columns" -> {
     Scaled[0.65], {
      Scaled[0.34]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
   "RowsIndexed" -> {}}},
 CellID->1],

Cell["Extract2DIsoSurfacePoints", "ObjectName",
 CellID->1224892054],

Cell[CellGroupData[{

Cell[BoxData[GridBox[{
   {"", Cell[TextData[{
     Cell[BoxData[
      RowBox[{"Extract2DIsoSurfacePoints", "[", 
       RowBox[{"fun", ",", " ", "isolevel", ",", " ", 
        RowBox[{"{", 
         RowBox[{"x", ",", "xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "ymin", ",", "ymax"}], "}"}], ",", "npts"}], 
       "]"}]], "InlineFormula"],
     " \[LineSeparator]finds the iso-surface/zero level-set of ",
     Cell[BoxData[
      RowBox[{
       RowBox[{"fun", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "==", "isolevel"}]], "InlineFormula"],
     
     ". The function fun can be a ",
     Cell[BoxData["Function"], "InlineFormula"],
     " or a numerical function produced from ",
     Cell[BoxData["RBFInterpolation"], "InlineFormula"],
     ". The function extracts a total of ",
     Cell[BoxData["npts"], "InlineFormula"],
     " points that are approximately even-spaced."
    }]]}
  }]], "Usage",
 GridBoxOptions->{
 GridBoxBackground->{
  "Columns" -> {{None}}, "ColumnsIndexed" -> {}, "Rows" -> {{None}}, 
   "RowsIndexed" -> {}}},
 CellID->982511436],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 ButtonBox[Cell[TextData[{
   Cell[BoxData[
    InterpretationBox[
     StyleBox[
      GraphicsBox[{},
       BaselinePosition->Baseline,
       ImageSize->{6, 0}],
      CacheGraphics->False],
     Spacer[6]]]],
   "Details"
  }], "NotesFrameText"],
  Appearance->{Automatic, None},
  BaseStyle->None,
  ButtonFunction:>(FrontEndExecute[{
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], All, ButtonCell], 
     FrontEndToken["OpenCloseGroup"], 
     FrontEnd`SelectionMove[
      FrontEnd`SelectedNotebook[], After, CellContents]}]& ),
  Evaluator->None,
  Method->"Preemptive"]]]], "NotesSection",
 WholeCellGroupOpener->True,
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->1742720679],

Cell["", "SectionHeaderSpacer"],

Cell["\<\
This function is a utility function to be used with the Wildfires package. \
\>", "Notes",
 CellID->1067943069],

Cell["\<\
The input function must take only 2 inputs. The input function is typically a \
terrain map which describes the elevation of the terrain.\
\>", "Notes",
 CellID->1454667831],

Cell["", "SectionFooterSpacer"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(1)", "ExampleCount"]
}], "PrimaryExamplesSection",
 WholeCellGroupOpener->True,
 CellTags->"PrimaryExamplesSection",
 CellID->376990520],

Cell[CellGroupData[{

Cell[TextData[{
 "Basic Examples",
 "\[NonBreakingSpace]\[NonBreakingSpace]",
 Cell["(1)", "ExampleCount"]
}], "ExampleSection", "ExampleSection",
 WholeCellGroupOpener->True,
 CellID->1002910990],

Cell["\<\
Construct a 2D function. This could be a surface terrain. The function \
describes the elevation of the terrain. The terrain is defined over the \
region {{-15,20},{-20,20}}:\
\>", "ExampleText",
 CellID->1007818609],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"hills", " ", "=", " ", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}], ",", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "0.02"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x", "-", "3"}], ")"}], "^", "2"}], "+", 
          RowBox[{"y", "^", "2"}]}], ")"}]}], "]"}], " ", "+", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "0.05"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x", "-", "9"}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"y", "+", "9"}], ")"}], "^", "2"}]}], ")"}]}], "]"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"xmin", ",", "xmax"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"ymin", ",", "ymax"}], "}"}]}], "}"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "15"}], ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "20"}], ",", "20"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Rasterize", "[", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"hills", "[", 
     RowBox[{"x", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "xmin", ",", "xmax"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "ymin", ",", "ymax"}], "}"}], ",", " ", 
    RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
    RowBox[{"ColorFunction", "\[Rule]", " ", "\"\<CherryTones\>\""}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ymin", ",", "ymax"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1.2"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", 
    RowBox[{"FillingStyle", "\[Rule]", "Black"}], ",", " ", 
    RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", " ", 
    RowBox[{"BoxRatios", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "0.4"}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{
         RowBox[{"Text", "[", "\"\<x\>\"", "]"}], ",", "Black", ",", "Thick", 
         ",", "17"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{
         RowBox[{"Text", "[", "\"\<y\>\"", "]"}], ",", "Black", ",", "Thick", 
         ",", "17"}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{
         RowBox[{"Text", "[", "\"\<z  \>\"", "]"}], ",", "Black", ",", 
         "Thick", ",", "17"}], "]"}]}], "}"}]}], ",", " ", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}], "]"}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->84558754],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzsnXd0VFeW9Xu+mek13f/MzFqzetkoVc5V79XLqcKrUkY5oZyzEDlHAybn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   "], {{0, 0}, {400, 312}}, {0, 255},
   ColorFunction->RGBColor],
  ImageSize->{400, 312},
  PlotRange->{{0, 400}, {0, 312}}]], "Output",
 ImageSize->{404, 312},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->1890996833]
}, Open  ]],

Cell["\<\
Extract the iso-surfaces at various z-levels. The function can extract \
multiple iso-surfaces:\
\>", "ExampleText",
 CellID->1373280278],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"pts", " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Join", "@@", 
       RowBox[{"Extract2DIsoSurfacePoints", "[", 
        RowBox[{"hills", ",", "#", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "15"}], ",", "20"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"-", "15"}], ",", "20"}], "}"}], ",", "30"}], "]"}]}], 
      "&"}], " ", "/@", " ", 
     RowBox[{"{", 
      RowBox[{"0.2", ",", "0.5", ",", "0.8"}], "}"}]}]}], ";"}], 
  " "}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"pts", ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "15"}], ",", "20"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "20"}], ",", "20"}], "}"}]}], "}"}]}], ",", " ", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z=0.2\>\"", ",", "\"\<z=0.5\>\"", ",", "\"\<z=0.8\>\""}], 
     "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", "False"}], ",", " ", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", " ", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", " ", 
   RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}]}], "Input",
 CellLabel->"In[2]:=",
 CellID->1707285268],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3U9rI1t6x3HnzyJvI5C1CXkBAecNNEy2l8AMTGUTappJUPBCixgvYpoQ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    "], {{0, 338}, {364, 
    0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{364, 338},
  PlotRange->{{0, 364}, {0, 338}}]], "Output",
 ImageSize->{368, 338},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[2]=",
 CellID->706679139]
}, Open  ]]
}, Open  ]],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "Related Guides"
}], "MoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->38303248],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Wildfires Simulation Package"]],
   "paclet:WildfiresDoc/guide/Fire-front Tracking"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->325863627]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"Extract2DIsoSurfacePoints - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "SymbolColor", "LinkTrails" -> 
  GridBox[{{
      RowBox[{
        ButtonBox[
        "Mathematica", ButtonData -> "paclet:WildfiresDoc/guide/WildfiresDoc",
          BaseStyle -> {"Link", "DockedLinkTrail"}]}]}}, ColumnAlignments -> 
    Left], "HasOptions" -> False, "ExampleCounter" -> 1, 
  "ExamplePageLinks" -> {}, "RootCaptions" -> "", 
  "Metadata" -> {
   "built" -> "{2014, 11, 8, 17, 52, 19.227671}", 
    "history" -> {"0.0", "", "", ""}, "context" -> "WildfiresDoc`", 
    "keywords" -> {}, "specialkeywords" -> {}, 
    "tutorialcollectionlinks" -> {}, "index" -> True, "label" -> 
    "Wildfires Doc Symbol", "language" -> "en", "paclet" -> "WildfiresDoc", 
    "status" -> "None", "summary" -> 
    "Extract2DIsoSurfacePoints[fun, isolevel, {x, xmin, xmax}, {y, ymin, \
ymax}, npts] finds the iso-surface/zero level-set of fun[x, y] == isolevel. \
The function fun can be a Function or a numerical function produced from \
RBFInterpolation. The function extracts a total of npts points that are \
approximately even-spaced.", "synonyms" -> {}, "title" -> 
    "Extract2DIsoSurfacePoints", "titlemodifier" -> "", "windowtitle" -> 
    "Extract2DIsoSurfacePoints", "type" -> "Symbol", "uri" -> 
    "WildfiresDoc/ref/Extract2DIsoSurfacePoints"}, "SearchTextTranslated" -> 
  ""},
CellContext->"Global`",
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 29, \
2014)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"]}, Visible -> False, 
  FrontEndVersion -> 
  "10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 29, 2014)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "PrimaryExamplesSection"->{
  Cell[6006, 180, 387, 15, 70, "PrimaryExamplesSection",
   CellTags->"PrimaryExamplesSection",
   CellID->376990520]},
 "RasterizedOutput"->{
  Cell[78548, 1466, 9120, 158, 70, "Output",
   CellTags->"RasterizedOutput",
   CellID->706679139]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"PrimaryExamplesSection", 90513, 1710},
 {"RasterizedOutput", 90656, 1714}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[619, 21, 2992, 74, 70, "AnchorBarGrid",
 CellID->1],
Cell[3614, 97, 68, 1, 70, "ObjectName",
 CellID->1224892054],
Cell[CellGroupData[{
Cell[3707, 102, 1108, 29, 70, "Usage",
 CellID->982511436],
Cell[CellGroupData[{
Cell[4840, 135, 739, 24, 70, "NotesSection",
 CellGroupingRules->{"SectionGrouping", 50},
 CellID->1742720679],
Cell[5582, 161, 31, 0, 70, "SectionHeaderSpacer"],
Cell[5616, 163, 121, 3, 70, "Notes",
 CellID->1067943069],
Cell[5740, 168, 183, 4, 70, "Notes",
 CellID->1454667831],
Cell[5926, 174, 31, 0, 70, "SectionFooterSpacer"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6006, 180, 387, 15, 70, "PrimaryExamplesSection",
 CellTags->"PrimaryExamplesSection",
 CellID->376990520],
Cell[CellGroupData[{
Cell[6418, 199, 196, 6, 70, "ExampleSection",
 CellID->1002910990],
Cell[6617, 207, 226, 5, 70, "ExampleText",
 CellID->1007818609],
Cell[CellGroupData[{
Cell[6868, 216, 3148, 92, 70, "Input",
 CellID->84558754],
Cell[10019, 310, 67006, 1104, 70, "Output",
 CellID->1890996833]
}, Open  ]],
Cell[77040, 1417, 147, 4, 70, "ExampleText",
 CellID->1373280278],
Cell[CellGroupData[{
Cell[77212, 1425, 1333, 39, 70, "Input",
 CellID->1707285268],
Cell[78548, 1466, 9120, 158, 70, "Output",
 CellTags->"RasterizedOutput",
 CellID->706679139]
}, Open  ]]
}, Open  ]],
Cell[87695, 1628, 31, 0, 70, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87763, 1633, 276, 12, 70, "MoreAboutSection",
 CellID->38303248],
Cell[88042, 1647, 31, 0, 70, "SectionHeaderSpacer"],
Cell[88076, 1649, 207, 6, 70, "MoreAbout",
 CellID->325863627]
}, Open  ]],
Cell[88298, 1658, 23, 0, 70, "FooterCell"]
}
]
*)

(* End of internal cache information *)
